// define() gets called for each chunk generated by the first Rollup pass.
// The order the chunks are called in is controlled by the imports in bundle.js:
//
// shared.js: shared dependencies between main and worker threads
// scene_worker.js: worker thread code
// index.js: main thread code

// Once all chunks have been provided, the worker thread code is assembled,
// incorporating the shared chunk code, then turned into a blob URL which
// can be used to instantiate the worker.

var shared, worker, Tangram = {};

function define(_, chunk) {
	if (!shared) {
	    shared = chunk;
	} else if (!worker) {
	    worker = chunk;
	} else {
	    var worker_bundle = 'var shared_chunk = {}; (' + shared + ')(shared_chunk); (' + worker + ')(shared_chunk);'
	    var shared_chunk = {};
	    shared(shared_chunk);
	    Tangram = chunk(shared_chunk);
	    Tangram.workerURL = window.URL.createObjectURL(new Blob([worker_bundle], { type: 'text/javascript' }));
	}
}


define(["exports"],function(e){"use strict";const t={};try{window instanceof Window&&window.document instanceof HTMLDocument&&(t.is_worker=!1,t.is_main=!0);}catch(e){t.is_worker=!0,t.is_main=!1,self.window={document:{}},self.document=self.window.document;}function i(){return (i=Object.assign||function(e){for(var t=1;t<arguments.length;t++){var i=arguments[t];for(var r in i)Object.prototype.hasOwnProperty.call(i,r)&&(e[r]=i[r]);}return e}).apply(this,arguments)}var r,s="v0.21.1",n=r={},o=0,a={};function l(e){var t=[];"string"==typeof e&&(t=e.split("."),e=t.pop());var i=r.targets;for(let e=0;e<t.length;e++){if(!i[t[e]])return [];i=i[t[e]];}return [e,i]}function u(e){Array.isArray(e)&&e.filter(e=>e.parent&&e.property).forEach(e=>delete e.parent[e.property]);}r.targets={},r.addTarget=function(e,t){r.targets[e]=t;},r.removeTarget=function(e){e&&delete r.targets[e];},r.withTransferables=function(...e){if(!(this instanceof r.withTransferables))return new r.withTransferables(...e);this.value=e,this.transferables=function e(t,i=null,r=null,s=[]){if(!t)return s;if(Array.isArray(t))t.forEach((i,r)=>e(i,t,r,s));else if("object"==typeof t)if(t instanceof ArrayBuffer)s.push({object:t,parent:i,property:r});else if(t.buffer instanceof ArrayBuffer)s.push({object:t.buffer,parent:i,property:r});else for(let i in t)e(t[i],t,i,s);return s}(this.value);},t.is_main&&(r.postMessage=function(e,t,...i){if(Array.isArray(e))return Promise.all(e.map(e=>r.postMessage(e,t,...i)));let s={};"object"==typeof t&&(s=t,t=t.method);var n=new Promise((e,r)=>{a[o]={method:t,message:i,resolve:e,reject:r};});let l,h=[];return i&&1===i.length&&i[0]instanceof r.withTransferables&&(h=i[0].transferables,i=i[0].value),l={type:"main_send",message_id:o,method:t,message:i},s.stringify&&(l=JSON.stringify(l)),e.postMessage(l,h.map(e=>e.object)),u(h),h.length>0&&f("trace",`'${t}' transferred ${h.length} objects to worker thread`),o++,n},r.addWorker=function(e){if(!(e instanceof Worker))throw Error("Worker broker could not add non-Worker object",e);e.addEventListener("message",function(t){let i="string"==typeof t.data?JSON.parse(t.data):t.data,s=i.message_id;if("worker_reply"===i.type)a[s]&&(i.error?a[s].reject(i.error):a[s].resolve(i.message),delete a[s]);else if("worker_send"===i.type&&null!=s){let t,n,o,a,h;try{if([a,o]=l(i.method),!o)throw Error(`Worker broker could not dispatch message type ${i.method} on target ${i.target} because no object with that name is registered on main thread`);if(!(h="function"==typeof o[a]&&o[a]))throw Error(`Worker broker could not dispatch message type ${i.method} on target ${i.target} because object has no method with that name`);t=h.apply(o,i.message);}catch(e){n=e;}let c,d=[];t instanceof Promise?t.then(t=>{t instanceof r.withTransferables&&(d=t.transferables,t=t.value[0]),c={type:"main_reply",message_id:s,message:t},e.postMessage(c,d.map(e=>e.object)),u(d),d.length>0&&f("trace",`'${a}' transferred ${d.length} objects to worker thread`);},t=>{e.postMessage({type:"main_reply",message_id:s,error:t instanceof Error?`${t.message}: ${t.stack}`:t});}):(t instanceof r.withTransferables&&(d=t.transferables,t=t.value[0]),c={type:"main_reply",message_id:s,message:t,error:n instanceof Error?`${n.message}: ${n.stack}`:n},e.postMessage(c,d.map(e=>e.object)),u(d),d.length>0&&f("trace",`'${a}' transferred ${d.length} objects to worker thread`));}});},r.getMessages=function(){return a},r.getMessageId=function(){return o}),t.is_worker&&(r.postMessage=function(e,...t){let i={};"object"==typeof e&&(i=e,e=e.method);var s=new Promise((i,r)=>{a[o]={method:e,message:t,resolve:i,reject:r};});let n,l=[];return t&&1===t.length&&t[0]instanceof r.withTransferables&&(l=t[0].transferables,t=t[0].value),n={type:"worker_send",message_id:o,method:e,message:t},i.stringify&&(n=JSON.stringify(n)),self.postMessage(n,l.map(e=>e.object)),u(l),l.length>0&&f("trace",`'${e}' transferred ${l.length} objects to main thread`),o++,s},self.addEventListener("message",function(e){let t="string"==typeof e.data?JSON.parse(e.data):e.data,i=t.message_id;if("main_reply"===t.type)a[i]&&(t.error?a[i].reject(t.error):a[i].resolve(t.message),delete a[i]);else if("main_send"===t.type&&null!=i){let e,s,n,o,a;try{if([o,n]=l(t.method),!n)throw Error(`Worker broker could not dispatch message type ${t.method} on target ${t.target} because no object with that name is registered on main thread`);if(!(a="function"==typeof n[o]&&n[o]))throw Error(`Worker broker could not dispatch message type ${t.method} because worker has no method with that name`);e=a.apply(n,t.message);}catch(e){s=e;}let h,c=[];e instanceof Promise?e.then(e=>{e instanceof r.withTransferables&&(c=e.transferables,e=e.value[0]),h={type:"worker_reply",message_id:i,message:e},self.postMessage(h,c.map(e=>e.object)),u(c),c.length>0&&f("trace",`'${o}' transferred ${c.length} objects to main thread`);},e=>{self.postMessage({type:"worker_reply",message_id:i,error:e instanceof Error?`${e.message}: ${e.stack}`:e});}):(e instanceof r.withTransferables&&(c=e.transferables,e=e.value[0]),h={type:"worker_reply",message_id:i,message:e,error:s instanceof Error?`${s.message}: ${s.stack}`:s},self.postMessage(h,c.map(e=>e.object)),u(c),c.length>0&&f("trace",`'${o}' transferred ${c.length} objects to main thread`));}}));const h={silent:-1,error:0,warn:1,info:2,debug:3,trace:4},c={};let d={};function f(e,...i){let r="object"==typeof e?e.level:e;if(h[r]<=h[f.level]){if(t.is_worker)return n.postMessage({method:"_logProxy",stringify:!0},e,...i);{if("object"==typeof e&&!0===e.once){if(d[JSON.stringify(i)])return Promise.resolve(!1);d[JSON.stringify(i)]=!0;}let n=function(e){if(t.is_main)return c[e]=c[e]||(console[e]?console[e]:console.log).bind(console),c[e]}(r);i.length>1?n(`Tangram ${s} [${r}]: ${i[0]}`,...i.slice(1)):n(`Tangram ${s} [${r}]: ${i[0]}`);}return Promise.resolve(!0)}return Promise.resolve(!1)}f.level="info",f.workers=null,f.setLevel=function(e){f.level=e,t.is_main&&Array.isArray(f.workers)&&n.postMessage(f.workers,"_logSetLevelProxy",e);},t.is_main&&(f.setWorkers=function(e){f.workers=e;},f.reset=function(){d={};}),n.addTarget("_logProxy",f),n.addTarget("_logSetLevelProxy",f.setLevel);const _={};let p;n.addTarget("Utils",_),_.isSafari=function(){return /^((?!chrome|android).)*safari/i.test(navigator.userAgent)},_.isMicrosoft=function(){return /(Trident\/7.0|Edge[ \/](\d+[.\d]+))/i.test(navigator.userAgent)},_._requests={},_._proxy_requests={},_.io=function(e,i=6e4,r="text",s="GET",o={},a=null,l=!1){if(t.is_worker&&_.isMicrosoft())return f("debug","Proxying request for URL to worker",e),a&&(_._proxy_requests[a]=!0),n.postMessage("Utils.io",e,i,r,s,o,a,!0);var u=new XMLHttpRequest,h=new Promise((t,n)=>{if(u.open(s,e,!0),u.timeout=i,u.responseType=r,o&&"object"==typeof o)for(let e in o)u.setRequestHeader(e,o[e]);u.onload=(()=>{200===u.status?["text","json"].indexOf(u.responseType)>-1?t({body:u.responseText,status:u.status}):t({body:u.response,status:u.status}):204===u.status?t({body:null,status:u.status}):n(Error("Request error with a status of "+u.statusText));}),u.onerror=(e=>{n(Error("There was a network error"+e.toString()));}),u.ontimeout=(e=>{n(Error("timeout "+e.toString()));}),u.send();});return h=h.then(e=>(a&&delete _._requests[a],l?n.withTransferables(e):e)),a&&(_._requests[a]=u),h},_.cancelRequest=function(e){if(t.is_worker&&_._proxy_requests[e])return n.postMessage("Utils.cancelRequest",e);_._requests[e]?(f("trace",`Cancelling network request key '${e}'`),_._requests[e].abort(),delete _._requests[e]):f("trace",`Could not find network request key '${e}'`);},_.serializeWithFunctions=function(e){if("function"==typeof e)return e.toString();return JSON.stringify(e,function(e,t){return "function"==typeof t?t.toString():t})},_.use_high_density_display=!0,_.updateDevicePixelRatio=function(){let e=_.device_pixel_ratio;return _.device_pixel_ratio=_.use_high_density_display&&window.devicePixelRatio||1,_.device_pixel_ratio!==e},t.is_main&&_.updateDevicePixelRatio(),_.isPowerOf2=function(e){return 0==(e&e-1)},_.interpolate=function(e,t,i){if(!Array.isArray(t)||!Array.isArray(t[0]))return t;if(t.length<1)return t;var r,s,n,o,a;if(e<=t[0][0])o=t[0][1],"function"==typeof i&&(o=i(o));else if(e>=t[t.length-1][0])o=t[t.length-1][1],"function"==typeof i&&(o=i(o));else for(var l=0;l<t.length-1;l++)if(e>=t[l][0]&&e<t[l+1][0]){if(r=t[l][0],s=t[l+1][0],Array.isArray(t[l][1])){o=[];for(var u=0;u<t[l][1].length;u++)"function"==typeof i?(a=i(t[l][1][u]),n=i(t[l+1][1][u])-a,o[u]=n*(e-r)/(s-r)+a):(n=t[l+1][1][u]-t[l][1][u],o[u]=n*(e-r)/(s-r)+t[l][1][u]);}else "function"==typeof i?(a=i(t[l][1]),o=(n=i(t[l+1][1])-a)*(e-r)/(s-r)+a):o=(n=t[l+1][1]-t[l][1])*(e-r)/(s-r)+t[l][1];break}return o},_.toCSSColor=function(e){if(null!=e)return 1===e[3]?`rgb(${e.slice(0,3).map(e=>Math.round(255*e)).join(", ")})`:`rgba(${e.map((e,t)=>t<3&&Math.round(255*e)||e).join(", ")})`};var m=p={draw_label_collision_boxes:!1,draw_label_texture_boxes:!1,suppress_label_fade_in:!1,suppress_label_snap_animation:!1,show_hidden_labels:!1,layer_stats:!1,wireframe:!1};function g(e){if("string"==typeof e&&-1===e.search(/^(data|blob):/)){let t=e.indexOf("?");t>-1&&(e=e.substr(0,t));let i=e.indexOf("#");return i>-1&&(e=e.substr(0,i)),e.substr(0,e.lastIndexOf("/")+1)||""}return ""}function x(e){if("string"==typeof e)return !(e.search(/^(http|https|data|blob):/)>-1||"//"===e.substr(0,2))}let y;function v(e,t){e=e.replace(/[[]/,"\\[").replace(/[\]]/,"\\]");var i=new RegExp("[\\?&]"+e+"=([^&#]*)").exec(t);return null===i?"":decodeURIComponent(i[1].replace(/\+/g," "))}const b={id:0,queue:[],max_time:20,start_time:null,state:{},add(e){e.id=b.id++,e.max_time=e.max_time||b.max_time,e.pause_factor=e.pause_factor||1;let t=new Promise((t,i)=>{e.resolve=t,e.reject=i;});return e.promise=t,e.elapsed=0,e.total_elapsed=0,e.stats={calls:0},this.queue.push(e),this.start_time=this.start_time||performance.now(),this.elapsed=performance.now()-this.start_time,(this.elapsed<b.max_time||e.immediate)&&this.process(e),e.promise},remove(e){let t=this.queue.indexOf(e);t>-1&&this.queue.splice(t,1);},process(e){if(!this.state.user_moving_view||!1!==e.user_moving_view)return e.pause?(e.pause--,!0):(e.stats.calls++,e.start_time=performance.now(),e.run(e))},processAll(){this.start_time=this.start_time||performance.now();for(let e=0;e<this.queue.length;e++){let t=this.queue[e];if(!0!==this.process(t)&&(t.pause||(t.pause=t.elapsed>t.max_time?t.pause_factor:0),t.total_elapsed+=t.elapsed),this.elapsed=performance.now()-this.start_time,this.elapsed>=b.max_time){this.start_time=null;break}}},finish(e,t){return e.elapsed=performance.now()-e.start_time,e.total_elapsed+=e.elapsed,this.remove(e),e.resolve(t),e.promise},cancel(e){let t;e.cancel instanceof Function&&(t=e.cancel(e)),e.resolve(t);},shouldContinue(e){return e.elapsed=performance.now()-e.start_time,this.elapsed=performance.now()-this.start_time,e.elapsed<e.max_time&&this.elapsed<b.max_time},removeForTile(e){for(let t=this.queue.length-1;t>=0;t--)this.queue[t].tile_id===e&&(this.cancel(this.queue[t]),this.queue.splice(t,1));},setState(e){this.state=e;}};function A(e){let t=[];return Object.assign(e,{subscribe(e){-1===t.indexOf(e)&&t.push(e);},unsubscribe(e){let i=t.indexOf(e);i>-1&&t.splice(i,1);},unsubscribeAll(){t=[];},trigger(e,...i){t.forEach(t=>{if("function"==typeof t[e])try{t[e](...i);}catch(t){f("warn",`Caught exception in listener for event '${e}':`,t);}});},hasSubscribersFor(e){let i=!1;return t.forEach(t=>{"function"==typeof t[e]&&(i=!0);}),i}})}function T(e,t){let i={};return t.forEach(t=>i[t]=e[t]),i}class w{constructor(e,t,i={}){i=w.sliceOptions(i),this.gl=e,this.texture=e.createTexture(),this.texture&&(this.valid=!0),this.bind(),this.name=t,this.retain_count=0,this.config_type=null,this.loading=null,this.loaded=!1,this.filtering=i.filtering,this.density=i.density||1,this.sprites=i.sprites,this.texcoords={},this.sizes={},this.css_sizes={},this.aspects={},this.setData(1,1,new Uint8Array([0,0,0,0]),{filtering:"nearest"}),this.loaded=!1,w.textures[this.name]&&(this.retain_count=w.textures[this.name].retain_count,w.textures[this.name].retain_count=0,w.textures[this.name].destroy()),w.textures[this.name]=this,w.texture_configs[this.name]=JSON.stringify(Object.assign({name:t},i)),this.load(i),f("trace",`creating Texture ${this.name}`);}destroy({force:e}={}){this.retain_count>0&&!e?f("error",`Texture '${this.name}': destroying texture with retain count of '${this.retain_count}'`):this.valid&&(this.gl.deleteTexture(this.texture),this.texture=null,w.textures[this.name]===this&&(delete w.textures[this.name],delete w.texture_configs[this.name]),this.valid=!1,f("trace",`destroying Texture ${this.name}`));}retain(){this.retain_count++;}release(){this.retain_count<=0&&f("error",`Texture '${this.name}': releasing texture with retain count of '${this.retain_count}'`),this.retain_count--,this.retain_count<=0&&this.destroy();}bind(e=0){this.valid&&(w.activeUnit!==e&&(this.gl.activeTexture(this.gl.TEXTURE0+e),w.activeUnit=e,w.boundTexture=null),w.boundTexture!==this.texture&&(this.gl.bindTexture(this.gl.TEXTURE_2D,this.texture),w.boundTexture=this.texture));}load(e){return e?(this.loading=null,"string"==typeof e.url?(this.config_type="url",this.setUrl(e.url,e)):e.element?(this.config_type="element",this.setElement(e.element,e)):e.data&&e.width&&e.height&&(this.config_type="data",this.setData(e.width,e.height,e.data,e)),this.loading=this.loading&&this.loading.then(()=>(this.calculateSprites(),this))||Promise.resolve(this),this.loading):this.loading||Promise.resolve(this)}setUrl(e,t={}){if(this.valid)return this.url=e,this.loading=new Promise(e=>{let i=new Image;i.onload=(()=>{try{if("data:"===this.url.slice(0,5)){const e=document.createElement("canvas"),r=e.getContext("2d");e.width=i.width,e.height=i.height,r.drawImage(i,0,0),this.setElement(e,t);}else this.setElement(i,t);}catch(e){this.loaded=!1,f("warn",`Texture '${this.name}': failed to load url: '${this.url}'`,e,t),w.trigger("warning",{message:`Failed to load texture from ${this.url}`,error:e,texture:t});}this.loaded=!0,e(this);}),i.onerror=(i=>{this.loaded=!1,f("warn",`Texture '${this.name}': failed to load url: '${this.url}'`,i,t),w.trigger("warning",{message:`Failed to load texture from ${this.url}`,error:i,texture:t}),e(this);}),_.isSafari()&&"data:"===this.url.slice(0,5)||(i.crossOrigin="anonymous"),i.src=this.url;}),this.loading}setData(e,t,i,r={}){return this.width=e,this.height=t,Array.isArray(i)&&(i=new Uint8Array(i)),this.update(i,r),this.setFiltering(r),this.loaded=!0,this.loading=Promise.resolve(this),this.loading}setElement(e,t){let i=e;if("string"==typeof e&&(e=document.querySelector(e)),e instanceof HTMLCanvasElement||e instanceof HTMLImageElement||e instanceof HTMLVideoElement)this.update(e,t),this.setFiltering(t);else {this.loaded=!1;let e=`the 'element' parameter (\`element: ${JSON.stringify(i)}\`) must be a CSS `;e+="selector string, or a <canvas>, <image> or <video> object",f("warn",`Texture '${this.name}': ${e}`,t),w.trigger("warning",{message:`Failed to load texture because ${e}`,texture:t});}return this.loaded=!0,this.loading=Promise.resolve(this),this.loading}update(e,t={}){this.valid&&(this.bind(),e instanceof HTMLCanvasElement||e instanceof HTMLVideoElement||e instanceof HTMLImageElement&&e.complete?(this.width=e.width,this.height=e.height,this.gl.pixelStorei(this.gl.UNPACK_FLIP_Y_WEBGL,!1!==t.UNPACK_FLIP_Y_WEBGL),this.gl.pixelStorei(this.gl.UNPACK_PREMULTIPLY_ALPHA_WEBGL,t.UNPACK_PREMULTIPLY_ALPHA_WEBGL||!1),this.gl.texImage2D(this.gl.TEXTURE_2D,0,this.gl.RGBA,this.gl.RGBA,this.gl.UNSIGNED_BYTE,e)):(this.gl.pixelStorei(this.gl.UNPACK_FLIP_Y_WEBGL,null),this.gl.pixelStorei(this.gl.UNPACK_PREMULTIPLY_ALPHA_WEBGL,null),this.gl.texImage2D(this.gl.TEXTURE_2D,0,this.gl.RGBA,this.width,this.height,0,this.gl.RGBA,this.gl.UNSIGNED_BYTE,e)),w.trigger("update",this));}setFiltering(e={}){if(this.valid){e.filtering=e.filtering||"linear";var t=this.gl;this.bind(),_.isPowerOf2(this.width)&&_.isPowerOf2(this.height)?(this.power_of_2=!0,t.texParameteri(t.TEXTURE_2D,t.TEXTURE_WRAP_S,e.TEXTURE_WRAP_S||e.repeat&&t.REPEAT||t.CLAMP_TO_EDGE),t.texParameteri(t.TEXTURE_2D,t.TEXTURE_WRAP_T,e.TEXTURE_WRAP_T||e.repeat&&t.REPEAT||t.CLAMP_TO_EDGE),"mipmap"===e.filtering?(this.filtering="mipmap",t.texParameteri(t.TEXTURE_2D,t.TEXTURE_MIN_FILTER,t.LINEAR_MIPMAP_LINEAR),t.texParameteri(t.TEXTURE_2D,t.TEXTURE_MAG_FILTER,t.LINEAR),t.generateMipmap(t.TEXTURE_2D)):"linear"===e.filtering?(this.filtering="linear",t.texParameteri(t.TEXTURE_2D,t.TEXTURE_MIN_FILTER,t.LINEAR),t.texParameteri(t.TEXTURE_2D,t.TEXTURE_MAG_FILTER,t.LINEAR)):"nearest"===e.filtering&&(this.filtering="nearest",t.texParameteri(t.TEXTURE_2D,t.TEXTURE_MIN_FILTER,t.NEAREST),t.texParameteri(t.TEXTURE_2D,t.TEXTURE_MAG_FILTER,t.NEAREST))):(this.power_of_2=!1,t.texParameteri(t.TEXTURE_2D,t.TEXTURE_WRAP_S,t.CLAMP_TO_EDGE),t.texParameteri(t.TEXTURE_2D,t.TEXTURE_WRAP_T,t.CLAMP_TO_EDGE),"nearest"===e.filtering?(this.filtering="nearest",t.texParameteri(t.TEXTURE_2D,t.TEXTURE_MIN_FILTER,t.NEAREST),t.texParameteri(t.TEXTURE_2D,t.TEXTURE_MAG_FILTER,t.NEAREST)):(this.filtering="linear",t.texParameteri(t.TEXTURE_2D,t.TEXTURE_MIN_FILTER,t.LINEAR),t.texParameteri(t.TEXTURE_2D,t.TEXTURE_MAG_FILTER,t.LINEAR))),w.trigger("update",this);}}calculateSprites(){if(this.sprites)for(let e in this.sprites){let t=this.sprites[e];this.texcoords[e]=w.getTexcoordsForSprite([t[0],t[1]],[t[2],t[3]],[this.width,this.height]),this.sizes[e]=[t[2],t[3]],this.css_sizes[e]=[t[2]/this.density,t[3]/this.density],this.aspects[e]=t[2]/t[3];}}byteSize(){return Math.round(this.width*this.height*4*("mipmap"==this.filtering?1.33:1))}}w.create=function(e,t,i){return new w(e,t,i)},w.retain=function(e){w.textures[e]&&w.textures[e].retain();},w.release=function(e){w.textures[e]&&w.textures[e].release();},w.destroy=function(e){Object.keys(w.textures).forEach(t=>{var i=w.textures[t];i.gl===e&&i.destroy({force:!0});});},w.getSpriteInfo=function(e,t){let i=w.textures[e];return i&&{size:i.sizes[t],css_size:i.css_sizes[t],aspect:i.aspects[t],texcoords:i.texcoords[t]}},w.getTexcoordsForSprite=function(e,t,i){var r=i[1]-e[1]-t[1];return [e[0]/i[0],r/i[1],(t[0]+e[0])/i[0],(t[1]+r)/i[1]]},w.createFromObject=function(e,t){let i=[];if(t)for(let r in t){let s=t[r];if(s.skip_create)continue;if(!w.changed(r,s))continue;let n=w.create(e,r,s);i.push(n.loading);}return Promise.all(i)},w.default="__default",w.createDefault=function(e){return w.create(e,w.default)},w.sliceOptions=function(e){return {filtering:e.filtering,sprites:e.sprites,url:e.url,element:e.element,data:e.data,width:e.width,height:e.height,density:e.density,repeat:e.repeat,TEXTURE_WRAP_S:e.TEXTURE_WRAP_S,TEXTURE_WRAP_T:e.TEXTURE_WRAP_T,UNPACK_FLIP_Y_WEBGL:e.UNPACK_FLIP_Y_WEBGL,UNPACK_PREMULTIPLY_ALPHA_WEBGL:e.UNPACK_PREMULTIPLY_ALPHA_WEBGL}},w.changed=function(e,t){let i=w.textures[e];if(i){if("element"===i.config_type||null!=t.element)return !0;if(t=w.sliceOptions(t),w.texture_configs[e]===JSON.stringify(Object.assign({name:e},t)))return !1}return !0},w.getInfo=function(e){if(e||(e=Object.keys(w.textures)),Array.isArray(e))return Promise.all(e.map(e=>w.getInfo(e)));var t=w.textures[e];return t?(t.loading||Promise.resolve(t)).then(()=>({name:t.name,width:t.width,height:t.height,density:t.density,css_size:[t.width/t.density,t.height/t.density],aspect:t.width/t.height,sprites:t.sprites,texcoords:t.texcoords,sizes:t.sizes,css_sizes:t.css_sizes,aspects:t.aspects,filtering:t.filtering,power_of_2:t.power_of_2,valid:t.valid})):Promise.resolve(null)},w.syncTexturesToWorker=function(e){return n.postMessage("Texture.getInfo",e).then(e=>(e&&e.filter(e=>e).forEach(e=>w.textures[e.name]=e),w.textures))},w.getMaxTextureSize=function(e){return e.getParameter(e.MAX_TEXTURE_SIZE)},w.textures={},w.texture_configs={},w.boundTexture=null,w.activeUnit=null,n.addTarget("Texture",w),A(w);var E={parseUniforms:function(e){var t=[];for(var i in e){var r,s=i,n=e[i];if("number"==typeof n)t.push({type:"float",method:"1f",name:i,value:n,key:s,uniforms:e});else if(Array.isArray(n)){if("number"==typeof n[0])n.length>=2&&n.length<=4?t.push({type:"vec"+n.length,method:n.length+"fv",name:i,value:n,key:s,uniforms:e}):n.length>4&&t.push({type:"float[]",method:"1fv",name:i+"[0]",value:n,key:s,uniforms:e});else if("string"==typeof n[0])for(r=0;r<n.length;r++)t.push({type:"sampler2D",method:"1i",name:i+"["+r+"]",value:n[r],key:r,uniforms:n});else if(Array.isArray(n[0])&&"number"==typeof n[0][0]&&n[0].length>=2&&n[0].length<=4)for(r=0;r<n.length;r++)t.push({type:"vec"+n[0].length,method:n[0].length+"fv",name:i+"["+r+"]",value:n[r],key:r,uniforms:n});}else "boolean"==typeof n?t.push({type:"bool",method:"1i",name:i,value:n,key:s,uniforms:e}):"string"==typeof n&&t.push({type:"sampler2D",method:"1i",name:i,value:n,key:s,uniforms:e});}return t},defineVariable:function(e,t){var i,r;if("number"==typeof t)i="float";else if(Array.isArray(t))"number"==typeof t[0]?t.length>=2&&t.length<=4?i="vec"+t.length:(i="float",r=t.length):"string"==typeof t[0]?(i="sampler2D",r=t.length):Array.isArray(t[0])&&"number"==typeof t[0][0]&&t[0].length>=2&&t[0].length<=4&&(i="vec"+t[0].length,r=t.length);else if("boolean"==typeof t)i="bool";else {if("string"!=typeof t)return;i="sampler2D";}var s="";return s+=`${i} ${e}`,r&&(s+=`[${r}]`),s+=";\n"},defineUniform:function(e,t){var i=E.defineVariable(e,t);if(i)return "uniform "+i},expandVec3:function(e,t=1){let i;if(Array.isArray(e)){if(2!==e.length)return e;i=[...e,t].map(parseFloat);}else i=[e,e,e].map(parseFloat);if(i&&i.every(e=>"number"==typeof e&&!isNaN(e)))return i},expandVec4:function(e,t=1){let i;if(Array.isArray(e)){if(3!==e.length)return e;i=[...e,t].map(parseFloat);}else i=[e,e,e,t].map(parseFloat);if(i&&i.every(e=>"number"==typeof e&&!isNaN(e)))return i}};let R=[];function M(e,t){let i=R.filter(t=>t[0]===e)[0];return (i=i&&i[1])||(R.push([e,{}]),i=R[R.length-1][1]),i[t]||(i[t]=e.getExtension(t)),i[t]}function z(e){var t,i,r=0;if(0===e.length)return r;for(t=0,i=e.length;t<i;t++)r=(r<<5)-r+e.charCodeAt(t),r|=0;return r}var N=function(e){e=String(e);var t,i=[];for(;t=e.match(/ERROR\:([^\n]+)/);){e=e.slice(t.index+1);var r=t[1].trim(),s=r.split(":"),n=s.slice(2).join(":").trim(),o=parseInt(s[0],10),r=parseInt(s[1],10);i.push({message:n,file:o,line:r});}return i};const S=/^\s*#pragma.*$/gm,k=/\\\s*\n/gm;class P{constructor(e,t,i,r){r=r||{},this.gl=e,this.program=null,this.compiled=!1,this.compiling=!1,this.error=null,this.defines=Object.assign({},r.defines||{}),this.blocks=Object.assign({},r.blocks||{}),this.block_scopes=Object.assign({},r.block_scopes||{}),this.extensions=r.extensions||[],this.dependent_uniforms=r.uniforms,this.uniforms={},this.attribs={},this.vertex_source=t,this.fragment_source=i,this.id=P.id++,this.name=r.name;}destroy(){this.gl.useProgram(null),this.gl.deleteProgram(this.program),this.program=null,this.uniforms={},this.attribs={},this.compiled=!1;}use(){this.compiled&&(P.current!==this&&this.gl.useProgram(this.program),P.current=this);}compile(){if(this.compiling)throw new Error(`ShaderProgram.compile(): skipping for ${this.id} (${this.name}) because already compiling`);this.compiling=!0,this.compiled=!1,this.error=null,this.computed_vertex_source=this.vertex_source,this.computed_fragment_source=this.fragment_source;let e=this.checkExtensions();var t,i=this.buildDefineList(),r=this.buildShaderBlockList();for(var s in r){var n=r[s];if(n&&(!Array.isArray(n)||0!==n.length)){t=new RegExp("^\\s*#pragma\\s+tangram:\\s+"+s+"\\s*$","m");var o=this.computed_vertex_source.match(t),a=this.computed_fragment_source.match(t);if(null!=o||null!=a){var l="";n.forEach(e=>{let t=`${e.scope}, ${e.key}, ${e.num}`;l+=`\n// tangram-block-start: ${t}\n`,l+=e.source,l+=`\n// tangram-block-end: ${t}\n`;}),null!=o&&(this.computed_vertex_source=this.computed_vertex_source.replace(t,l)),null!=a&&(this.computed_fragment_source=this.computed_fragment_source.replace(t,l)),i["TANGRAM_BLOCK_"+s.replace(/[\s-]+/g,"_").toUpperCase()]=!0;}}}this.computed_vertex_source=this.computed_vertex_source.replace(S,""),this.computed_fragment_source=this.computed_fragment_source.replace(S,""),this.ensureUniforms(this.dependent_uniforms);let u="",h=this.gl.getShaderPrecisionFormat(this.gl.FRAGMENT_SHADER,this.gl.HIGH_FLOAT);u=h&&h.precision>0?"precision highp float;\n":"precision mediump float;\n",i.TANGRAM_VERTEX_SHADER=!0,i.TANGRAM_FRAGMENT_SHADER=!1,this.computed_vertex_source=u+P.buildDefineString(i)+this.computed_vertex_source,i.TANGRAM_VERTEX_SHADER=!1,i.TANGRAM_FRAGMENT_SHADER=!0,this.computed_fragment_source=P.buildExtensionString(e)+u+P.buildDefineString(i)+this.computed_fragment_source,this.computed_vertex_source=this.computed_vertex_source.replace(k,""),this.computed_fragment_source=this.computed_fragment_source.replace(k,"");try{this.program=P.updateProgram(this.gl,this.program,this.computed_vertex_source,this.computed_fragment_source),this.compiled=!0,this.compiling=!1;}catch(e){throw this.program=null,this.compiled=!1,this.compiling=!1,this.error=e,this.error.vertex_shader_source=this.computed_vertex_source,this.error.fragment_shader_source=this.computed_fragment_source,"vertex"!==e.type&&"fragment"!==e.type||(this.shader_errors=e.errors,this.shader_errors.forEach(t=>{t.type=e.type,t.block=this.block(e.type,t.line),t.line=this.block(e.type,t.line);}),this.error.shader_errors=this.shader_errors),e}this.computed_vertex_source=null,this.computed_fragment_source=null,this.use(),this.refreshUniforms(),this.refreshAttributes();}buildDefineList(){var e,t={};for(e in P.defines)t[e]=P.defines[e];for(e in this.defines)t[e]=this.defines[e];return t}buildShaderBlockList(){let e,t={};for(e in P.blocks)t[e]=[],Array.isArray(P.blocks[e])?t[e].push(...P.blocks[e].map((t,i)=>({key:e,source:t,num:i,scope:"ShaderProgram"}))):t[e]=[{key:e,source:P.blocks[e],num:0,scope:"ShaderProgram"}];for(e in this.blocks)if(t[e]=t[e]||[],Array.isArray(this.blocks[e])){let i=this.block_scopes&&this.block_scopes[e]||[],r=null,s=0;for(let n=0;n<this.blocks[e].length;n++)i[n]!==r&&(r=i[n],s=0),t[e].push({key:e,source:this.blocks[e][n],num:s,scope:r||this.name}),s++;}else t[e].push({key:e,source:this.blocks[e],num:0,scope:this.name});return t}ensureUniforms(e){if(!e)return;const t=Object.entries(e).map(([e,t])=>E.defineUniform(e,t)).filter(e=>e);this.computed_vertex_source=t.join("\n")+this.computed_vertex_source,this.computed_fragment_source=t.join("\n")+this.computed_fragment_source;}setUniforms(e,t=!0){if(!this.compiled)return;t&&(this.texture_unit=0);const i=E.parseUniforms(e);for(let e=0;e<i.length;e++){const t=i[e];"sampler2D"===t.type?this.setTextureUniform(t.name,t.value):this.uniform(t.method,t.name,t.value);}}saveUniforms(e){let t=e||this.uniforms;for(let e in t){let t=this.uniforms[e];t&&(t.saved_value=t.value);}this.saved_texture_unit=this.texture_unit||0;}restoreUniforms(e){let t=e||this.uniforms;for(let e in t){let t=this.uniforms[e];t&&t.saved_value&&(t.value=t.saved_value,this.updateUniform(t));}this.texture_unit=this.saved_texture_unit||0;}setTextureUniform(e,t){var i=w.textures[t];null!=i?(i.bind(this.texture_unit),this.uniform("1i",e,this.texture_unit),this.texture_unit++):f("warn",`Cannot find texture '${t}'`);}uniform(e,t,i){if(!this.compiled)return;this.uniforms[t]=this.uniforms[t]||{};let r=this.uniforms[t];r.name=t,void 0===r.location&&(r.location=this.gl.getUniformLocation(this.program,t)),r.method=e,r.value=i,this.updateUniform(r);}updateUniform(e){this.compiled&&e&&null!=e.location&&(this.use(),this.commitUniform(e));}commitUniform(e){let t=e.location,i=e.value;switch(e.method){case"1i":this.gl.uniform1i(t,i);break;case"1f":this.gl.uniform1f(t,i);break;case"2f":this.gl.uniform2f(t,i[0],i[1]);break;case"3f":this.gl.uniform3f(t,i[0],i[1],i[2]);break;case"4f":this.gl.uniform4f(t,i[0],i[1],i[2],i[3]);break;case"1iv":this.gl.uniform1iv(t,i);break;case"3iv":this.gl.uniform3iv(t,i);break;case"1fv":this.gl.uniform1fv(t,i);break;case"2fv":this.gl.uniform2fv(t,i);break;case"3fv":this.gl.uniform3fv(t,i);break;case"4fv":this.gl.uniform4fv(t,i);break;case"Matrix3fv":this.gl.uniformMatrix3fv(t,!1,i);break;case"Matrix4fv":this.gl.uniformMatrix4fv(t,!1,i);}}refreshUniforms(){if(this.compiled)for(var e in this.uniforms){let t=this.uniforms[e];t.location=this.gl.getUniformLocation(this.program,e),this.updateUniform(t);}}refreshAttributes(){this.attribs={};}attribute(e){if(this.compiled){var t=this.attribs[e]=this.attribs[e]||{};return null!=t.location?t:(t.name=e,t.location=this.gl.getAttribLocation(this.program,e),t)}}source(e){return "vertex"===e?this.computed_vertex_source:"fragment"===e?this.computed_fragment_source:void 0}lines(e){let t=this.source(e);return t?t.split("\n"):[]}line(e,t){let i=this.lines(e);if(i)return i[t]}block(e,t){let i,r=this.lines(e);for(let e=0;e<t&&e<r.length;e++){let t=r[e],s=t.match(/\/\/ tangram-block-start: ([A-Za-z0-9_-]+), ([A-Za-z0-9_-]+), (\d+)/);s&&s.length>1?i={scope:s[1],name:s[2],num:s[3]}:(s=t.match(/\/\/ tangram-block-end: ([A-Za-z0-9_-]+), ([A-Za-z0-9_-]+), (\d+)/))&&s.length>1&&(i=null),i&&(i.line=null==i.line?-1:i.line+1,i.source=t);}return i}checkExtensions(){let e=[];return this.extensions.forEach(t=>{let i=M(this.gl,t),r=`TANGRAM_EXTENSION_${t}`;this.defines[r]=null!=i,i?e.push(t):f("debug",`Could not enable extension '${t}'`);}),e}}P.id=0,P.current=null,P.defines={},P.blocks={},P.reset=function(){P.programs_by_source={},P.shaders_by_source={};},P.reset(),P.buildDefineString=function(e){var t="";for(var i in e)null!=e[i]&&!1!==e[i]&&("boolean"==typeof e[i]&&!0===e[i]?t+="#define "+i+"\n":"number"==typeof e[i]&&Math.floor(e[i])===e[i]?t+="#define "+i+" "+e[i].toFixed(1)+"\n":t+="#define "+i+" "+e[i]+"\n");return t},P.buildExtensionString=function(e){let t="";return (e=e||[]).forEach(e=>{t+=`#ifdef GL_${e}\n#extension GL_${e} : enable\n#endif\n`;}),t},P.addBlock=function(e,...t){P.blocks[e]=P.blocks[e]||[],P.blocks[e].push(...t);},P.removeBlock=function(e){P.blocks[e]=[];},P.replaceBlock=function(e,...t){P.removeBlock(e),P.addBlock(e,...t);},P.updateProgram=function(e,t,i,r){let s=z(e._tangram_id+"::"+i+"::"+r);if(P.programs_by_source[s])return f("trace","Reusing identical source GL program object"),P.programs_by_source[s];var n=P.createShader(e,i,e.VERTEX_SHADER),o=P.createShader(e,r,e.FRAGMENT_SHADER);if(e.useProgram(null),null!=t)for(var a=e.getAttachedShaders(t),l=0;l<a.length;l++)e.detachShader(t,a[l]);else t=e.createProgram();if(null==n||null==o)return t;if(e.attachShader(t,n),e.attachShader(t,o),e.bindAttribLocation(t,0,"a_position"),e.linkProgram(t),!e.getProgramParameter(t,e.LINK_STATUS)){let s=new Error(`WebGL program error:\n            VALIDATE_STATUS: ${e.getProgramParameter(t,e.VALIDATE_STATUS)}\n            ERROR: ${e.getError()}\n            --- Vertex Shader ---\n            ${i}\n            --- Fragment Shader ---\n            ${r}`);throw Object.assign(new Error(s),{type:"program"})}return P.programs_by_source[s]=t,t},P.createShader=function(e,t,i){let r=z(e._tangram_id+"::"+t);if(P.shaders_by_source[r])return f("trace","Reusing identical source GL shader object"),P.shaders_by_source[r];let s=e.createShader(i);if(e.shaderSource(s,t),e.compileShader(s),!e.getShaderParameter(s,e.COMPILE_STATUS)){let t=i===e.VERTEX_SHADER?"vertex":"fragment",r=e.getShaderInfoLog(s),n=N(r);throw Object.assign(new Error(r),{type:t,errors:n})}return P.shaders_by_source[r]=s,s};var L,O={disabled:!1,bound_vao:[],init(e){let t;!0!==this.disabled&&(t=M(e,"OES_vertex_array_object")),null!=t?f("info","Vertex Array Object extension available"):!0!==this.disabled?f("warn","Vertex Array Object extension NOT available"):f("warn","Vertex Array Object extension force disabled");},getExtension(e,t){if(!0!==this.disabled)return M(e,t)},create(e,t,i){let r={};r.setup=t,r.teardown=i;let s=this.getExtension(e,"OES_vertex_array_object");return null!=s&&(r._vao=s.createVertexArrayOES(),s.bindVertexArrayOES(r._vao)),r.setup(),r},getCurrentBinding(e){let t=this.bound_vao.filter(t=>t[0]===e)[0];return t&&t[1]},setCurrentBinding(e,t){let i=this.bound_vao,r=i.filter(t=>t[0]===e)[0];null==r?i.push([e,t]):r[1]=t;},bind(e,t){let i=this.getExtension(e,"OES_vertex_array_object");if(null!=t)null!=i&&null!=t._vao?(i.bindVertexArrayOES(t._vao),this.setCurrentBinding(e,t)):t.setup();else {let t=this.getCurrentBinding(e);null!=i?i.bindVertexArrayOES(null):null!=t&&"function"==typeof t.teardown&&t.teardown(),this.setCurrentBinding(e,null);}},destroy(e,t){let i=this.getExtension(e,"OES_vertex_array_object");null!=i&&null!=t&&null!=t._vao&&(i.deleteVertexArrayOES(t._vao),t._vao=null);}};function I(e,...t){for(let i=0;i<t.length;i++){let r=t[i];if(r)for(let t in r){let i=r[t];null===i||"object"!=typeof i||Array.isArray(i)?void 0!==i&&(e[t]=i):null===e[t]||"object"!=typeof e[t]||Array.isArray(e[t])?e[t]=I({},i):e[t]=I(e[t],i);}}return e}var F=L={};L.default_source_max_zoom=18,L.default_view_max_zoom=20,L.max_style_zoom=25,L.tile_size=256,L.half_circumference_meters=20037508.342789244,L.circumference_meters=2*L.half_circumference_meters,L.min_zoom_meters_per_pixel=L.circumference_meters/L.tile_size;let U=[];L.metersPerPixel=function(e){return U[e]=U[e]||L.min_zoom_meters_per_pixel/Math.pow(2,e),U[e]};let D=[];L.metersPerTile=function(e){return D[e]=D[e]||L.circumference_meters/Math.pow(2,e),D[e]},L.tile_scale=4096,L.units_per_pixel=L.tile_scale/L.tile_size,L.height_scale=16;let G=[];L.unitsPerMeter=function(e){return G[e]=G[e]||L.tile_scale/(L.tile_size*L.metersPerPixel(e)),G[e]},L.metersForTile=function(e){return {x:e.x*L.circumference_meters/Math.pow(2,e.z)-L.half_circumference_meters,y:-(e.y*L.circumference_meters/Math.pow(2,e.z)-L.half_circumference_meters)}},L.tileForMeters=function([e,t],i){return {x:Math.floor((e+L.half_circumference_meters)/(L.circumference_meters/Math.pow(2,i))),y:Math.floor((-t+L.half_circumference_meters)/(L.circumference_meters/Math.pow(2,i))),z:i}},L.wrapTile=function({x:e,y:t,z:i},r={x:!0,y:!1}){var s=(1<<i)-1;return r.x&&(e&=s),r.y&&(t&=s),{x:e,y:t,z:i}},L.metersToLatLng=function(e){return e[0]/=L.half_circumference_meters,e[1]/=L.half_circumference_meters,e[1]=(2*Math.atan(Math.exp(e[1]*Math.PI))-Math.PI/2)/Math.PI,e[0]*=180,e[1]*=180,e},L.latLngToMeters=function(e){return e[1]=Math.log(Math.tan(e[1]*Math.PI/360+Math.PI/4))/Math.PI,e[1]*=L.half_circumference_meters,e[0]*=L.half_circumference_meters/180,e},L.tileSpaceToLatlng=function(e,t,i){const r=L.unitsPerMeter(t);return L.transformGeometry(e,e=>{e[0]=e[0]/r+i.x,e[1]=e[1]/r+i.y,L.metersToLatLng(e);}),e},L.copyGeometry=function(e){if(null==e)return;let t={type:e.type};return "Point"===e.type?t.coordinates=[e.coordinates[0],e.coordinates[1]]:"LineString"===e.type||"MultiPoint"===e.type?t.coordinates=e.coordinates.map(e=>[e[0],e[1]]):"Polygon"===e.type||"MultiLineString"===e.type?t.coordinates=e.coordinates.map(e=>e.map(e=>[e[0],e[1]])):"MultiPolygon"===e.type&&(t.coordinates=e.coordinates.map(e=>e.map(e=>e.map(e=>[e[0],e[1]])))),t},L.transformGeometry=function(e,t){null!=e&&("Point"===e.type?t(e.coordinates):"LineString"===e.type||"MultiPoint"===e.type?e.coordinates.forEach(t):"Polygon"===e.type||"MultiLineString"===e.type?e.coordinates.forEach(e=>e.forEach(t)):"MultiPolygon"===e.type&&e.coordinates.forEach(e=>{e.forEach(e=>e.forEach(t));}));},L.boxIntersect=function(e,t){return !(t.sw.x>e.ne.x||t.ne.x<e.sw.x||t.sw.y>e.ne.y||t.ne.y<e.sw.y)},L.findBoundingBox=function(e){for(var t=1/0,i=-1/0,r=1/0,s=-1/0,n=e[0].length,o=0;o<n;o++){var a=e[0][o];a[0]<t&&(t=a[0]),a[1]<r&&(r=a[1]),a[0]>i&&(i=a[0]),a[1]>s&&(s=a[1]);}return [t,r,i,s]},L.geometryType=function(e){return "Polygon"===e||"MultiPolygon"===e?"polygon":"LineString"===e||"MultiLineString"===e?"line":"Point"===e||"MultiPoint"===e?"point":void 0},L.centroid=function(e,t=!0){if(!e||0===e.length)return;let i,r=0,s=0,n=0,o=e[0],a=o.length;t&&(i=o[0],o=o.map(e=>[e[0]-i[0],e[1]-i[1]]));for(let e=0,t=a-1;e<a;t=e,e++){let i=o[e],a=o[t],l=i[1]*a[0]-a[1]*i[0];r+=(i[0]+a[0])*l,s+=(i[1]+a[1])*l,n+=3*l;}if(!n)return;let l=[r/n,s/n];return t&&(l[0]+=i[0],l[1]+=i[1]),l},L.multiCentroid=function(e){let t=0,i=null;for(let r=0;r<e.length;r++){let s=L.centroid(e[r]);s&&((i=i||[0,0])[0]+=s[0],i[1]+=s[1],t++);}return t>0&&(i[0]/=t,i[1]/=t),i},L.signedPolygonRingAreaSum=function(e){let t=0,i=e.length;for(let r=0;r<i-1;r++){let i=e[r],s=e[r+1];t+=i[0]*s[1]-s[0]*i[1];}return t+=e[i-1][0]*e[0][1]-e[0][0]*e[i-1][1]},L.polygonRingArea=function(e){return Math.abs(L.signedPolygonRingAreaSum(e))/2},L.polygonArea=function(e){if(e)return L.polygonRingArea(e[0])},L.multiPolygonArea=function(e){let t=0;for(let i=0;i<e.length;i++)t+=L.polygonArea(e[i]);return t},L.ringWinding=function(e){let t=L.signedPolygonRingAreaSum(e);return t>0?"CW":t<0?"CCW":void 0};const C={functions:{},num_functions:0,num_cached:0};function j(e,t){if("string"==typeof e)e=$(e,t);else if(null!=e&&"object"==typeof e)for(let i in e)e[i]=j(e[i],t);return e}function $(e,t){let i="string"==typeof e&&e.match(/^\s*function[^(]*\(([^)]*)\)\s*?\{([\s\S]*)\}$/m);if(i&&i.length>2)try{const r=i[2],s="function"==typeof t?t(r):r,n=z(s);if(void 0===C.functions[n]){let e=i[1].length>0&&i[1].split(",").map(e=>e.trim()).filter(e=>e);e=e.length>0?e:["context"],C.functions[n]=new Function(e.toString(),s),C.functions[n].source=r,C.num_functions++;}else C.num_cached++;return C.functions[n]}catch(t){return e}return e}function V(e,t){return e(t={exports:{}},t.exports),t.exports}var B=V(function(e,t){var i={transparent:[0,0,0,0],aliceblue:[240,248,255,1],antiquewhite:[250,235,215,1],aqua:[0,255,255,1],aquamarine:[127,255,212,1],azure:[240,255,255,1],beige:[245,245,220,1],bisque:[255,228,196,1],black:[0,0,0,1],blanchedalmond:[255,235,205,1],blue:[0,0,255,1],blueviolet:[138,43,226,1],brown:[165,42,42,1],burlywood:[222,184,135,1],cadetblue:[95,158,160,1],chartreuse:[127,255,0,1],chocolate:[210,105,30,1],coral:[255,127,80,1],cornflowerblue:[100,149,237,1],cornsilk:[255,248,220,1],crimson:[220,20,60,1],cyan:[0,255,255,1],darkblue:[0,0,139,1],darkcyan:[0,139,139,1],darkgoldenrod:[184,134,11,1],darkgray:[169,169,169,1],darkgreen:[0,100,0,1],darkgrey:[169,169,169,1],darkkhaki:[189,183,107,1],darkmagenta:[139,0,139,1],darkolivegreen:[85,107,47,1],darkorange:[255,140,0,1],darkorchid:[153,50,204,1],darkred:[139,0,0,1],darksalmon:[233,150,122,1],darkseagreen:[143,188,143,1],darkslateblue:[72,61,139,1],darkslategray:[47,79,79,1],darkslategrey:[47,79,79,1],darkturquoise:[0,206,209,1],darkviolet:[148,0,211,1],deeppink:[255,20,147,1],deepskyblue:[0,191,255,1],dimgray:[105,105,105,1],dimgrey:[105,105,105,1],dodgerblue:[30,144,255,1],firebrick:[178,34,34,1],floralwhite:[255,250,240,1],forestgreen:[34,139,34,1],fuchsia:[255,0,255,1],gainsboro:[220,220,220,1],ghostwhite:[248,248,255,1],gold:[255,215,0,1],goldenrod:[218,165,32,1],gray:[128,128,128,1],green:[0,128,0,1],greenyellow:[173,255,47,1],grey:[128,128,128,1],honeydew:[240,255,240,1],hotpink:[255,105,180,1],indianred:[205,92,92,1],indigo:[75,0,130,1],ivory:[255,255,240,1],khaki:[240,230,140,1],lavender:[230,230,250,1],lavenderblush:[255,240,245,1],lawngreen:[124,252,0,1],lemonchiffon:[255,250,205,1],lightblue:[173,216,230,1],lightcoral:[240,128,128,1],lightcyan:[224,255,255,1],lightgoldenrodyellow:[250,250,210,1],lightgray:[211,211,211,1],lightgreen:[144,238,144,1],lightgrey:[211,211,211,1],lightpink:[255,182,193,1],lightsalmon:[255,160,122,1],lightseagreen:[32,178,170,1],lightskyblue:[135,206,250,1],lightslategray:[119,136,153,1],lightslategrey:[119,136,153,1],lightsteelblue:[176,196,222,1],lightyellow:[255,255,224,1],lime:[0,255,0,1],limegreen:[50,205,50,1],linen:[250,240,230,1],magenta:[255,0,255,1],maroon:[128,0,0,1],mediumaquamarine:[102,205,170,1],mediumblue:[0,0,205,1],mediumorchid:[186,85,211,1],mediumpurple:[147,112,219,1],mediumseagreen:[60,179,113,1],mediumslateblue:[123,104,238,1],mediumspringgreen:[0,250,154,1],mediumturquoise:[72,209,204,1],mediumvioletred:[199,21,133,1],midnightblue:[25,25,112,1],mintcream:[245,255,250,1],mistyrose:[255,228,225,1],moccasin:[255,228,181,1],navajowhite:[255,222,173,1],navy:[0,0,128,1],oldlace:[253,245,230,1],olive:[128,128,0,1],olivedrab:[107,142,35,1],orange:[255,165,0,1],orangered:[255,69,0,1],orchid:[218,112,214,1],palegoldenrod:[238,232,170,1],palegreen:[152,251,152,1],paleturquoise:[175,238,238,1],palevioletred:[219,112,147,1],papayawhip:[255,239,213,1],peachpuff:[255,218,185,1],peru:[205,133,63,1],pink:[255,192,203,1],plum:[221,160,221,1],powderblue:[176,224,230,1],purple:[128,0,128,1],rebeccapurple:[102,51,153,1],red:[255,0,0,1],rosybrown:[188,143,143,1],royalblue:[65,105,225,1],saddlebrown:[139,69,19,1],salmon:[250,128,114,1],sandybrown:[244,164,96,1],seagreen:[46,139,87,1],seashell:[255,245,238,1],sienna:[160,82,45,1],silver:[192,192,192,1],skyblue:[135,206,235,1],slateblue:[106,90,205,1],slategray:[112,128,144,1],slategrey:[112,128,144,1],snow:[255,250,250,1],springgreen:[0,255,127,1],steelblue:[70,130,180,1],tan:[210,180,140,1],teal:[0,128,128,1],thistle:[216,191,216,1],tomato:[255,99,71,1],turquoise:[64,224,208,1],violet:[238,130,238,1],wheat:[245,222,179,1],white:[255,255,255,1],whitesmoke:[245,245,245,1],yellow:[255,255,0,1],yellowgreen:[154,205,50,1]};function r(e){return (e=Math.round(e))<0?0:e>255?255:e}function s(e){return e<0?0:e>1?1:e}function n(e){return "%"===e[e.length-1]?r(parseFloat(e)/100*255):r(parseInt(e))}function o(e){return "%"===e[e.length-1]?s(parseFloat(e)/100):s(parseFloat(e))}function a(e,t,i){return i<0?i+=1:i>1&&(i-=1),6*i<1?e+(t-e)*i*6:2*i<1?t:3*i<2?e+(t-e)*(2/3-i)*6:e}try{t.parseCSSColor=function(e){var t,s=e.replace(/ /g,"").toLowerCase();if(s in i)return i[s].slice();if("#"===s[0])return 4===s.length?(t=parseInt(s.substr(1),16))>=0&&t<=4095?[(3840&t)>>4|(3840&t)>>8,240&t|(240&t)>>4,15&t|(15&t)<<4,1]:null:7===s.length&&(t=parseInt(s.substr(1),16))>=0&&t<=16777215?[(16711680&t)>>16,(65280&t)>>8,255&t,1]:null;var l=s.indexOf("("),u=s.indexOf(")");if(-1!==l&&u+1===s.length){var h=s.substr(0,l),c=s.substr(l+1,u-(l+1)).split(","),d=1;switch(h){case"rgba":if(4!==c.length)return null;d=o(c.pop());case"rgb":return 3!==c.length?null:[n(c[0]),n(c[1]),n(c[2]),d];case"hsla":if(4!==c.length)return null;d=o(c.pop());case"hsl":if(3!==c.length)return null;var f=(parseFloat(c[0])%360+360)%360/360,_=o(c[1]),p=o(c[2]),m=p<=.5?p*(_+1):p+_-p*_,g=2*p-m;return [r(255*a(g,m,f+1/3)),r(255*a(g,m,f)),r(255*a(g,m,f-1/3)),d];default:return null}}return null};}catch(e){}});B.parseCSSColor;const q={},X=e=>Math.max(e,0),H=e=>isNaN(e)?0:e,W=e=>Array.isArray(e)?e.map(parseFloat).map(H):H(parseFloat(e)),Y=e=>Array.isArray(e)?e.map(W).map(X):X(W(e));Object.assign(q,{clampPositive:X,noNaN:H,parseNumber:W,parsePositiveNumber:Y}),q.wrapFunction=function(e){return `\n        var feature = context.feature.properties;\n        var global = context.global;\n        var $zoom = context.zoom;\n        var $layer = context.layer;\n        var $source = context.source;\n        var $geometry = context.geometry;\n        var $meters_per_pixel = context.meters_per_pixel;\n        var $id = context.id;\n\n        var val = (function(){ ${e} }());\n\n        if (typeof val === 'number' && isNaN(val)) {\n            val = null; // convert NaNs to nulls\n        }\n\n        return val;\n    `},q.zeroPair=Object.freeze([0,0]),q.defaults={color:[1,1,1,1],width:1,size:1,extrude:!1,height:20,min_height:0,order:0,z:0,outline:{color:[0,0,0,0],width:0},material:{ambient:1,diffuse:1}},q.macros={"Style.color.pseudoRandomColor":function(){return [parseInt(feature.id,16)/100%1*.7,parseInt(feature.id,16)/1e4%1*.7,parseInt(feature.id,16)/1e6%1*.7,1]},"Style.color.randomColor":function(){return [.7*Math.random(),.7*Math.random(),.7*Math.random(),1]}},q.getFeatureParseContext=function(e,t,i){return {feature:e,id:e.id,tile:t,global:i,zoom:t.style_z,geometry:F.geometryType(e.geometry.type),meters_per_pixel:t.meters_per_pixel,meters_per_pixel_sq:t.meters_per_pixel_sq,units_per_meter_overzoom:t.units_per_meter_overzoom}};const Z={STATIC:0,DYNAMIC:1,ZOOM:2};q.CACHE_TYPE=Z,q.createPropertyCache=function(e,t=null,i=null){if(null==e)return;if(e.value)return {value:e.value,zoom:e.zoom?{}:null,type:e.type};let r={value:e,type:Z.STATIC};return Array.isArray(r.value)&&Array.isArray(r.value[0])?(r.zoom={},r.type=Z.ZOOM):"function"==typeof r.value&&(r.type=Z.DYNAMIC,r.dynamic_transform="function"==typeof i?i:null),"function"==typeof t&&(r.zoom?r.value=r.value.map((e,i)=>[e[0],t(e[1],i)]):"function"!=typeof r.value&&(r.value=t(r.value,0))),r},q.createColorPropertyCache=function(e){return q.createPropertyCache(e,e=>"Style.color.pseudoRandomColor"===e?$(q.wrapFunction(q.macros["Style.color.pseudoRandomColor"])):"Style.color.randomColor"===e?q.macros["Style.color.randomColor"]:e)};const J=e=>"string"==typeof e&&"%"===e[e.length-1],K=e=>"auto"===e,Q=e=>J(e)||K(e),ee="'size' can specify either width or height as derived from aspect ratio, but not both";function te(e,t){return q.createPropertyCache(e.value,(i,r)=>(Array.isArray(i)?(i=i.map((t,i)=>e.has_ratio[r][i]?t:Y(t)).map((i,s)=>e.has_pct[r][s]?t.css_size[s]*i/100:i),e.has_ratio[r][0]?i[0]=i[1]*t.aspect:e.has_ratio[r][1]&&(i[1]=i[0]/t.aspect)):(i=Y(i),i=e.has_pct[r]?t.css_size.map(e=>e*i/100):[i,i]),i))}function ie(e,t){try{return e(t)}catch(i){f("warn",`Property function in layer '${t.layers[t.layers.length-1]}' failed with\n`,`error ${i.stack}\n`,`function '${e.source}'\n`,t.feature,t);}}q.createPointSizePropertyCache=function(e,t){let i=null,r=null;if(J(e))i=[!0];else if(Array.isArray(e)){if(Array.isArray(e[0])){if(e.some(e=>Array.isArray(e[1])?e[1].some(e=>Q(e)):J(e[1]))&&(i=e.map(e=>Array.isArray(e[1])?e[1].map(e=>J(e)):J(e[1])),(r=e.map(e=>Array.isArray(e[1])&&e[1].map(e=>K(e)))).some(e=>Array.isArray(e)&&e.every(e=>e))))throw ee}else if(e.some(Q)&&(i=[e.map(J)],(r=[e.map(K)])[0].every(e=>e)))throw ee}else if(K(e))throw "this value only allowed as half of an array, eg [16px, auto]:";if(i||r){if(!t)throw "% or 'auto' keywords can only be used to specify point size when a texture is defined";(e={value:e}).has_pct=i,e.has_ratio=r,e.sprites={};}else e=q.createPropertyCache(e,Y);return e},q.evalCachedPointSizeProperty=function(e,t,i,r){if(null!=e)return e.has_pct||e.has_ratio?t?(e.sprites[t.sprite]||(e.sprites[t.sprite]=te(e,t)),q.evalCachedProperty(e.sprites[t.sprite],r)):(e.texture=e.texture||te(e,i),q.evalCachedProperty(e.texture,r)):q.evalCachedProperty(e,r)},q.evalCachedProperty=function(e,t){return null==e?void 0:e.dynamic?ie(e.dynamic,t):e.static?e.static:e.zoom&&e.zoom[t.zoom]?e.zoom[t.zoom]:"function"==typeof e.value?(e.dynamic_transform?e.dynamic=function(t){return e.dynamic_transform(e.value(t))}:e.dynamic=e.value,ie(e.dynamic,t)):Array.isArray(e.value)&&Array.isArray(e.value[0])?(e.zoom=e.zoom||{},e.zoom[t.zoom]=_.interpolate(t.zoom,e.value),e.zoom[t.zoom]):(e.static=e.value,e.static)},q.convertUnits=function(e,t){if(null!=e.value)return "px"===e.units?e.value*F.metersPerPixel(t.zoom):e.value;if("string"==typeof e)"px"===e.trim().slice(-2)?(e=W(e),e*=F.metersPerPixel(t.zoom)):e=W(e);else if(Array.isArray(e))return Array.isArray(e[0])?e.map(e=>[e[0],q.convertUnits(e[1],t)]):e.map(e=>q.convertUnits(e,t));return e},q.parseUnits=function(e){var t={value:W(e)};return 0!==t.value&&"string"==typeof e&&"px"===e.trim().slice(-2)&&(t.units="px"),t},q.evalCachedDistanceProperty=function(e,t){return null==e?void 0:e.dynamic?ie(e.dynamic,t):e.zoom&&e.zoom[t.zoom]?e.zoom[t.zoom]:"function"==typeof e.value?(e.dynamic=e.value,ie(e.dynamic,t)):e.zoom?(e.zoom[t.zoom]=_.interpolate(t.zoom,e.value,e=>q.convertUnits(e,t)),e.zoom[t.zoom]):q.convertUnits(e.value,t)},q.string_colors={},q.colorForString=function(e){if(q.string_colors[e])return q.string_colors[e];let t=B.parseCSSColor(e);return t&&4===t.length?(t[0]/=255,t[1]/=255,t[2]/=255):t=q.defaults.color,q.string_colors[e]=t,t},q.evalCachedColorProperty=function(e,t={}){if(null!=e){if(e.dynamic){let i=ie(e.dynamic,t);return "string"==typeof i&&(i=q.colorForString(i)),i&&null==i[3]&&(i[3]=1),i}if(e.static)return e.static;if(e.zoom&&e.zoom[t.zoom])return e.zoom[t.zoom];if("function"==typeof e.value){e.dynamic=e.value;let i=ie(e.dynamic,t);return "string"==typeof i&&(i=q.colorForString(i)),i&&null==i[3]&&(i[3]=1),i}if("string"==typeof e.value)return e.static=q.colorForString(e.value),e.static;if(e.zoom){if(!e.zoom_preprocessed){for(let t=0;t<e.value.length;t++){let i=e.value[t];i&&"string"==typeof i[1]&&(i[1]=q.colorForString(i[1]));}e.zoom_preprocessed=!0;}return e.zoom[t.zoom]=_.interpolate(t.zoom,e.value),e.zoom[t.zoom][3]=e.zoom[t.zoom][3]||1,e.zoom[t.zoom]}return e.static=e.value.map(e=>e),e.static&&null==e.static[3]&&(e.static[3]=1),e.static}},q.evalCachedColorPropertyWithAlpha=function(e,t,i){const r=q.evalCachedColorProperty(e,i);if(null!=r&&null!=t){const e=q.evalCachedProperty(t,i);if(null!=e)return [r[0],r[1],r[2],e]}return r},q.parseColor=function(e,t={}){if("function"==typeof e&&(e=ie(e,t)),"string"==typeof e)e=q.colorForString(e);else if(Array.isArray(e)&&Array.isArray(e[0])){for(let t=0;t<e.length;t++){let i=e[t];"string"==typeof i[1]&&(i[1]=q.colorForString(i[1]));}t.zoom&&(e=_.interpolate(t.zoom,e));}return Array.isArray(e)?null==(e=e.map(e=>e))[3]&&(e[3]=1):e=[0,0,0,1],e},q.calculateOrder=function(e,t){return "function"==typeof e?e=ie(e,t):"string"==typeof e&&(e=t.feature.properties[e]?t.feature.properties[e]:Y(e)),e},q.evalProperty=function(e,t){return "function"==typeof e?ie(e,t):e};class re{constructor(e,t,i){this.gl=e,this.workers=t,this._lock_fn="function"==typeof i&&i,this.init();}init(){this.requests={},this.feature=null,this.read_delay=0,this.read_delay_timer=null,this.pixels=null,this.fbo=this.gl.createFramebuffer(),this.gl.bindFramebuffer(this.gl.FRAMEBUFFER,this.fbo),this.fbo_size={width:256,height:256};var e=w.create(this.gl,"__selection_fbo",{filtering:"nearest"});e.setData(this.fbo_size.width,this.fbo_size.height,null,{filtering:"nearest"}),this.gl.framebufferTexture2D(this.gl.FRAMEBUFFER,this.gl.COLOR_ATTACHMENT0,this.gl.TEXTURE_2D,e.texture,0);var t=this.gl.createRenderbuffer();this.gl.bindRenderbuffer(this.gl.RENDERBUFFER,t),this.gl.renderbufferStorage(this.gl.RENDERBUFFER,this.gl.DEPTH_COMPONENT16,this.fbo_size.width,this.fbo_size.height),this.gl.framebufferRenderbuffer(this.gl.FRAMEBUFFER,this.gl.DEPTH_ATTACHMENT,this.gl.RENDERBUFFER,t),this.gl.bindFramebuffer(this.gl.FRAMEBUFFER,null);}destroy(){this.gl&&this.fbo&&(this.gl.deleteFramebuffer(this.fbo),this.fbo=null,this.gl.bindFramebuffer(this.gl.FRAMEBUFFER,null));}get locked(){return this._lock_fn&&this._lock_fn()||!1}bind(){this.gl.bindFramebuffer(this.gl.FRAMEBUFFER,this.fbo),this.gl.viewport(0,0,this.fbo_size.width,this.fbo_size.height),this.gl.clearColor(...re.defaultColor);}getFeatureAt(e,{radius:t}){return !e||e.x<0||e.y<0||e.x>1||e.y>1?Promise.resolve({feature:null,changed:!1}):new Promise((i,r)=>{this.selection_request_id=this.selection_request_id+1||0,this.requests[this.selection_request_id]={id:this.selection_request_id,point:e,radius:t,resolve:i,reject:r};})}pendingRequests(){return Object.keys(this.requests).length?this.requests:null}hasPendingRequests(){return null!=this.pendingRequests()}clearPendingRequests(){for(var e in this.requests){var t=this.requests[e];t.sent||(t.reject({request:t}),delete this.requests[e]);}}read(){null!=this.read_delay_timer&&clearTimeout(this.read_delay_timer),this.read_delay_timer=setTimeout(()=>{if(!this.locked){var e=this.gl;for(var t in e.bindFramebuffer(e.FRAMEBUFFER,this.fbo),this.requests){var i=this.requests[t];if(i.sent)continue;let r,s,o=255,{point:a,radius:l}=i;if(l){let e=Math.min(this.fbo_size.width,this.fbo_size.height);s={x:Math.min(Math.ceil(2*l.x*this.fbo_size.width),e),y:Math.min(Math.ceil(2*l.y*this.fbo_size.height),e)};}else l={x:0,y:0},s={x:1,y:1};if((null==this.pixels||this.pixels.byteLength<s.x*s.y*4)&&(this.pixels=new Uint8Array(s.x*s.y*4)),this.pixels.fill instanceof Function)this.pixels.fill(0);else for(let e=0;e<this.pixels.length;e++)this.pixels[e]=0;e.readPixels(Math.round((a.x-l.x)*this.fbo_size.width),Math.round((1-a.y-l.y)*this.fbo_size.height),s.x,s.y,e.RGBA,e.UNSIGNED_BYTE,this.pixels);let u=4*(Math.round(s.y/2)*s.x+Math.round(s.x/2)),h=this.pixels[u]+(this.pixels[u+1]<<8)+(this.pixels[u+2]<<16);if(h>0)r=h+(this.pixels[u+3]<<24)>>>0,o=this.pixels[u+3];else {let e=-1>>>0;u=0;for(let t=0;t<s.y;t++)for(let i=0;i<s.x;i++,u+=4)if((h=this.pixels[u]+(this.pixels[u+1]<<8)+(this.pixels[u+2]<<16))>0){let n=(i-s.x/2)*(i-s.x/2)+(t-s.y/2)*(t-s.y/2);n<=e&&(r=h+(this.pixels[u+3]<<24)>>>0,o=this.pixels[u+3],e=n);}}255!==o?null!=this.workers[o]&&n.postMessage(this.workers[o],"self.getFeatureSelection",{id:i.id,key:r}).then(e=>{this.finishRead(e);}):this.finishRead({id:i.id}),i.sent=!0;}e.bindFramebuffer(e.FRAMEBUFFER,null);}},this.read_delay);}finishRead(e){var t=this.requests[e.id];if(t){var i=e.feature,r=!1;(null!=i&&null==this.feature||null==i&&null!=this.feature||null!=i&&null!=this.feature&&JSON.stringify(i)!==JSON.stringify(this.feature))&&(r=!0),this.feature=i,t.resolve({feature:i,changed:r,request:t}),delete this.requests[e.id];}else f("error","FeatureSelection.finishRead(): could not find message",e);}static makeEntry(e){this.map_entry++;var t=255&this.map_entry,i=this.map_entry>>8&255,r=this.map_entry>>16&255,s=this.map_prefix,n=t/255,o=i/255,a=r/255,l=s/255,u=t+(i<<8)+(r<<16)+(s<<24)>>>0;return this.map[u]={color:[n,o,a,l]},this.map_size++,this.tiles[e.key]||(this.tiles[e.key]={entries:[],tile:{key:e.key,coords:e.coords,style_z:e.style_z,source:e.source,generation:e.generation}}),this.tiles[e.key].entries.push(u),this.map[u]}static makeColor(e,t,i){var r=this.makeEntry(t);return r.feature={id:e.id,properties:e.properties,source_name:i.source,source_layer:i.layer,layers:i.layers,tile:this.tiles[t.key].tile},r.color}static reset(e){Array.isArray(e)?e.forEach(e=>this.clearSource(e)):(this.tiles={},this.map={},this.map_size=0,this.map_entry=0);}static clearSource(e){for(let t in this.tiles)this.tiles[t].tile.source===e&&this.clearTile(t);}static clearTile(e){this.tiles[e]&&(this.tiles[e].entries.forEach(e=>delete this.map[e]),this.map_size-=this.tiles[e].entries.length,delete this.tiles[e]);}static getMapSize(){return this.map_size}static setPrefix(e){this.map_prefix=e;}}var se;re.map={},re.tiles={},re.map_size=0,re.map_entry=0,re.map_prefix=0,re.defaultColor=[0,0,0,1];var ne=se={};se.BYTE=5120,se.UNSIGNED_BYTE=5121,se.SHORT=5122,se.UNSIGNED_SHORT=5123,se.INT=5124,se.UNSIGNED_INT=5125,se.FLOAT=5126;class oe{constructor(e,t,i,r,s){s=s||{},this.gl=e,this.vertex_data=t,this.element_data=i,this.vertex_layout=r,this.vertex_buffer=this.gl.createBuffer(),this.buffer_size=this.vertex_data.byteLength,this.draw_mode=s.draw_mode||this.gl.TRIANGLES,this.data_usage=s.data_usage||this.gl.STATIC_DRAW,this.vertices_per_geometry=3,this.uniforms=s.uniforms,this.textures=s.textures,this.retain=s.retain||!1,this.created_at=+new Date,this.fade_in_time=s.fade_in_time||0,this.vertex_count=this.vertex_data.byteLength/this.vertex_layout.stride,this.element_count=0,this.vaos={},this.toggle_element_array=!1,this.element_data?(this.toggle_element_array=!0,this.element_count=this.element_data.length,this.geometry_count=this.element_count/this.vertices_per_geometry,this.element_type=this.element_data.constructor===Uint16Array?this.gl.UNSIGNED_SHORT:this.gl.UNSIGNED_INT,this.element_buffer=this.gl.createBuffer(),this.buffer_size+=this.element_data.byteLength,this.gl.bindBuffer(this.gl.ELEMENT_ARRAY_BUFFER,this.element_buffer),this.gl.bufferData(this.gl.ELEMENT_ARRAY_BUFFER,this.element_data,this.data_usage)):this.geometry_count=this.vertex_count/this.vertices_per_geometry,this.upload(),this.retain||(delete this.vertex_data,delete this.element_data),this.valid=!0;}render(e={}){if(!this.valid)return !1;var t=e.program||P.current;t.use(),this.uniforms&&(t.saveUniforms(this.uniforms),t.setUniforms(this.uniforms,!1));let i=(+new Date-this.created_at)/1e3;return t.uniform("1f","u_visible_time",i),this.bind(t),this.toggle_element_array?this.gl.drawElements(this.draw_mode,this.element_count,this.element_type,0):this.gl.drawArrays(this.draw_mode,0,this.vertex_count),O.bind(this.gl,null),this.uniforms&&t.restoreUniforms(this.uniforms),i<this.fade_in_time}bind(e){let t=this.vaos[e.id];t?O.bind(this.gl,t):this.vaos[e.id]=O.create(this.gl,()=>{this.gl.bindBuffer(this.gl.ARRAY_BUFFER,this.vertex_buffer),this.toggle_element_array&&this.gl.bindBuffer(this.gl.ELEMENT_ARRAY_BUFFER,this.element_buffer),this.vertex_layout.enableDynamicAttributes(this.gl,e);}),this.vertex_layout.enableStaticAttributes(this.gl,e);}upload(){this.gl.bindBuffer(this.gl.ARRAY_BUFFER,this.vertex_buffer),this.gl.bufferData(this.gl.ARRAY_BUFFER,this.vertex_data,this.data_usage);}destroy(){if(!this.valid)return !1;this.valid=!1;for(let e in this.vaos)O.destroy(this.gl,this.vaos[e]);return this.gl.deleteBuffer(this.vertex_buffer),this.vertex_buffer=null,this.element_buffer&&(this.gl.deleteBuffer(this.element_buffer),this.element_buffer=null),delete this.vertex_data,delete this.element_data,this.textures&&this.textures.forEach(e=>w.release(e)),!0}}var ae="/*\n\nDefines globals:\nmaterial\nlight_accumulator_*\n\n*/\n\n\n// MATERIALS\n//\nstruct Material {\n    #ifdef TANGRAM_MATERIAL_EMISSION\n        vec4 emission;\n        #ifdef TANGRAM_MATERIAL_EMISSION_TEXTURE\n            vec3 emissionScale;\n        #endif\n    #endif\n\n    #ifdef TANGRAM_MATERIAL_AMBIENT\n        vec4 ambient;\n        #ifdef TANGRAM_MATERIAL_AMBIENT_TEXTURE\n            vec3 ambientScale;\n        #endif\n    #endif\n\n    #ifdef TANGRAM_MATERIAL_DIFFUSE\n        vec4 diffuse;\n        #ifdef TANGRAM_MATERIAL_DIFFUSE_TEXTURE\n            vec3 diffuseScale;\n        #endif\n    #endif\n\n    #ifdef TANGRAM_MATERIAL_SPECULAR\n        vec4 specular;\n        float shininess;\n        #ifdef TANGRAM_MATERIAL_SPECULAR_TEXTURE\n            vec3 specularScale;\n        #endif\n    #endif\n\n\n    #ifdef TANGRAM_MATERIAL_NORMAL_TEXTURE\n        vec3 normalScale;\n        float normalAmount;\n    #endif\n};\n\n// Note: uniform is copied to a global instance to allow modification\nuniform Material u_material;\nMaterial material;\n\n#ifdef TANGRAM_MATERIAL_EMISSION_TEXTURE\nuniform sampler2D u_material_emission_texture;\n#endif\n\n#ifdef TANGRAM_MATERIAL_AMBIENT_TEXTURE\nuniform sampler2D u_material_ambient_texture;\n#endif\n\n#ifdef TANGRAM_MATERIAL_DIFFUSE_TEXTURE\nuniform sampler2D u_material_diffuse_texture;\n#endif\n\n#ifdef TANGRAM_MATERIAL_SPECULAR_TEXTURE\nuniform sampler2D u_material_specular_texture;\n#endif\n\n#ifdef TANGRAM_MATERIAL_NORMAL_TEXTURE\nuniform sampler2D u_material_normal_texture;\n#endif\n\n// Global light accumulators for each property\nvec4 light_accumulator_ambient = vec4(vec3(0.0), 1.);\nvec4 light_accumulator_diffuse = vec4(vec3(0.0), 1.);\n#ifdef TANGRAM_MATERIAL_SPECULAR\n    vec4 light_accumulator_specular = vec4(vec3(0.0), 1.);\n#endif\n\n\n#ifdef TANGRAM_MATERIAL_TEXTURE_SPHEREMAP\nvec4 getSphereMap (in sampler2D _tex, in vec3 _eyeToPoint, in vec3 _normal, in vec2 _skew) {\n    // Normalized vector from camera to surface\n    vec3 eye = normalize(_eyeToPoint);\n\n    // Adjust for camera skew\n    eye.xy -= _skew;\n    eye = normalize(eye);\n\n    // Reflection of eye off of surface normal\n    vec3 r = reflect(eye, _normal);\n\n    // Map reflected vector onto the surface of a sphere\n    r.z += 1.0;\n    float m = 2. * length(r);\n\n    // Adjust xy to account for spherical shape, and center in middle of texture\n    vec2 uv = r.xy / m + .5;\n\n    // Sample the environment map\n    return texture2D(_tex, uv);\n}\n#endif\n\n\n#ifdef TANGRAM_MATERIAL_TEXTURE_TRIPLANAR\nvec3 getTriPlanarBlend (in vec3 _normal) {\n    vec3 blending = abs(_normal);\n    blending = normalize(max(blending, 0.00001));\n    float b = (blending.x + blending.y + blending.z);\n    return blending / b;\n}\n\nvec4 getTriPlanar (in sampler2D _tex, in vec3 _pos, in vec3 _normal, in vec3 _scale) {\n    vec3 blending = getTriPlanarBlend(_normal);\n    vec4 xaxis = texture2D(_tex, fract(_pos.yz * _scale.x));\n    vec4 yaxis = texture2D(_tex, fract(_pos.xz * _scale.y));\n    vec4 zaxis = texture2D(_tex, fract(_pos.xy * _scale.z));\n    return  xaxis * blending.x + yaxis * blending.y + zaxis * blending.z;\n}\n#endif\n\n\n#ifdef TANGRAM_MATERIAL_TEXTURE_PLANAR\nvec4 getPlanar (in sampler2D _tex, in vec3 _pos, in vec2 _scale) {\n    return texture2D( _tex, fract(_pos.xy * _scale.x) );\n}\n#endif\n\n\n#ifdef TANGRAM_MATERIAL_NORMAL_TEXTURE\nvoid calculateNormal (inout vec3 _normal) {\n    // Get NORMALMAP\n    //------------------------------------------------\n    #ifdef TANGRAM_MATERIAL_NORMAL_TEXTURE_UV\n    _normal += texture2D(u_material_normal_texture, fract(v_texcoord*material.normalScale.xy)).rgb*2.0-1.0;\n    #endif\n\n    #ifdef TANGRAM_MATERIAL_NORMAL_TEXTURE_PLANAR\n    vec3 normalTex = getPlanar(u_material_normal_texture, v_world_position.xyz, material.normalScale.xy).rgb*2.0-1.0;\n    _normal += normalTex;\n    #endif\n\n    #ifdef TANGRAM_MATERIAL_NORMAL_TEXTURE_TRIPLANAR\n    vec3 normalTex = getTriPlanar(u_material_normal_texture, v_world_position.xyz, _normal, material.normalScale).rgb*2.0-1.0;\n    _normal += normalTex;\n    #endif\n\n    _normal = normalize(_normal);\n}\n#endif\n\nvoid calculateMaterial (in vec3 _eyeToPoint, inout vec3 _normal) {\n    // get EMISSION TEXTUREMAP\n    //------------------------------------------------\n    #ifdef TANGRAM_MATERIAL_EMISSION_TEXTURE\n        #ifdef TANGRAM_MATERIAL_EMISSION_TEXTURE_UV\n        material.emission *= texture2D(u_material_emission_texture,v_texcoord);\n        #endif\n\n        #ifdef TANGRAM_MATERIAL_EMISSION_TEXTURE_PLANAR\n        material.emission *= getPlanar(u_material_emission_texture, v_world_position.xyz, material.emissionScale.xy);\n        #endif\n\n        #ifdef TANGRAM_MATERIAL_EMISSION_TEXTURE_TRIPLANAR\n        material.emission *= getTriPlanar(u_material_emission_texture, v_world_position.xyz, _normal, material.emissionScale);\n        #endif\n\n        #ifdef TANGRAM_MATERIAL_EMISSION_TEXTURE_SPHEREMAP\n        material.emission *= getSphereMap(u_material_emission_texture, _eyeToPoint, _normal, u_vanishing_point);\n        #endif\n    #endif\n\n    // get AMBIENT TEXTUREMAP\n    //------------------------------------------------\n    #ifdef TANGRAM_MATERIAL_AMBIENT_TEXTURE\n        #ifdef TANGRAM_MATERIAL_AMBIENT_TEXTURE_UV\n        material.ambient *= texture2D(u_material_ambient_texture,v_texcoord);\n        #endif\n\n        #ifdef TANGRAM_MATERIAL_AMBIENT_TEXTURE_PLANAR\n        material.ambient *= getPlanar(u_material_ambient_texture, v_world_position.xyz, material.ambientScale.xy);\n        #endif\n\n        #ifdef TANGRAM_MATERIAL_AMBIENT_TEXTURE_TRIPLANAR\n        material.ambient *= getTriPlanar(u_material_ambient_texture, v_world_position.xyz, _normal, material.ambientScale);\n        #endif\n\n        #ifdef TANGRAM_MATERIAL_AMBIENT_TEXTURE_SPHEREMAP\n        material.ambient *= getSphereMap(u_material_ambient_texture, _eyeToPoint, _normal, u_vanishing_point);\n        #endif\n    #endif\n\n    // get DIFFUSE TEXTUREMAP\n    //------------------------------------------------\n    #ifdef TANGRAM_MATERIAL_DIFFUSE_TEXTURE\n        #ifdef TANGRAM_MATERIAL_DIFFUSE_TEXTURE_UV\n        material.diffuse *= texture2D(u_material_diffuse_texture,v_texcoord);\n        #endif\n\n        #ifdef TANGRAM_MATERIAL_DIFFUSE_TEXTURE_PLANAR\n        material.diffuse *= getPlanar(u_material_diffuse_texture, v_world_position.xyz, material.diffuseScale.xy);\n        #endif\n\n        #ifdef TANGRAM_MATERIAL_DIFFUSE_TEXTURE_TRIPLANAR\n        material.diffuse *= getTriPlanar(u_material_diffuse_texture, v_world_position.xyz, _normal, material.diffuseScale);\n        #endif\n\n        #ifdef TANGRAM_MATERIAL_DIFFUSE_TEXTURE_SPHEREMAP\n        material.diffuse *= getSphereMap(u_material_diffuse_texture, _eyeToPoint, _normal, u_vanishing_point);\n        #endif\n    #endif\n\n    // get SPECULAR TEXTUREMAP\n    //------------------------------------------------\n    #ifdef TANGRAM_MATERIAL_SPECULAR_TEXTURE\n        #ifdef TANGRAM_MATERIAL_SPECULAR_TEXTURE_UV\n        material.specular *= texture2D(u_material_specular_texture,v_texcoord);\n        #endif\n\n        #ifdef TANGRAM_MATERIAL_SPECULAR_TEXTURE_PLANAR\n        material.specular *= getPlanar(u_material_specular_texture, v_world_position.xyz, material.specularScale.xy);\n        #endif\n\n        #ifdef TANGRAM_MATERIAL_SPECULAR_TEXTURE_TRIPLANAR\n        material.specular *= getTriPlanar(u_material_specular_texture, v_world_position.xyz, _normal, material.specularScale);\n        #endif\n\n        #ifdef TANGRAM_MATERIAL_SPECULAR_TEXTURE_SPHEREMAP\n        material.specular *= getSphereMap(u_material_specular_texture, _eyeToPoint, _normal, u_vanishing_point);\n        #endif\n    #endif\n}\n";const le=["emission","ambient","diffuse","specular"];class ue{constructor(e){e=e||{},le.forEach(t=>{const i=e[t];null!=i&&(i.texture?this[t]={texture:i.texture,mapping:i.mapping||"spheremap",scale:E.expandVec3(null!=i.scale?i.scale:1),amount:E.expandVec4(null!=i.amount?i.amount:1)}:"number"==typeof i||Array.isArray(i)?this[t]={amount:E.expandVec4(i)}:this[t]="string"==typeof i?{amount:q.parseColor(i)}:i);}),this.specular&&(this.specular.shininess=e.shininess?parseFloat(e.shininess):.2),null!=e.normal&&(this.normal={texture:e.normal.texture,mapping:e.normal.mapping||"triplanar",scale:E.expandVec3(null!=e.normal.scale?e.normal.scale:1),amount:null!=e.normal.amount?e.normal.amount:1});}static isValid(e){return null!=e&&(null!=e.emission||null!=e.ambient||null!=e.diffuse||null!=e.specular)}inject(e){le.forEach(t=>{let i=`TANGRAM_MATERIAL_${t.toUpperCase()}`,r=i+"_TEXTURE";e.defines[i]=null!=this[t],this[t]&&this[t].texture&&(e.defines[r]=!0,e.defines[r+"_"+this[t].mapping.toUpperCase()]=!0,e.defines[`TANGRAM_MATERIAL_TEXTURE_${this[t].mapping.toUpperCase()}`]=!0,e.texcoords=e.texcoords||"uv"===this[t].mapping);}),this.normal&&this.normal.texture&&(e.defines.TANGRAM_MATERIAL_NORMAL_TEXTURE=!0,e.defines["TANGRAM_MATERIAL_NORMAL_TEXTURE_"+this.normal.mapping.toUpperCase()]=!0,e.defines[`TANGRAM_MATERIAL_TEXTURE_${this.normal.mapping.toUpperCase()}`]=!0,e.texcoords=e.texcoords||"uv"===this.normal.mapping),e.replaceShaderBlock(ue.block,ae,"Material"),e.addShaderBlock("setup","\nmaterial = u_material;\n","Material");}setupProgram(e){le.forEach(t=>{this[t]&&(this[t].texture?(e.setTextureUniform(`u_material_${t}_texture`,this[t].texture),e.uniform("3fv",`u_material.${t}Scale`,this[t].scale),e.uniform("4fv",`u_material.${t}`,this[t].amount)):this[t].amount&&e.uniform("4fv",`u_material.${t}`,this[t].amount));}),this.specular&&e.uniform("1f","u_material.shininess",this.specular.shininess),this.normal&&this.normal.texture&&(e.setTextureUniform("u_material_normal_texture",this.normal.texture),e.uniform("3fv","u_material.normalScale",this.normal.scale),e.uniform("1f","u_material.normalAmount",this.normal.amount));}}var he;ue.block="material";var ce=he={};he.copy=function(e){for(var t=[],i=e.length,r=0;r<i;r++)t[r]=e[r];return t},he.neg=function(e){for(var t=[],i=e.length,r=0;r<i;r++)t[r]=-e[r];return t},he.add=function(e,t){for(var i=[],r=Math.min(e.length,t.length),s=0;s<r;s++)i[s]=e[s]+t[s];return i},he.sub=function(e,t){for(var i=[],r=Math.min(e.length,t.length),s=0;s<r;s++)i[s]=e[s]-t[s];return i},he.signed_area=function(e,t,i){return (t[0]-e[0])*(i[1]-e[1])-(i[0]-e[0])*(t[1]-e[1])},he.mult=function(e,t){var i,r=[],s=e.length;if("number"==typeof t)for(i=0;i<s;i++)r[i]=e[i]*t;else for(s=Math.min(e.length,t.length),i=0;i<s;i++)r[i]=e[i]*t[i];return r},he.div=function(e,t){var i,r=[];if("number"==typeof t)for(i=0;i<e.length;i++)r[i]=e[i]/t;else {var s=Math.min(e.length,t.length);for(i=0;i<s;i++)r[i]=e[i]/t[i];}return r},he.perp=function(e,t){return [t[1]-e[1],e[0]-t[0]]},he.rot=function(e,t){var i=Math.cos(t),r=Math.sin(t);return [e[0]*i-e[1]*r,e[0]*r+e[1]*i]},he.angle=function([e,t]){return Math.atan2(t,e)},he.angleBetween=function(e,t){var i=he.dot(he.normalize(he.copy(e)),he.normalize(he.copy(t)));return i>1&&(i=1),Math.acos(i)},he.isEqual=function(e,t){for(var i=e.length,r=0;r<i;r++)if(e[r]!==t[r])return !1;return !0},he.lengthSq=function(e){return 2===e.length?e[0]*e[0]+e[1]*e[1]:e.length>=3?e[0]*e[0]+e[1]*e[1]+e[2]*e[2]:0},he.length=function(e){return Math.sqrt(he.lengthSq(e))},he.normalize=function(e){var t;if(2===e.length){if(1===(t=e[0]*e[0]+e[1]*e[1]))return e;0!==(t=Math.sqrt(t))?(e[0]/=t,e[1]/=t):(e[0]=0,e[1]=0);}else if(e.length>=3){if(1===(t=e[0]*e[0]+e[1]*e[1]+e[2]*e[2]))return e;0!==(t=Math.sqrt(t))?(e[0]/=t,e[1]/=t,e[2]/=t):(e[0]=0,e[1]=0,e[2]=0);}return e},he.cross=function(e,t){return 2===e.length?e[0]*t[1]-e[1]*t[0]:3===e.length?[e[1]*t[2]-e[2]*t[1],e[2]*t[0]-e[0]*t[2],e[0]*t[1]-e[1]*t[0]]:void 0},he.dot=function(e,t){for(var i=0,r=Math.min(e.length,t.length),s=0;s<r;s++)i+=e[s]*t[s];return i};var de="/*\n\nExpected globals:\nlight_accumulator_*\n\n*/\n\nstruct AmbientLight {\n    vec3 ambient;\n};\n\nvoid calculateLight(in AmbientLight _light, in vec3 _eyeToPoint, in vec3 _normal) {\n    light_accumulator_ambient.rgb += _light.ambient;\n}\n",fe="/*\n\nExpected globals:\nmaterial\nlight_accumulator_*\n\n*/\n\nstruct DirectionalLight {\n    vec3 ambient;\n    vec3 diffuse;\n    vec3 specular;\n    vec3 direction;\n};\n\nvoid calculateLight(in DirectionalLight _light, in vec3 _eyeToPoint, in vec3 _normal) {\n\n    light_accumulator_ambient.rgb += _light.ambient;\n\n    float nDotVP = clamp(dot(_normal, -_light.direction), 0.0, 1.0);\n\n    #ifdef TANGRAM_MATERIAL_DIFFUSE\n        light_accumulator_diffuse.rgb += _light.diffuse * nDotVP;\n    #endif\n\n    #ifdef TANGRAM_MATERIAL_SPECULAR\n        float pf = 0.0;\n        if (nDotVP > 0.0) {\n            vec3 reflectVector = reflect(_light.direction, _normal);\n            float eyeDotR = max(dot(normalize(_eyeToPoint), reflectVector), 0.0);\n            pf = pow(eyeDotR, material.shininess);\n        }\n        light_accumulator_specular.rgb += _light.specular * pf;\n    #endif\n}\n",_e="/*\n\nExpected globals:\nmaterial\nlight_accumulator_*\n\n*/\n\nstruct PointLight {\n    vec3 ambient;\n    vec3 diffuse;\n    vec3 specular;\n    vec4 position;\n\n#ifdef TANGRAM_POINTLIGHT_ATTENUATION_EXPONENT\n    float attenuationExponent;\n#endif\n\n#ifdef TANGRAM_POINTLIGHT_ATTENUATION_INNER_RADIUS\n    float innerRadius;\n#endif\n\n#ifdef TANGRAM_POINTLIGHT_ATTENUATION_OUTER_RADIUS\n    float outerRadius;\n#endif\n};\n\nvoid calculateLight(in PointLight _light, in vec3 _eyeToPoint, in vec3 _normal) {\n\n    float dist = length(_light.position.xyz - _eyeToPoint);\n\n    // Compute vector from surface to light position\n    vec3 VP = (_light.position.xyz - _eyeToPoint) / dist;\n\n    // Normalize the vector from surface to light position\n    float nDotVP = clamp(dot(VP, _normal), 0.0, 1.0);\n\n    // Attenuation defaults\n    float attenuation = 1.0;\n    #ifdef TANGRAM_POINTLIGHT_ATTENUATION_EXPONENT\n        float Rin = 1.0;\n        float e = _light.attenuationExponent;\n\n        #ifdef TANGRAM_POINTLIGHT_ATTENUATION_INNER_RADIUS\n            Rin = _light.innerRadius;\n        #endif\n\n        #ifdef TANGRAM_POINTLIGHT_ATTENUATION_OUTER_RADIUS\n            float Rdiff = _light.outerRadius-Rin;\n            float d = clamp(max(0.0,dist-Rin)/Rdiff, 0.0, 1.0);\n            attenuation = 1.0-(pow(d,e));\n        #else\n            // If no outer is provide behaves like:\n            // https://imdoingitwrong.wordpress.com/2011/01/31/light-attenuation/\n            float d = max(0.0,dist-Rin)/Rin+1.0;\n            attenuation = clamp(1.0/(pow(d,e)), 0.0, 1.0);\n        #endif\n    #else\n        float Rin = 0.0;\n\n        #ifdef TANGRAM_POINTLIGHT_ATTENUATION_INNER_RADIUS\n            Rin = _light.innerRadius;\n            #ifdef TANGRAM_POINTLIGHT_ATTENUATION_OUTER_RADIUS\n                float Rdiff = _light.outerRadius-Rin;\n                float d = clamp(max(0.0,dist-Rin)/Rdiff, 0.0, 1.0);\n                attenuation = 1.0-d*d;\n            #else\n                // If no outer is provide behaves like:\n                // https://imdoingitwrong.wordpress.com/2011/01/31/light-attenuation/\n                float d = max(0.0,dist-Rin)/Rin+1.0;\n                attenuation = clamp(1.0/d, 0.0, 1.0);\n            #endif\n        #else\n            #ifdef TANGRAM_POINTLIGHT_ATTENUATION_OUTER_RADIUS\n                float d = clamp(dist/_light.outerRadius, 0.0, 1.0);\n                attenuation = 1.0-d*d;\n            #else\n                attenuation = 1.0;\n            #endif\n        #endif\n    #endif\n\n    // Computer accumulators\n    light_accumulator_ambient.rgb += _light.ambient * attenuation;\n\n    #ifdef TANGRAM_MATERIAL_DIFFUSE\n        light_accumulator_diffuse.rgb += _light.diffuse * nDotVP * attenuation;\n    #endif\n\n    #ifdef TANGRAM_MATERIAL_SPECULAR\n        float pf = 0.0; // power factor for shiny speculars\n        if (nDotVP > 0.0) {\n            vec3 reflectVector = reflect(-VP, _normal);\n            float eyeDotR = max(0.0, dot(-normalize(_eyeToPoint), reflectVector));\n            pf = pow(eyeDotR, material.shininess);\n        }\n\n        light_accumulator_specular.rgb += _light.specular * pf * attenuation;\n    #endif\n}\n",pe="/*\n\nExpected globals:\nmaterial\nlight_accumulator_*\n\n*/\n\nstruct SpotLight {\n    vec3 ambient;\n    vec3 diffuse;\n    vec3 specular;\n    vec4 position;\n\n#ifdef TANGRAM_POINTLIGHT_ATTENUATION_EXPONENT\n    float attenuationExponent;\n#endif\n\n#ifdef TANGRAM_POINTLIGHT_ATTENUATION_INNER_RADIUS\n    float innerRadius;\n#endif\n\n#ifdef TANGRAM_POINTLIGHT_ATTENUATION_OUTER_RADIUS\n    float outerRadius;\n#endif\n\n    vec3 direction;\n    float spotCosCutoff;\n    float spotExponent;\n};\n\nvoid calculateLight(in SpotLight _light, in vec3 _eyeToPoint, in vec3 _normal) {\n\n    float dist = length(_light.position.xyz - _eyeToPoint);\n\n    // Compute vector from surface to light position\n    vec3 VP = (_light.position.xyz - _eyeToPoint) / dist;\n\n    // normal . light direction\n    float nDotVP = clamp(dot(_normal, VP), 0.0, 1.0);\n\n    // Attenuation defaults\n    float attenuation = 1.0;\n    #ifdef TANGRAM_POINTLIGHT_ATTENUATION_EXPONENT\n        float Rin = 1.0;\n        float e = _light.attenuationExponent;\n\n        #ifdef TANGRAM_POINTLIGHT_ATTENUATION_INNER_RADIUS\n            Rin = _light.innerRadius;\n        #endif\n\n        #ifdef TANGRAM_POINTLIGHT_ATTENUATION_OUTER_RADIUS\n            float Rdiff = _light.outerRadius-Rin;\n            float d = clamp(max(0.0,dist-Rin)/Rdiff, 0.0, 1.0);\n            attenuation = 1.0-(pow(d,e));\n        #else\n            // If no outer is provide behaves like:\n            // https://imdoingitwrong.wordpress.com/2011/01/31/light-attenuation/\n            float d = max(0.0,dist-Rin)/Rin+1.0;\n            attenuation = clamp(1.0/(pow(d,e)), 0.0, 1.0);\n        #endif\n    #else\n        float Rin = 0.0;\n\n        #ifdef TANGRAM_POINTLIGHT_ATTENUATION_INNER_RADIUS\n            Rin = _light.innerRadius;\n            #ifdef TANGRAM_POINTLIGHT_ATTENUATION_OUTER_RADIUS\n                float Rdiff = _light.outerRadius-Rin;\n                float d = clamp(max(0.0,dist-Rin)/Rdiff, 0.0, 1.0);\n                attenuation = 1.0-d*d;\n            #else\n                // If no outer is provide behaves like:\n                // https://imdoingitwrong.wordpress.com/2011/01/31/light-attenuation/\n                float d = max(0.0,dist-Rin)/Rin+1.0;\n                attenuation = clamp(1.0/d, 0.0, 1.0);\n            #endif\n        #else\n            #ifdef TANGRAM_POINTLIGHT_ATTENUATION_OUTER_RADIUS\n                float d = clamp(dist/_light.outerRadius, 0.0, 1.0);\n                attenuation = 1.0-d*d;\n            #else\n                attenuation = 1.0;\n            #endif\n        #endif\n    #endif\n\n    // spotlight attenuation factor\n    float spotAttenuation = 0.0;\n\n    // See if point on surface is inside cone of illumination\n    float spotDot = clamp(dot(-VP, _light.direction), 0.0, 1.0);\n\n    if (spotDot >= _light.spotCosCutoff) {\n        spotAttenuation = pow(spotDot, _light.spotExponent);\n    }\n\n    light_accumulator_ambient.rgb += _light.ambient * attenuation * spotAttenuation;\n\n    #ifdef TANGRAM_MATERIAL_DIFFUSE\n        light_accumulator_diffuse.rgb += _light.diffuse * nDotVP * attenuation * spotAttenuation;\n    #endif\n\n    #ifdef TANGRAM_MATERIAL_SPECULAR\n        // Power factor for shiny speculars\n        float pf = 0.0;\n        if (nDotVP > 0.0) {\n            vec3 reflectVector = reflect(-VP, _normal);\n            float eyeDotR = max(dot(-normalize(_eyeToPoint), reflectVector), 0.0);\n            pf = pow(eyeDotR, material.shininess);\n        }\n        light_accumulator_specular.rgb += _light.specular * pf * attenuation * spotAttenuation;\n    #endif\n}\n";class me{constructor(e,t){this.name=t.name,this.view=e,null==t.ambient||"number"==typeof t.ambient?this.ambient=E.expandVec3(t.ambient||0):this.ambient=q.parseColor(t.ambient).slice(0,3),null==t.diffuse||"number"==typeof t.diffuse?this.diffuse=E.expandVec3(null!=t.diffuse?t.diffuse:1):this.diffuse=q.parseColor(t.diffuse).slice(0,3),null==t.specular||"number"==typeof t.specular?this.specular=E.expandVec3(t.specular||0):this.specular=q.parseColor(t.specular).slice(0,3);}static create(e,t){if(me.types[t.type])return new me.types[t.type](e,t)}static setMode(e,t){!0===e&&(e="fragment"),e=me.enabled&&(null!=e?e:"fragment"),t.defines.TANGRAM_LIGHTING_FRAGMENT="fragment"===e,t.defines.TANGRAM_LIGHTING_VERTEX="vertex"===e;}static inject(e){if(P.removeBlock(me.block),!me.enabled)return;let t="";if(e&&Object.keys(e).length>0){let i={};for(let t in e)i[e[t].type]=!0;for(let e in i)me.types[e].inject();for(let i in e)e[i].inject(),t+=`calculateLight(${i}, _eyeToPoint, _normal);\n`;}let i=`\n            vec4 calculateLighting(in vec3 _eyeToPoint, in vec3 _normal, in vec4 _color) {\n\n                // Do initial material calculations over normal, emission, ambient, diffuse and specular values\n                calculateMaterial(_eyeToPoint,_normal);\n\n                // Un roll the loop of individual ligths to calculate\n                ${t}\n\n                //  Final light intensity calculation\n                vec4 color = vec4(vec3(0.), _color.a); // start with vertex color alpha\n\n                #ifdef TANGRAM_MATERIAL_EMISSION\n                    color.rgb = material.emission.rgb;\n                    color.a *= material.emission.a;\n                #endif\n\n                #ifdef TANGRAM_MATERIAL_AMBIENT\n                    color.rgb += light_accumulator_ambient.rgb * _color.rgb * material.ambient.rgb;\n                    color.a *= material.ambient.a;\n                #else\n                    #ifdef TANGRAM_MATERIAL_DIFFUSE\n                        color.rgb += light_accumulator_ambient.rgb * _color.rgb * material.diffuse.rgb;\n                    #endif\n                #endif\n\n                #ifdef TANGRAM_MATERIAL_DIFFUSE\n                    color.rgb += light_accumulator_diffuse.rgb * _color.rgb * material.diffuse.rgb;\n                    color.a *= material.diffuse.a;\n                #endif\n\n                #ifdef TANGRAM_MATERIAL_SPECULAR\n                    color.rgb += light_accumulator_specular.rgb * material.specular.rgb;\n                    color.a *= material.specular.a;\n                #endif\n\n                // Clamp final color\n                color = clamp(color, 0.0, 1.0);\n\n                return color;\n            }`;P.addBlock(me.block,i);}inject(){let e=`\n            uniform ${this.struct_name} u_${this.name};\n            ${this.struct_name} ${this.name};\n            `,t=`\n            ${this.name} = u_${this.name};\n\n        `;P.addBlock(me.block,e),P.addBlock("setup",t);}update(){}setupProgram(e){e.uniform("3fv",`u_${this.name}.ambient`,this.ambient),e.uniform("3fv",`u_${this.name}.diffuse`,this.diffuse),e.uniform("3fv",`u_${this.name}.specular`,this.specular);}}me.types={},me.block="lighting",me.enabled=!0;me.types.ambient=class extends me{constructor(e,t){super(e,t),this.type="ambient",this.struct_name="AmbientLight";}static inject(){P.addBlock(me.block,de);}setupProgram(e){e.uniform("3fv",`u_${this.name}.ambient`,this.ambient);}};me.types.directional=class extends me{constructor(e,t){if(super(e,t),this.type="directional",this.struct_name="DirectionalLight",t.direction)this._direction=t.direction;else {let e=135,i=Math.sin(60*Math.PI/180);this._direction=[Math.cos(Math.PI*e/180)*i,Math.sin(Math.PI*e/180)*i,-.5],null==t.ambient&&(this.ambient=E.expandVec3(.5));}this.direction=this._direction.map(parseFloat);}get direction(){return this._direction}set direction(e){this._direction=ce.normalize(ce.copy(e));}static inject(){P.addBlock(me.block,fe);}setupProgram(e){super.setupProgram(e),e.uniform("3fv",`u_${this.name}.direction`,this.direction);}};class ge extends me{constructor(e,t){super(e,t),this.type="point",this.struct_name="PointLight",this.position=t.position||[0,0,"100px"],this.position_eye=[],this.origin=t.origin||"ground",this.attenuation=isNaN(parseFloat(t.attenuation))?0:parseFloat(t.attenuation),t.radius?Array.isArray(t.radius)&&2===t.radius.length?this.radius=t.radius:this.radius=[null,t.radius]:this.radius=null;}static inject(){P.addBlock(me.block,_e);}inject(){super.inject(),P.defines.TANGRAM_POINTLIGHT_ATTENUATION_EXPONENT=0!==this.attenuation,P.defines.TANGRAM_POINTLIGHT_ATTENUATION_INNER_RADIUS=null!=this.radius&&null!=this.radius[0],P.defines.TANGRAM_POINTLIGHT_ATTENUATION_OUTER_RADIUS=null!=this.radius;}update(){this.updateEyePosition();}updateEyePosition(){if("world"===this.origin){const e=F.latLngToMeters([...this.position]);this.position_eye[0]=e[0]-this.view.camera.position_meters[0],this.position_eye[1]=e[1]-this.view.camera.position_meters[1],this.position_eye[2]=q.convertUnits(this.position[2],{zoom:this.view.zoom,meters_per_pixel:F.metersPerPixel(this.view.zoom)}),this.position_eye[2]=this.position_eye[2]-this.view.camera.position_meters[2];}else "ground"!==this.origin&&"camera"!==this.origin||(this.position_eye=q.convertUnits(this.position,{zoom:this.view.zoom,meters_per_pixel:F.metersPerPixel(this.view.zoom)}),"ground"===this.origin&&(this.position_eye[2]=this.position_eye[2]-this.view.camera.position_meters[2]));this.position_eye[3]=1;}setupProgram(e){super.setupProgram(e),e.uniform("4fv",`u_${this.name}.position`,this.position_eye),P.defines.TANGRAM_POINTLIGHT_ATTENUATION_EXPONENT&&e.uniform("1f",`u_${this.name}.attenuationExponent`,this.attenuation),P.defines.TANGRAM_POINTLIGHT_ATTENUATION_INNER_RADIUS&&e.uniform("1f",`u_${this.name}.innerRadius`,q.convertUnits(this.radius[0],{zoom:this.view.zoom,meters_per_pixel:F.metersPerPixel(this.view.zoom)})),P.defines.TANGRAM_POINTLIGHT_ATTENUATION_OUTER_RADIUS&&e.uniform("1f",`u_${this.name}.outerRadius`,q.convertUnits(this.radius[1],{zoom:this.view.zoom,meters_per_pixel:F.metersPerPixel(this.view.zoom)}));}}me.types.point=ge;me.types.spotlight=class extends ge{constructor(e,t){super(e,t),this.type="spotlight",this.struct_name="SpotLight",this.direction=this._direction=(t.direction||[0,0,-1]).map(parseFloat),this.exponent=t.exponent?parseFloat(t.exponent):.2,this.angle=t.angle?parseFloat(t.angle):20;}get direction(){return this._direction}set direction(e){this._direction=ce.normalize(ce.copy(e));}static inject(){P.addBlock(me.block,pe);}setupProgram(e){super.setupProgram(e),e.uniform("3fv",`u_${this.name}.direction`,this.direction),e.uniform("1f",`u_${this.name}.spotCosCutoff`,Math.cos(3.14159*this.angle/180)),e.uniform("1f",`u_${this.name}.spotExponent`,this.exponent);}};class xe extends Error{constructor(e){super(),this.name="MethodNotImplemented",this.message="Method "+e+" must be implemented in subclass";}}class ye{constructor(e,t){if(this.validate(e),this.config=e,this.sources=t,this.id=e.id,this.name=e.name,this.pad_scale=e.pad_scale||1e-5,this.default_winding=null,this.rasters=[],Array.isArray(e.rasters)&&e.rasters.forEach(e=>{-1===this.rasters.indexOf(e)&&this.rasters.push(e);}),this.preprocess=e.preprocess,"function"==typeof this.preprocess&&this.preprocess.bind(this),this.transform=e.transform,"function"==typeof this.transform&&this.transform.bind(this),this.extra_data=e.extra_data,this.scripts=e.scripts,this.setZooms(e),this.zoom_offset=null!=e.zoom_offset?e.zoom_offset:0,this.zoom_offset<0){f({level:"warn",once:!0},`Data source '${this.name}' zoom_offset must not be negative – setting to 0.`),this.zoom_offset=0;}this.setTileSize(e.tile_size),this.min_display_zoom=Math.max(e.min_display_zoom||0,this.zooms[0]),this.max_display_zoom=null!=e.max_display_zoom?e.max_display_zoom:null;}static register(e,t){e&&t&&(ye.types[e]=t);}static create(e,t){if("function"==typeof ye.types[e.type]){const i=ye.types[e.type](e);if(i)return new i(e,t)}}static tileLayoutChanged(e,t){if(!e||!t)return !0;const i=["max_zoom","zooms","min_display_zoom","max_display_zoom","bounds","tile_size","zoom_offset"],r=T(e.config,i),s=T(t.config,i);return JSON.stringify(r)!==JSON.stringify(s)}static projectData(e){var t=+new Date;for(var i in e.layers)for(var r=e.layers[i].features.length,s=0;s<r;s++){var n=e.layers[i].features[s];F.transformGeometry(n.geometry,this.projectCoord);}void 0!==e.debug&&(e.debug.projection=+new Date-t);}static projectCoord(e){F.latLngToMeters(e);}static scaleData(e,{coords:{z:t},min:i}){let r=F.unitsPerMeter(t);for(var s in e.layers)for(var n=e.layers[s].features.length,o=0;o<n;o++){var a=e.layers[s].features[o];F.transformGeometry(a.geometry,e=>{e[0]=(e[0]-i.x)*r,e[1]=(e[1]-i.y)*r*-1;});}}load(e){return e.source_data={},e.source_data.layers={},e.pad_scale=this.pad_scale,e.rasters=[...this.rasters],this._load(e).then(e=>{for(let t in e.source_data.layers){let i=e.source_data.layers[t];i&&i.features&&i.features.forEach(e=>{F.transformGeometry(e.geometry,e=>{e[1]=-e[1],this.pad_scale&&(e[0]=Math.round(e[0]*(1+this.pad_scale)-F.tile_scale*this.pad_scale/2),e[1]=Math.round(e[1]*(1+this.pad_scale)-F.tile_scale*this.pad_scale/2));}),this.updateDefaultWinding(e.geometry);});}return e.default_winding=this.default_winding||"CCW",e})}_load(){throw new xe("_load")}copyTileData(e,t){return f("trace",`Copy tile data from ${e.key} to ${t.key}`),t.source_data={layers:e.source_data.layers},t.rasters=[...e.rasters],t.pad_scale=e.pad_scale,t.default_winding=e.default_winding,t}setZooms({max_zoom:e,zooms:t}){if(this.max_zoom=null!=e?e:F.default_source_max_zoom,Array.isArray(t))this.zooms=t,this.max_zoom=this.zooms[this.zooms.length-1];else {this.zooms=[];for(let e=0;e<=this.max_zoom;e++)this.zooms[e]=e;}}setTileSize(e){this.tile_size=e||256,("number"!=typeof this.tile_size||this.tile_size<256||!_.isPowerOf2(this.tile_size))&&(f({level:"warn",once:!0},`Data source '${this.name}': 'tile_size' parameter must be a number that is a power of 2 greater than or equal to 256, but was '${e}'`),this.tile_size=256),this.zoom_bias=Math.log2(this.tile_size)-8+this.zoom_offset;}updateDefaultWinding(e){return null==this.default_winding&&("Polygon"===e.type?this.default_winding=F.ringWinding(e.coordinates[0]):"MultiPolygon"===e.type&&(this.default_winding=F.ringWinding(e.coordinates[0][0]))),this.default_winding}includesTile(e,t){if(e.z<this.min_display_zoom||null!=this.max_display_zoom&&t>this.max_display_zoom)return !1;for(let t=0;t<this.rasters.length;t++){const i=this.rasters[t];if(this.sources[i]&&this.sources[i]!==this&&!this.sources[i].includesTile(e,e.z))return !1}return !0}validate(){}}ye.types={};let ve=0;class be extends ye{constructor(e,t){super(e,t),this.response_type="";let[i,r]=function(e,t){if(!t||0===Object.keys(t).length)return [e,[]];var i=e.indexOf("?"),r=e.indexOf("#"),s="";r>-1&&(s=e.slice(r),e=e.slice(0,r)),-1===i&&(i=e.length,e+="?"),i++;var n="",o=[];for(var a in t)""===v(a,e)?n+=`${a}=${t[a]}&`:o.push([a,t[a]]);return [e=e.slice(0,i)+n+e.slice(i)+s,o]}(e.url,e.url_params);this.url=i,r.forEach(([t,i])=>{f({level:"warn",once:!0},`Data source '${this.name}': parameter '${t}' already present in URL '${e.url}', `+`skipping value '${t}=${i}' specified in 'url_params'`);}),e.request_headers&&"object"==typeof e.request_headers&&(this.request_headers=e.request_headers);}_load(e){let t=this.formatURL(this.url,e),i=e.source_data;return i.url=t,e.debug=e.debug||{},e.debug.network=+new Date,new Promise(r=>{let s=ve+++"-"+t,n=_.io(t,6e4,this.response_type,"GET",this.request_headers,s);i.request_id=s,i.error=null,n.then(({body:t})=>{e.debug.response_size=t&&(t.length||t.byteLength),e.debug.network=+new Date-e.debug.network,e.debug.parsing=+new Date,null!=t&&"function"==typeof this.preprocess&&(t=this.preprocess(t)),(t=t instanceof Promise?t:Promise.resolve(t)).then(t=>{null!=t?this.parseSourceData(e,i,t):i.layers={},e.debug.parsing=+new Date-e.debug.parsing,r(e);});}).catch(t=>{i.error=t.stack,r(e);});})}validate(e){if("string"!=typeof e.url)throw Error("Network data source must provide a string `url` property")}formatURL(){throw new xe("formatURL")}parseSourceData(){throw new xe("parseSourceData")}}class Ae extends be{constructor(e,t){super(e,t),this.tiled=!0,this.bounds=this.parseBounds(e),this.builds_geometry_tiles=!1,this.tms=!0===e.tms,this.url&&this.url.search("{s}")>-1&&(Array.isArray(e.url_subdomains)&&e.url_subdomains.length>0?(this.url_subdomains=e.url_subdomains,this.next_url_subdomain=0):f({level:"warn",once:!0},`Data source '${this.name}': source URL includes '{s}' subdomain marker ('${this.url}'), but no subdomains `+"were specified in 'url_subdomains' parameter")),this.url&&this.url.search("{r}")>-1&&(Array.isArray(e.url_density_scales)&&e.url_density_scales.length>0?this.url_density_scales=e.url_density_scales:this.url_density_scales=[1,2]);}parseBounds(e){if(Array.isArray(e.bounds)&&4===e.bounds.length){const[t,i,r,s]=e.bounds;return {latlng:[...e.bounds],meters:{min:F.latLngToMeters([t,s]),max:F.latLngToMeters([r,i])},tiles:{min:{},max:{}}}}}checkBounds(e,t){if(t){e=F.wrapTile(e);let i=t.tiles.min[e.z];i||(i=t.tiles.min[e.z]=F.tileForMeters(t.meters.min,e.z));let r=t.tiles.max[e.z];if(r||(r=t.tiles.max[e.z]=F.tileForMeters(t.meters.max,e.z)),e.y<i.y||e.y>r.y)return !1;if(i.x<=r.x){if(e.x<i.x||e.x>r.x)return !1}else if(e.x>r.x&&e.x<i.x)return !1}return !0}includesTile(e,t){return !!super.includesTile(e,t)&&!!this.checkBounds(e,this.bounds)}formatURL(e,t){let i=F.wrapTile(t.coords,{x:!0});this.tms&&(i.y=Math.pow(2,i.z)-1-i.y);let r=e.replace("{x}",i.x).replace("{y}",i.y).replace("{z}",i.z).replace("{r}",this.getDensityModifier()).replace("{q}",this.toQuadKey(i));return null!=this.url_subdomains&&(r=r.replace("{s}",this.url_subdomains[this.next_url_subdomain]),this.next_url_subdomain=(this.next_url_subdomain+1)%this.url_subdomains.length),r}getDensityModifier(){if(this.url_density_scales){const e=_.device_pixel_ratio;let t=this.url_density_scales.filter(t=>e>=t).reverse()[0];if((t=null!=t?t:this.url_density_scales[0])>1)return `@${t}x`}return ""}toQuadKey({x:e,y:t,z:i}){let r="";for(let s=i;s>0;s--){let i=0,n=1<<s-1;0!=(e&n)&&i++,0!=(t&n)&&(i+=2),r+=i.toString();}return r}static urlHasTilePattern(e){return e&&(e.search("{x}")>-1&&e.search("{y}")>-1&&e.search("{z}")>-1||e.search("{q}")>-1)}}const Te={coord(e){return {x:e.x,y:e.y,z:e.z,key:this.coordKey(e)}},coordKey:({x:e,y:t,z:i})=>e+"/"+t+"/"+i,key(e,t,i){if(!(e.y<0||e.y>=1<<e.z||e.z<0))return [t.name,e.x,e.y,e.z,i].join("/")},normalizedKey(e,t,i){return this.key(this.normalizedCoord(e,t),t,i)},normalizedCoord(e,t){return t.zoom_bias&&(e=this.coordAtZoom(e,Math.max(e.z-t.zoom_bias,t.zooms[0]))),this.coordForTileZooms(e,t.zooms)},coordAtZoom({x:e,y:t,z:i},r){if(i!==(r=Math.max(0,r))){let s=Math.pow(2,i-r);e=Math.floor(e/s),t=Math.floor(t/s),i=r;}return this.coord({x:e,y:t,z:i})},coordForTileZooms({x:e,y:t,z:i},r){const s=this.findZoomInRange(i,r);return s!==i?this.coordAtZoom({x:e,y:t,z:i},s):this.coord({x:e,y:t,z:i})},findZoomInRange:(e,t)=>t.filter(t=>e>=t).reverse()[0]||t[0],isDescendant(e,t){if(t.z>e.z){let{x:i,y:r}=this.coordAtZoom(t,e.z);return e.x===i&&e.y===r}return !1},parent({coords:e,source:t,style_z:i}){if(i>0){i--;const r=Math.max(i-t.zoom_bias,t.zooms[0]),s=this.coordForTileZooms(this.coordAtZoom(e,r),t.zooms);return s.z>i?null:{key:this.key(s,t,i),coords:s,style_z:i,source:t}}},children({coords:e,source:t,style_z:i},r={}){i++;const s=this.coordForTileZooms(this.coordAtZoom(e,i-t.zoom_bias),t.zooms);if(s.z===e.z)return [{key:this.key(s,t,i),coords:s,style_z:i,source:t}];{const n=this.key(s,t,i);if(r[t.id]=r[t.id]||{},null==r[t.id][n]){const o=Math.pow(2,s.z-e.z),a=e.x*o,l=e.y*o;let u=[];for(let e=a;e<a+o;e++)for(let r=l;r<l+o;r++){let n=this.coord({x:e,y:r,z:s.z});u.push({key:this.key(n,t,i),coords:n,style_z:i,source:t});}r[t.id][n]=u;}return r[t.id][n]}}};class we extends Ae{constructor(e,t){super(e,t),-1===this.rasters.indexOf(this.name)&&this.rasters.unshift(this.name),this.filtering=e.filtering,this.textures={};}async load(e){e.source_data={},e.source_data.layers={},e.pad_scale=this.pad_scale,e.rasters=[...this.rasters];let t=F.tile_scale;return e.source_data.layers={_default:{type:"FeatureCollection",features:[{geometry:{type:"Polygon",coordinates:[[[0,0],[t,0],[t,-t],[0,-t],[0,0]]]},properties:{}}]}},e.default_winding="CW",e}async tileTexture(e){let t=this.adjustRasterTileZoom(e),i=t.key;if(!this.textures[i]){let e=this.formatURL(this.url,{coords:t});this.textures[i]={name:e,url:e,filtering:this.filtering,coords:t};}return this.textures[i]}adjustRasterTileZoom(e){let t=e.coords;const i=this.sources[e.source];if(i!==this){let r=this.zoom_bias-i.zoom_bias;r>0?t=Te.normalizedCoord(e.coords,{zoom_bias:r,zooms:this.zooms}):(r<0&&f({level:"warn",once:!0},`Raster source '${this.name}' supports higher zoom detail than source '${i.name}' `+`it's attached to. Downsampling this source ${-r} extra zoom levels to match.`),t=Te.coordForTileZooms(t,this.zooms));}return t}}class Ee extends we{constructor(e,t){super(e,t),this.load_image={},this.alpha=null!=e.alpha?Math.max(Math.min(e.alpha,1),0):null,this.mask_alpha=!0,this.preserve_tiles_within_zoom=0,this.max_display_density=e.max_display_density,Array.isArray(e.composite)?this.images=e.composite.map(e=>({url:e.url,bounds:this.parseBounds(e),alpha:null!=e.alpha?Math.max(Math.min(e.alpha,1),0):null})):this.images=[{url:this.url,bounds:this.bounds,alpha:this.alpha}];}async tileTexture(e,{blend:t,generation:i}){let r=this.adjustRasterTileZoom(e);const s="opaque"!==t,n=`raster-${this.name}-${r.key}-${s?"alpha":"opaque"}-${i}`;if(w.textures[n])return {name:n,coords:r,skip_create:!0};let o=_.device_pixel_ratio;this.max_display_density&&(o=Math.min(o,this.max_display_density)),o*=2;const a=document.createElement("canvas"),l=a.getContext("2d");a.width=this.tile_size*o,a.height=this.tile_size*o,l.imageSmoothingEnabled="nearest"!==this.filtering;const u=this.images.filter(t=>this.checkBounds(e.coords,t.bounds));return await Promise.all(u.map(t=>{const i=s?null!=t.alpha?t.alpha:this.alpha:1;return this.drawImage(t.url,t.bounds,i,e,o,l)})),{name:n,element:a,filtering:this.filtering,coords:r}}async drawImage(e,t,i,r,s,n){const o=z(e);this.load_image[o]=this.load_image[o]||this.loadImage(e);const a=await this.load_image[o],l=F.metersPerPixel(r.coords.z)/s/(this.tile_size/F.tile_size),u=(t.meters.min[0]-r.min.x)/l,h=-(t.meters.min[1]-r.min.y)/l,c=(t.meters.max[0]-t.meters.min[0])/l,d=-(t.meters.max[1]-t.meters.min[1])/l;n.globalAlpha=null!=i?i:1,n.drawImage(a,u,h,c,d);}loadImage(e){return new Promise(t=>{let i=new Image;i.onload=(()=>t(i)),i.onerror=(i=>{f("warn",`Raster source '${this.name}': failed to load url: '${e}'`,i),t(null);}),_.isSafari()&&"data:"===e.slice(0,5)||(i.crossOrigin="anonymous"),i.src=e;})}includesTile(e,t){return !!ye.prototype.includesTile.call(this,e,t)&&this.images.some(t=>this.checkBounds(e,t.bounds))}validate(e){let t="Raster data source must provide a string `url` parameter, or an array of `composite` raster ";t+="image objects that each have a `url` parameter";let i="Raster data source must provide a `bounds` parameter, or an array of `composite` raster ";i+="image objects that each have a `bounds` parameter";let r="Raster data source must have *either* a single image specified as `url` and `bounds `";if(r+="parameters, or an array of `composite` raster image objects, each with `url` and `bounds`.",Array.isArray(e.composite)){if(e.composite.some(e=>"string"!=typeof e.url))throw Error(t);if(e.composite.some(e=>!(Array.isArray(e.bounds)&&4===e.bounds.length)))throw Error(i);if(null!=e.url||null!=e.bounds)throw Error("Raster data source must have *either* a single image specified as `url` and `bounds `parameters, or an array of `composite` raster image objects, each with `url` and `bounds`.")}else {if("string"!=typeof e.url)throw Error(t);if(!Array.isArray(e.bounds)||4!==e.bounds.length)throw Error(i)}}}ye.register("Raster",e=>we.urlHasTilePattern(e.url)?we:Ee);var Re={init({generation:e,styles:t,sources:i={},introspection:r}={}){this.setGeneration(e),this.styles=t,this.sources=i,this.defines=Object.prototype.hasOwnProperty.call(this,"defines")&&this.defines||{},this.shaders=Object.prototype.hasOwnProperty.call(this,"shaders")&&this.shaders||{},this.introspection=r||!1,this.selection=this.selection||this.introspection||!1,this.compile_setup=!1,this.program=null,this.selection_program=null,this.feature_style={},this.vertex_template=[],this.tile_data={},this.stencil_proxy_tiles=!0,this.variants={},this.vertex_layouts={},this.defines.TANGRAM_WORLD_POSITION_WRAP=1e5,this.blend=this.blend||"opaque","opaque"!==this.blend?null==this.blend_order&&(this.blend_order=this.default_blend_orders[this.blend]):this.blend_order=this.default_blend_orders[this.blend],this.defines[`TANGRAM_BLEND_${this.blend.toUpperCase()}`]=!0,this.removeShaderBlock("setup"),this.material instanceof ue||(ue.isValid(this.material)||(this.material=q.defaults.material),this.material=new ue(this.material)),this.material.inject(this),me.setMode(this.lighting,this),this.setupRasters(),this.setupCustomAttributes(),this.initialized=!0;},destroy(){this.program&&(this.program.destroy(),this.program=null),this.selection_program&&(this.selection_program.destroy(),this.selection_program=null),n.removeTarget(this.main_thread_target),this.gl=null,this.initialized=!1;},reset(){},baseStyle(){return this.base||this.name},setGeneration(e){this.generation=e,this.main_thread_target=["Style",this.name,this.generation].join("_"),t.is_main&&n.addTarget(this.main_thread_target,this);},startData(e){this.tile_data[e.id]=this.tile_data[e.id]||{meshes:{},uniforms:{},textures:[]};},async endData(e){var t=this.tile_data[e.id];if(this.tile_data[e.id]=null,t&&Object.keys(t.meshes).length>0){for(let e in t.meshes){let i=t.meshes[e];0!==i.vertex_data.vertex_count?(i.vertex_data.end(),i.vertex_elements=i.vertex_data.element_buffer,i.vertex_data=i.vertex_data.vertex_buffer):delete t.meshes[e];}return this.buildRasterTextures(e,t)}return null},hasDataForTile(e){return null!=this.tile_data[e.id]},getTileMesh(e,t){const i=this.tile_data[e.id].meshes;if(null==i[t.key]){const e=this.vertexLayoutForMeshVariant(t);i[t.key]={variant:t,vertex_data:e.createVertexData()};}return i[t.key]},vertexLayoutForMeshVariant(){},meshVariantTypeForDraw(){},addFeature(e,t,i){let r=i.tile;if(r.generation!==this.generation)return;this.tile_data[r.id]||this.startData(r);let s=this.parseFeature(e,t,i);s&&this.buildGeometry(e.geometry,s,i)>0&&(e.generation=this.generation);},buildGeometry(e,t,i){let r;if("Polygon"===e.type?r=this.buildPolygons([e.coordinates],t,i):"MultiPolygon"===e.type?r=this.buildPolygons(e.coordinates,t,i):"LineString"===e.type?r=this.buildLines([e.coordinates],t,i):"MultiLineString"===e.type?r=this.buildLines(e.coordinates,t,i):"Point"===e.type?r=this.buildPoints([e.coordinates],t,i):"MultiPoint"===e.type&&(r=this.buildPoints(e.coordinates,t,i)),r>0&&m.layer_stats){let e=i.tile;e.debug.layers=e.debug.layers||{list:{},tree:{}};let t=e.debug.layers.list,s=e.debug.layers.tree,n={};i.layers.forEach(e=>{Me(t,e,1,r,{[this.name]:r},{[this.baseStyle()]:r});let i=s,o=n,a=e.split(":");for(let e=0;e<a.length;e++){let t=a[e];i[t]=i[t]||{features:0,geoms:0,styles:{},base:{}},null==o[t]&&(o[t]={},Me(i,t,1,r,{[this.name]:r},{[this.baseStyle()]:r})),e<a.length-1&&(i[t].layers=i[t].layers||{}),i=i[t].layers,o=o[t];}});}return r},parseFeature(e,t,i){try{var r=this.feature_style;if(r.order=this.parseOrder(t.order,i),null==r.order&&"overlay"!==this.blend){let e=`Layer '${t.layers.join(", ")}', draw group '${t.group}': `;return e+="'order' parameter is required unless blend mode is 'overlay'",null!=t.order&&(e+="; 'order' was set to a dynamic value (e.g. string tied to feature property, ",e+="or JS function), but evaluated to null for one or more features"),void f({level:"warn",once:!0},e)}if(!(r=this._parseFeature(e,t,i)))return;if(this.shaders.attributes){r.attributes=r.attributes||{};for(const e in this.shaders.attributes)r.attributes[e]=q.evalCachedProperty(t.attributes&&t.attributes[e],i),"number"!=typeof r.attributes[e]&&(r.attributes[e]=0);}return this.selection?r.interactive=q.evalProperty(t.interactive,i):r.interactive=!1,!0===r.interactive?r.selection_color=re.makeColor(e,i.tile,i):r.selection_color=re.defaultColor,r}catch(t){f("error","Style.parseFeature: style parsing error",e,r,t.stack);}},_parseFeature(){return this.feature_style},preprocess(e){if(!e.preprocessed){if(this.draw)for(let t in this.draw){let i=this.draw[t];"object"!=typeof i||Array.isArray(i)?null==e[t]&&(e[t]=i):e[t]=I({},i,e[t]);}if(this.selection?this.introspection&&(e.interactive=!0):e.interactive=!1,!(e=this._preprocess(e)))return;if(this.shaders.attributes){e.attributes=e.attributes||{};for(const t in this.shaders.attributes)e.attributes[t]=q.createPropertyCache(null!=e.attributes[t]?e.attributes[t]:0);}e.preprocessed=!0;}return e},_preprocess:e=>e,parseOrder:(e,t)=>"number"!=typeof e?q.calculateOrder(e,t):e,scaleOrder:e=>2*e,parseColor(e,t){return e?q.evalCachedColorProperty(e,t):this.shaders.blocks.color||this.shaders.blocks.filter?q.defaults.color:void 0},buildPolygons:()=>0,buildLines:()=>0,buildPoints:()=>0,setGL(e){this.gl=e,this.max_texture_size=w.getMaxTextureSize(this.gl);},makeMesh(e,t,r={}){let s=this.vertexLayoutForMeshVariant(r.variant);return m.wireframe?(t=function(e){const t=new Uint16Array(2*e.length);for(let i=0;i<e.length;i+=3)t.set([e[i],e[i+1],e[i+1],e[i+2],e[i+2],e[i]],2*i);return t}(t),new oe(this.gl,e,t,s,i({},r,{draw_mode:this.gl.LINES}))):new oe(this.gl,e,t,s,r)},render:e=>e.render(),getProgram(e="program"){this.compileSetup();const t=this[e];if(t&&!t.error){if(!t.compiled){f("debug",`Compiling style '${this.name}', program key '${e}'`);try{t.compile();}catch(t){throw f("error",`Style: error compiling program for style '${this.name}' (program key '${e}')`,this,t.stack,t.type,t.shader_errors),t}}return t}},compileSetup(){if(!this.compile_setup){if(!this.gl)throw new Error(`style.compile(): skipping for ${this.name} because no GL context`);var e=this.buildDefineList();if(this.selection){var t=Object.assign({},e);t.TANGRAM_FEATURE_SELECTION=!0;}var i=this.shaders&&this.shaders.blocks,r=this.shaders&&this.shaders.block_scopes,s=Object.assign({},this.shaders&&this.shaders.uniforms);for(let e in s)null==s[e]&&f({level:"warn",once:!0},`Style '${this.name}' has invalid uniform '${e}': uniform values must be non-null`);var n=this.shaders&&this.shaders.extensions;"string"==typeof n&&(n=[n]),this.program=new P(this.gl,this.vertex_shader_src,this.fragment_shader_src,{name:this.name,defines:e,uniforms:s,blocks:i,block_scopes:r,extensions:n}),this.selection?this.selection_program=new P(this.gl,this.vertex_shader_src,"// Fragment shader for feature selection passes\n// Renders in silhouette according to selection (picking) color, or black if none defined\n\n#ifdef TANGRAM_FEATURE_SELECTION\n    varying vec4 v_selection_color;\n#endif\n\nvoid main (void) {\n    #ifdef TANGRAM_FEATURE_SELECTION\n        gl_FragColor = v_selection_color;\n    #else\n        gl_FragColor = vec4(0., 0., 0., 1.);\n    #endif\n}\n",{name:this.name+" (selection)",defines:t,uniforms:s,blocks:i,block_scopes:r,extensions:n}):this.selection_program=null,this.compile_setup=!0;}},addShaderBlock(e,t,i=null){this.shaders.blocks=this.shaders.blocks||{},this.shaders.blocks[e]=this.shaders.blocks[e]||[],this.shaders.blocks[e].push(t),this.shaders.block_scopes=this.shaders.block_scopes||{},this.shaders.block_scopes[e]=this.shaders.block_scopes[e]||[],this.shaders.block_scopes[e].push(i);},removeShaderBlock(e){this.shaders.blocks&&(this.shaders.blocks[e]=null),this.shaders.block_scopes&&(this.shaders.block_scopes[e]=null);},replaceShaderBlock(e,t,i=null){this.removeShaderBlock(e),this.addShaderBlock(e,t,i);},buildDefineList(){var e={};if(null!=this.defines)for(var t in this.defines)e[t]=this.defines[t];if(null!=this.shaders&&null!=this.shaders.defines)for(t in this.shaders.defines)e[t]=this.shaders.defines[t];return e},hasRasters(){return ["color","normal","custom"].indexOf(this.raster)>-1},setupRasters(){if(!this.hasRasters())return;"color"===this.raster?this.defines.TANGRAM_RASTER_TEXTURE_COLOR=!0:"normal"===this.raster&&(this.defines.TANGRAM_RASTER_TEXTURE_NORMAL=!0);let e=Object.keys(this.sources).filter(e=>this.sources[e]instanceof we).length;if(this.defines.TANGRAM_NUM_RASTER_SOURCES=`${e}`,e>0){const t=Object.keys(this.sources).filter(e=>this.sources[e].mask_alpha).length;this.defines.TANGRAM_HAS_MASKED_RASTERS=t>0,this.defines.TANGRAM_ALL_MASKED_RASTERS=t===e,this.defines.TANGRAM_MODEL_POSITION_BASE_ZOOM_VARYING=!0,this.replaceShaderBlock("raster","// Uniforms defining raster textures and macros for accessing them\n\n#ifdef TANGRAM_FRAGMENT_SHADER\nuniform sampler2D u_rasters[TANGRAM_NUM_RASTER_SOURCES];    // raster tile texture samplers\nuniform vec2 u_raster_sizes[TANGRAM_NUM_RASTER_SOURCES];    // raster tile texture sizes (width/height in pixels)\nuniform vec3 u_raster_offsets[TANGRAM_NUM_RASTER_SOURCES];  // raster tile texture UV starting offset for tile\n\n// Raster sources can optionally mask by the alpha channel (render with only full or no alpha, based on a threshold),\n// which is used for handling transparency outside the raster image when rendering with opaque blending\n#if defined(TANGRAM_HAS_MASKED_RASTERS) && !defined(TANGRAM_ALL_MASKED_RASTERS) // only add uniform if we need it\nuniform bool u_raster_mask_alpha;\n#endif\n\n// Note: the raster accessors below are #defines rather than functions to\n// avoid issues with constant integer expressions for array indices\n\n// Adjusts UVs in model space to account for raster tile texture overzooming\n// (applies scale and offset adjustments)\n#define adjustRasterUV(raster_index, uv) \\\n    ((uv) * u_raster_offsets[raster_index].z + u_raster_offsets[raster_index].xy)\n\n// Returns the UVs of the current model position for a raster sampler\n#define currentRasterUV(raster_index) \\\n    (adjustRasterUV(raster_index, v_modelpos_base_zoom.xy))\n\n// Returns pixel location in raster tile texture at current model position\n#define currentRasterPixel(raster_index) \\\n    (currentRasterUV(raster_index) * rasterPixelSize(raster_index))\n\n// Samples a raster tile texture for the current model position\n#define sampleRaster(raster_index) \\\n    (texture2D(u_rasters[raster_index], currentRasterUV(raster_index)))\n\n// Samples a raster tile texture for a given pixel\n#define sampleRasterAtPixel(raster_index, pixel) \\\n    (texture2D(u_rasters[raster_index], (pixel) / rasterPixelSize(raster_index)))\n\n// Returns size of raster sampler in pixels\n#define rasterPixelSize(raster_index) \\\n    (u_raster_sizes[raster_index])\n\n#endif\n","Raster");}},async buildRasterTextures(e,t){if(!this.hasRasters())return t;if(0===e.rasters.length)return t;let i;try{i=await n.postMessage(`${this.main_thread_target}.loadTextures`,{coords:e.coords,source:e.source,rasters:e.rasters,min:e.min,max:e.max});}catch(e){return t}if(!i||i.length<1)return t;if(i.some(e=>!e.loaded))return null;t.uniforms.u_raster_mask_alpha=!0===this.sources[e.rasters[0]].mask_alpha;const r=t.uniforms.u_rasters=[],s=t.uniforms.u_raster_sizes=[],o=t.uniforms.u_raster_offsets=[];return i.forEach(i=>{const n=i.index;if(r[n]=i.name,t.textures.push(i.name),s[n]=[i.width,i.height],e.coords.z>i.coords.z){let t=e.coords.z-i.coords.z,r=Math.pow(2,t);o[n]=[(e.coords.x%r+r)%r/r,(r-1-e.coords.y%r)/r,1/r];}else o[n]=[0,0,1];}),t},async loadTextures(e){let t={},i={},r=[];e.rasters.map(e=>this.sources[e]).filter(e=>e).forEach((s,n)=>{s instanceof we&&r.push(s.tileTexture(e,this).then(e=>{t[e.name]=e,i[e.name]=n;}));}),await Promise.all(r),await w.createFromObject(this.gl,t);let s=await Promise.all(Object.keys(t).map(e=>w.textures[e]&&w.textures[e].load()).filter(e=>e));return s.forEach(e=>e.retain()),s.map(e=>({name:e.name,width:e.width,height:e.height,loaded:e.loaded,index:i[e.name],coords:t[e.name].coords}))},setupCustomAttributes(){if(this.shaders.attributes)for(const[e,t]of Object.entries(this.shaders.attributes))"float"===t.type&&(!1!==t.varying?(this.addShaderBlock("attributes",`\n                            #ifdef TANGRAM_VERTEX_SHADER\n                                attribute float a_${e};\n                                varying float v_${e};\n                                #define ${e} a_${e}\n                            #else\n                                varying float v_${e};\n                                #define ${e} v_${e}\n                            #endif\n                        `),this.addShaderBlock("setup",`#ifdef TANGRAM_VERTEX_SHADER\nv_${e} = a_${e};\n#endif`)):this.addShaderBlock("attributes",`\n                            #ifdef TANGRAM_VERTEX_SHADER\n                                attribute float a_${e};\n                                #define ${e} a_${e}\n                            #endif\n                        `));},addCustomAttributesToAttributeList(e){if(this.shaders.attributes)for(const[t,i]of Object.entries(this.shaders.attributes))"float"===i.type&&e.push({name:`a_${t}`,size:1,type:ne.FLOAT,normalized:!1});return e},addCustomAttributesToVertexTemplate(e,t){if(this.shaders.attributes)for(let i in this.shaders.attributes)this.vertex_template[t++]=null!=e.attributes[i]?e.attributes[i]:0;},setup(){this.setUniforms(),this.material.setupProgram(P.current);},setUniforms(){var e=P.current;e&&e.setUniforms(this.shaders&&this.shaders.uniforms,!0);},render_states:{opaque:{depth_test:!0,depth_write:!0},translucent:{depth_test:!0,depth_write:!0},add:{depth_test:!0,depth_write:!1},multiply:{depth_test:!0,depth_write:!1},inlay:{depth_test:!0,depth_write:!1},overlay:{depth_test:!1,depth_write:!1}},default_blend_orders:{opaque:Number.MIN_SAFE_INTEGER,add:1,multiply:2,inlay:3,translucent:4,overlay:5},getBlendOrderForDraw(e){return "opaque"!==this.blend&&null!=e.blend_order?e.blend_order:this.blend_order}};function Me(e,t,i,r,s,n){e[t]=e[t]||{features:0,geoms:0,styles:{},base:{}},e[t].features+=i,e[t].geoms+=r;for(let i in s)e[t].styles[i]=e[t].styles[i]||0,e[t].styles[i]+=s[i];for(let i in n)e[t].base[i]=e[t].base[i]||0,e[t].base[i]+=n[i];}let ze=Math.pow(2,16)-1,Ne=!1;class Se{constructor(){this.array=[],this.has_overflown=!1;}push(e){this.has_overflown&&!Ne||e>ze&&(this.has_overflown=!0,!Ne)||this.array.push(e);}end(){if(this.array.length){let t=(e=this.array,new(this.has_overflown&&Ne?Uint32Array:Uint16Array)(e));return this.array=[],this.has_overflown=!1,t}return !1;var e;}}Se.setElementIndexUint=function(e){Ne=e;};let ke={[ne.FLOAT]:Float32Array,[ne.BYTE]:Int8Array,[ne.UNSIGNED_BYTE]:Uint8Array,[ne.INT]:Int32Array,[ne.UNSIGNED_INT]:Uint32Array,[ne.SHORT]:Int16Array,[ne.UNSIGNED_SHORT]:Uint16Array};class Pe{constructor(e,{prealloc:t=500}={}){this.vertex_layout=e,this.vertex_elements=new Se,this.stride=this.vertex_layout.stride,Pe.array_pool.length>0?(this.vertex_buffer=Pe.array_pool.pop(),this.byte_length=this.vertex_buffer.byteLength,this.size=Math.floor(this.byte_length/this.stride),f("trace",`VertexData: reused buffer of bytes ${this.byte_length}, ${this.size} vertices`)):(this.size=t,this.byte_length=this.stride*this.size,this.vertex_buffer=new Uint8Array(this.byte_length)),this.offset=0,this.vertex_count=0,this.realloc_count=0,this.setBufferViews(),this.setAddVertexFunction();}setBufferViews(){this.views={},this.views[ne.UNSIGNED_BYTE]=this.vertex_buffer,this.vertex_layout.dynamic_attribs.forEach(e=>{if(null==this.views[e.type]){var t=ke[e.type];this.views[e.type]=new t(this.vertex_buffer.buffer);}});}checkBufferSize(){if(this.offset+this.stride>this.byte_length){this.size=Math.floor(1.5*this.size),this.size-=this.size%4,this.byte_length=this.stride*this.size;var e=new Uint8Array(this.byte_length);e.set(this.vertex_buffer),Pe.array_pool.push(this.vertex_buffer),this.vertex_buffer=e,this.setBufferViews(),this.realloc_count++;}}setAddVertexFunction(){this.vertexLayoutAddVertex=this.vertex_layout.getAddVertexFunction();}addVertex(e){this.checkBufferSize(),this.vertexLayoutAddVertex(e,this.views,this.offset),this.offset+=this.stride,this.vertex_count++;}end(){return this.vertex_buffer=this.vertex_buffer.subarray(0,this.offset),this.element_buffer=this.vertex_elements.end(),f("trace",`VertexData: ${this.size} vertices total, realloc count ${this.realloc_count}`),this}}Pe.array_pool=[];class Le{constructor(e){this.attribs=e,this.dynamic_attribs=this.attribs.filter(e=>null==e.static),this.static_attribs=this.attribs.filter(e=>null!=e.static),this.components=[],this.index={},this.offset={},this.stride=0;let t=0,i=0;for(let e=0;e<this.attribs.length;e++){let r=this.attribs[e];if(null==r.static){r.offset=this.stride,r.byte_size=r.size;let e=0;switch(r.type){case ne.FLOAT:case ne.INT:case ne.UNSIGNED_INT:r.byte_size*=4,e=2;break;case ne.SHORT:case ne.UNSIGNED_SHORT:r.byte_size*=2,e=1;}3&r.byte_size&&(r.byte_size+=4-(3&r.byte_size)),this.stride+=r.byte_size;let s=r.offset>>e;for(let t=0;t<r.size;t++)this.components.push({type:r.type,shift:e,offset:s++,index:i++});this.index[r.name]=t,t+=r.size,this.offset[r.name]=r.offset;}else r.static=Array.isArray(r.static)?r.static:[r.static],r.method=`vertexAttrib${r.static.length}fv`;}}enableDynamicAttributes(e,t){for(const t in Le.enabled_attribs)e.disableVertexAttribArray(t);Le.enabled_attribs={},this.dynamic_attribs.forEach(i=>{const r=t.attribute(i.name).location;-1!==r&&(e.enableVertexAttribArray(r),e.vertexAttribPointer(r,i.size,i.type,i.normalized,this.stride,i.offset),Le.enabled_attribs[r]=t);});}enableStaticAttributes(e,t){this.static_attribs.forEach(i=>{const r=t.attribute(i.name).location;-1!==r&&e[i.method]instanceof Function&&(e.enableVertexAttribArray(r),e[i.method](r,i.static),e.disableVertexAttribArray(r));});}createVertexData(){return new Pe(this)}getAddVertexFunction(){return null==this.addVertex&&this.createAddVertexFunction(),this.addVertex}createAddVertexFunction(){let e=z(JSON.stringify(this.attribs));if(null==Le.add_vertex_funcs[e]){let t,i=["var t, o;"],r=[...this.components];r.sort((e,t)=>e.type!==t.type?e.type-t.type:e.index-t.index);for(let e=0;e<r.length;e++){let s=r[e];t!==s.type&&(i.push(`t = vs[${s.type}];`),i.push(`o = off${s.shift?" >> "+s.shift:""};`),t=s.type),i.push(`t[o + ${s.offset}] = v[${s.index}];`);}i=i.join("\n");let s=new Function("v","vs","off",i);Le.add_vertex_funcs[e]=s;}this.addVertex=Le.add_vertex_funcs[e];}}Le.enabled_attribs={},Le.add_vertex_funcs={};const Oe=[{x:0,y:0},{x:F.tile_scale,y:-F.tile_scale}],Ie=[0,0,1,1];function Fe(e,t,i){let r=Oe[0],s=Oe[1];return e[0]<=r.x+i&&t[0]<=r.x+i||e[0]>=s.x-i&&t[0]>=s.x-i||e[1]>=r.y-i&&t[1]>=r.y-i||e[1]<=s.y+i&&t[1]<=s.y+i}function Ue(e,t){t=t||0;let i=Oe[0],r=Oe[1];return e[0]<=i.x+t||e[0]>=r.x-t||e[1]>=i.y-t||e[1]<=r.y+t}var De=Ce,Ge=Ce;function Ce(e,t,i){i=i||2;var r,s,n,o,a,l,u,h=t&&t.length,c=h?t[0]*i:e.length,d=je(e,0,c,i,!0),f=[];if(!d||d.next===d.prev)return f;if(h&&(d=function(e,t,i,r){var s,n,o,a,l,u=[];for(s=0,n=t.length;s<n;s++)o=t[s]*r,a=s<n-1?t[s+1]*r:e.length,(l=je(e,o,a,r,!1))===l.next&&(l.steiner=!0),u.push(Ke(l));for(u.sort(We),s=0;s<u.length;s++)Ye(u[s],i),i=$e(i,i.next);return i}(e,t,d,i)),e.length>80*i){r=n=e[0],s=o=e[1];for(var _=i;_<c;_+=i)(a=e[_])<r&&(r=a),(l=e[_+1])<s&&(s=l),a>n&&(n=a),l>o&&(o=l);u=0!==(u=Math.max(n-r,o-s))?1/u:0;}return Ve(d,f,i,r,s,u),f}function je(e,t,i,r,s){var n,o;if(s===ct(e,t,i,r)>0)for(n=t;n<i;n+=r)o=lt(n,e[n],e[n+1],o);else for(n=i-r;n>=t;n-=r)o=lt(n,e[n],e[n+1],o);return o&&it(o,o.next)&&(ut(o),o=o.next),o}function $e(e,t){if(!e)return e;t||(t=e);var i,r=e;do{if(i=!1,r.steiner||!it(r,r.next)&&0!==tt(r.prev,r,r.next))r=r.next;else {if(ut(r),(r=t=r.prev)===r.next)break;i=!0;}}while(i||r!==t);return t}function Ve(e,t,i,r,s,n,o){if(e){!o&&n&&function(e,t,i,r){var s=e;do{null===s.z&&(s.z=Je(s.x,s.y,t,i,r)),s.prevZ=s.prev,s.nextZ=s.next,s=s.next;}while(s!==e);s.prevZ.nextZ=null,s.prevZ=null,function(e){var t,i,r,s,n,o,a,l,u=1;do{for(i=e,e=null,n=null,o=0;i;){for(o++,r=i,a=0,t=0;t<u&&(a++,r=r.nextZ);t++);for(l=u;a>0||l>0&&r;)0!==a&&(0===l||!r||i.z<=r.z)?(s=i,i=i.nextZ,a--):(s=r,r=r.nextZ,l--),n?n.nextZ=s:e=s,s.prevZ=n,n=s;i=r;}n.nextZ=null,u*=2;}while(o>1)}(s);}(e,r,s,n);for(var a,l,u=e;e.prev!==e.next;)if(a=e.prev,l=e.next,n?qe(e,r,s,n):Be(e))t.push(a.i/i),t.push(e.i/i),t.push(l.i/i),ut(e),e=l.next,u=l.next;else if((e=l)===u){o?1===o?Ve(e=Xe($e(e),t,i),t,i,r,s,n,2):2===o&&He(e,t,i,r,s,n):Ve($e(e),t,i,r,s,n,1);break}}}function Be(e){var t=e.prev,i=e,r=e.next;if(tt(t,i,r)>=0)return !1;for(var s=e.next.next;s!==e.prev;){if(Qe(t.x,t.y,i.x,i.y,r.x,r.y,s.x,s.y)&&tt(s.prev,s,s.next)>=0)return !1;s=s.next;}return !0}function qe(e,t,i,r){var s=e.prev,n=e,o=e.next;if(tt(s,n,o)>=0)return !1;for(var a=s.x<n.x?s.x<o.x?s.x:o.x:n.x<o.x?n.x:o.x,l=s.y<n.y?s.y<o.y?s.y:o.y:n.y<o.y?n.y:o.y,u=s.x>n.x?s.x>o.x?s.x:o.x:n.x>o.x?n.x:o.x,h=s.y>n.y?s.y>o.y?s.y:o.y:n.y>o.y?n.y:o.y,c=Je(a,l,t,i,r),d=Je(u,h,t,i,r),f=e.prevZ,_=e.nextZ;f&&f.z>=c&&_&&_.z<=d;){if(f!==e.prev&&f!==e.next&&Qe(s.x,s.y,n.x,n.y,o.x,o.y,f.x,f.y)&&tt(f.prev,f,f.next)>=0)return !1;if(f=f.prevZ,_!==e.prev&&_!==e.next&&Qe(s.x,s.y,n.x,n.y,o.x,o.y,_.x,_.y)&&tt(_.prev,_,_.next)>=0)return !1;_=_.nextZ;}for(;f&&f.z>=c;){if(f!==e.prev&&f!==e.next&&Qe(s.x,s.y,n.x,n.y,o.x,o.y,f.x,f.y)&&tt(f.prev,f,f.next)>=0)return !1;f=f.prevZ;}for(;_&&_.z<=d;){if(_!==e.prev&&_!==e.next&&Qe(s.x,s.y,n.x,n.y,o.x,o.y,_.x,_.y)&&tt(_.prev,_,_.next)>=0)return !1;_=_.nextZ;}return !0}function Xe(e,t,i){var r=e;do{var s=r.prev,n=r.next.next;!it(s,n)&&rt(s,r,r.next,n)&&ot(s,n)&&ot(n,s)&&(t.push(s.i/i),t.push(r.i/i),t.push(n.i/i),ut(r),ut(r.next),r=e=n),r=r.next;}while(r!==e);return $e(r)}function He(e,t,i,r,s,n){var o=e;do{for(var a=o.next.next;a!==o.prev;){if(o.i!==a.i&&et(o,a)){var l=at(o,a);return o=$e(o,o.next),l=$e(l,l.next),Ve(o,t,i,r,s,n),void Ve(l,t,i,r,s,n)}a=a.next;}o=o.next;}while(o!==e)}function We(e,t){return e.x-t.x}function Ye(e,t){if(t=function(e,t){var i,r=t,s=e.x,n=e.y,o=-1/0;do{if(n<=r.y&&n>=r.next.y&&r.next.y!==r.y){var a=r.x+(n-r.y)*(r.next.x-r.x)/(r.next.y-r.y);if(a<=s&&a>o){if(o=a,a===s){if(n===r.y)return r;if(n===r.next.y)return r.next}i=r.x<r.next.x?r:r.next;}}r=r.next;}while(r!==t);if(!i)return null;if(s===o)return i;var l,u=i,h=i.x,c=i.y,d=1/0;r=i;do{s>=r.x&&r.x>=h&&s!==r.x&&Qe(n<c?s:o,n,h,c,n<c?o:s,n,r.x,r.y)&&(l=Math.abs(n-r.y)/(s-r.x),ot(r,e)&&(l<d||l===d&&(r.x>i.x||r.x===i.x&&Ze(i,r)))&&(i=r,d=l)),r=r.next;}while(r!==u);return i}(e,t)){var i=at(t,e);$e(t,t.next),$e(i,i.next);}}function Ze(e,t){return tt(e.prev,e,t.prev)<0&&tt(t.next,e,e.next)<0}function Je(e,t,i,r,s){return (e=1431655765&((e=858993459&((e=252645135&((e=16711935&((e=32767*(e-i)*s)|e<<8))|e<<4))|e<<2))|e<<1))|(t=1431655765&((t=858993459&((t=252645135&((t=16711935&((t=32767*(t-r)*s)|t<<8))|t<<4))|t<<2))|t<<1))<<1}function Ke(e){var t=e,i=e;do{(t.x<i.x||t.x===i.x&&t.y<i.y)&&(i=t),t=t.next;}while(t!==e);return i}function Qe(e,t,i,r,s,n,o,a){return (s-o)*(t-a)-(e-o)*(n-a)>=0&&(e-o)*(r-a)-(i-o)*(t-a)>=0&&(i-o)*(n-a)-(s-o)*(r-a)>=0}function et(e,t){return e.next.i!==t.i&&e.prev.i!==t.i&&!function(e,t){var i=e;do{if(i.i!==e.i&&i.next.i!==e.i&&i.i!==t.i&&i.next.i!==t.i&&rt(i,i.next,e,t))return !0;i=i.next;}while(i!==e);return !1}(e,t)&&(ot(e,t)&&ot(t,e)&&function(e,t){var i=e,r=!1,s=(e.x+t.x)/2,n=(e.y+t.y)/2;do{i.y>n!=i.next.y>n&&i.next.y!==i.y&&s<(i.next.x-i.x)*(n-i.y)/(i.next.y-i.y)+i.x&&(r=!r),i=i.next;}while(i!==e);return r}(e,t)&&(tt(e.prev,e,t.prev)||tt(e,t.prev,t))||it(e,t)&&tt(e.prev,e,e.next)>0&&tt(t.prev,t,t.next)>0)}function tt(e,t,i){return (t.y-e.y)*(i.x-t.x)-(t.x-e.x)*(i.y-t.y)}function it(e,t){return e.x===t.x&&e.y===t.y}function rt(e,t,i,r){var s=nt(tt(e,t,i)),n=nt(tt(e,t,r)),o=nt(tt(i,r,e)),a=nt(tt(i,r,t));return s!==n&&o!==a||(!(0!==s||!st(e,i,t))||(!(0!==n||!st(e,r,t))||(!(0!==o||!st(i,e,r))||!(0!==a||!st(i,t,r)))))}function st(e,t,i){return t.x<=Math.max(e.x,i.x)&&t.x>=Math.min(e.x,i.x)&&t.y<=Math.max(e.y,i.y)&&t.y>=Math.min(e.y,i.y)}function nt(e){return e>0?1:e<0?-1:0}function ot(e,t){return tt(e.prev,e,e.next)<0?tt(e,t,e.next)>=0&&tt(e,e.prev,t)>=0:tt(e,t,e.prev)<0||tt(e,e.next,t)<0}function at(e,t){var i=new ht(e.i,e.x,e.y),r=new ht(t.i,t.x,t.y),s=e.next,n=t.prev;return e.next=t,t.prev=e,i.next=s,s.prev=i,r.next=i,i.prev=r,n.next=r,r.prev=n,r}function lt(e,t,i,r){var s=new ht(e,t,i);return r?(s.next=r.next,s.prev=r,r.next.prev=s,r.next=s):(s.prev=s,s.next=s),s}function ut(e){e.next.prev=e.prev,e.prev.next=e.next,e.prevZ&&(e.prevZ.nextZ=e.nextZ),e.nextZ&&(e.nextZ.prevZ=e.prevZ);}function ht(e,t,i){this.i=e,this.x=t,this.y=i,this.prev=null,this.next=null,this.z=null,this.prevZ=null,this.nextZ=null,this.steiner=!1;}function ct(e,t,i,r){for(var s=0,n=t,o=i-r;n<i;n+=r)s+=(e[o]-e[n])*(e[n+1]+e[o+1]),o=n;return s}Ce.deviation=function(e,t,i,r){var s=t&&t.length,n=s?t[0]*i:e.length,o=Math.abs(ct(e,0,n,i));if(s)for(var a=0,l=t.length;a<l;a++){var u=t[a]*i,h=a<l-1?t[a+1]*i:e.length;o-=Math.abs(ct(e,u,h,i));}var c=0;for(a=0;a<r.length;a+=3){var d=r[a]*i,f=r[a+1]*i,_=r[a+2]*i;c+=Math.abs((e[d]-e[_])*(e[f+1]-e[d+1])-(e[d]-e[f])*(e[_+1]-e[d+1]));}return 0===o&&0===c?0:Math.abs((c-o)/o)},Ce.flatten=function(e){for(var t=e[0][0].length,i={vertices:[],holes:[],dimensions:t},r=0,s=0;s<e.length;s++){for(var n=0;n<e[s].length;n++)for(var o=0;o<t;o++)i.vertices.push(e[s][n][o]);s>0&&(r+=e[s-1].length,i.holes.push(r));}return i},De.default=Ge;const dt=[0,0,1];function ft(e,t,i,{texcoord_index:r,texcoord_scale:s,texcoord_normalize:n}){let o,a,l,u,h,c,d,f,_,p,m,g,x=t.vertex_elements,y=e.length,v=0;r&&(n=n||1,[o,a,l,u]=s||Ie);for(let s=0;s<y;s++){let y=e[s],A=t.vertex_count,T=(b=De.flatten(y),De(b.vertices,b.holes,b.dimensions)),w=T.length;if(w){r&&([h,c,d,f]=F.findBoundingBox(y),m=(l-o)/(_=d-h),g=(u-a)/(p=f-c));for(let e=0;e<y.length;e++){let s=y[e];for(let e=0;e<s.length;e++){let l=s[e];i[0]=l[0],i[1]=l[1],r&&(i[r+0]=((l[0]-h)*m+o)*n,i[r+1]=((l[1]-c)*g+a)*n),t.addVertex(i);}}for(let e=0;e<w;e++)x.push(A+T[e]);v+=w/3;}}var b;return v}var _t='uniform vec2 u_resolution;\nuniform float u_time;\nuniform vec3 u_map_position;\nuniform vec4 u_tile_origin;\nuniform float u_tile_proxy_order_offset;\nuniform float u_meters_per_pixel;\nuniform float u_device_pixel_ratio;\n\nuniform mat4 u_model;\nuniform mat4 u_modelView;\nuniform mat3 u_normalMatrix;\nuniform mat3 u_inverseNormalMatrix;\n\nattribute vec4 a_position;\nattribute vec4 a_color;\n\n// Optional normal attribute, otherwise default to up\n#ifdef TANGRAM_NORMAL_ATTRIBUTE\n    attribute vec3 a_normal;\n    #define TANGRAM_NORMAL a_normal\n#else\n    #define TANGRAM_NORMAL vec3(0., 0., 1.)\n#endif\n\n// Optional dynamic line extrusion\n#ifdef TANGRAM_EXTRUDE_LINES\n    attribute vec2 a_extrude; // extrusion direction in xy plane\n    attribute vec2 a_offset;  // offset direction in xy plane\n\n    // Polygon and line styles have slightly different VBO layouts, saving memory by optimizing vertex packing.\n    // All lines have a width scaling factor, but only some have a height (position.z) or offset.\n    // The vertex height is stored in different attributes to account for this.\n    attribute vec2 a_z_and_offset_scale; // stores vertex height in x, and offset scaling factor in y\n    #define TANGRAM_POSITION_Z a_z_and_offset_scale.x // vertex height is stored in separate line-specific attrib\n    #define TANGRAM_OFFSET_SCALING a_z_and_offset_scale.y // zoom scaling factor for line offset\n    #define TANGRAM_WIDTH_SCALING a_position.z // zoom scaling factor for line width (stored in position attrib)\n\n    uniform float u_v_scale_adjust; // scales texture UVs for line dash patterns w/fractional pixel width\n#else\n    #define TANGRAM_POSITION_Z a_position.z // vertex height\n#endif\n\nvarying vec4 v_position;\nvarying vec3 v_normal;\nvarying vec4 v_color;\nvarying vec4 v_world_position;\n\n// Optional texture UVs\n#if defined(TANGRAM_TEXTURE_COORDS) || defined(TANGRAM_EXTRUDE_LINES)\n    attribute vec2 a_texcoord;\n    varying vec2 v_texcoord;\n#endif\n\n// Optional model position varying for tile coordinate zoom\n#ifdef TANGRAM_MODEL_POSITION_BASE_ZOOM_VARYING\n    varying vec4 v_modelpos_base_zoom;\n#endif\n\n#if defined(TANGRAM_LIGHTING_VERTEX)\n    varying vec4 v_lighting;\n#endif\n\n#define TANGRAM_UNPACK_SCALING(x) (x / 1024.)\n\n#pragma tangram: attributes\n#pragma tangram: camera\n#pragma tangram: material\n#pragma tangram: lighting\n#pragma tangram: raster\n#pragma tangram: global\n\nvoid main() {\n    // Initialize globals\n    #pragma tangram: setup\n\n    // Texture UVs\n    #ifdef TANGRAM_TEXTURE_COORDS\n        v_texcoord = a_texcoord;\n        #ifdef TANGRAM_EXTRUDE_LINES\n            v_texcoord.y *= u_v_scale_adjust;\n        #endif\n    #endif\n\n    // Pass model position to fragment shader\n    #ifdef TANGRAM_MODEL_POSITION_BASE_ZOOM_VARYING\n        v_modelpos_base_zoom = modelPositionBaseZoom();\n    #endif\n\n    // Position\n    vec4 position = vec4(a_position.xy, TANGRAM_POSITION_Z / TANGRAM_HEIGHT_SCALE, 1.); // convert height back to meters\n\n    #ifdef TANGRAM_EXTRUDE_LINES\n        vec2 _extrude = a_extrude.xy;\n        vec2 _offset = a_offset.xy;\n\n        // Adjust line width based on zoom level, to prevent proxied lines\n        // from being either too small or too big.\n        // "Flattens" the zoom between 1-2 to peg it to 1 (keeps lines from\n        // prematurely shrinking), then interpolate and clamp to 4 (keeps lines\n        // from becoming too small when far away).\n        float _dz = clamp(u_map_position.z - u_tile_origin.z, 0., 4.);\n        _dz += step(1., _dz) * (1. - _dz) + mix(0., 2., clamp((_dz - 2.) / 2., 0., 1.));\n\n        // Interpolate line width between zooms\n        float _mdz = (_dz - 0.5) * 2.; // zoom from mid-point\n        _extrude -= _extrude * TANGRAM_UNPACK_SCALING(TANGRAM_WIDTH_SCALING) * _mdz;\n\n        // Interpolate line offset between zooms\n        // Scales from the larger value to the smaller one\n        float _dwdz = TANGRAM_UNPACK_SCALING(TANGRAM_OFFSET_SCALING);\n        float _sdwdz = sign(step(0., _dwdz) - 0.5); // sign indicates "direction" of scaling\n        _offset -= _offset * abs(_dwdz) * ((1.-step(0., _sdwdz)) - (_dz * -_sdwdz)); // scale "up" or "down"\n\n        // Scale line width and offset to be consistent in screen space\n        float _ssz = exp2(-_dz - (u_tile_origin.z - u_tile_origin.w));\n        _extrude *= _ssz;\n        _offset *= _ssz;\n\n        // Modify line width before extrusion\n        #ifdef TANGRAM_BLOCK_WIDTH\n            float width = 1.;\n            #pragma tangram: width\n            _extrude *= width;\n        #endif\n\n        position.xy += _extrude + _offset;\n    #endif\n\n    // World coordinates for 3d procedural textures\n    v_world_position = wrapWorldPosition(u_model * position);\n\n    // Adjust for tile and view position\n    position = u_modelView * position;\n\n    // Modify position before camera projection\n    #pragma tangram: position\n\n    // Setup varyings\n    v_position = position;\n    v_normal = normalize(u_normalMatrix * TANGRAM_NORMAL);\n    v_color = a_color;\n\n    #if defined(TANGRAM_LIGHTING_VERTEX)\n        // Vertex lighting\n        vec3 normal = v_normal;\n\n        // Modify normal before lighting\n        #pragma tangram: normal\n\n        // Pass lighting intensity to fragment shader\n        v_lighting = calculateLighting(position.xyz - u_eye, normal, vec4(1.));\n    #endif\n\n    // Camera\n    cameraProjection(position);\n\n    // +1 is to keep all layers including proxies > 0\n    applyLayerOrder(a_position.w + u_tile_proxy_order_offset + 1., position);\n\n    gl_Position = position;\n}\n',pt="uniform vec2 u_resolution;\nuniform float u_time;\nuniform vec3 u_map_position;\nuniform vec4 u_tile_origin;\nuniform float u_meters_per_pixel;\nuniform float u_device_pixel_ratio;\n\nuniform mat3 u_normalMatrix;\nuniform mat3 u_inverseNormalMatrix;\n\nvarying vec4 v_position;\nvarying vec3 v_normal;\nvarying vec4 v_color;\nvarying vec4 v_world_position;\n\n#ifdef TANGRAM_EXTRUDE_LINES\n    uniform bool u_has_line_texture;\n    uniform sampler2D u_texture;\n    uniform float u_texture_ratio;\n    uniform vec4 u_dash_background_color;\n    uniform float u_has_dash;\n#endif\n\n#define TANGRAM_NORMAL v_normal\n\n#if defined(TANGRAM_TEXTURE_COORDS) || defined(TANGRAM_EXTRUDE_LINES)\n    varying vec2 v_texcoord;\n#endif\n\n#ifdef TANGRAM_MODEL_POSITION_BASE_ZOOM_VARYING\n    varying vec4 v_modelpos_base_zoom;\n#endif\n\n#if defined(TANGRAM_LIGHTING_VERTEX)\n    varying vec4 v_lighting;\n#endif\n\n#pragma tangram: attributes\n#pragma tangram: camera\n#pragma tangram: material\n#pragma tangram: lighting\n#pragma tangram: raster\n#pragma tangram: global\n\nvoid main (void) {\n    // Initialize globals\n    #pragma tangram: setup\n\n    vec4 color = v_color;\n    vec3 normal = TANGRAM_NORMAL;\n\n    // Apply raster to vertex color\n    #ifdef TANGRAM_RASTER_TEXTURE_COLOR\n        vec4 _raster_color = sampleRaster(0);\n\n        #if defined(TANGRAM_BLEND_OPAQUE) || defined(TANGRAM_BLEND_TRANSLUCENT) || defined(TANGRAM_BLEND_MULTIPLY)\n            // Raster sources can optionally mask by the alpha channel, which will render with only full or no alpha.\n            // This is used for handling transparency outside the raster image in some blend modes,\n            // which either don't support alpha, or would cause transparent pixels to write to the depth buffer,\n            // obscuring geometry underneath.\n            #ifdef TANGRAM_HAS_MASKED_RASTERS   // skip masking logic if no masked raster sources\n            #ifndef TANGRAM_ALL_MASKED_RASTERS  // skip source check for masking if *all* raster sources are masked\n            if (u_raster_mask_alpha) {\n            #else\n            {\n            #endif\n                #if defined(TANGRAM_BLEND_TRANSLUCENT) || defined(TANGRAM_BLEND_MULTIPLY)\n                if (_raster_color.a < TANGRAM_EPSILON) {\n                    discard;\n                }\n                #else // TANGRAM_BLEND_OPAQUE\n                if (_raster_color.a < 1. - TANGRAM_EPSILON) {\n                    discard;\n                }\n                // only allow full alpha in opaque blend mode (avoids artifacts blending w/canvas tile background)\n                _raster_color.a = 1.;\n                #endif\n            }\n            #endif\n        #endif\n\n        color *= _raster_color; // multiplied to tint texture color\n    #endif\n\n    // Apply line texture\n    #ifdef TANGRAM_EXTRUDE_LINES\n    { // enclose in scope to avoid leakage of internal variables\n        if (u_has_line_texture) {\n            vec2 _line_st = vec2(v_texcoord.x, fract(v_texcoord.y / u_texture_ratio));\n            vec4 _line_color = texture2D(u_texture, _line_st);\n\n            // If the line has a dash pattern, the line texture indicates if the current fragment should be\n            // the dash foreground or background color. If the line doesn't have a dash pattern,\n            // the line texture color is used directly (but also tinted by the vertex color).\n            color = mix(\n                color * _line_color, // no dash: tint the line texture with the vertex color\n                mix(u_dash_background_color, color, _line_color.a), // choose dash foreground or background color\n                u_has_dash // 0 if no dash, 1 if has dash\n            );\n\n            // Use alpha discard test as a lower-quality substitute for blending\n            #if defined(TANGRAM_BLEND_OPAQUE)\n                if (color.a < TANGRAM_ALPHA_TEST) {\n                    discard;\n                }\n            #endif\n        }\n    }\n    #endif\n\n    // First, get normal from raster tile (if applicable)\n    #ifdef TANGRAM_RASTER_TEXTURE_NORMAL\n        normal = normalize(sampleRaster(0).rgb * 2. - 1.);\n    #endif\n\n    // Second, alter normal with normal map texture (if applicable)\n    #if defined(TANGRAM_LIGHTING_FRAGMENT) && defined(TANGRAM_MATERIAL_NORMAL_TEXTURE)\n        calculateNormal(normal);\n    #endif\n\n    // Normal modification applied here for fragment lighting or no lighting,\n    // and in vertex shader for vertex lighting\n    #if !defined(TANGRAM_LIGHTING_VERTEX)\n        #pragma tangram: normal\n    #endif\n\n    // Color modification before lighting is applied\n    #pragma tangram: color\n\n    #if defined(TANGRAM_LIGHTING_FRAGMENT)\n        // Calculate per-fragment lighting\n        color = calculateLighting(v_position.xyz - u_eye, normal, color);\n    #elif defined(TANGRAM_LIGHTING_VERTEX)\n        // Apply lighting intensity interpolated from vertex shader\n        color *= v_lighting;\n    #endif\n\n    // Post-processing effects (modify color after lighting)\n    #pragma tangram: filter\n\n    gl_FragColor = color;\n}\n";const mt=Object.create(Re);Object.assign(mt,{name:"polygons",built_in:!0,vertex_shader_src:_t,fragment_shader_src:pt,selection:!0,init(){Re.init.apply(this,arguments),this.defines.TANGRAM_NORMAL_ATTRIBUTE=!0,this.defines.TANGRAM_TEXTURE_COORDS=this.texcoords;},_parseFeature(e,t,i){var r=this.feature_style;return r.color=this.parseColor(t.color,i),r.color?(r.alpha=q.evalCachedProperty(t.alpha,i),r.variant=t.variant,r.z=q.evalCachedDistanceProperty(t.z,i)||q.defaults.z,r.z*=F.height_scale,r.extrude=q.evalProperty(t.extrude,i),r.extrude&&(!0===r.extrude?(r.height=e.properties.height||q.defaults.height,r.min_height=e.properties.min_height||q.defaults.min_height):"number"==typeof r.extrude?(r.height=r.extrude,r.min_height=0):Array.isArray(r.extrude)&&(r.min_height=r.extrude[0],r.height=r.extrude[1]),r.height*=F.height_scale,r.min_height*=F.height_scale),r.tile_edges=t.tile_edges,r):null},_preprocess(e){return e.color=q.createColorPropertyCache(e.color),e.alpha=q.createPropertyCache(e.alpha),e.z=q.createPropertyCache(e.z,q.parseUnits),this.computeVariant(e),e},computeVariant(e){const t=e.interactive?1:0,i=null!=e.extrude?1:0,r=this.texcoords?1:0,s=this.getBlendOrderForDraw(e),n=[t,i,r,s].join("/");e.variant=n,null==this.variants[n]&&(this.variants[n]={key:n,blend_order:s,mesh_order:0,selection:t,normal:i,texcoords:r});},vertexLayoutForMeshVariant(e){if(null==this.vertex_layouts[e.key]){const t=[{name:"a_position",size:4,type:ne.SHORT,normalized:!1},{name:"a_normal",size:3,type:ne.BYTE,normalized:!0,static:e.normal?null:[0,0,1]},{name:"a_color",size:4,type:ne.UNSIGNED_BYTE,normalized:!0},{name:"a_selection_color",size:4,type:ne.UNSIGNED_BYTE,normalized:!0,static:e.selection?null:[0,0,0,0]},{name:"a_texcoord",size:2,type:ne.UNSIGNED_SHORT,normalized:!0,static:e.texcoords?null:[0,0]}];this.addCustomAttributesToAttributeList(t),this.vertex_layouts[e.key]=new Le(t);}return this.vertex_layouts[e.key]},meshVariantTypeForDraw(e){return this.variants[e.variant]},makeVertexTemplate(e,t){let i=0;return this.vertex_template[i++]=0,this.vertex_template[i++]=0,this.vertex_template[i++]=e.z||0,this.vertex_template[i++]=this.scaleOrder(e.order),t.variant.normal&&(this.vertex_template[i++]=0,this.vertex_template[i++]=0,this.vertex_template[i++]=127),this.vertex_template[i++]=255*e.color[0],this.vertex_template[i++]=255*e.color[1],this.vertex_template[i++]=255*e.color[2],this.vertex_template[i++]=255*(null!=e.alpha?e.alpha:e.color[3]),t.variant.selection&&(this.vertex_template[i++]=255*e.selection_color[0],this.vertex_template[i++]=255*e.selection_color[1],this.vertex_template[i++]=255*e.selection_color[2],this.vertex_template[i++]=255*e.selection_color[3]),t.variant.texcoords&&(this.vertex_template[i++]=0,this.vertex_template[i++]=0),this.addCustomAttributesToVertexTemplate(e,i),this.vertex_template},buildPolygons(e,t,i){let r=this.getTileMesh(i.tile,this.meshVariantTypeForDraw(t)),s=r.vertex_data,n=s.vertex_layout,o=this.makeVertexTemplate(t,r),a={texcoord_index:n.index.a_texcoord,texcoord_normalize:65535,remove_tile_edges:!t.tile_edges,tile_edge_tolerance:F.tile_scale*i.tile.pad_scale*4,winding:i.winding};return t.extrude&&t.height?function(e,t,i,r,s,n,o,a,{remove_tile_edges:l,tile_edge_tolerance:u,texcoord_index:h,texcoord_scale:c,texcoord_normalize:d,winding:f}){var _=t+(r||0),p=t+i;n[2]=p;var m=ft(e,s,n,{texcoord_index:h,texcoord_scale:c,texcoord_normalize:d}),g=s.vertex_elements,x=s.vertex_count;if(h){d=d||1;var[y,v,b,A]=c||Ie,T=[[y,A],[y,v],[b,v],[b,A]];}for(var w=e.length,E=0;E<w;E++)for(var R=e[E],M=0;M<R.length;M++)for(var z=R[M],N=0;N<z.length-1;N++){if(l&&Fe(z[N],z[N+1],u))continue;let e,t;"CCW"===f?(e=N,t=N+1):(e=N+1,t=N);var S=[[z[t][0],z[t][1],p],[z[t][0],z[t][1],_],[z[e][0],z[e][1],_],[z[e][0],z[e][1],p]];let i=ce.normalize([z[t][0]-z[e][0],z[t][1]-z[e][1],0]),r=ce.cross(dt,i);n[o+0]=r[0]*a,n[o+1]=r[1]*a,n[o+2]=r[2]*a;for(var k=0;k<S.length;k++)n[0]=S[k][0],n[1]=S[k][1],n[2]=S[k][2],h&&(n[h+0]=T[k][0]*d,n[h+1]=T[k][1]*d),s.addVertex(n);g.push(x+0),g.push(x+1),g.push(x+2),g.push(x+2),g.push(x+3),g.push(x+0),x+=4,m+=2;}return m}(e,t.z,t.height,t.min_height,s,o,n.index.a_normal,127,a):ft(e,s,o,a)}});const gt=[0,0],xt={butt:0,square:1,round:2},yt={miter:0,bevel:1,round:2},vt=3,bt=5,At=65535,Tt=F.tile_scale,wt=[0,0],Et=[1,0],Rt=[.5,0];function Mt(e,t){if(!(e.length<2)){var i,r,s,n,{join_type:o,cap_type:a,closed_polygon:l,remove_tile_edges:u,tile_edge_tolerance:h,v_scale:c,miter_len_sq:d}=t,f=null!=t.texcoord_index,_=0;if(l&&o===yt.miter){var p=function(e){if(Ue(e[0]))return 0;for(var t=0;t<e.length;t++){var i=e[e.length-1-t];if(Ue(i))return e.length-1-t}return 0}(e);if(0!==p){var m=function(e,t){var i=[];for(let s=0;s<e.length;s++){var r=(s+t)%e.length;0!==r&&i.push(e[r]);}return i.push(i[0]),i}(e,p);return t.extra_lines=t.extra_lines||[],void t.extra_lines.push(m)}}var g=0,x=e.length-1,y=0;for(i=e[g],r=e[g+1];ce.isEqual(i,r);)if(i=r,r=e[++g+1],y++,g===e.length-1)return;for(;ce.isEqual(e[x],e[x-1]);)if(y++,0===--x)return;if(!(e.length<2+y))if(n=ce.normalize(ce.perp(i,r)),u&&Fe(i,r,h)){var v=zt(e,g,h);v&&(t.extra_lines=t.extra_lines||[],t.extra_lines.push(v));}else {l?function(e,t,i,r,s){if(void 0===r||Ue(e))Lt(e,i,i,1,0,s,1),Lt(e,i,i,0,0,s,-1);else {r===yt.miter?St(0,e,t,i,s.miter_len_sq,!0,s):kt(r,0,e,t,i,!0,s);}}(i,s=ce.normalize(ce.perp(e[x-1],i)),n,o,t):(Ue(i)||(Ft(i,_,n,a,!0,t),f&&a!==xt.butt&&(_+=.5*c*t.texcoord_width)),Lt(i,n,n,1,_,t,1),Lt(i,n,n,0,_,t,-1)),f&&(_+=c*ce.length(ce.sub(r,i)));for(var b=g+1;b<x;b++){var A=b,T=b+1;if(i=e[A],r=e[T],!ce.isEqual(i,r)){if(u&&Fe(i,r,h)){Lt(i,n,n,1,_,t,1),Lt(i,n,n,0,_,t,-1),Pt(1,t);var w=zt(e,A+1,h);return void(w&&(t.extra_lines=t.extra_lines||[],t.extra_lines.push(w)))}s=n,n=ce.normalize(ce.perp(i,r)),o===yt.miter?St(_,i,s,n,d,!1,t):kt(o,_,i,s,n,!1,t),f&&(_+=c*ce.length(ce.sub(r,i)));}}i=r,s=n,l?function(e,t,i,r,s,n){if(Ue(e))Lt(e,t,t,1,s,n,1),Lt(e,t,t,0,s,n,-1),Pt(1,n);else {var o=Nt(t,i);r===yt.miter&&ce.lengthSq(o)>n.miter_len_sq&&(r=yt.bevel),r===yt.miter?(Lt(e,o,t,1,s,n,1),Lt(e,o,t,0,s,n,-1),Pt(1,n)):(Lt(e,t,t,1,s,n,1),Lt(e,t,t,0,s,n,-1),Pt(1,n));}}(i,s,n=ce.normalize(ce.perp(i,e[1])),o,_,t):(Lt(i,s,n,1,_,t,1),Lt(i,s,n,0,_,t,-1),Pt(1,t),Ue(i)||Ft(i,_,s,a,!1,t));}}}function zt(e,t,i){for(var r=t;e[r+1]&&Fe(e[r],e[r+1],i);)r++;return e.length-r>=2&&e.slice(r)}function Nt(e,t){var i=ce.normalize(ce.add(e,t)),r=2/(1+Math.abs(ce.dot(e,i)));return ce.mult(i,r*r)}function St(e,t,i,r,s,n,o){var a=Nt(i,r);ce.lengthSq(a)>s?kt(yt.bevel,e,t,i,r,n,o):(Lt(t,a,a,1,e,o,1),Lt(t,a,a,0,e,o,-1),n||Pt(1,o));}function kt(e,t,i,r,s,n,o){var a=Nt(r,s),l=s[0]*r[1]-s[1]*r[0]>0;null!=o.texcoord_index&&(wt[1]=t,Et[1]=t),l?(Lt(i,a,a,1,t,o,1),Lt(i,r,a,0,t,o,-1),n||Pt(1,o),It(i,ce.neg(r),a,ce.neg(s),a,wt,Et,wt,!1,e===yt.bevel,o),Lt(i,a,a,1,t,o,1),Lt(i,s,a,0,t,o,-1)):(Lt(i,r,a,1,t,o,1),Lt(i,a,a,0,t,o,-1),n||Pt(1,o),It(i,r,ce.neg(a),s,a,Et,wt,Et,!1,e===yt.bevel,o),Lt(i,s,a,1,t,o,1),Lt(i,a,a,0,t,o,-1));}function Pt(e,t){for(var i=t.vertex_data.vertex_elements,r=t.vertex_data.vertex_count-2*e-2,s=0;s<e;s++)i.push(r+2*s+2),i.push(r+2*s+1),i.push(r+2*s+0),i.push(r+2*s+2),i.push(r+2*s+3),i.push(r+2*s+1),t.geom_count+=2;}function Lt(e,t,i,r,s,n,o){var a=n.vertex_template,l=n.vertex_data;a[0]=e[0],a[1]=e[1];let u=n.half_width*o;a[n.extrude_index+0]=t[0]*u,a[n.extrude_index+1]=t[1]*u,n.offset&&(a[n.offset_index+0]=i[0]*n.offset,a[n.offset_index+1]=i[1]*n.offset),null!=n.texcoord_index&&(a[n.texcoord_index+0]=r*At,a[n.texcoord_index+1]=s*At),l.addVertex(a);}var Ot=[0,0];function It(e,t,i,r,s,n,o,a,l,u,h){for(var c=t[0]*r[1]-t[1]*r[0],d=ce.dot(t,r),f=Math.atan2(c,d);f>=Math.PI;)f-=2*Math.PI;if(u)_=1;else {var _=function(e,t){e<0&&(e=-e);var i=t>2*bt?Math.log2(t/bt):1;return Math.ceil(e/Math.PI*i)}(f,h.half_width);if(_<1)return}var p=h.vertex_data.vertex_count,m=h.vertex_data.vertex_elements;Lt(e,i,s,o[0],o[1],h,1),Lt(e,t,s,n[0],n[1],h,1);var g=t,x=null!=h.texcoord_index;if(x)if(l)var y=ce.sub(n,o);else {Ot=ce.copy(n);var v=ce.div(ce.sub(a,n),_);}var b=f/_;let A,T,w=f<0?-1:1;c>0?(A=2,T=1):(A=1,T=2);for(var E=0;E<_;E++)0===E&&f<0&&(g=ce.neg(g)),g=ce.rot(g,b),x&&(l?(y=ce.rot(y,b),Ot[0]=y[0]+o[0],Ot[1]=y[1]*h.texcoord_width*h.v_scale+o[1]):Ot=ce.add(Ot,v)),Lt(e,g,s,Ot[0],Ot[1],h,w),m.push(p+E+A),m.push(p),m.push(p+E+T);}function Ft(e,t,i,r,s,n){var o=ce.neg(i),a=null!=n.texcoord_index;switch(r){case xt.square:var l;s?(l=[i[1],-i[0]],Lt(e,ce.add(i,l),i,1,t,n,1),Lt(e,ce.add(o,l),i,0,t,n,1),a&&(t+=.5*n.texcoord_width*n.v_scale),Lt(e,i,i,1,t,n,1),Lt(e,o,i,0,t,n,1)):(l=[-i[1],i[0]],Lt(e,i,i,1,t,n,1),Lt(e,o,i,0,t,n,1),a&&(t+=.5*n.texcoord_width*n.v_scale),Lt(e,ce.add(i,l),i,1,t,n,1),Lt(e,ce.add(o,l),i,0,t,n,1)),Pt(1,n);break;case xt.round:var u,h,c=wt,d=Et,f=Rt;s?(u=i,h=o,a&&(t+=.5*n.texcoord_width*n.v_scale,c=Et,d=wt,f=Rt)):(u=o,h=i),a&&(wt[1]=t,Et[1]=t,Rt[1]=t),It(e,u,gt,h,i,c,f,d,!0,!1,n);break;case xt.butt:return}}const Ut=[255,255,255,255],Dt=[0,0,0,0];const Gt=Object.create(Re);Object.assign(Gt,{name:"lines",built_in:!0,vertex_shader_src:_t,fragment_shader_src:pt,selection:!0,init(){Re.init.apply(this,arguments),this.defines.TANGRAM_EXTRUDE_LINES=!0,this.defines.TANGRAM_TEXTURE_COORDS=!0,this.outline_feature_style={},this.inline_feature_style=this.feature_style,this.dash_textures={};},calcDistance:(e,t)=>q.evalCachedDistanceProperty(e,t)||0,calcDistanceNextZoom(e,t){t.zoom++;let i=this.calcDistance(e,t);return t.zoom--,i},calcWidth(e,t,i){let r,s=this.calcDistance(e.width,i);if(!(s<0)){if(r=e.next_width?this.calcDistanceNextZoom(e.next_width,i):s/2,0===s&&0===r||r<0)return !1;if(t.width_unscaled=s,t.next_width_unscaled=r,e.next_width){let e=.5*(s+(r*=2));t.width=e*i.units_per_meter_overzoom,t.width_scale=1-r/e;}else t.width=s*i.units_per_meter_overzoom,t.width_scale=0;return e.texcoords&&(e.inline_texcoord_width?t.texcoord_width=e.inline_texcoord_width:t.texcoord_width=(t.width_unscaled||t.next_width_unscaled)*i.units_per_meter_overzoom/i.tile.overzoom2),!0}},calcOffset(e,t,i){if(e.offset_precalc)t.offset=e.offset_precalc,t.offset_scale=e.offset_scale_precalc;else if(e.offset){let r=this.calcDistance(e.offset,i);if(e.next_offset){let s=2*this.calcDistanceNextZoom(e.next_offset,i);Math.abs(r)>=Math.abs(s)?(t.offset=r*i.units_per_meter_overzoom,t.offset_scale=0!==r?1-s/r:0):(t.offset=s*i.units_per_meter_overzoom,t.offset_scale=0!==s?-1*(1-r/s):0);}else t.offset=r*i.units_per_meter_overzoom,t.offset_scale=0;}else t.offset=0,t.offset_scale=0;},_parseFeature(e,t,i){var r=this.feature_style;if(!1!==this.calcWidth(t,r,i)&&(this.calcOffset(t,r,i),r.color=this.parseColor(t.color,i),r.color)){if(r.alpha=q.evalCachedProperty(t.alpha,i),r.variant=t.variant,r.z=q.evalCachedDistanceProperty(t.z,i)||q.defaults.z,r.height=e.properties.height||q.defaults.height,r.extrude=q.evalProperty(t.extrude,i),r.extrude&&("number"==typeof r.extrude?r.height=r.extrude:Array.isArray(r.extrude)&&(r.height=r.extrude[1])),r.extrude&&r.height&&(r.z+=r.height),r.z*=F.height_scale,r.cap=t.cap,r.join=t.join,r.miter_limit=t.miter_limit,r.tile_edges=t.tile_edges,r.outline=r.outline||{width:{},next_width:{},preprocessed:!0},t.outline&&!1!==t.outline.visible&&t.outline.color&&t.outline.width){let e=2*this.calcDistance(t.outline.width,i),s=2*this.calcDistanceNextZoom(t.outline.next_width,i);0===e&&0===s||e<0||s<0?(r.outline.width.value=null,r.outline.next_width.value=null,r.outline.color=null,r.outline.inline_texcoord_width=null,r.outline.texcoords=!1):(r.outline.width.value=e+r.width_unscaled,r.outline.next_width.value=s+r.next_width_unscaled,r.outline.inline_texcoord_width=r.texcoord_width,r.outline.offset_precalc=r.offset,r.outline.offset_scale_precalc=r.offset_scale,r.outline.color=t.outline.color,r.outline.alpha=t.outline.alpha,r.outline.interactive=t.outline.interactive,r.outline.cap=t.outline.cap,r.outline.join=t.outline.join,r.outline.miter_limit=t.outline.miter_limit,r.outline.texcoords=t.outline.texcoords,r.outline.extrude=t.outline.extrude,r.outline.z=t.outline.z,r.outline.style=t.outline.style,r.outline.variant=t.outline.variant,t.outline.order?r.outline.order=this.parseOrder(t.outline.order,i):r.outline.order=r.order,r.outline.order>r.order&&(r.outline.order=r.order),r.outline.order-=.5);}else r.outline.width.value=null,r.outline.next_width.value=null,r.outline.color=null,r.outline.inline_texcoord_width=null;return r}},_preprocess(e){if(e.color=q.createColorPropertyCache(e.color),e.alpha=q.createPropertyCache(e.alpha),e.width=q.createPropertyCache(e.width,q.parseUnits),e.width&&e.width.type!==q.CACHE_TYPE.STATIC&&(e.next_width=q.createPropertyCache(e.width,q.parseUnits)),e.offset=e.offset&&q.createPropertyCache(e.offset,q.parseUnits),e.offset&&e.offset.type!==q.CACHE_TYPE.STATIC&&(e.next_offset=q.createPropertyCache(e.offset,q.parseUnits)),e.z=q.createPropertyCache(e.z,q.parseUnits),e.dash=void 0!==e.dash?e.dash:this.dash,e.dash_key=e.dash&&this.dashTextureKey(e.dash),e.dash_background_color=void 0!==e.dash_background_color?e.dash_background_color:this.dash_background_color,e.dash_background_color=e.dash_background_color&&q.parseColor(e.dash_background_color),e.texture_merged=e.dash_key||(void 0!==e.texture?e.texture:this.texture),e.texcoords=this.texcoords||e.texture_merged?1:0,this.computeVariant(e),e.outline){e.outline.is_outline=!0,e.outline.style=e.outline.style||this.name,e.outline.color=q.createColorPropertyCache(e.outline.color),e.outline.alpha=q.createPropertyCache(e.outline.alpha),e.outline.width=q.createPropertyCache(e.outline.width,q.parseUnits),e.outline.next_width=q.createPropertyCache(e.outline.width,q.parseUnits),e.outline.interactive=null!=e.outline.interactive?e.outline.interactive:e.interactive,e.outline.cap=e.outline.cap||e.cap,e.outline.join=e.outline.join||e.join,e.outline.miter_limit=null!=e.outline.miter_limit?e.outline.miter_limit:e.miter_limit,e.outline.offset=e.offset,e.outline.extrude=e.extrude,e.outline.z=e.z;let t=this.styles[e.outline.style];t?(e.outline.dash=void 0!==e.outline.dash?e.outline.dash:t.dash,e.outline.texture=void 0!==e.outline.texture?e.outline.texture:t.texture,null!=e.outline.dash?(e.outline.dash_key=e.outline.dash&&this.dashTextureKey(e.outline.dash),e.outline.texture_merged=e.outline.dash_key):null===e.outline.dash?(e.outline.dash_key=null,e.outline.texture_merged=e.outline.texture):null!=e.outline.texture?(e.outline.dash_key=null,e.outline.texture_merged=e.outline.texture):(e.outline.dash=e.dash,e.outline.dash_key=e.outline.dash&&this.dashTextureKey(e.outline.dash),e.outline.texture_merged=e.outline.dash_key),e.outline.dash_background_color=void 0!==e.outline.dash_background_color?e.outline.dash_background_color:t.dash_background_color,e.outline.dash_background_color=void 0!==e.outline.dash_background_color?e.outline.dash_background_color:e.dash_background_color,e.outline.dash_background_color=e.outline.dash_background_color&&q.parseColor(e.outline.dash_background_color),e.outline.texcoords=t.texcoords||e.outline.texture_merged?1:0,void 0===e.outline.blend_order&&null!=e.blend_order&&(e.outline.blend_order=e.blend_order),t.computeVariant(e.outline)):(f({level:"warn",once:!0},`Layer group '${e.layers.join(", ")}': `+`line 'outline' specifies non-existent draw style '${e.outline.style}' (or maybe the style is `+"defined but is missing a 'base' or has another error), skipping outlines for features matching this layer group"),e.outline=null);}return e},dashTextureKey:e=>"__dash_"+JSON.stringify(e),getDashTexture(e){let t=this.dashTextureKey(e);if(null==this.dash_textures[t]){this.dash_textures[t]=!0;const i=function(e,t={}){const i=t.dash_color||Ut,r=t.background_color||Dt,s=e,n=t.scale||1;s.length%2==1&&Array.prototype.push.apply(s,s);let o=!0,a=[];for(let e=0;e<s.length;e++){let t=Math.floor(s[e]*n);for(let e=0;e<t;e++)Array.prototype.push.apply(a,o?i:r);o=!o;}return a.reverse(),{pixels:a=new Uint8Array(a),length:a.length/4}}(e,{scale:20});w.create(this.gl,t,{data:i.pixels,height:i.length,width:1,filtering:"nearest"});}},async endData(e){const t=await Re.endData.call(this,e);if(t){t.uniforms.u_has_line_texture=!1,t.uniforms.u_texture=w.default,t.uniforms.u_v_scale_adjust=F.tile_scale;let e=[];for(let i in t.meshes){let r=t.meshes[i].variant;if(r.texture){let s=t.meshes[i].uniforms=t.meshes[i].uniforms||{};if(s.u_has_line_texture=!0,s.u_texture=r.texture,s.u_texture_ratio=1,r.dash&&(s.u_v_scale_adjust=20*F.tile_scale,s.u_has_dash=null!=r.dash_background_color?1:0,s.u_dash_background_color=r.dash_background_color||[0,0,0,0]),r.dash_key&&null==this.dash_textures[r.dash_key]){this.dash_textures[r.dash_key]=!0;try{await n.postMessage(this.main_thread_target+".getDashTexture",r.dash);}catch(e){f("trace",`${this.name}: line dash texture create failed because style no longer on main thread`);}}if(null==w.textures[r.texture])e.push(w.syncTexturesToWorker([r.texture]).then(e=>{let t=e[r.texture];t&&(s.u_texture_ratio=t.height/t.width);}));else {let e=w.textures[r.texture];s.u_texture_ratio=e.height/e.width;}}}await Promise.all(e);}return t},computeVariant(e){let t=e.offset?1:0;t+="/"+e.texcoords,t+="/"+(e.interactive?1:0),t+="/"+(e.extrude||e.z?1:0),t+="/"+e.is_outline,e.dash_key&&(t+=e.dash_key,e.dash_background_color&&(t+=e.dash_background_color)),e.texture_merged&&(t+=e.texture_merged);const i=this.getBlendOrderForDraw(e);t=z(t+="/"+i),e.variant=t,null==this.variants[t]&&(this.variants[t]={key:t,blend_order:i,mesh_order:e.is_outline?0:1,selection:e.interactive?1:0,offset:e.offset?1:0,z_or_offset:e.offset||e.extrude||e.z?1:0,texcoords:e.texcoords,texture:e.texture_merged,dash:e.dash,dash_key:e.dash_key,dash_background_color:e.dash_background_color});},vertexLayoutForMeshVariant(e){if(null==this.vertex_layouts[e.key]){const t=[{name:"a_position",size:4,type:ne.SHORT,normalized:!1},{name:"a_extrude",size:2,type:ne.SHORT,normalized:!1},{name:"a_offset",size:2,type:ne.SHORT,normalized:!1,static:e.offset?null:[0,0]},{name:"a_z_and_offset_scale",size:2,type:ne.SHORT,normalized:!1,static:e.z_or_offset?null:[0,0]},{name:"a_texcoord",size:2,type:ne.UNSIGNED_SHORT,normalized:!0,static:e.texcoords?null:[0,0]},{name:"a_color",size:4,type:ne.UNSIGNED_BYTE,normalized:!0},{name:"a_selection_color",size:4,type:ne.UNSIGNED_BYTE,normalized:!0,static:e.selection?null:[0,0,0,0]}];this.addCustomAttributesToAttributeList(t),this.vertex_layouts[e.key]=new Le(t);}return this.vertex_layouts[e.key]},meshVariantTypeForDraw(e){return this.variants[e.variant]},makeVertexTemplate(e,t){let i=0;return this.vertex_template[i++]=0,this.vertex_template[i++]=0,this.vertex_template[i++]=1024*e.width_scale,this.vertex_template[i++]=this.scaleOrder(e.order),this.vertex_template[i++]=0,this.vertex_template[i++]=0,t.variant.offset&&(this.vertex_template[i++]=0,this.vertex_template[i++]=0),t.variant.z_or_offset&&(this.vertex_template[i++]=e.z||0,this.vertex_template[i++]=1024*e.offset_scale),t.variant.texcoords&&(this.vertex_template[i++]=0,this.vertex_template[i++]=0),this.vertex_template[i++]=255*e.color[0],this.vertex_template[i++]=255*e.color[1],this.vertex_template[i++]=255*e.color[2],this.vertex_template[i++]=255*(null!=e.alpha?e.alpha:e.color[3]),t.variant.selection&&(this.vertex_template[i++]=255*e.selection_color[0],this.vertex_template[i++]=255*e.selection_color[1],this.vertex_template[i++]=255*e.selection_color[2],this.vertex_template[i++]=255*e.selection_color[3]),this.addCustomAttributesToVertexTemplate(e,i),this.vertex_template},buildLines(e,t,i,r){if(this.feature_style=this.outline_feature_style,t.outline&&null!=t.outline.color&&null!=t.outline.width.value){var s=this.styles[t.outline.style];s&&s.addFeature(i.feature,t.outline,i);}this.feature_style=this.inline_feature_style;let n=this.getTileMesh(i.tile,this.meshVariantTypeForDraw(t)),o=n.vertex_data,a=o.vertex_layout;return function(e,t,i,r,s,n,o,a){var l,u=t.cap?xt[t.cap]:xt.butt,h=t.join?yt[t.join]:yt.miter;if(h===yt.miter){const e=t.miter_limit||vt;var c=e*e;}s.a_texcoord&&(l=1/(t.texcoord_width*Tt));var d={closed_polygon:n,remove_tile_edges:o,tile_edge_tolerance:a,miter_len_sq:c,join_type:h,cap_type:u,vertex_data:i,vertex_template:r,half_width:t.width/2,extrude_index:s.a_extrude,offset_index:s.a_offset,v_scale:l,texcoord_index:s.a_texcoord,texcoord_width:t.texcoord_width,offset:t.offset,geom_count:0};for(let t=0;t<e.length;t++)Mt(e[t],d);if(d.extra_lines)for(let e=0;e<d.extra_lines.length;e++)Mt(d.extra_lines[e],d);return d.geom_count}(e,t,o,this.makeVertexTemplate(t,n),a.index,r&&r.closed_polygon,!t.tile_edges&&r&&r.remove_tile_edges,F.tile_scale*i.tile.pad_scale*2)},buildPolygons(e,t,i){let r=0;for(let s=0;s<e.length;s++)r+=this.buildLines(e[s],t,i,{closed_polygon:!0,remove_tile_edges:!0});return r}});const Ct=128/Math.PI,jt=16384/Math.PI,$t=64,Vt=65535,Bt=128,qt=[0,2,2,0],Xt=[1,1,3,3],Ht=new Array(4);const Wt=["left","top-left","bottom-left"],Yt=["right","top-right","bottom-right"],Zt=["top","top-left","top-right"],Jt=["bottom","bottom-left","bottom-right"],Kt={computeOffset(e,t,i,r=null){if(!i||"center"===i)return e;let s=[e[0],e[1]];return r=r||this.default_buffer,this.isLeftAnchor(i)?(s[0]-=t[0]/2,"left"===i&&(s[0]-=r[0])):this.isRightAnchor(i)&&(s[0]+=t[0]/2,"right"===i&&(s[0]+=r[1])),this.isTopAnchor(i)?(s[1]-=t[1]/2,"top"===i&&(s[1]-=r[2])):this.isBottomAnchor(i)&&(s[1]+=t[1]/2,"bottom"===i&&(s[1]+=r[3])),s},alignForAnchor(e){if(e&&"center"!==e){if(this.isLeftAnchor(e))return "right";if(this.isRightAnchor(e))return "left"}return "center"},isLeftAnchor:e=>Wt.indexOf(e)>-1,isRightAnchor:e=>Yt.indexOf(e)>-1,isTopAnchor:e=>Zt.indexOf(e)>-1,isBottomAnchor:e=>Jt.indexOf(e)>-1,default_buffer:[2.5,2.5,1.5,.75],zero_buffer:[0,0,0,0]};function Qt(e,t){return !(e[2]<t[0]||e[0]>t[2]||e[3]<t[1]||e[1]>t[3])}const ei=[[1,0],[0,1]],ti=[],ii=[];let ri,si,ni,oi;class ai{constructor(e,t,i,r,s){this.dimension=[r/2,s/2],this.angle=i,this.centroid=[e,t],this.quad=null,this.axis_0=null,this.axis_1=null,this.update();}toJSON(){return {x:this.centroid[0],y:this.centroid[1],a:this.angle,w:this.dimension[0],h:this.dimension[1]}}getExtent(){if(0===this.angle)return [this.quad[0],this.quad[1],this.quad[4],this.quad[5]];return [Math.min(this.quad[0],this.quad[2],this.quad[4],this.quad[6]),Math.min(this.quad[1],this.quad[3],this.quad[5],this.quad[7]),Math.max(this.quad[0],this.quad[2],this.quad[4],this.quad[6]),Math.max(this.quad[1],this.quad[3],this.quad[5],this.quad[7])]}updateAxes(){this.axis_0=ce.normalize([this.quad[4]-this.quad[6],this.quad[5]-this.quad[7]]),this.axis_1=ce.normalize([this.quad[4]-this.quad[2],this.quad[5]-this.quad[3]]);}update(){const e=this.centroid,t=this.dimension[0],i=this.dimension[1];if(0===this.angle)this.quad=[e[0]-t,e[1]-i,e[0]+t,e[1]-i,e[0]+t,e[1]+i,e[0]-t,e[1]+i],this.axis_0=ei[0],this.axis_1=ei[1];else {let r=Math.cos(this.angle)*t,s=Math.sin(this.angle)*t,n=-Math.sin(this.angle)*i,o=Math.cos(this.angle)*i;this.quad=[e[0]-r-n,e[1]-s-o,e[0]+r-n,e[1]+s-o,e[0]+r+n,e[1]+s+o,e[0]-r+n,e[1]-s+o],this.updateAxes();}}static projectToAxis(e,t,i){let r=e.quad;return ri=r[0]*t[0]+r[1]*t[1],si=r[2]*t[0]+r[3]*t[1],ni=r[4]*t[0]+r[5]*t[1],oi=r[6]*t[0]+r[7]*t[1],i[0]=Math.min(ri,si,ni,oi),i[1]=Math.max(ri,si,ni,oi),i}static axisCollide(e,t,i,r){return ai.projectToAxis(e,i,ti),ai.projectToAxis(t,i,ii),!(ii[0]>ti[1]||ii[1]<ti[0])&&(ai.projectToAxis(e,r,ti),ai.projectToAxis(t,r,ii),!(ii[0]>ti[1]||ii[1]<ti[0]))}static intersect(e,t){return ai.axisCollide(e,t,e.axis_0,e.axis_1)&&ai.axisCollide(e,t,t.axis_0,t.axis_1)}}class li{constructor(e,t={}){this.id=li.nextLabelId(),this.type="",this.size=e,this.layout=t,this.position=null,this.angle=0,this.anchor=Array.isArray(this.layout.anchor)?this.layout.anchor[0]:this.layout.anchor,this.placed=null,this.offset=t.offset,this.unit_scale=this.layout.units_per_pixel,this.aabb=null,this.obb=null,this.align="center",this.throw_away=!1;}toJSON(){return {id:this.id,type:this.type,obb:this.obb.toJSON(),position:this.position,angle:this.angle,size:this.size,offset:this.offset,breach:this.breach,may_repeat_across_tiles:this.may_repeat_across_tiles,layout:ui(this.layout)}}update(){this.align=this.layout.align||Kt.alignForAnchor(this.anchor);}occluded(e,t=null){let i=!1,r=e.aabb,s=e.obb;return r.length>0&&function(e,t,i){for(let r=0;r<t.length&&(!Qt(e,t[r])||null==i(r));r++);}(this.aabb,r,e=>{if(!t||r[e]!==t.aabb)return 0===this.obb.angle&&0===s[e].angle?(i=!0,!0):ai.intersect(this.obb,s[e])?(i=!0,!0):void 0}),i}inTileBounds(){return this.aabb[0]>=0&&this.aabb[1]>-F.tile_scale&&this.aabb[0]<F.tile_scale&&this.aabb[1]<=0||this.aabb[2]>=0&&this.aabb[3]>-F.tile_scale&&this.aabb[2]<F.tile_scale&&this.aabb[3]<=0}mayRepeatAcrossTiles(){if(this.layout.collide)return !0;const e=this.layout.repeat_distance;return 0!==e&&(Math.abs(this.position[0])<e||Math.abs(this.position[0]-F.tile_scale)<e||Math.abs(this.position[1])<e||Math.abs(-(this.position[1]-F.tile_scale))<e)}discard(e,t=null){return !!this.throw_away||this.occluded(e,t)}}function ui(e){return {priority:e.priority,collide:e.collide,repeat_distance:e.repeat_distance,repeat_group:e.repeat_group,buffer:e.buffer,italic:e.italic}}li.add=function(e,t){if(e.placed=!0,e.aabb&&(t.aabb.push(e.aabb),t.obb.push(e.obb)),e.aabbs)for(let i=0;i<e.aabbs.length;i++)t.aabb.push(e.aabbs[i]),t.obb.push(e.obbs[i]);},li.id=0,li.id_prefix=0,li.id_multiplier=0,li.nextLabelId=function(){return li.id_prefix+li.id++*li.id_multiplier},li.epsilon=.9999;class hi{constructor(e,t){this.key=e,this.repeat_dist=t,this.repeat_dist_sq=this.repeat_dist*this.repeat_dist,this.positions=[];}check(e){let t=e.position;for(let e=0;e<this.positions.length;e++){let i=this.positions[e],r=t[0]-i[0],s=t[1]-i[1];if(r*r+s*s<this.repeat_dist_sq)return !0}}add(e){e&&e.position&&this.positions.push(e.position);}static clear(e){this.groups[e]={};}static check(e,t,i){if(t.repeat_distance&&t.repeat_group&&this.groups[i][t.repeat_group])return this.groups[i][t.repeat_group].check(e)}static add(e,t,i){t.repeat_distance&&t.repeat_group&&(null==this.groups[i][t.repeat_group]&&(this.groups[i][t.repeat_group]=new hi(t.repeat_group,t.repeat_distance*t.repeat_scale)),this.groups[i][t.repeat_group].add(e));}}hi.groups={};class ci{constructor(e,t){this.anchor=e,this.span=t,this.cells={};}addLabel(e){e.aabb&&this.addLabelBboxes(e,e.aabb),e.aabbs&&e.aabbs.forEach(t=>this.addLabelBboxes(e,t));}addLabelBboxes(e,t){const i=[Math.max(Math.floor((t[0]-this.anchor.x)/this.span),0),Math.max(Math.floor(-(t[1]-this.anchor.y)/this.span),0),Math.max(Math.floor((t[2]-this.anchor.x)/this.span),0),Math.max(Math.floor(-(t[3]-this.anchor.y)/this.span),0)];e.cells=[];for(let t=i[1];t<=i[3];t++){this.cells[t]=this.cells[t]||{};for(let r=i[0];r<=i[2];r++)this.cells[t][r]=this.cells[t][r]||{aabb:[],obb:[]},e.cells.push(this.cells[t][r]);}}}const di={tiles:{},grid:null,initGrid(e){this.grid=null==e?null:new ci(e.anchor,e.span);},startTile(e,{apply_repeat_groups:t=!0,return_hidden:i=!1}={}){let r=this.tiles[e]={bboxes:{aabb:[],obb:[]},objects:{},labels:{},styles:{},repeat:t,return_hidden:i};null==r.complete&&(r.complete=new Promise((e,t)=>{r.resolve=e,r.reject=t;}));},resetTile(e){delete this.tiles[e];},abortTile(e){this.tiles[e]&&this.tiles[e].resolve&&this.tiles[e].resolve([]),this.resetTile(e);},addStyle(e,t){this.tiles[t].styles[e]=!0;},collide(e,t,i){let r=this.tiles[i];if(!r)return f("trace","Collision.collide() called with null tile",i,this.tiles,t,e),Promise.resolve([]);let s=r.objects;for(let i=0;i<e.length;i++){let r=e[i],n=r.label.layout.priority;s[n]=s[n]||{},s[n][t]=s[n][t]||[],s[n][t].push(r);}return delete r.styles[t],0===Object.keys(r.styles).length&&this.endTile(i),r.complete.then(()=>(r.resolve=null,r.labels[t]||[]))},endTile(e){let t=this.tiles[e],i=t.labels;this.grid&&this.addLabelsToGrid(e),t.repeat&&hi.clear(e);let r=Object.keys(t.objects).sort((e,t)=>e-t);for(let s=0;s<r.length;s++){let n=t.objects[r[s]];if(n)for(let r in n){let s=n[r];i[r]=i[r]||[];for(let n=0;n<s.length;n++){let o=s[n];this.canBePlaced(o,e,o.linked,t)?o.linked?this.canBePlaced(o.linked,e,o,t)?(o.show=!0,(o.label.breach||o.linked.label.breach)&&(o.label.breach=!0,o.linked.label.breach=!0),(o.label.may_repeat_across_tiles||o.linked.label.may_repeat_across_tiles)&&(o.label.may_repeat_across_tiles=!0,o.linked.label.may_repeat_across_tiles=!0),i[r].push(o),this.place(o,e,t),this.place(o.linked,e,t)):t.return_hidden&&(o.show=!1,i[r].push(o)):(o.show=!0,i[r].push(o),this.place(o,e,t)):t.return_hidden&&(o.show=!1,i[r].push(o));}}}delete this.tiles[e],t.resolve();},addLabelsToGrid(e){const t=this.tiles[e];for(const e in t.objects){const i=t.objects[e];if(i)for(const e in i){i[e].forEach(e=>this.grid.addLabel(e.label));}}},canBePlaced(e,t,i=null,{repeat:r=!0}={}){let s=e.label,n=e.label.layout;if(null!=s.placed)return s.placed;let o=!n.collide;if(o||(o=this.grid&&s.cells?s.cells.reduce((e,t)=>(e&&s.discard(t,i&&i.label)&&(e=!1),e),!0):!s.discard(this.tiles[t].bboxes,i&&i.label)),o){if(!r||!hi.check(s,n,t))return !0;s.placed=!1;}else n.collide&&(s.placed=!1);return s.placed},place({label:e},t,{repeat:i=!0}){null==e.placed&&(i&&hi.add(e,e.layout,t),this.grid&&e.cells?e.cells.forEach(t=>li.add(e,t)):li.add(e,this.tiles[t].bboxes));}};class fi extends li{constructor(e,t,i,r=0){super(t,i),this.type="point",this.position=[e[0],e[1]],this.angle=r,this.parent=this.layout.parent,this.update(),this.start_anchor_index=1,this.degenerate=!(this.size[0]||this.size[1]||this.layout.buffer[0]||this.layout.buffer[1]),this.throw_away=!1;}update(){super.update(),this.computeOffset(),this.updateBBoxes();}computeOffset(){if(this.offset=[this.layout.offset[0],this.layout.offset[1]],this.parent){let e=this.parent;this.offset=Kt.computeOffset(this.offset,e.size,e.anchor,Kt.zero_buffer),this.offset=Kt.computeOffset(this.offset,e.size,this.anchor,Kt.zero_buffer),e.offset!==q.zeroPair&&(this.offset===q.zeroPair?this.offset=e.offset:(this.offset[0]+=e.offset[0],this.offset[1]+=e.offset[1]));}this.offset=Kt.computeOffset(this.offset,this.size,this.anchor);}updateBBoxes(){let e=(this.size[0]+2*this.layout.buffer[0])*this.unit_scale*li.epsilon,t=(this.size[1]+2*this.layout.buffer[1])*this.unit_scale*li.epsilon;this.layout.italic&&(e+=5*this.unit_scale),this.obb=new ai(this.position[0]+this.offset[0]*this.unit_scale,this.position[1]-this.offset[1]*this.unit_scale,-this.angle,e,t),this.aabb=this.obb.getExtent(),this.inTileBounds&&(this.breach=!this.inTileBounds()),this.mayRepeatAcrossTiles&&(this.may_repeat_across_tiles=this.mayRepeatAcrossTiles());}discard(e,t=null){if(this.degenerate)return !1;if(super.discard(e,t)){if(Array.isArray(this.layout.anchor))for(let i=this.start_anchor_index;i<this.layout.anchor.length;i++)if(this.anchor=this.layout.anchor[i],this.update(),!super.discard(e,t))return !1;return !0}return !1}}fi.PLACEMENT={VERTEX:0,MIDPOINT:1,SPACED:2,CENTROID:3};const _i=fi.PLACEMENT,pi=80;function mi(e,t,i){const r=[],s=i.placement,n=Math.max(t[0],t[1])*i.placement_min_length_ratio*i.units_per_pixel;if(s===_i.SPACED){let s=function(e,t,i){let r=i.units_per_pixel,s=(i.placement_spacing||pi)*r,n=function(e){let t=0;for(let i=0;i<e.length-1;i++)t+=xi(e[i],e[i+1]);return t}(e);if(n<=t)return !1;let o=Math.max(Math.floor(n/s),1),a=[],l=[],u=.5*(n-(o-1)*s);for(let r=0;r<o;r++){let{position:r,angle:n}=yi(e,u,t,i);null!=r&&null!=n&&(a.push(r),l.push(n)),u+=s;}return {positions:a,angles:l}}(e,n,i);if(!s)return [];let o=s.positions,a=s.angles;for(let e=0;e<o.length;e++){let s=o[e],n=a[e];!0!==i.tile_edges&&Ue(s)||r.push(new fi(s,t,i,n));}}else if(s===_i.VERTEX){let s,n;for(let o=0;o<e.length-1;o++)if(s=e[o],n=e[o+1],!0===i.tile_edges||!Ue(s)){const e=gi(s,n,i.angle);r.push(new fi(s,t,i,e));}const o=gi(s,n,i.angle);r.push(new fi(n,t,i,o));}else if(s===_i.MIDPOINT)for(let s=0;s<e.length-1;s++){let o=e[s],a=e[s+1],l=[.5*(o[0]+a[0]),.5*(o[1]+a[1])];if((!0===i.tile_edges||!Ue(l))&&(!n||xi(o,a)>n)){const e=gi(o,a,i.angle);r.push(new fi(l,t,i,e));}}return r}function gi(e,t,i=0){return "auto"===i?Math.atan2(t[0]-e[0],t[1]-e[1]):i}function xi(e,t){return Math.sqrt(Math.pow(e[0]-t[0],2)+Math.pow(e[1]-t[1],2))}function yi(e,t,i,r){let s,n,o=0;for(let a=0;a<e.length-1;a++){let l=e[a],u=e[a+1];const h=xi(l,u);if(!(h<=i)&&(o+=h)>t){s=vi(l,u,o-t),n=gi(l,u,r.angle);break}}return {position:s,angle:n}}function vi(e,t,i){let r=i/xi(e,t);return [r*e[0]+(1-r)*t[0],r*e[1]+(1-r)*t[1]]}const bi={key:e=>[e.style,e.weight,e.family,e.px_size,e.fill,e.stroke,e.stroke_width,e.underline_width,e.background_color,e.background_width,e.background_stroke_color,e.background_stroke_width,e.transform,e.text_wrap,e.max_lines,e.supersample,_.device_pixel_ratio].join("/"),defaults:{style:"normal",weight:"normal",size:"12px",px_size:12,family:"Helvetica",fill:[1,1,1,1],text_wrap:15,max_lines:5,align:"center"},compute(e,t){const i={};e.font=e.font||this.defaults,i.supersample=e.supersample_text?1.5:1,i.can_articulate=e.can_articulate,i.fill=q.evalCachedColorPropertyWithAlpha(e.font.fill,e.font.alpha,t),i.fill=_.toCSSColor(i.fill),e.font.stroke&&e.font.stroke.color&&(i.stroke=q.evalCachedColorPropertyWithAlpha(e.font.stroke.color,e.font.stroke.alpha,t),i.stroke=_.toCSSColor(i.stroke),i.stroke_width=q.evalCachedProperty(e.font.stroke.width,t)),!0!==e.font.underline||i.can_articulate||(i.underline_width=1.5*i.supersample),e.font.background&&!i.can_articulate&&(i.background_color=q.evalCachedColorPropertyWithAlpha(e.font.background.color,e.font.background.alpha,t),i.background_color=_.toCSSColor(i.background_color),i.background_color&&(i.background_width=q.evalCachedProperty(e.font.background.width,t)),i.background_stroke_color=e.font.background.stroke&&e.font.background.stroke.color&&q.evalCachedColorPropertyWithAlpha(e.font.background.stroke.color,e.font.background.stroke.alpha,t),i.background_stroke_color&&(i.background_stroke_color=_.toCSSColor(i.background_stroke_color),i.background_stroke_width=null!=e.font.background.stroke.width?q.evalCachedProperty(e.font.background.stroke.width,t):1)),i.weight=q.evalCachedProperty(e.font.weight,t)||this.defaults.weight,"number"==typeof i.weight&&(i.weight=Math.min(Math.max(i.weight,1),1e3)),e.font.family?(i.family=e.font.family,i.family!==this.defaults.family&&(i.family+=", "+this.defaults.family)):i.family=this.defaults.family,i.style=e.font.style||this.defaults.style,i.transform=e.font.transform,i.px_size=q.evalCachedProperty(e.font.px_size,t)*i.supersample,i.font_css=this.fontCSS(i);let r=e.text_wrap;return null!=r||i.can_articulate||(r=!0),!0===r&&(r=this.defaults.text_wrap),i.text_wrap=r,i.max_lines=e.max_lines||this.defaults.max_lines,i},fontCSS:({style:e,weight:t,px_size:i,family:r})=>[e,t,i+"px",r].filter(e=>e).join(" ")};var Ai=V(function(e){!function(){function t(e,t){document.addEventListener?e.addEventListener("scroll",t,!1):e.attachEvent("scroll",t);}function i(e){this.a=document.createElement("div"),this.a.setAttribute("aria-hidden","true"),this.a.appendChild(document.createTextNode(e)),this.b=document.createElement("span"),this.c=document.createElement("span"),this.h=document.createElement("span"),this.f=document.createElement("span"),this.g=-1,this.b.style.cssText="max-width:none;display:inline-block;position:absolute;height:100%;width:100%;overflow:scroll;font-size:16px;",this.c.style.cssText="max-width:none;display:inline-block;position:absolute;height:100%;width:100%;overflow:scroll;font-size:16px;",this.f.style.cssText="max-width:none;display:inline-block;position:absolute;height:100%;width:100%;overflow:scroll;font-size:16px;",this.h.style.cssText="display:inline-block;width:200%;height:200%;font-size:16px;max-width:none;",this.b.appendChild(this.h),this.c.appendChild(this.f),this.a.appendChild(this.b),this.a.appendChild(this.c);}function r(e,t){e.a.style.cssText="max-width:none;min-width:20px;min-height:20px;display:inline-block;overflow:hidden;position:absolute;width:auto;margin:0;padding:0;top:-999px;left:-999px;white-space:nowrap;font:"+t+";";}function s(e){var t=e.a.offsetWidth,i=t+100;return e.f.style.width=i+"px",e.c.scrollLeft=i,e.b.scrollLeft=e.b.scrollWidth+100,e.g!==t&&(e.g=t,!0)}function n(e,i){function r(){var e=n;s(e)&&e.a.parentNode&&i(e.g);}var n=e;t(e.b,r),t(e.c,r),s(e);}function o(e,t){var i=t||{};this.family=e,this.style=i.style||"normal",this.weight=i.weight||"normal",this.stretch=i.stretch||"normal";}var a=null,l=null,u=null,h=null;function c(){if(null===u){var e=document.createElement("div");try{e.style.font="condensed 100px sans-serif";}catch(e){}u=""!==e.style.font;}return u}function d(e,t){return [e.style,e.weight,c()?e.stretch:"","100px",t].join(" ")}o.prototype.load=function(e,t){var s=this,o=e||"BESbswy",u=0,c=t||3e3,f=(new Date).getTime();return new Promise(function(e,t){var _;if(null===h&&(h=!!document.fonts),(_=h)&&(null===l&&(l=/OS X.*Version\/10\..*Safari/.test(navigator.userAgent)&&/Apple/.test(navigator.vendor)),_=!l),_){_=new Promise(function(e,t){!function i(){(new Date).getTime()-f>=c?t():document.fonts.load(d(s,'"'+s.family+'"'),o).then(function(t){1<=t.length?e():setTimeout(i,25);},function(){t();});}();});var p=new Promise(function(e,t){u=setTimeout(t,c);});Promise.race([p,_]).then(function(){clearTimeout(u),e(s);},function(){t(s);});}else !function(e){document.body?e():document.addEventListener?document.addEventListener("DOMContentLoaded",function t(){document.removeEventListener("DOMContentLoaded",t),e();}):document.attachEvent("onreadystatechange",function t(){"interactive"!=document.readyState&&"complete"!=document.readyState||(document.detachEvent("onreadystatechange",t),e());});}(function(){function l(){var t;(t=-1!=m&&-1!=g||-1!=m&&-1!=x||-1!=g&&-1!=x)&&((t=m!=g&&m!=x&&g!=x)||(null===a&&(t=/AppleWebKit\/([0-9]+)(?:\.([0-9]+))/.exec(window.navigator.userAgent),a=!!t&&(536>parseInt(t[1],10)||536===parseInt(t[1],10)&&11>=parseInt(t[2],10))),t=a&&(m==y&&g==y&&x==y||m==v&&g==v&&x==v||m==b&&g==b&&x==b)),t=!t),t&&(A.parentNode&&A.parentNode.removeChild(A),clearTimeout(u),e(s));}var h=new i(o),_=new i(o),p=new i(o),m=-1,g=-1,x=-1,y=-1,v=-1,b=-1,A=document.createElement("div");A.dir="ltr",r(h,d(s,"sans-serif")),r(_,d(s,"serif")),r(p,d(s,"monospace")),A.appendChild(h.a),A.appendChild(_.a),A.appendChild(p.a),document.body.appendChild(A),y=h.a.offsetWidth,v=_.a.offsetWidth,b=p.a.offsetWidth,function e(){if((new Date).getTime()-f>=c)A.parentNode&&A.parentNode.removeChild(A),t(s);else {var i=document.hidden;!0!==i&&void 0!==i||(m=h.a.offsetWidth,g=_.a.offsetWidth,x=p.a.offsetWidth,l()),u=setTimeout(e,50);}}(),n(h,function(e){m=e,l();}),r(h,d(s,'"'+s.family+'",sans-serif')),n(_,function(e){g=e,l();}),r(_,d(s,'"'+s.family+'",serif')),n(p,function(e){x=e,l();}),r(p,d(s,'"'+s.family+'",monospace'));});})},e.exports=o;}();});const Ti={fonts_loaded:Promise.resolve(),last_loaded:null,loadFonts(e){const t=JSON.stringify(e)===this.last_loaded;if(e&&!t){const t=[];for(const i in e)Array.isArray(e[i])?e[i].forEach(e=>t.push(this.loadFontFace(i,e))):t.push(this.loadFontFace(i,e[i]));this.last_loaded=JSON.stringify(e),this.fonts_loaded=Promise.all(t.filter(e=>e));}return this.fonts_loaded},async loadFontFace(e,t){if(null==t||"object"!=typeof t&&"external"!==t)return;const i={family:e};"object"==typeof t&&(Object.assign(i,t),"string"==typeof t.url&&await this.injectFontFace(i));try{i.weight="string"==typeof i.weight?i.weight.split(" ")[0]:i.weight;const t=new Ai(e,i);await t.load(),f("debug",`Font face '${e}' is available`,i);}catch(t){f("warn",`Font face '${e}' is NOT available`,i,t);}},async injectFontFace({family:e,url:t,weight:i,style:r}){void 0===this.supports_native_font_loading&&(this.supports_native_font_loading=void 0!==window.FontFace);let s=t;if("blob:"===t.slice(0,5)){s=(await _.io(t,6e4,"arraybuffer")).body;let e=new Uint8Array(s);if(this.supports_native_font_loading)s=e;else {let t="";for(let i=0;i<e.length;i++)t+=String.fromCharCode(e[i]);s="data:font/opentype;base64,"+btoa(t);}}if(this.supports_native_font_loading){let t;"string"==typeof s?t=new FontFace(e,`url(${encodeURI(s)})`,{weight:i,style:r}):s instanceof Uint8Array&&(t=new FontFace(e,s,{weight:i,style:r})),document.fonts.add(t),f("trace","Adding FontFace to document.fonts:",t);}else {let t=`\n                @font-face {\n                    font-family: '${e}';\n                    font-weight: ${i||"normal"};\n                    font-style: ${r||"normal"};\n                    src: url(${encodeURI(s)});\n                }`,n=document.createElement("style");n.appendChild(document.createTextNode("")),document.head.appendChild(n),n.sheet.insertRule(t,0),f("trace","Injecting CSS font face:",t);}}},wi=new RegExp("[֑-߿‏‫‮יִ-﷽ﹰ-ﻼ]");function Ei(e){return wi.test(e)}const Ri="\0-/:-@[-`{-¿×÷ʹ-˿ -⯿‐-\u2029‬ -⯿",Mi=new RegExp("["+Ri+"]+");function zi(e){return Mi.test(e)}const Ni="‏",Si=new RegExp("^["+Ri+"؀-ۿ]+"),ki=new RegExp("["+Ri+"آ-إاد-زوٱ-ٷڈ-ڙۄ-ۋۏےۓۮۯ]"),Pi=new RegExp("^[ؐ-ًؚ-ٰٟۖ-ۜ۟-۪ۤۧۨ-ۭ]+"),Li="[̀-֑ͯ-ׇֽֿׁׂׅׄަ-ްऀ-ःऺ-ौॎॏ॑-ॗॢॣঁ-ঃ়া-ৌৗৢৣਁ-ਃ਼-ੌੑઁ-ઃ઼ા-ૌૢૣଁ-ଃ଼ା-ୌୖୗୢୣஂா-்ௗఀ-ఃా-ౌౕౖౢౣಁ-ಃ಼ಾ-ೌೕೖೢೣഁ-ഃാ-ൌൎൗൢൣංඃ්-ෟෲෳัิ-ฺ็-๎ັິ-ຼ່-ໍ༹༘༙༵༷༾༿ཱ-ྃ྆྇ྍ-ྼ࿆ါ-း်-ှၖ-ၙၞ-ၠၢ-ၤၧ-ၭၱ-ၴႂ-ႍႏႚ-ႝ឴-៑៓ᩕ-ᩞᩡ-᩼᷀-᷿⃐-⃿]",Oi=new RegExp(`^.(?:${Li}+)?([्্੍્୍్್്྄္្᩠᩿]\\W(?:${Li}+)?)*`),Ii={Mongolian:"᠀-᢯"},Fi=Object.keys(Ii).map(e=>Ii[e]).join(""),Ui=new RegExp("["+Fi+"]");const Di=2;function Gi(e,t,i){const r=t?1:Di;if(e.length<r)return [e];let s=e;if(i.segment[s])return i.stats.segment_hits++,i.segment[s];let n=[];if(Si.exec(e)){n=e.split(ki);let t=-1;for(var o=0;o<n.length-1;o++){if(o>0){let e=Pi.exec(n[o]);e&&(n[o]=n[o].substring(e[0].length),n[o-1]+=e[0],t+=e[0].length);}t+=1+n[o].length,n[o]+=e.slice(t,t+1);}e="";}for(;e.length;){let t="",i=e,s=0;for(;s<r&&i.length;s++){let e=(Oi.exec(i)||i)[0];t+=e,i=i.substring(e.length);}n.push(t),e=e.substring(t.length);}return t&&n.reverse(),i.stats.segment_misses++,i.segment[s]=n,n}class Ci{constructor(e,t=1/0,i=1/0){this.width=0,this.height=0,this.lines=[],this.max_lines=t,this.text_wrap=i,this.context=e;}createLine(e){return this.lines.length<this.max_lines&&new ji(e,this.text_wrap)}push(e){if(this.lines.length<this.max_lines){let t=this.context.measureText(e.text).width;return e.width=t,t>this.width&&(this.width=Math.ceil(t)),this.lines.push(e),this.height+=e.height,!0}return this.addEllipsis(),!1}advance(e,t){return !!this.push(e)&&this.createLine(t)}addEllipsis(){let e=this.lines[this.lines.length-1],t=Math.ceil(this.context.measureText(Ci.ellipsis).width);e.append(Ci.ellipsis),e.width+=t,e.width>this.width&&(this.width=e.width);}finish(e){e?this.push(e):this.addEllipsis();}static parse(e,t,i,r,s){let n;n="number"==typeof t?e.split(" "):[e];let o=new Ci(s,i,t),a=o.createLine(r);for(let e=0;e<n.length;e++){let i=n[e].split("\n"),s=0===e;for(let n=0;n<i.length&&a;n++){let l=i[n];Ei(l)&&zi(l[l.length-1])&&(l+=Ni);let u=s?l:" "+l;if(t&&e>0&&a.exceedsTextwrap(u)){if(!(a=o.advance(a,r)))break;a.append(l),s=!0;}else a.append(u);n<i.length-1&&(a=o.advance(a,r),s=!0);}e===n.length-1&&o.finish(a);}return o}}Ci.ellipsis="...";class ji{constructor(e=0,t=0){this.chars=0,this.text="",this.height=Math.ceil(e),this.text_wrap=t;}append(e){this.chars+=e.length,this.text+=e;}exceedsTextwrap(e){return e.length+this.chars>this.text_wrap}}class $i{constructor(){this.createCanvas(),this.vertical_text_buffer=8,this.horizontal_text_buffer=4,this.background_size=4;}createCanvas(){this.canvas=document.createElement("canvas"),this.canvas.style.backgroundColor="transparent",this.context=this.canvas.getContext("2d");}resize(e,t){this.canvas.width=e,this.canvas.height=t,this.context.clearRect(0,0,e,t);}setFont({font_css:e,fill:t,stroke:i,stroke_width:r,px_size:s,supersample:n}){this.px_size=s;let o=this.context,a=_.device_pixel_ratio*n;i&&r>0&&(o.strokeStyle=i,o.lineWidth=r*a),o.fillStyle=t,o.font=e,o.miterLimit=2;}async textSizes(e,t){return await Ti.loadFonts(),b.add({type:"textSizes",run:this.processTextSizesTask.bind(this),texts:t,tile_id:e,cursor:{styles:Object.keys(t),texts:null,style_idx:null,text_idx:null}})}processTextSizesTask(e){let{cursor:t,texts:i}=e;for(t.style_idx=t.style_idx||0;t.style_idx<t.styles.length;){let s=t.styles[t.style_idx];null==t.text_idx&&(t.text_idx=0,t.texts=Object.keys(i[s]));let n=i[s],o=!0;for(;t.text_idx<t.texts.length;){let i=t.texts[t.text_idx],a=n[i],l=a.text_settings;if(o&&(this.setFont(l),o=!1),a.size=this.textSize(s,i,l).size,l.can_articulate){let e=!1,t=!1;if(Ei(i)&&(zi(i)?e=!0:t=!0),a.isRTL=e,a.no_curving=t||(r=i,Ui.test(r)),a.vertical_buffer=this.vertical_text_buffer,a.segment_sizes=[],!a.no_curving){let t=Gi(i,e,$i.cache);a.segments=t;for(let e=0;e<t.length;e++)a.segment_sizes.push(this.textSize(s,t[e],l).size);}}if(t.text_idx++,!b.shouldContinue(e))return !1}t.text_idx=null,t.style_idx++;}var r;return b.finish(e,i),!0}textSize(e,t,{transform:i,text_wrap:r,max_lines:s,stroke_width:n=0,background_color:o,background_stroke_width:a=0,background_width:l,underline_width:u=0,supersample:h}){if($i.cache.text[e]=$i.cache.text[e]||{},$i.cache.text[e][t])return $i.cache.stats.text_hits++,$i.cache.text[e][t];$i.cache.stats.text_misses++,$i.cache.text_count++;const c=_.device_pixel_ratio*h,d=this.applyTextTransform(t,i),f=this.context,p=this.vertical_text_buffer*c,m=(n+this.horizontal_text_buffer)*c;l=null!=l?l:this.background_size;const g=o||a?(l+a)*c:0,x=(2+u+(u?n+1:0))*c,y=this.px_size+x;let{width:v,height:b,lines:A}=Ci.parse(d,r,s,y,f),T=[(v+=2*g)/c,(b+=2*g)/c],w=[v+2*m,b+2*p],E=[w[0]/c,w[1]/c];return $i.cache.text[e][t]={lines:A,size:{collision_size:T,texture_size:w,logical_size:E,horizontal_buffer:m,vertical_buffer:p,dpr:c,line_height:y,background_size:g}},$i.cache.text[e][t]}drawTextMultiLine(e,[t,i],r,s,n){const{dpr:o,collision_size:a,texture_size:l,line_height:u,horizontal_buffer:h,vertical_buffer:c}=r;if(s.background_color||s.background_stroke_color){const e=s.background_stroke_color,r=(s.background_stroke_width||0)*o;this.context.save(),s.background_color&&(this.context.fillStyle=s.background_color,this.context.fillRect(t+h+("curved"===n?l[0]:0)+r,i+c+r,o*a[0]-2*r,o*a[1]-2*r)),e&&r&&(this.context.strokeStyle=e,this.context.lineWidth=r,this.context.strokeRect(t+h+("curved"===n?l[0]:0)+.5*r,i+c+.5*r,o*a[0]-r,o*a[1]-r)),this.context.restore();}const d=s.underline_width||0,f=s.stroke_width||0;let _=i-(d?.5*(d+f+1)*o:0);for(let i=0;i<e.length;i++){let o=e[i];this.drawTextLine(o,[t,_],r,s,n),_+=u;}this.drawTextDebug([t,i],r,n);}drawTextLine(e,[t,i],r,s,n){const{stroke:o,stroke_width:a,transform:l,align:u="center"}=s,{horizontal_buffer:h,vertical_buffer:c,texture_size:d,background_size:f,line_height:_,dpr:p}=r,m=(s.underline_width||0)*p,g=this.applyTextTransform(e.text,l);let x;"left"===u?x=t+h+f:"center"===u?x=t+d[0]/2-e.width/2:"right"===u&&(x=t+d[0]-e.width-h-f);const y=i+.75*c+_+f-.5*m,v=o&&a>0&&"curved"===n?d[0]:0;if(m){this.context.save(),this.context.strokeStyle=this.context.fillStyle,this.context.lineWidth=m;const t=y+(.5*a+2)*p+.5*this.context.lineWidth;this.context.beginPath(),this.context.moveTo(x+v,t),this.context.lineTo(x+v+e.width,t),this.context.stroke(),this.context.restore();}o&&a>0&&this.context.strokeText(g,x+v,y),this.context.fillText(g,x,y);}drawTextDebug([e,t],i,r){const{dpr:s,horizontal_buffer:n,vertical_buffer:o,texture_size:a,collision_size:l}=i;m.draw_label_collision_boxes&&(this.context.save(),this.context.strokeStyle="blue",this.context.lineWidth=2,this.context.strokeRect(e+n,t+o,s*l[0],s*l[1]),"curved"===r&&this.context.strokeRect(e+a[0]+n,t+o,s*l[0],s*l[1]),this.context.restore()),m.draw_label_texture_boxes&&(this.context.save(),this.context.strokeStyle="green",this.context.lineWidth=2,this.context.strokeRect(e+2,t+2,a[0]-4,a[1]-4),"curved"===r&&this.context.strokeRect(e+2+a[0],t+2,a[0]-4,a[1]-4),this.context.restore());}rasterize(e,t,i,r,s){return b.add({type:"rasterizeLabels",run:this.processRasterizeTask.bind(this),cancel:this.cancelRasterizeTask.bind(this),pause_factor:2,user_moving_view:!1,texts:e,textures:t,texture_prefix:r,gl:s,tile_id:i,cursor:{styles:Object.keys(e),texts:null,style_idx:0,text_idx:null,texture_idx:0,texture_resize:!0,texture_names:[]}})}processRasterizeTask(e){let t,{cursor:r,texts:s,textures:n}=e;for(;r.texture_idx<e.textures.length;){for(t=n[r.texture_idx],r.texture_resize&&(r.texture_resize=!1,this.resize(...t.texture_size));r.style_idx<r.styles.length;){let n=r.styles[r.style_idx];null==r.text_idx&&(r.text_idx=0,r.texts=Object.keys(s[n]));let o=s[n],a=!0;for(;r.text_idx<r.texts.length;){let s=r.texts[r.text_idx],l=o[s],u=l.text_settings;if(a&&(this.setFont(u),a=!1),u.can_articulate){l.texcoords=l.texcoords||{};for(let e=0;e<l.type.length;e++){let i=l.type[e];if("straight"===i){if(l.textures[e]!==r.texture_idx)continue;let o,a=l.isRTL?s.split().reverse().join():s,h=t.texcoord_cache[n][a];if(h.texcoord)o=h.texcoord;else {let e=h.texture_position,{size:r,lines:s}=this.textSize(n,a,u);this.drawTextMultiLine(s,e,r,u,i),o=w.getTexcoordsForSprite(e,r.texture_size,t.texture_size),h.texcoord=o;}l.texcoords[i]={texcoord:o,texture_id:h.texture_id};}else if("curved"===i){let s=l.segments;l.texcoords.curved=l.texcoords.curved||[],l.texcoords_stroke=l.texcoords_stroke||[];for(let o=0;o<s.length;o++){if(l.textures[e][o]!==r.texture_idx)continue;let a,h,c=s[o],d=t.texcoord_cache[n][c];if(d.texcoord)a=d.texcoord,h=d.texcoord_stroke,l.texcoords_stroke.push(h);else {let e=d.texture_position,{size:r,lines:s}=this.textSize(n,c,u);this.drawTextMultiLine(s,e,r,u,i),a=w.getTexcoordsForSprite(e,r.texture_size,t.texture_size);let o=[e[0]+r.texture_size[0],e[1]];h=w.getTexcoordsForSprite(o,r.texture_size,t.texture_size),d.texcoord=a,d.texcoord_stroke=h,l.texcoords_stroke.push(h);}l.texcoords.curved.push({texcoord:a,texture_id:d.texture_id});}}}}else {let e=this.textSize(n,s,u).lines;const o=i({},u);for(let i in l.align)l.align[i].texture_id===r.texture_idx&&(o.align=i,this.drawTextMultiLine(e,l.align[i].texture_position,l.size,o),l.align[i].texcoords=w.getTexcoordsForSprite(l.align[i].texture_position,l.size.texture_size,t.texture_size));}if(r.text_idx++,!b.shouldContinue(e))return !1}r.text_idx=null,r.style_idx++;}let o=e.texture_prefix+r.texture_idx;w.create(e.gl,o,{element:this.canvas,filtering:"linear",UNPACK_PREMULTIPLY_ALPHA_WEBGL:!0}),w.retain(o),r.texture_names.push(o),r.texture_idx++,r.texture_resize=!0,r.style_idx=0;}return b.finish(e,r.texture_names),!0}cancelRasterizeTask(e){f("trace",`RasterizeTask: release textures [${e.cursor.texture_names.join(", ")}]`),e.cursor.texture_names.forEach(e=>w.release(e));}setTextureTextPositions(e,t){let i={cx:0,cy:0,width:0,height:0,column_width:0,texture_id:0,texcoord_cache:{}},r=[];for(let s in e){let n=e[s];for(let e in n){let o,a=n[e];if(a.text_settings.can_articulate){a.textures=[],i.texcoord_cache[s]=i.texcoord_cache[s]||{};for(let n=0;n<a.type.length;n++){let l=a.type[n];if("straight"===l){let l=a.isRTL?e.split().reverse().join():e;if(!i.texcoord_cache[s][l]){let e=a.size.texture_size;o=this.placeText(e[0],e[1],s,i,r,t),i.texcoord_cache[s][l]={texture_id:i.texture_id,texture_position:o};}a.textures[n]=i.texture_id;}else if("curved"===l){a.textures[n]=[];for(let e=0;e<a.segment_sizes.length;e++){let l=a.segments[e];if(!i.texcoord_cache[s][l]){let n=a.segment_sizes[e].texture_size,u=2*n[0];o=this.placeText(u,n[1],s,i,r,t),i.texcoord_cache[s][l]={texture_id:i.texture_id,texture_position:o};}a.textures[n].push(i.texture_id);}}}}else {let e=a.size.texture_size;for(let n in a.align)o=this.placeText(e[0],e[1],s,i,r,t),a.align[n].texture_id=i.texture_id,a.align[n].texture_position=o;}}}return i.column_width>0&&i.height>0&&(r[i.texture_id]={texture_size:[i.width,i.height],texcoord_cache:i.texcoord_cache}),r}placeText(e,t,i,r,s,n){let o;return r.cy+t>n?(r.cx+=r.column_width,r.cy=0,r.column_width=e):r.column_width=Math.max(r.column_width,e),r.cx+r.column_width<=n?(o=[r.cx,r.cy],r.cy+=t,r.height=Math.max(r.height,r.cy),r.width=Math.max(r.width,r.cx+r.column_width)):(s[r.texture_id]={texture_size:[r.width,r.height],texcoord_cache:r.texcoord_cache},r.texcoord_cache={},r.texcoord_cache[i]={},r.texture_id++,r.cx=0,r.cy=t,r.column_width=e,r.width=e,r.height=t,o=[0,0]),o}applyTextTransform(e,t){return "capitalize"===t?e.replace(/\w\S*/g,function(e){return e.charAt(0).toUpperCase()+e.substr(1)}):"uppercase"===t?e.toUpperCase():"lowercase"===t?e.toLowerCase():e}static fontPixelSize(e){if(null==e)return;e="string"==typeof e?e:String(e);let[,t,i]=e.match($i.font_size_re)||[];return "em"===(i=i||"px")?t*=16:"pt"===i?t/=.75:"%"===i&&(t/=6.25),t=q.parsePositiveNumber(t),t*=_.device_pixel_ratio}static pruneTextCache(){$i.cache.text_count>$i.cache.text_count_max&&($i.cache.text={},$i.cache.text_count=0,f("debug","TextCanvas: pruning text cache")),Object.keys($i.cache.segment).length>$i.cache.segment_count_max&&($i.cache.segment={},f("debug","TextCanvas: pruning segment cache"));}}$i.font_size_re=/((?:[0-9]*\.)?[0-9]+)\s*(px|pt|em|%)?/,$i.cache={text:{},text_count:0,text_count_max:2e3,segment:{},segment_count_max:2e3,stats:{text_hits:0,text_misses:0,segment_hits:0,segment_misses:0}};let Vi=0;const Bi={resetText(){t.is_main?this.canvas=new $i:t.is_worker&&(this.texts={});},freeText(e){delete this.texts[e.id];},parseTextFeature(e,t,i,r){let s=this.parseTextSource(e,t,i);if(null==s||""===s)return;let n=bi.compute(t,i),o=bi.key(n);this.texts[r.id]=this.texts[r.id]||{};let a=this.texts[r.id][o]=this.texts[r.id][o]||{};if(s instanceof Object){let l=[],u=s.left+"-"+s.right;for(let h in s){let c=s[h];if(!c)continue;let d=this.computeTextLayout({},e,t,i,r,c,n,u,h);a[c]||(a[c]={text_settings:n,ref:0}),l.push({draw:t,text:c,text_settings_key:o,layout:d});}return l.length>0&&l}{let l=this.computeTextLayout({},e,t,i,r,s,n);return a[s]||(a[s]={text_settings:n,ref:0}),{draw:t,text:s,text_settings_key:o,layout:l}}},parseTextSource(e,t,i){let r,s=t.text_source||"name";if(null==s||Array.isArray(s)||"object"!=typeof s)r=this.parseTextSourceValue(s,e,i);else {r={};for(let t in s)r[t]=this.parseTextSourceValue(s[t],e,i);}return r},parseTextSourceValue(e,t,i){let r;if(Array.isArray(e)){for(let s=0;s<e.length;s++)if("string"==typeof e[s]?r=t.properties[e[s]]:"function"==typeof e[s]&&(r=e[s](i)),r)return r}else "string"==typeof e?r=t.properties[e]:e instanceof Function&&(r=e(i));return r},async prepareTextLabels(e,t){if(0===Object.keys(this.texts[e.id]||{}).length)return [];try{const i=await n.postMessage(this.main_thread_target+".calcTextSizes",e.id,this.texts[e.id]);return e.canceled?(f("trace",`Style ${this.name}: stop tile build because tile was canceled: ${e.key}, post-calcTextSizes()`),[]):(this.texts[e.id]=i||[],i?this.buildTextLabels(e,t):(di.abortTile(e.id),[]))}catch(t){return di.abortTile(e.id),[]}},async collideAndRenderTextLabels(e,t,r){let s=await this.prepareTextLabels(e,r);if(0===s.length)return di.collide([],t,e.id),{};if(s=await di.collide(s,t,e.id),e.canceled)return f("trace",`stop tile build because tile was canceled: ${e.key}, post-collide()`),{};let o=this.texts[e.id];if(null==o||0===s.length)return {};this.cullTextStyles(o,s),s.forEach(e=>{let t=e.text_settings_key,i=o[t]&&o[t][e.text];i.text_settings.can_articulate?(i.type||(i.type=[]),-1===i.type.indexOf(e.label.type)&&i.type.push(e.label.type)):(i.align=i.align||{},i.align[e.label.align]={});});try{const t=await n.postMessage(this.main_thread_target+".rasterizeTexts",e.id,e.key,o);return e.canceled?(f("trace",`stop tile build because tile was canceled: ${e.key}, post-rasterizeTexts()`),{}):i({labels:s},t)}catch(e){return {}}},cullTextStyles(e,t){for(let i=0;i<t.length;i++){let r=t[i];e[r.text_settings_key][r.text].ref++;}for(let t in e)for(let i in e[t])e[t][i].ref<1&&delete e[t][i];for(let t in e)0===Object.keys(e[t]).length&&delete e[t];},calcTextSizes(e,t){return this.canvas.textSizes(e,t)},async rasterizeTexts(e,t,i){let r=new $i,s=Math.min(this.max_texture_size,2048),n=r.setTextureTextPositions(i,s),o=["labels",this.name,t,e,Vi,""].join("-");return Vi++,(n=await r.rasterize(i,n,e,o,this.gl))?{texts:i,textures:n}:{}},preprocessText(e){if(e&&e.font&&"object"==typeof e.font)return e.font.weight=q.createPropertyCache(e.font.weight),e.font.fill=q.createPropertyCache(e.font.fill||bi.defaults.fill),e.font.alpha=q.createPropertyCache(e.font.alpha),e.font.stroke&&(e.font.stroke.color=q.createPropertyCache(e.font.stroke.color),e.font.stroke.alpha=q.createPropertyCache(e.font.stroke.alpha)),e.font.background&&(e.font.background.color=q.createPropertyCache(e.font.background.color),e.font.background.alpha=q.createPropertyCache(e.font.background.alpha),e.font.background.width=q.createPropertyCache(e.font.background.width,q.parsePositiveNumber),e.font.background.stroke&&(e.font.background.stroke.color=q.createPropertyCache(e.font.background.stroke.color),e.font.background.stroke.alpha=q.createPropertyCache(e.font.background.stroke.alpha))),e.font.px_size=q.createPropertyCache(e.font.size||bi.defaults.size,$i.fontPixelSize,$i.fontPixelSize),e.font.stroke&&null!=e.font.stroke.width&&(e.font.stroke.width=q.createPropertyCache(e.font.stroke.width,q.parsePositiveNumber)),e.font.background&&e.font.background.stroke&&null!=e.font.background.stroke.width&&(e.font.background.stroke.width=q.createPropertyCache(e.font.background.stroke.width,q.parsePositiveNumber)),e.offset=q.createPropertyCache(e.offset,e=>Array.isArray(e)&&e.map(q.parseNumber)),e.buffer=q.createPropertyCache(e.buffer,e=>(Array.isArray(e)?e:[e,e]).map(q.parsePositiveNumber)),e.repeat_distance=q.createPropertyCache(e.repeat_distance,q.parsePositiveNumber),e},computeTextLayout(e,t,i,r,s,n,o,a,l){let u=e||{};return u=this.computeLayout(u,t,i,r,s),null==i.repeat_distance&&(u.repeat_distance="point"===r.geometry?0:F.tile_size,u.repeat_distance&&(u.repeat_distance*=u.units_per_pixel,u.repeat_scale=1,"function"==typeof i.repeat_group?u.repeat_group=i.repeat_group(r):u.repeat_group=i.repeat_group)),u.repeat_distance&&(a&&(u.repeat_group+="/"+a),u.repeat_group+="/"+n),u.subdiv=s.overzoom2,u.align=i.align,u.italic="normal"!==o.style,"right"===l?u.orientation=1:"left"===l&&(u.orientation=-1),u}};var qi=function(e){return e[0]=1,e[1]=0,e[2]=0,e[3]=0,e[4]=0,e[5]=1,e[6]=0,e[7]=0,e[8]=0,e[9]=0,e[10]=1,e[11]=0,e[12]=0,e[13]=0,e[14]=0,e[15]=1,e};const Xi={fromValues(e,t,i){var r=new Float64Array(3);return r[0]=e,r[1]=t,r[2]=i,r}},Hi={normalFromMat4:function(e,t){var i=t[0],r=t[1],s=t[2],n=t[3],o=t[4],a=t[5],l=t[6],u=t[7],h=t[8],c=t[9],d=t[10],f=t[11],_=t[12],p=t[13],m=t[14],g=t[15],x=i*a-r*o,y=i*l-s*o,v=i*u-n*o,b=r*l-s*a,A=r*u-n*a,T=s*u-n*l,w=h*p-c*_,E=h*m-d*_,R=h*g-f*_,M=c*m-d*p,z=c*g-f*p,N=d*g-f*m,S=x*N-y*z+v*M+b*R-A*E+T*w;return S?(S=1/S,e[0]=(a*N-l*z+u*M)*S,e[1]=(l*R-o*N-u*E)*S,e[2]=(o*z-a*R+u*w)*S,e[3]=(s*z-r*N-n*M)*S,e[4]=(i*N-s*R+n*E)*S,e[5]=(r*R-i*z-n*w)*S,e[6]=(p*T-m*A+g*b)*S,e[7]=(m*v-_*T-g*y)*S,e[8]=(_*A-p*v+g*x)*S,e):null},invert:function(e,t){var i=t[0],r=t[1],s=t[2],n=t[3],o=t[4],a=t[5],l=t[6],u=t[7],h=t[8],c=h*o-a*u,d=-h*n+a*l,f=u*n-o*l,_=i*c+r*d+s*f;return _?(_=1/_,e[0]=c*_,e[1]=(-h*r+s*u)*_,e[2]=(a*r-s*o)*_,e[3]=d*_,e[4]=(h*i-s*l)*_,e[5]=(-a*i+s*n)*_,e[6]=f*_,e[7]=(-u*i+r*l)*_,e[8]=(o*i-r*n)*_,e):null}},Wi={multiply:function(e,t,i){var r=t[0],s=t[1],n=t[2],o=t[3],a=t[4],l=t[5],u=t[6],h=t[7],c=t[8],d=t[9],f=t[10],_=t[11],p=t[12],m=t[13],g=t[14],x=t[15],y=i[0],v=i[1],b=i[2],A=i[3];return e[0]=y*r+v*a+b*c+A*p,e[1]=y*s+v*l+b*d+A*m,e[2]=y*n+v*u+b*f+A*g,e[3]=y*o+v*h+b*_+A*x,y=i[4],v=i[5],b=i[6],A=i[7],e[4]=y*r+v*a+b*c+A*p,e[5]=y*s+v*l+b*d+A*m,e[6]=y*n+v*u+b*f+A*g,e[7]=y*o+v*h+b*_+A*x,y=i[8],v=i[9],b=i[10],A=i[11],e[8]=y*r+v*a+b*c+A*p,e[9]=y*s+v*l+b*d+A*m,e[10]=y*n+v*u+b*f+A*g,e[11]=y*o+v*h+b*_+A*x,y=i[12],v=i[13],b=i[14],A=i[15],e[12]=y*r+v*a+b*c+A*p,e[13]=y*s+v*l+b*d+A*m,e[14]=y*n+v*u+b*f+A*g,e[15]=y*o+v*h+b*_+A*x,e},translate:function(e,t,i){var r,s,n,o,a,l,u,h,c,d,f,_,p=i[0],m=i[1],g=i[2];t===e?(e[12]=t[0]*p+t[4]*m+t[8]*g+t[12],e[13]=t[1]*p+t[5]*m+t[9]*g+t[13],e[14]=t[2]*p+t[6]*m+t[10]*g+t[14],e[15]=t[3]*p+t[7]*m+t[11]*g+t[15]):(r=t[0],s=t[1],n=t[2],o=t[3],a=t[4],l=t[5],u=t[6],h=t[7],c=t[8],d=t[9],f=t[10],_=t[11],e[0]=r,e[1]=s,e[2]=n,e[3]=o,e[4]=a,e[5]=l,e[6]=u,e[7]=h,e[8]=c,e[9]=d,e[10]=f,e[11]=_,e[12]=r*p+a*m+c*g+t[12],e[13]=s*p+l*m+d*g+t[13],e[14]=n*p+u*m+f*g+t[14],e[15]=o*p+h*m+_*g+t[15]);return e},scale:function(e,t,i){var r=i[0],s=i[1],n=i[2];return e[0]=t[0]*r,e[1]=t[1]*r,e[2]=t[2]*r,e[3]=t[3]*r,e[4]=t[4]*s,e[5]=t[5]*s,e[6]=t[6]*s,e[7]=t[7]*s,e[8]=t[8]*n,e[9]=t[9]*n,e[10]=t[10]*n,e[11]=t[11]*n,e[12]=t[12],e[13]=t[13],e[14]=t[14],e[15]=t[15],e},perspective:function(e,t,i,r,s){var n=1/Math.tan(t/2),o=1/(r-s);return e[0]=n/i,e[1]=0,e[2]=0,e[3]=0,e[4]=0,e[5]=n,e[6]=0,e[7]=0,e[8]=0,e[9]=0,e[10]=(s+r)*o,e[11]=-1,e[12]=0,e[13]=0,e[14]=2*s*r*o,e[15]=0,e},lookAt:function(e,t,i,r){var s,n,o,a,l,u,h,c,d,f,_=t[0],p=t[1],m=t[2],g=r[0],x=r[1],y=r[2],v=i[0],b=i[1],A=i[2];if(Math.abs(_-v)<1e-6&&Math.abs(p-b)<1e-6&&Math.abs(m-A)<1e-6)return qi(e);h=_-v,c=p-b,d=m-A,f=1/Math.sqrt(h*h+c*c+d*d),s=x*(d*=f)-y*(c*=f),n=y*(h*=f)-g*d,o=g*c-x*h,(f=Math.sqrt(s*s+n*n+o*o))?(s*=f=1/f,n*=f,o*=f):(s=0,n=0,o=0);a=c*o-d*n,l=d*s-h*o,u=h*n-c*s,(f=Math.sqrt(a*a+l*l+u*u))?(a*=f=1/f,l*=f,u*=f):(a=0,l=0,u=0);return e[0]=s,e[1]=a,e[2]=h,e[3]=0,e[4]=n,e[5]=l,e[6]=c,e[7]=0,e[8]=o,e[9]=u,e[10]=d,e[11]=0,e[12]=-(s*_+n*p+o*m),e[13]=-(a*_+l*p+u*m),e[14]=-(h*_+c*p+d*m),e[15]=1,e},identity:qi,copy:function(e,t){return e[0]=t[0],e[1]=t[1],e[2]=t[2],e[3]=t[3],e[4]=t[4],e[5]=t[5],e[6]=t[6],e[7]=t[7],e[8]=t[8],e[9]=t[9],e[10]=t[10],e[11]=t[11],e[12]=t[12],e[13]=t[13],e[14]=t[14],e[15]=t[15],e}};class Yi{constructor(e,t,i={}){this.view=t,this.position=i.position,this.zoom=i.zoom;}static create(e,t,i){switch(i.type){case"isometric":return new Ji(e,t,i);case"flat":return new Ki(e,t,i);case"perspective":default:return new Zi(e,t,i)}}update(){}setupProgram(){}updateView(){if(this.position||this.zoom){var e={};this.position&&(e={lng:this.position[0],lat:this.position[1],zoom:this.position[2]}),this.zoom&&(e.zoom=this.zoom),this.view.setView(e);}}setupMatrices(e,t){Wi.multiply(e.model_view32,this.view_matrix,e.model),t.uniform("Matrix4fv","u_modelView",e.model_view32),Hi.normalFromMat4(e.normal32,e.model_view32),Hi.invert(e.inverse_normal32,e.normal32),t.uniform("Matrix3fv","u_normalMatrix",e.normal32),t.uniform("Matrix3fv","u_inverseNormalMatrix",e.inverse_normal32);}}class Zi extends Yi{constructor(e,t,i={}){super(e,t,i),this.type="perspective",this.focal_length=i.focal_length,this.fov=i.fov,this.focal_length||this.fov||(this.focal_length=[[16,2],[17,2.5],[18,3],[19,4],[20,6]]),this.vanishing_point=i.vanishing_point||[0,0],this.vanishing_point=this.vanishing_point.map(parseFloat),this.vanishing_point_skew=[],this.position_meters=null,this.view_matrix=new Float64Array(16),this.projection_matrix=new Float32Array(16),P.replaceBlock("camera","\n            uniform mat4 u_projection;\n            uniform vec3 u_eye;\n            uniform vec2 u_vanishing_point;\n\n            void cameraProjection (inout vec4 position) {\n                position = u_projection * position;\n            }");}constrainCamera({view_height:e,height:t,focal_length:i,fov:r}){return t?(i=2*t/e,r=2*Math.atan(1/i)):(i?r=2*Math.atan(1/i):r&&(r=r*Math.PI/180,i=1/Math.tan(r/2)),t=e/2*i),{view_height:e,height:t,focal_length:i,fov:r}}updateMatrices(){var e=this.view.size.css.height*this.view.meters_per_pixel,{height:t,fov:i}=this.constrainCamera({view_height:e,focal_length:_.interpolate(this.view.zoom,this.focal_length),fov:_.interpolate(this.view.zoom,this.fov)}),r=[this.view.center.meters.x,this.view.center.meters.y,t];this.position_meters=r,Wi.lookAt(this.view_matrix,Xi.fromValues(r[0],r[1],0),Xi.fromValues(r[0],r[1],-1),Xi.fromValues(0,1,0)),Wi.perspective(this.projection_matrix,i,this.view.aspect,1,2*t),this.vanishing_point_skew[0]=this.vanishing_point[0]/this.view.size.css.width,this.vanishing_point_skew[1]=this.vanishing_point[1]/this.view.size.css.height,this.projection_matrix[8]=2*-this.vanishing_point_skew[0],this.projection_matrix[9]=2*-this.vanishing_point_skew[1],Wi.translate(this.projection_matrix,this.projection_matrix,Xi.fromValues(e/2*this.view.aspect*(2*-this.vanishing_point_skew[0]),e/2*(2*-this.vanishing_point_skew[1]),0)),Wi.translate(this.projection_matrix,this.projection_matrix,Xi.fromValues(0,0,-t));}update(){super.update(),this.updateMatrices();}setupProgram(e){e.uniform("Matrix4fv","u_projection",this.projection_matrix),e.uniform("3f","u_eye",[0,0,this.position_meters[2]]),e.uniform("2fv","u_vanishing_point",this.vanishing_point_skew);}}class Ji extends Yi{constructor(e,t,i={}){super(e,t,i),this.type="isometric",this.axis=i.axis||{x:0,y:1},2===this.axis.length&&(this.axis={x:this.axis[0],y:this.axis[1]}),this.position_meters=null,this.viewport_height=null,this.view_matrix=new Float64Array(16),this.projection_matrix=new Float32Array(16),P.replaceBlock("camera","\n            uniform mat4 u_projection;\n            uniform vec3 u_eye;\n            uniform vec2 u_vanishing_point;\n\n            void cameraProjection (inout vec4 position) {\n                position = u_projection * position;\n                // position.xy += position.z * u_isometric_axis;\n\n                // Reverse z for depth buffer so up is negative,\n                // and scale down values so objects higher than one screen height will not get clipped\n                // pull forward slightly to avoid going past far clipping plane\n                position.z = -position.z / 100. + 1. - 0.001;\n            }");}update(){super.update(),this.viewport_height=this.view.size.css.height*this.view.meters_per_pixel;var e=[this.view.center.meters.x,this.view.center.meters.y,this.viewport_height];this.position_meters=e,Wi.identity(this.view_matrix),Wi.translate(this.view_matrix,this.view_matrix,Xi.fromValues(-e[0],-e[1],0)),Wi.identity(this.projection_matrix),this.projection_matrix[8]=this.axis.x/this.view.aspect,this.projection_matrix[9]=this.axis.y,Wi.scale(this.projection_matrix,this.projection_matrix,Xi.fromValues(2/this.view.size.meters.x,2/this.view.size.meters.y,2/this.view.size.meters.y));}setupProgram(e){e.uniform("Matrix4fv","u_projection",this.projection_matrix),e.uniform("3fv","u_eye",[0,0,this.viewport_height]),e.uniform("2fv","u_vanishing_point",[0,0]);}}class Ki extends Ji{constructor(e,t,i={}){super(e,t,i),this.type="flat";}update(){this.axis.x=0,this.axis.y=0,super.update();}}const Qi=.5;const er=fi.PLACEMENT,tr=Object.create(Re);Object.assign(tr,Bi),Object.assign(tr,{name:"points",built_in:!0,vertex_shader_src:"uniform vec2 u_resolution;\nuniform float u_time;\nuniform vec3 u_map_position;\nuniform vec4 u_tile_origin;\nuniform float u_tile_proxy_order_offset;\nuniform bool u_tile_fade_in;\nuniform float u_meters_per_pixel;\nuniform float u_device_pixel_ratio;\nuniform float u_visible_time;\nuniform bool u_view_panning;\nuniform float u_view_pan_snap_timer;\n\nuniform mat4 u_model;\nuniform mat4 u_modelView;\nuniform mat3 u_normalMatrix;\nuniform mat3 u_inverseNormalMatrix;\n\nattribute vec4 a_position;\nattribute vec4 a_shape;\nattribute vec4 a_color;\nattribute vec2 a_texcoord;\nattribute vec2 a_offset;\n\nuniform float u_point_type;\n\n#ifdef TANGRAM_CURVED_LABEL\n    attribute vec4 a_offsets;\n    attribute vec4 a_pre_angles;\n    attribute vec4 a_angles;\n#endif\n\nvarying vec4 v_color;\nvarying vec2 v_texcoord;\nvarying vec4 v_world_position;\nvarying float v_alpha_factor;\n\n#ifdef TANGRAM_HAS_SHADER_POINTS\n    attribute float a_outline_edge;\n    attribute vec4 a_outline_color;\n\n    varying float v_outline_edge;\n    varying vec4 v_outline_color;\n    varying float v_aa_offset;\n#endif\n\n#ifdef TANGRAM_SHOW_HIDDEN_LABELS\n    varying float v_label_hidden;\n#endif\n\n#define TANGRAM_PI 3.14159265359\n#define TANGRAM_NORMAL vec3(0., 0., 1.)\n\n#pragma tangram: attributes\n#pragma tangram: camera\n#pragma tangram: material\n#pragma tangram: lighting\n#pragma tangram: raster\n#pragma tangram: global\n\nvec2 rotate2D(vec2 _st, float _angle) {\n    return mat2(cos(_angle),-sin(_angle),\n                sin(_angle),cos(_angle)) * _st;\n}\n\n#ifdef TANGRAM_CURVED_LABEL\n    // Assumes stops are [0, 0.33, 0.66, 0.99];\n    float mix4linear(vec4 v, float x) {\n        x = clamp(x, 0., 1.);\n        return mix(mix(v[0], v[1], 3. * x),\n                   mix(v[1],\n                       mix(v[2], v[3], 3. * (max(x, .66) - .66)),\n                       3. * (clamp(x, .33, .66) - .33)),\n                   step(0.33, x)\n                );\n    }\n#endif\n\nvoid main() {\n    // Initialize globals\n    #pragma tangram: setup\n\n    // discard hidden labels by collapsing into degenerate triangle\n    #ifndef TANGRAM_SHOW_HIDDEN_LABELS\n        if (a_shape.w == 0.) {\n            gl_Position = vec4(0., 0., 0., 1.);\n            return;\n        }\n    #else\n        // highlight hidden label in fragment shader for debugging\n        if (a_shape.w == 0.) {\n            v_label_hidden = 1.; // label debug testing\n        }\n        else {\n            v_label_hidden = 0.;\n        }\n    #endif\n\n    v_alpha_factor = 1.0;\n    v_color = a_color;\n    v_texcoord = a_texcoord; // UV from vertex attribute\n\n    #ifdef TANGRAM_HAS_SHADER_POINTS\n        v_outline_color = a_outline_color;\n        v_outline_edge = a_outline_edge;\n\n        if (u_point_type == TANGRAM_POINT_TYPE_SHADER) { // shader point\n            // use point dimensions for UVs instead (ignore attribute), add antialiasing info for fragment shader\n            float _size = abs(a_shape.x / 128.); // radius in pixels\n            v_texcoord = sign(a_shape.xy) * (_size + 1.) / _size;\n            _size += 2.;\n            v_aa_offset = 2. / _size;\n        }\n    #endif\n\n    // Position\n    vec4 position = u_modelView * vec4(a_position.xyz, 1.);\n\n    // Apply positioning and scaling in screen space\n    vec2 _shape = a_shape.xy / 256.;                 // values have an 8-bit fraction\n    vec2 _offset = vec2(a_offset.x, -a_offset.y);    // flip y to make it point down\n    float _theta = a_shape.z / 4096.;\n\n    #ifdef TANGRAM_CURVED_LABEL\n        //TODO: potential bug? null is passed in for non-curved labels, otherwise the first offset will be 0\n        if (a_offsets[0] != 0.){\n            vec4 _angles_scaled = (TANGRAM_PI / 16384.) * a_angles;\n            vec4 _pre_angles_scaled = (TANGRAM_PI / 128.) * a_pre_angles;\n            vec4 _offsets_scaled = (1. / 64.) * a_offsets;\n\n            float _zoom = clamp(u_map_position.z - u_tile_origin.z, 0., 1.); //fract(u_map_position.z);\n            float _pre_angle = mix4linear(_pre_angles_scaled, _zoom);\n            float _angle = mix4linear(_angles_scaled, _zoom);\n            float _offset_curve = mix4linear(_offsets_scaled, _zoom);\n\n            _shape = rotate2D(_shape, _pre_angle); // rotate in place\n            _shape.x += _offset_curve;            // offset for curved label segment\n            _shape = rotate2D(_shape, _angle);     // rotate relative to curved label anchor\n            _shape += rotate2D(_offset, _theta);   // offset if specified in the scene file\n        }\n        else {\n            _shape = rotate2D(_shape + _offset, _theta);\n        }\n    #else\n        _shape = rotate2D(_shape + _offset, _theta);\n    #endif\n\n    // Fade in (if requested) based on time mesh has been visible.\n    // Value passed to fragment shader in the v_alpha_factor varying\n    #ifdef TANGRAM_FADE_IN_RATE\n        if (u_tile_fade_in) {\n            v_alpha_factor *= clamp(u_visible_time * TANGRAM_FADE_IN_RATE, 0., 1.);\n        }\n    #endif\n\n    // World coordinates for 3d procedural textures\n    v_world_position = u_model * position;\n    v_world_position.xy += _shape * u_meters_per_pixel;\n    v_world_position = wrapWorldPosition(v_world_position);\n\n    // Modify position before camera projection\n    #pragma tangram: position\n\n    cameraProjection(position);\n\n    #ifdef TANGRAM_LAYER_ORDER\n        // +1 is to keep all layers including proxies > 0\n        applyLayerOrder(a_position.w + u_tile_proxy_order_offset + 1., position);\n    #endif\n\n    // Apply pixel offset in screen-space\n    // Multiply by 2 is because screen is 2 units wide Normalized Device Coords (and u_resolution device pixels wide)\n    // Device pixel ratio adjustment is because shape is in logical pixels\n    position.xy += _shape * position.w * 2. * u_device_pixel_ratio / u_resolution;\n    #ifdef TANGRAM_HAS_SHADER_POINTS\n        if (u_point_type == TANGRAM_POINT_TYPE_SHADER) { // shader point\n            // enlarge by 1px to catch missed MSAA fragments\n            position.xy += sign(_shape) * position.w * u_device_pixel_ratio / u_resolution;\n        }\n    #endif\n\n    // Snap to pixel grid\n    // Only applied to fully upright sprites/labels (not shader-drawn points), while panning is not active\n    #ifdef TANGRAM_HAS_SHADER_POINTS\n    if (!u_view_panning && (abs(_theta) < TANGRAM_EPSILON) && u_point_type != TANGRAM_POINT_TYPE_SHADER) {\n    #else\n    if (!u_view_panning && (abs(_theta) < TANGRAM_EPSILON)) {\n    #endif\n        vec2 _position_fract = fract((((position.xy / position.w) + 1.) * .5) * u_resolution);\n        vec2 _position_snap = position.xy + ((step(0.5, _position_fract) - _position_fract) * position.w * 2. / u_resolution);\n\n        // Animate the snapping to smooth the transition and make it less noticeable\n        #ifdef TANGRAM_VIEW_PAN_SNAP_RATE\n            position.xy = mix(position.xy, _position_snap, clamp(u_view_pan_snap_timer * TANGRAM_VIEW_PAN_SNAP_RATE, 0., 1.));\n        #else\n            position.xy = _position_snap;\n        #endif\n    }\n\n    gl_Position = position;\n}\n",fragment_shader_src:"uniform vec2 u_resolution;\nuniform float u_time;\nuniform vec3 u_map_position;\nuniform vec4 u_tile_origin;\nuniform float u_meters_per_pixel;\nuniform float u_device_pixel_ratio;\nuniform float u_visible_time;\n\nuniform mat3 u_normalMatrix;\nuniform mat3 u_inverseNormalMatrix;\n\nuniform sampler2D u_texture;\nuniform float u_point_type;\nuniform bool u_apply_color_blocks;\n\nvarying vec4 v_color;\nvarying vec2 v_texcoord;\nvarying vec4 v_world_position;\nvarying float v_alpha_factor;\n\n#ifdef TANGRAM_HAS_SHADER_POINTS\n    varying vec4 v_outline_color;\n    varying float v_outline_edge;\n    varying float v_aa_offset;\n#endif\n\n#ifdef TANGRAM_SHOW_HIDDEN_LABELS\n    varying float v_label_hidden;\n#endif\n\n#define TANGRAM_NORMAL vec3(0., 0., 1.)\n\n#pragma tangram: attributes\n#pragma tangram: camera\n#pragma tangram: material\n#pragma tangram: lighting\n#pragma tangram: raster\n#pragma tangram: global\n\n#ifdef TANGRAM_HAS_SHADER_POINTS\n    //l is the distance from the center to the fragment, R is the radius of the drawn point\n    float _tangram_antialias(float l, float R){\n        float low  = R - v_aa_offset;\n        float high = R + v_aa_offset;\n        return 1. - smoothstep(low, high, l);\n    }\n#endif\n\nvoid main (void) {\n    // Initialize globals\n    #pragma tangram: setup\n\n    vec4 color = v_color;\n\n    #ifdef TANGRAM_HAS_SHADER_POINTS\n        // Only apply shader blocks to point, not to attached text (N.B.: for compatibility with ES)\n        if (u_point_type == TANGRAM_POINT_TYPE_TEXTURE) { // sprite texture\n            color *= texture2D(u_texture, v_texcoord);\n        }\n        else if (u_point_type == TANGRAM_POINT_TYPE_LABEL) { // label texture\n            color = texture2D(u_texture, v_texcoord);\n            color.rgb /= max(color.a, 0.001); // un-multiply canvas texture\n        }\n        else if (u_point_type == TANGRAM_POINT_TYPE_SHADER) { // shader point\n            // Mask of outermost circle, either outline or point boundary\n            float _d = length(v_texcoord); // distance to this fragment from the point center\n            float _outer_alpha = _tangram_antialias(_d, 1.);\n            float _fill_alpha = _tangram_antialias(_d, 1. - (v_outline_edge * 0.5)) * color.a;\n            float _stroke_alpha = (_outer_alpha - _tangram_antialias(_d, 1. - v_outline_edge)) * v_outline_color.a;\n\n            // Apply alpha compositing with stroke 'over' fill.\n            #ifdef TANGRAM_BLEND_ADD\n                color.a = _stroke_alpha + _fill_alpha;\n                color.rgb = color.rgb * _fill_alpha + v_outline_color.rgb * _stroke_alpha;\n            #else // TANGRAM_BLEND_OVERLAY (and fallback for not implemented blending modes)\n                color.a = _stroke_alpha + _fill_alpha * (1. - _stroke_alpha);\n                color.rgb = mix(color.rgb * _fill_alpha, v_outline_color.rgb, _stroke_alpha) / max(color.a, 0.001); // avoid divide by zero\n            #endif\n        }\n    #else\n        // If shader points not supported, assume label texture\n        color = texture2D(u_texture, v_texcoord);\n        color.rgb /= max(color.a, 0.001); // un-multiply canvas texture\n    #endif\n\n    // Shader blocks for color/filter are only applied for sprites, shader points, and standalone text,\n    // NOT for text attached to a point (N.B.: for compatibility with ES)\n    if (u_apply_color_blocks) {\n        #pragma tangram: color\n        #pragma tangram: filter\n    }\n\n    color.a *= v_alpha_factor;\n\n    // highlight hidden label in fragment shader for debugging\n    #ifdef TANGRAM_SHOW_HIDDEN_LABELS\n        if (v_label_hidden > 0.) {\n            color.a *= 0.5;\n            color.rgb = vec3(1., 0., 0.);\n        }\n    #endif\n\n    // Use alpha test as a lower-quality substitute\n    // For opaque and translucent: avoid transparent pixels writing to depth buffer, obscuring geometry underneath\n    // For multiply: avoid transparent pixels multiplying geometry underneath to zero/full black\n    #if defined(TANGRAM_BLEND_OPAQUE) || defined(TANGRAM_BLEND_TRANSLUCENT) || defined(TANGRAM_BLEND_MULTIPLY)\n        if (color.a < TANGRAM_ALPHA_TEST) {\n            discard;\n        }\n    #endif\n\n    // Make points more visible in wireframe debug mode\n    #ifdef TANGRAM_WIREFRAME\n        color = vec4(vec3(0.5), 1.); // use gray outline for textured points\n        #ifdef TANGRAM_HAS_SHADER_POINTS\n            if (u_point_type == TANGRAM_POINT_TYPE_SHADER) {\n                color = vec4(v_color.rgb, 1.); // use original vertex color outline for shader points\n            }\n        #endif\n    #endif\n\n    gl_FragColor = color;\n}\n",selection:!0,collision:!0,blend:"overlay",init(e={}){Re.init.call(this,e),this.setupDefines(),this.defines.TANGRAM_HAS_SHADER_POINTS=!0,this.defines.TANGRAM_POINT_TYPE_TEXTURE=1,this.defines.TANGRAM_POINT_TYPE_LABEL=2,this.defines.TANGRAM_POINT_TYPE_SHADER=3,this.collision_group_points=this.name+"-points",this.collision_group_text=this.name+"-text",this.stencil_proxy_tiles=!1,this.reset();},setupDefines(){"overlay"!==this.blend&&(this.defines.TANGRAM_LAYER_ORDER=!0),!0===m.suppress_label_fade_in?(this.fade_in_time=0,this.defines.TANGRAM_FADE_IN_RATE=null):(this.fade_in_time=.15,this.defines.TANGRAM_FADE_IN_RATE=1/this.fade_in_time),!0!==m.suppress_label_snap_animation&&(this.defines.TANGRAM_VIEW_PAN_SNAP_RATE=1/Qi),!0===m.show_hidden_labels&&(this.defines.TANGRAM_SHOW_HIDDEN_LABELS=!0),!0===m.wireframe&&(this.defines.TANGRAM_WIREFRAME=!0);},reset(){this.queues={},this.resetText(),this.texture_missing_sprites={};},addFeature(e,t,i){let r=i.tile;if(r.generation!==this.generation)return;let s,n={};if(n.color=this.parseColor(t.color,i),n.texture=t.texture,n.label_texture=null,n.blend_order=t.blend_order,!n.color&&!n.texture)return;if(n.alpha=q.evalCachedProperty(t.alpha,i),this.hasSprites(n)){if(!(s=this.parseSprite(n,t,i)))return void f({level:"debug",once:!0},`Layer group '${t.layers.join(", ")}' `+`uses a texture '${n.texture}', but doesn't specify which sprite to draw. `+"Features that match this layer group won't be drawn without specifying the sprite with the 'sprite' or 'sprite_default' properties. The merged draw parameters for this layer group are:",t).then(i=>{i&&f("debug",`Example feature for layer group '${t.layers.join(", ")}'`,e);});n.texcoords=s.texcoords;}else if(t.sprite)return void f({level:"warn",once:!0},`Layer group '${t.layers.join(", ")}' `+`specifies sprite '${t.sprite}', but the texture '${t.texture}' doesn't define any sprites. `+"Features that match this layer group won't be drawn. The merged draw parameters for this layer group are:",t);if(this.calcSize(t,n,s,i),t.outline&&(n.outline_width=q.evalCachedProperty(t.outline.width,i)||q.defaults.outline.width,n.outline_color=this.parseColor(t.outline.color,i)),n.outline_edge_pct=0,n.outline_width&&n.outline_color){let e=n.outline_width;n.size[0]+=e,n.size[1]+=e,n.outline_edge_pct=e/Math.min(n.size[0],n.size[1])*2,n.outline_alpha=q.evalCachedProperty(t.outline.alpha,i);}n.size[0]=Math.min(n.size[0],256),n.size[1]=Math.min(n.size[1],256),n.placement=t.placement,n.placement_min_length_ratio=q.evalCachedProperty(t.placement_min_length_ratio,i),n.placement===er.SPACED&&t.placement_spacing&&(n.placement_spacing=q.evalCachedProperty(t.placement_spacing,i)),n.angle=q.evalProperty(t.angle,i)||0,n.z=q.evalCachedDistanceProperty(t.z,i)||q.defaults.z,n.tile_edges=t.tile_edges,this.computeLayout(n,e,t,i,r);let o=t.text&&!1!==t.text.visible&&this.parseTextFeature(e,t.text,i,r);Array.isArray(o)&&(o=null,f({level:"warn",once:!0},`Layer group '${t.layers.join(", ")}': `+"cannot use boundary labels (e.g. 'text_source: { left: ..., right: ... }') for 'text' labels attached to 'points'; "+`provided 'text_source' value was ${JSON.stringify(t.text.text_source)}`)),o&&(o.layout.parent=n,o.layout.priority=t.text.priority?Math.max(o.layout.priority,n.priority+.5):n.priority+.5,di.addStyle(this.collision_group_text,r.id)),this.queueFeature({feature:e,draw:t,context:i,style:n,text_feature:o},r),di.addStyle(this.collision_group_points,r.id);},calcSize(e,t,i,r){if(t.size=e.size,t.size){if(t.size=q.evalCachedPointSizeProperty(e.size,i,w.textures[t.texture],r),null==t.size)return void f({level:"warn",once:!0},`Layer group '${e.layers.join(", ")}': `+`'size' (${JSON.stringify(e.size.value)}) couldn't be interpreted, features that match `+"this layer group won't be drawn");"number"==typeof t.size&&(t.size=[t.size,t.size]);}else t.size=i&&i.css_size||[16,16];},hasSprites:e=>e.texture&&w.textures[e.texture]&&w.textures[e.texture].sprites,getSpriteInfo(e,t){let i=w.textures[e.texture].sprites[t]&&w.getSpriteInfo(e.texture,t);return t&&!i?(this.texture_missing_sprites[e.texture]=this.texture_missing_sprites[e.texture]||{},this.texture_missing_sprites[e.texture][t]||(f("debug",`Style: in style '${this.name}', could not find sprite '${t}' for texture '${e.texture}'`),this.texture_missing_sprites[e.texture][t]=!0)):i&&(i.sprite=t),i},parseSprite(e,t,i){let r=q.evalProperty(t.sprite,i);return this.getSpriteInfo(e,r)||this.getSpriteInfo(e,t.sprite_default)},queueFeature(e,t){this.tile_data[t.id]&&this.queues[t.id]||this.startData(t),this.queues[t.id]=this.queues[t.id]||[],this.queues[t.id].push(e);},async endData(e){if(e.canceled)return f("trace",`Style ${this.name}: stop tile build because tile was canceled: ${e.key}`),null;let t=this.queues[e.id];delete this.queues[e.id];let i=[],r=[];t.forEach(e=>{let t=e.style,s=e.feature,n=s.geometry,o=this.buildLabels(t.size,n,t);for(let n=0;n<o.length;n++){let a=o[n],l={feature:s,draw:e.draw,context:e.context,style:t,label:a};if(r.push(l),e.text_feature){let t={feature:s,draw:e.text_feature.draw,context:e.context,text:e.text_feature.text,text_settings_key:e.text_feature.text_settings_key,layout:e.text_feature.layout,point_label:a,linked:l};i.push(t),e.draw.text.optional||(l.linked=t);}}});const[,{labels:s,texts:n,textures:o}]=await Promise.all([di.collide(r,this.collision_group_points,e.id).then(e=>{e.forEach(e=>{this.feature_style=e.style,this.feature_style.label=e.label,this.feature_style.linked=e.linked,Re.addFeature.call(this,e.feature,e.draw,e.context);});}),this.collideAndRenderTextLabels(e,this.collision_group_text,i)]);s&&n&&s.forEach(e=>{let t=e.text_settings_key,i=n[t]&&n[t][e.text],r=this.feature_style;r.label=e.label,r.linked=e.linked,r.size=i.size.logical_size,r.texcoords=i.align[e.label.align].texcoords,r.label_texture=o[i.align[e.label.align].texture_id],r.blend_order=e.draw.blend_order,Re.addFeature.call(this,e.feature,e.draw,e.context);}),this.freeText(e);const a=await Re.endData.call(this,e);return a&&o&&o.length&&(a.textures=a.textures||[],a.textures.push(...o)),a},_preprocess(e){e.color=q.createColorPropertyCache(e.color),e.alpha=q.createPropertyCache(e.alpha),e.texture=void 0!==e.texture?e.texture:this.texture,e.blend_order=this.getBlendOrderForDraw(e),e.outline&&(e.outline.color=q.createColorPropertyCache(e.outline.color),e.outline.alpha=q.createPropertyCache(e.outline.alpha),e.outline.width=q.createPropertyCache(e.outline.width,q.parsePositiveNumber)),e.z=q.createPropertyCache(e.z,q.parseUnits);try{e.size=q.createPointSizePropertyCache(e.size,e.texture);}catch(t){return f({level:"warn",once:!0},`Layer group '${e.layers.join(", ")}': `+`${t} (${JSON.stringify(e.size)}), features that match this layer group won't be drawn.`),null}if(e.offset=q.createPropertyCache(e.offset,e=>Array.isArray(e)&&e.map(q.parseNumber)),e.buffer=q.createPropertyCache(e.buffer,e=>(Array.isArray(e)?e:[e,e]).map(q.parsePositiveNumber)),e.repeat_distance=q.createPropertyCache(e.repeat_distance,q.parseNumber),e.placement=er[e.placement&&e.placement.toUpperCase()],null==e.placement&&(e.placement=er.VERTEX),e.placement_spacing=null!=e.placement_spacing?e.placement_spacing:80,e.placement_spacing=q.createPropertyCache(e.placement_spacing,q.parsePositiveNumber),e.placement_min_length_ratio=null!=e.placement_min_length_ratio?e.placement_min_length_ratio:1,e.placement_min_length_ratio=q.createPropertyCache(e.placement_min_length_ratio,q.parsePositiveNumber),"number"==typeof e.angle)e.angle=e.angle*Math.PI/180;else if("function"==typeof e.angle){const t=e.angle;e.angle=(e=>t(e)*Math.PI/180);}else e.angle=e.angle||0;return e.text=this.preprocessText(e.text),e.text&&(e.text.key=e.key,e.text.group=e.group,e.text.layers=e.layers,e.text.order=e.order,e.text.blend_order=e.blend_order,e.text.repeat_group=null!=e.text.repeat_group?e.text.repeat_group:e.repeat_group,e.text.anchor=e.text.anchor||this.default_anchor,e.text.optional="boolean"==typeof e.text.optional&&e.text.optional,e.text.interactive=e.text.interactive||e.interactive),e},default_anchor:["bottom","top","right","left"],computeLayout(e,t,i,r,s){let n=e||{};n.id=t,n.units_per_pixel=s.units_per_pixel||1,n.collide=!1!==i.collide,n.anchor=i.anchor,n.offset=q.evalCachedProperty(i.offset,r)||q.zeroPair,n.buffer=q.evalCachedProperty(i.buffer,r)||q.zeroPair,n.repeat_distance=q.evalCachedProperty(i.repeat_distance,r),n.repeat_distance&&(n.repeat_distance*=n.units_per_pixel,n.repeat_scale=1,"function"==typeof i.repeat_group?n.repeat_group=i.repeat_group(r):n.repeat_group=i.repeat_group||r.layer);let o=i.priority;return null!=o?"function"==typeof o&&(o=o(r)):o=-1>>>0,n.priority=o,n},buildTextLabels(e,t){let i=[];for(let r=0;r<t.length;r++){let s=t[r],n=this.texts[e.id][s.text_settings_key][s.text].size.collision_size;s.label=new fi(s.point_label.position,n,s.layout),i.push(s);}return i},buildLabels(e,t,i){let r=[];if("Point"===t.type)r.push(new fi(t.coordinates,e,i,i.angle));else if("MultiPoint"===t.type){let s=t.coordinates;for(let t=0;t<s.length;++t){let n=s[t];r.push(new fi(n,e,i,i.angle));}}else if("LineString"===t.type){let s=mi(t.coordinates,e,i);for(let e=0;e<s.length;++e)r.push(s[e]);}else if("MultiLineString"===t.type){let s=t.coordinates;for(let t=0;t<s.length;t++){let n=mi(s[t],e,i);for(let e=0;e<n.length;++e)r.push(n[e]);}}else if("Polygon"===t.type)if(i.placement===er.CENTROID){let s=F.centroid(t.coordinates);s&&r.push(new fi(s,e,i,i.angle));}else {let s=t.coordinates;for(let t=0;t<s.length;t++){let n=mi(s[t],e,i);for(let e=0;e<n.length;++e)r.push(n[e]);}}else if("MultiPolygon"===t.type)if(i.placement===er.CENTROID){let s=F.multiCentroid(t.coordinates);s&&r.push(new fi(s,e,i,i.angle));}else {let s=t.coordinates;for(let t=0;t<s.length;t++){let n=s[t];for(let t=0;t<n.length;t++){let s=mi(n[t],e,i);for(let e=0;e<s.length;++e)r.push(s[e]);}}}return r},makeVertexTemplate(e,t,i=!0){let r=0;this.vertex_template[r++]=0,this.vertex_template[r++]=0,this.vertex_template[r++]=e.z||0,this.vertex_template[r++]=this.scaleOrder(e.order),this.vertex_template[r++]=0,this.vertex_template[r++]=0,this.vertex_template[r++]=0,this.vertex_template[r++]=e.label.layout.collide?0:1,t.variant.shader_point||(this.vertex_template[r++]=0,this.vertex_template[r++]=0),this.vertex_template[r++]=0,this.vertex_template[r++]=0;const s=e.color||q.defaults.color;if(this.vertex_template[r++]=255*s[0],this.vertex_template[r++]=255*s[1],this.vertex_template[r++]=255*s[2],this.vertex_template[r++]=255*(null!=e.alpha?e.alpha:s[3]),t.variant.selection&&(this.vertex_template[r++]=255*e.selection_color[0],this.vertex_template[r++]=255*e.selection_color[1],this.vertex_template[r++]=255*e.selection_color[2],this.vertex_template[r++]=255*e.selection_color[3]),t.variant.shader_point){const t=e.outline_color||q.defaults.outline.color;this.vertex_template[r++]=255*t[0],this.vertex_template[r++]=255*t[1],this.vertex_template[r++]=255*t[2],this.vertex_template[r++]=255*(null!=e.outline_alpha?e.outline_alpha:t[3]),this.vertex_template[r++]=e.outline_edge_pct||q.defaults.outline.width;}return i&&this.addCustomAttributesToVertexTemplate(e,r),this.vertex_template},buildQuad:(e,t,i,r,s,n,o,a,l,u,h)=>t[0]<=0||t[1]<=0?0:function(e,t,i,r,s,n,o,a,l,u,h,c){const d=s[0]*Bt,f=s[1]*Bt;Ht[0]=-d,Ht[1]=-f,Ht[2]=d,Ht[3]=f;const _=h||Ie,p=t.vertex_elements;let m=t.vertex_count;for(let s=0;s<4;s++)i[r.a_position+0]=e[0],i[r.a_position+1]=e[1],i[r.a_shape+0]=Ht[qt[s]],i[r.a_shape+1]=Ht[Xt[s]],i[r.a_shape+2]=l,i[r.a_offset+0]=n[0],i[r.a_offset+1]=n[1],r.a_texcoord&&(i[r.a_texcoord+0]=_[qt[s]]*Vt,i[r.a_texcoord+1]=_[Xt[s]]*Vt),c&&(i[r.a_pre_angles+0]=Ct*a[0],i[r.a_pre_angles+1]=Ct*a[1],i[r.a_pre_angles+2]=Ct*a[2],i[r.a_pre_angles+3]=Ct*a[3],i[r.a_angles+0]=jt*u[0],i[r.a_angles+1]=jt*u[1],i[r.a_angles+2]=jt*u[2],i[r.a_angles+3]=jt*u[3],i[r.a_offsets+0]=$t*o[0],i[r.a_offsets+1]=$t*o[1],i[r.a_offsets+2]=$t*o[2],i[r.a_offsets+3]=$t*o[3]),t.addVertex(i);return p.push(m+0),p.push(m+1),p.push(m+2),p.push(m+2),p.push(m+3),p.push(m+0),2}(e,u,h,u.vertex_layout.index,t,n,o,s,4096*i,r,a,l),build(e,t){let i=e.label;return "curved"===i.type?this.buildCurvedLabel(i,e,t):this.buildStraightLabel(i,e,t)},buildStraightLabel(e,t,i){let r,s,n=this.getTileMesh(i.tile,this.meshVariantTypeForDraw(t)),o=this.makeVertexTemplate(t,n);"point"!==e.type?(r=t.size[e.type],s=t.texcoords[e.type].texcoord):(r=t.size,s=t.texcoords),n.uniforms=n.uniforms||{},t.label_texture?(n.uniforms.u_texture=t.label_texture,n.uniforms.u_point_type=2,n.uniforms.u_apply_color_blocks=!1):t.texture?(n.uniforms.u_texture=t.texture,n.uniforms.u_point_type=1,n.uniforms.u_apply_color_blocks=!0):(n.uniforms.u_texture=w.default,n.uniforms.u_point_type=3,n.uniforms.u_apply_color_blocks=!0);let a=e.offset,l=this.buildQuad(e.position,r,e.angle,null,null,a,null,s,!1,n.vertex_data,o);const u=t.linked&&t.linked.label.id;return this.trackLabel(e,u,n,l,i),l},buildCurvedLabel(e,t,i){let r,s,n=0;for(let o=0;o<e.num_segments;o++){let a=t.size[e.type][o],l=t.texcoords_stroke[o];t.label_texture=t.label_textures[o],r=this.getTileMesh(i.tile,this.meshVariantTypeForDraw(t)),s=this.makeVertexTemplate(t,r),r.uniforms=r.uniforms||{},r.uniforms.u_texture=t.label_texture,r.uniforms.u_point_type=2,r.uniforms.u_apply_color_blocks=!1;let u=e.offset||[0,0],h=e.position,c=e.angles[o],d=e.offsets[o],f=e.pre_angles[o],_=this.buildQuad(h,a,e.angle,c,f,u,d,l,!0,r.vertex_data,s);n+=_;const p=t.linked&&t.linked.label.id;this.trackLabel(e,p,r,_,i);}for(let o=0;o<e.num_segments;o++){let a=t.size[e.type][o],l=t.texcoords[e.type][o].texcoord;t.label_texture=t.label_textures[o],r=this.getTileMesh(i.tile,this.meshVariantTypeForDraw(t)),s=this.makeVertexTemplate(t,r),r.uniforms=r.uniforms||{},r.uniforms.u_texture=t.label_texture,r.uniforms.u_point_type=2,r.uniforms.u_apply_color_blocks=!1;let u=e.offset||[0,0],h=e.position,c=e.angles[o],d=e.offsets[o],f=e.pre_angles[o],_=this.buildQuad(h,a,e.angle,c,f,u,d,l,!0,r.vertex_data,s);n+=_;const p=t.linked&&t.linked.label.id;this.trackLabel(e,p,r,_,i);}return n},trackLabel(e,t,i,r){if(e.layout.collide||e.may_repeat_across_tiles){i.labels=i.labels||{},i.labels[e.id]=i.labels[e.id]||{container:{label:e.toJSON(),linked:t},ranges:[]};const s=2*r,n=i.vertex_data.offset-i.vertex_data.stride*s;i.labels[e.id].ranges.push([n,s]);}},buildLines(e,t,i){return this.build(t,i)},buildPoints(e,t,i){return this.build(t,i)},buildPolygons(e,t,i){return this.build(t,i)},vertexLayoutForMeshVariant(e){if(null==this.vertex_layouts[e.shader_point]){const t=[{name:"a_position",size:4,type:ne.SHORT,normalized:!1},{name:"a_shape",size:4,type:ne.SHORT,normalized:!1},{name:"a_texcoord",size:2,type:ne.UNSIGNED_SHORT,normalized:!0,static:e.shader_point?[0,0]:null},{name:"a_offset",size:2,type:ne.SHORT,normalized:!1},{name:"a_color",size:4,type:ne.UNSIGNED_BYTE,normalized:!0},{name:"a_selection_color",size:4,type:ne.UNSIGNED_BYTE,normalized:!0,static:e.selection?null:[0,0,0,0]},{name:"a_outline_color",size:4,type:ne.UNSIGNED_BYTE,normalized:!0,static:e.shader_point?null:[0,0,0,0]},{name:"a_outline_edge",size:1,type:ne.FLOAT,normalized:!1,static:e.shader_point?null:0}];this.addCustomAttributesToAttributeList(t),this.vertex_layouts[e.shader_point]=new Le(t);}return this.vertex_layouts[e.shader_point]},meshVariantTypeForDraw(e){const t=e.label_texture||e.texture||"__shader_point",i=t+"/"+e.blend_order;return null==this.variants[i]&&(this.variants[i]={key:i,selection:1,shader_point:"__shader_point"===t,blend_order:e.blend_order,mesh_order:e.label_texture?1:0}),this.variants[i]},makeMesh(e,t,i={}){return i=Object.assign({},i,{fade_in_time:this.fade_in_time}),Re.makeMesh.call(this,e,t,i)}});const ir=[0,.33,.66,.99],rr=.1,sr=1.3,nr=.4,or=1,ar=1.2,lr=.01;let ur=function(e,t,i,r){const s=[{type:"straight",tolerance:r.no_curving?1.8:1.5},{type:"curved"},{type:"straight",tolerance:2.3}];for(let n=0;n<s.length;n++){let o,a=s[n];if("straight"===a.type?o=new cr(t,i,r,a.tolerance):"curved"===a.type&&!r.no_curving&&i.length>2&&(o=new dr(e,i,r)),o&&!o.throw_away)return o}return !1};class hr{constructor(e){this.id=li.nextLabelId(),this.layout=e,this.position=[],this.angle=0,this.offset=e.offset.slice(),this.unit_scale=this.layout.units_per_pixel,this.obbs=[],this.aabbs=[],this.type="",this.throw_away=!1;}toJSON(){return {id:this.id,type:this.type,position:this.position,size:this.size,offset:this.offset,angle:this.angle,breach:this.breach,may_repeat_across_tiles:this.may_repeat_across_tiles,layout:ui(this.layout)}}static splitLineByOrientation(e){let t=[e[0]],i=0,r=0,s=0,n=t,o=!1;for(let a=1;a<e.length;a++){let l=e[a],u=e[a-1],h=ce.length(ce.sub(l,u));l[0]>u[0]?1===s?(t.push(l),(i+=h)>r&&(n=t,r=i,o=!1)):(t=[u,l],(i=h)>r&&(n=t,r=i,o=!1),s=1):l[0]<u[0]?-1===s?(t.unshift(l),(i+=h)>r&&(n=t,r=i,o=!0)):(t=[l,u],(i=h)>r&&(n=t,r=i,o=!0),s=-1):(-1===s?t.unshift(l):(t.push(l),s=1),(i+=h)>r&&(n=t,r=i,o=-1===s));}return [n,o]}discard(e,t=null){if(this.throw_away)return !0;for(let i=0;i<this.obbs.length;i++){let r={aabb:this.aabbs[i],obb:this.obbs[i]};if(li.prototype.occluded.call(r,e,t))return !0}return !1}inTileBounds(){for(let e=0;e<this.aabbs.length;e++){let t={aabb:this.aabbs[e]};if(!li.prototype.inTileBounds.call(t))return !1}return !0}static createOBB(e,t,i,r,s,n,o){let a=e[0],l=e[1];return !n||0===n[0]&&0===n[1]||(a+=(n=ce.rot(n,s))[0]*o,l-=n[1]*o),new ai(a,l,-r,t,i)}}class cr extends hr{constructor(e,t,i,r){super(i),this.type="straight",this.size=e,this.throw_away=!this.fit(e,t,i,r);}fit(e,t,i,r){let s,n=this.unit_scale;[t,s]=hr.splitLineByOrientation(t),"number"==typeof i.orientation&&(this.offset[1]+=ar*(e[1]-i.vertical_buffer),s&&(this.offset[1]*=-1),-1===i.orientation&&(this.offset[1]*=-1));let o=pr(t),a=e[0]*n;for(let s=0;s<t.length-1;s++){let n,l=t[s],u=0,h=0,c=s+1;for(;c<t.length;){let d=t[c-1],f=t[c],_=_r(d,f);if(c!==s+1&&(u+=mr(_,n)),Math.abs(u)>rr)break;if(fr(h+=o[c-1],a)<r){let t=ce.mult(ce.add(l,f),.5);return this.angle=-_,Math.abs(this.angle-Math.PI/2)<lr&&(this.angle=-Math.PI/2,"number"==typeof i.orientation&&(this.offset[1]*=-1)),this.position=t,this.updateBBoxes(this.position,e,this.angle,this.angle,this.offset),!0}n=_,c++;}}return !1}updateBBoxes(e,t,i,r,s){let n=this.unit_scale;this.obbs=[],this.aabbs=[];let o=(t[0]+2*this.layout.buffer[0])*n*li.epsilon,a=(t[1]+2*this.layout.buffer[1])*n*li.epsilon,l=hr.createOBB(e,o,a,i,r,s,n),u=l.getExtent();this.obbs.push(l),this.aabbs.push(u),this.inTileBounds&&(this.breach=!this.inTileBounds()),this.mayRepeatAcrossTiles&&(this.may_repeat_across_tiles=this.mayRepeatAcrossTiles());}}class dr extends hr{constructor(e,t,i){super(i),this.type="curved",this.angles=[],this.pre_angles=[],this.offsets=[],this.num_segments=e.length,this.sizes=e,this.throw_away=!this.fit(this.sizes,t,i);}toJSON(){return {id:this.id,type:this.type,obbs:this.obbs.map(e=>e.toJSON()),position:this.position,breach:this.breach,may_repeat_across_tiles:this.may_repeat_across_tiles,layout:ui(this.layout)}}fit(e,t,i){let r,s=this.unit_scale,n=Math.max(...e.map(e=>e[1])),o=n*s;[t,r]=hr.splitLineByOrientation(t),"number"==typeof i.orientation&&(this.offset[1]+=ar*(n-i.vertical_buffer),r&&(this.offset[1]*=-1),-1===i.orientation&&(this.offset[1]*=-1));let a=pr(t),l=e.map(e=>e[0]*s),u=a.reduce((e,t)=>e+t,0),h=l.reduce((e,t)=>e+t,0);if(h>u)return !1;let c=t.length-1;if(c-0<2)return !1;let d=dr.curvaturePlacement(t,u,a,h,0,c),f=t[d];if(-1===d||c-d<2)return !1;this.position=f;for(var _=0;_<l.length;_++){this.offsets[_]=[],this.angles[_]=[],this.pre_angles[_]=[];for(var p=0;p<ir.length;p++){let e=ir[p],[i,r]=dr.scaleLine(e,t);f=i[d];let{positions:n,offsets:a,angles:u,pre_angles:h}=dr.placeAtIndex(d,i,r,l),c=a.map(e=>Math.sqrt(e[0]*e[0]+e[1]*e[1])/s);if(0===e){this.angle=1/u.length*u.reduce((e,t)=>e+t);for(let e=0;e<n.length;e++){let t=n[e],i=h[e],r=l[e],a=i+u[e],c=this.angle,d=hr.createOBB(t,r,o,a,c,this.offset,s),f=d.getExtent();this.obbs.push(d),this.aabbs.push(f);}}this.offsets[_].push(c[_]),this.angles[_].push(u[_]),this.pre_angles[_].push(h[_]);}}return !0}static curvaturePlacement(e,t,i,r,s,n){s=s||0,n=n||e.length-1;var o=[];for(let t=s+1;t<n;t++){var a=e[t-1],l=e[t],u=e[t+1],h=ce.perp(l,a),c=ce.perp(u,l),d=ce.angleBetween(h,c);d>or&&(d=1/0),o.push(d);}o.push(1/0);var f=[],_=[],p=s,m=0;for(let e=0;e<s;e++)m+=i[e];for(;m+r<t;){for(var g=m+r,x=m,y=p,v=0;y<n&&x+i[y]<g&&(v+=o[y])!==1/0;)x+=i[y],y++;if(0===v)return p;var b=v/(y-p);f.push(v),_.push(b),m+=i[p],p++;}if(0===f.length)return -1;var A=Math.min.apply(null,f),T=_[f.indexOf(A)];return A<sr&&T<nr?f.indexOf(A):-1}static scaleLine(e,t){var i=[t[0]],r=[];return t.forEach((s,n)=>{if(n!==t.length-1){var o=ce.sub(t[n+1],t[n]),a=ce.mult(o,1+e);i.push(ce.add(i[n],a)),r.push(ce.length(a));}}),[i,r]}static placeAtIndex(e,t,i,r){let s=t[e],[n,o]=dr.getIndicesAndOffsets(e,i,r),a=dr.getPositionsFromIndicesAndOffsets(t,n,o),[l,u,h]=dr.getAnglesFromIndicesAndOffsets(s,n,t,a);return {positions:a,offsets:l,angles:u,pre_angles:h}}static getIndicesAndOffsets(e,t,i){let r=i.length,s=[],n=[],o=0,a=0,l=0;for(;o<r;){let u=i[o];for(;o<r&&a+.5*u<=l+t[e];){let t=a-l+.5*u;n.push(t),s.push(e),a+=u,u=i[++o];}l+=t[e],e++;}return [s,n]}static getPositionsFromIndicesAndOffsets(e,t,i){let r=[];for(let s=0;s<t.length;s++){let n=t[s],o=i[s],a=_r(e[n],e[n+1]),l=ce.rot([o,0],a),u=ce.add(e[n],l);r.push(u);}return r}static getAnglesFromIndicesAndOffsets(e,t,i,r){let s=[],n=[],o=[];for(let u=0;u<r.length;u++){let h=r[u],c=t[u],d=ce.sub(h,e),f=-ce.angle(d),_=(a=i[c],l=i[c+1],-_r(a,l))-f;if(u>0){let e=s[u-1],t=n[u-1];Math.abs(f-e)>Math.PI&&(f+=f>e?-2*Math.PI:2*Math.PI),Math.abs(t-_)>Math.PI&&(_+=_>t?-2*Math.PI:2*Math.PI);}s.push(f),n.push(_),o.push(d);}var a,l;return [o,s,n]}}function fr(e,t){return t/e}function _r(e,t){let i=ce.sub(t,e);return ce.angle(i)}function pr(e){let t=[];for(let i=0;i<e.length-1;i++){let r=e[i],s=e[i+1],n=Math.hypot(r[0]-s[0],r[1]-s[1]);t.push(n);}return t}function mr(e,t){let i,r;for(e>t?(i=t,r=e):(i=e,r=t);r-i>Math.PI;)i+=2*Math.PI;return Math.abs(r-i)}let gr=Object.create(tr);Object.assign(gr,{name:"text",super:tr,built_in:!0,init(e={}){Re.init.call(this,e),this.setupDefines(),this.defines.TANGRAM_HAS_SHADER_POINTS=!1,this.defines.TANGRAM_CURVED_LABEL=!0,this.reset();},makeVertexTemplate(e,t){this.super.makeVertexTemplate.call(this,e,t,!1);let i=t.vertex_data.vertex_layout.index.a_pre_angles;for(let e=0;e<12;e++)this.vertex_template[i++]=0;return this.addCustomAttributesToVertexTemplate(e,i),this.vertex_template},reset(){this.queues={},this.resetText();},addFeature(e,t,i){let r=i.tile;if(r.generation!==this.generation)return;let s=e.geometry.type;t.can_articulate="LineString"===s||"MultiLineString"===s,t.supersample_text="LineString"===s||"MultiLineString"===s;let n=this.parseTextFeature(e,t,i,r);n&&(n instanceof Array?n.forEach(t=>{t.feature=e,t.context=i,t.layout.vertex=!1,this.queueFeature(t,r);}):(n.feature=e,n.context=i,n.layout.vertex=!1,this.queueFeature(n,r)),di.addStyle(this.name,r.id));},async endData(e){let t=this.queues[e.id];delete this.queues[e.id];const{labels:i,texts:r,textures:s}=await this.collideAndRenderTextLabels(e,this.name,t);i&&r&&(this.texts[e.id]=r,i.forEach(t=>{let i=t.text_settings_key,r=this.texts[e.id][i]&&this.texts[e.id][i][t.text],n=this.feature_style;n.label=t.label,r.text_settings.can_articulate?(n.size={},n.texcoords={},"straight"===t.label.type?(n.size.straight=r.size.logical_size,n.texcoords.straight=r.texcoords.straight,n.label_texture=s[r.texcoords.straight.texture_id]):(n.size.curved=r.segment_sizes.map(function(e){return e.logical_size}),n.texcoords_stroke=r.texcoords_stroke,n.texcoords.curved=r.texcoords.curved,n.label_textures=r.texcoords.curved.map(e=>s[e.texture_id]))):(n.size=r.size.logical_size,n.texcoords=r.align[t.label.align].texcoords,n.label_texture=s[r.align[t.label.align].texture_id]),n.blend_order=t.draw.blend_order,Re.addFeature.call(this,t.feature,t.draw,t.context);})),this.freeText(e);const n=await Re.endData.call(this,e);if(n){s&&s.length&&n.textures.push(...s);for(let e in n.meshes)n.meshes[e].uniforms.u_apply_color_blocks=!0;}return n},_preprocess(e){return e.blend_order=this.getBlendOrderForDraw(e),this.preprocessText(e)},buildTextLabels(e,t){let i=[];for(let s=0;s<t.length;s++){let n,o=t[s],a=this.texts[e.id][o.text_settings_key][o.text];if(o.layout.vertical_buffer=a.vertical_buffer,a.text_settings.can_articulate){var r=a.segment_sizes.map(e=>e.collision_size);o.layout.no_curving=a.no_curving,n=this.buildLabels(r,o.feature.geometry,o.layout,a.size.collision_size);}else n=this.buildLabels(a.size.collision_size,o.feature.geometry,o.layout);for(let e=0;e<n.length;e++){let t=Object.create(o);t.label=n[e],i.push(t);}}return i},buildLabels(e,t,i,r){let s=[];if("LineString"===t.type)Array.prototype.push.apply(s,this.buildLineLabels(t.coordinates,e,i,r));else if("MultiLineString"===t.type){let n=t.coordinates;for(let t=0;t<n.length;++t)Array.prototype.push.apply(s,this.buildLineLabels(n[t],e,i,r));}else if("Point"===t.type)s.push(new fi(t.coordinates,e,i));else if("MultiPoint"===t.type){let r=t.coordinates;for(let t=0;t<r.length;++t)s.push(new fi(r[t],e,i));}else if("Polygon"===t.type){let r=F.centroid(t.coordinates);r&&s.push(new fi(r,e,i));}else if("MultiPolygon"===t.type){let r=F.multiCentroid(t.coordinates);r&&s.push(new fi(r,e,i));}return s},buildLineLabels(e,t,i,r){let s=[],n=Math.min(i.subdiv,e.length-1);if(n>1){let o=(e.length-1)/n;for(let a=0;a<n;a++){let n=Math.floor(a*o),l=Math.floor((a+1)*o)+1,u=e.slice(n,l),h=ur(t,r,u,i);h&&s.push(h);}}if(s.length<n){let n=ur(t,r,e,i);n&&s.push(n);}return s},vertexLayoutForMeshVariant(e){if(null==this.vertex_layouts[e.shader_point]){const t=[{name:"a_position",size:4,type:ne.SHORT,normalized:!1},{name:"a_shape",size:4,type:ne.SHORT,normalized:!1},{name:"a_texcoord",size:2,type:ne.UNSIGNED_SHORT,normalized:!0},{name:"a_offset",size:2,type:ne.SHORT,normalized:!1},{name:"a_color",size:4,type:ne.UNSIGNED_BYTE,normalized:!0},{name:"a_selection_color",size:4,type:ne.UNSIGNED_BYTE,normalized:!0,static:e.selection?null:[0,0,0,0]},{name:"a_pre_angles",size:4,type:ne.BYTE,normalized:!1},{name:"a_angles",size:4,type:ne.SHORT,normalized:!1},{name:"a_offsets",size:4,type:ne.UNSIGNED_SHORT,normalized:!1}];this.addCustomAttributesToAttributeList(t),this.vertex_layouts[e.shader_point]=new Le(t);}return this.vertex_layouts[e.shader_point]}}),gr.texture_id=0;let xr=Object.create(mt);Object.assign(xr,{name:"raster",super:mt,built_in:!0,init(){this.raster=this.raster||"color",this.super.init.apply(this,arguments),this.selection=!1;},_preprocess(e){return e.color=e.color||q.defaults.color,this.super._preprocess.apply(this,arguments)}});var yr="#ifdef TANGRAM_VERTEX_SHADER\n\n// Apply layer ordering to avoid z-fighting\nvoid applyLayerOrder (float layer, inout vec4 position) {\n    position.z -= layer * TANGRAM_LAYER_DELTA * position.w;\n}\n\n// Vertex position in model space: [0, 1] range over the local tile\n// Note positions can be outside that range due to unclipped geometry, geometry higher than a unit cube, etc.\nvec4 modelPosition() {\n    return\n        vec4(\n            a_position.xyz / TANGRAM_TILE_SCALE         // scale coords to ~0-1 range\n            * exp2(u_tile_origin.z - u_tile_origin.w),  // adjust for tile overzooming\n        1.)\n        + vec4(0., 1., 0., 0.);\n        // NB: additional offset to account for unusual Tangram JS y coords,\n        // should be refactored to remove\n}\n\n// Position in model space as above, but according to tile coordinate (as opposed to style) zoom\n// e.g. unadjusted for tile overzooming\nvec4 modelPositionBaseZoom() {\n    return\n        vec4(\n            a_position.xyz / TANGRAM_TILE_SCALE,    // scale coords to ~0-1 range\n        1.)\n        + vec4(0., 1., 0., 0.); // see note on offset above\n}\n\n#endif\n\n// Vertex position in world coordinates, useful for 3d procedural textures, etc.\nvec4 worldPosition() {\n    return v_world_position;\n}\n\n// Optionally wrap world coordinates (allows more precision at higher zooms)\n// e.g. at wrap 1000, the world space will wrap every 1000 meters\n#ifdef TANGRAM_VERTEX_SHADER\n\nvec4 wrapWorldPosition(vec4 world_position) {\n    #if defined(TANGRAM_WORLD_POSITION_WRAP)\n    vec2 anchor = u_tile_origin.xy - mod(u_tile_origin.xy, TANGRAM_WORLD_POSITION_WRAP);\n        world_position.xy -= anchor;\n    #endif\n    return world_position;\n}\n\n#endif\n\n// Normal in world space\n#if defined(TANGRAM_VERTEX_SHADER)\n\nvec3 worldNormal() {\n    return TANGRAM_NORMAL;\n}\n\n#elif defined(TANGRAM_FRAGMENT_SHADER)\n\nvec3 worldNormal() {\n    return u_inverseNormalMatrix * TANGRAM_NORMAL;\n}\n\n#endif\n",vr="// Vertex attribute + varying for feature selection\n#if defined(TANGRAM_FEATURE_SELECTION) && defined(TANGRAM_VERTEX_SHADER)\n    attribute vec4 a_selection_color;\n    varying vec4 v_selection_color;\n#endif\n",br="// Selection pass-specific rendering\n#if defined(TANGRAM_FEATURE_SELECTION) && defined(TANGRAM_VERTEX_SHADER)\n    if (a_selection_color.rgb == vec3(0.)) {\n        // Discard by forcing invalid triangle if we're in the feature\n        // selection pass but have no selection info\n        // TODO: in some cases we may actually want non-selectable features to occlude selectable ones?\n        gl_Position = vec4(0., 0., 0., 1.);\n        return;\n    }\n    v_selection_color = a_selection_color;\n#endif\n";function Ar(e){return null!=e}function Tr(e){return "("+e+")"}function wr(e){return "string"==typeof e?'"'+e+'"':e}function Er(e){if("$"===e[0])return "context['"+e.substring(1)+"']";if(e.indexOf(".")>-1){if(-1===e.indexOf("\\."))return `context.feature.properties${e.split(".").map(e=>"['"+e+"']").join("")}`;return `context.feature.properties${e.replace(/\\\./g,"__TANGRAM_DELIMITER__").split(".").map(e=>e.replace(/__TANGRAM_DELIMITER__/g,".")).map(e=>"['"+e+"']").join("")}`}return "context.feature.properties['"+e+"']"}function Rr(e,t){return Tr(wr(t)+" === "+Er(e))}function Mr(e,t){return Tr(`${"["+t.map(wr).join(",")+"]"}.indexOf(${Er(e)}) > -1`)}function zr(e,t){return Tr(e.filter(Ar).map(function(e){return Tr(e.join(" && "))}).join(" "+t+" "))}function Nr(e,t,i){return t&&t.length>0?zr(t.map(function(e){return Fr(e,i)}),"||"):"true"}function Sr(e,t,i){return t&&t.length>0?zr(t.map(function(e){return Fr(e,i)}),"&&"):"true"}function kr(e,t,i){return "!"+Tr(Fr(t,i).join(" && "))}function Pr(e,t,i){return "!"+Tr(Nr(0,t,i))}function Lr(e,t){return Tr(Er(e)+(t?" != ":" == ")+"null")}function Or(e,t,i){var r=[],s=i&&"function"==typeof i.rangeTransform&&i.rangeTransform;if(t.max){var n=s?s(t.max):t.max;r.push(Er(e)+" < "+n);}if(t.min){var o=s?o=s(t.min):t.min;r.push(Er(e)+" >= "+o);}return Tr(r.join(" && "))}function Ir(e,t){let i=[];if(t.includes_any){const r="["+(Array.isArray(t.includes_any)?t.includes_any:[t.includes_any]).map(wr).join(",")+"]";i.push(`${Er(e)} != null && ${r}.some(function(v) { return ${Er(e)}.indexOf(v) > -1 })`);}if(t.includes_all){const r="["+(Array.isArray(t.includes_all)?t.includes_all:[t.includes_all]).map(wr).join(",")+"]";i.push(`${Er(e)} != null && ${r}.every(function(v) { return ${Er(e)}.indexOf(v) > -1 })`);}return Tr(i.join(" && "))}function Fr(e,t){var i=[];if("function"==typeof e)return [Tr(e.toString()+"(context)")];if(Array.isArray(e))return [Nr(0,e,t)];if(null==e)return ["true"];for(var r=Object.keys(e),s=0;s<r.length;s++){var n=r[s],o=e[n],a=typeof o;if("string"===a||"number"===a)i.push(Rr(n,o));else if("boolean"===a)i.push(Lr(n,o));else if("not"===n)i.push(kr(0,o,t));else if("any"===n)i.push(Nr(0,o,t));else if("all"===n)i.push(Sr(0,o,t));else if("none"===n)i.push(Pr(0,o,t));else if(Array.isArray(o))i.push(Mr(n,o));else if("object"===a&&null!=o)o.max||o.min?i.push(Or(n,o,t)):(o.includes_any||o.includes_all)&&i.push(Ir(n,o));else {if(null!=o)throw new Error("Unknown Query syntax: "+o);i.push(" true ");}}return 0===r.length?["true"]:i}function Ur(e,t){return null==e?function(){return !0}:new Function("context","return "+Tr(Fr(e,t).join(" && "))+";")}const Dr=["filter","draw","visible","enabled","data","exclusive","priority"];let Gr={};function Cr(e,t){let i,r=0;for(let t=0;t<e.length;t++)e[t].length>r&&(r=e[t].length);if(0===r)return null;let s={visible:!0};for(let n=0;n<r;n++)i=[],e.forEach(e=>{e[n]&&e[n][t]&&-1===i.indexOf(e[n][t])&&i.push(e[n][t]);}),0!==i.length&&I(s,...i);return !1===s.visible?null:s}const jr=["any","all","not","none"];class $r{constructor({layer:e,name:t,parent:i,draw:r,visible:s,enabled:n,filter:o,exclusive:a,priority:l,styles:u}){if(this.id=$r.id++,this.config_data=e.data,this.parent=i,this.name=t,this.full_name=this.parent?this.parent.full_name+":"+this.name:this.name,this.draw=r,this.filter=o,this.exclusive=!0===a,this.priority=null!=l?l:Number.MAX_SAFE_INTEGER,this.styles=u,this.is_built=!1,n=void 0===n?s:n,this.enabled=!1!==n,this.draw)for(let e in this.draw)if(this.draw[e]=null==this.draw[e]?{}:this.draw[e],"object"!=typeof this.draw[e]){let t=`Draw group '${e}' for layer ${this.full_name} is invalid, must be an object, `;f("warn",t+=`but was set to \`${e}: ${this.draw[e]}\` instead`),delete this.draw[e];}}build(){f("trace",`Building layer '${this.full_name}'`),this.buildFilter(),this.buildDraw(),this.is_built=!0;}buildDraw(){this.draw=j(this.draw,q.wrapFunction),this.calculatedDraw=function(e){let t=[];if(e.parent){let i=e.parent.calculatedDraw||[];t.push(...i);}return t.push(e.draw),t}(this);}buildFilter(){this.filter_original=this.filter,this.filter=j(this.filter,q.wrapFunction);let e=typeof this.filter;if(null==this.filter||"object"===e||"function"===e)try{this.buildZooms(),this.buildPropMatches(),null!=this.filter&&("function"==typeof this.filter||Object.keys(this.filter).length>0)?this.filter=Ur(this.filter,qr):this.filter=null;}catch(e){let t=`Filter for layer ${this.full_name} is invalid, \`filter: ${JSON.stringify(this.filter)}\` `;f("warn",t+=`failed with error '${e.message}', stack trace: ${e.stack}`);}else {let e=`Filter for layer ${this.full_name} is invalid, filter value must be an object or function, `;f("warn",e+=`but was set to \`filter: ${this.filter}\` instead`);}}buildZooms(){let e=this.filter&&this.filter.$zoom,t=typeof e;if(null!=e){if(this.zooms={},"number"===t)this.zooms[e]=!0;else if(Array.isArray(e))for(let t=0;t<e.length;t++)this.zooms[e[t]]=!0;else if("object"===t&&(null!=e.min||null!=e.max)){let t=e.min||0,i=e.max||F.max_style_zoom;for(let e=t;e<i;e++)this.zooms[e]=!0;}delete this.filter.$zoom;}}buildPropMatches(){this.filter&&!Array.isArray(this.filter)&&"function"!=typeof this.filter&&Object.keys(this.filter).forEach(e=>{if(-1===jr.indexOf(e)){let t=this.filter[e],i=typeof t,r=Array.isArray(t);if(!r&&"string"!==i&&"number"!==i)return;"$"===e[0]?(this.context_prop_matches=this.context_prop_matches||[],this.context_prop_matches.push([e.substring(1),r?t:[t]]),delete this.filter[e]):-1===e.indexOf(".")&&(this.feature_prop_matches=this.feature_prop_matches||[],this.feature_prop_matches.push([e,r?t:[t]]),delete this.filter[e]);}});}doPropMatches(e){if(this.feature_prop_matches)for(let t=0;t<this.feature_prop_matches.length;t++){let i=this.feature_prop_matches[t],r=e.feature.properties[i[0]];if(null==r||-1===i[1].indexOf(r))return !1}if(this.context_prop_matches)for(let t=0;t<this.context_prop_matches.length;t++){let i=this.context_prop_matches[t],r=e[i[0]];if(null==r||-1===i[1].indexOf(r))return !1}return !0}doesMatch(e){if(!this.enabled)return !1;if(this.is_built||this.build(),null!=this.zooms&&!this.zooms[e.zoom])return !1;if(!this.doPropMatches(e))return !1;let t;if(this.filter instanceof Function)try{t=this.filter(e);}catch(t){let i=`Filter for this ${this.full_name}: \`filter: ${this.filter_original}\` `;f("error",i+=`failed with error '${t.message}', stack trace: ${t.stack}`,e.feature);}else t=null==this.filter;return !!t&&(this.children_to_parse&&(!function(e,t,i){for(let r in t){let s=t[r];if("object"!=typeof s||Array.isArray(s)){let t=`Layer value must be an object: cannot create layer '${r}: ${JSON.stringify(s)}'`;t+=`, under parent layer '${e.full_name}'.`,i[e.name]&&(t+=` The parent name '${e.name}' is also the name of a style, did you mean to create a 'draw' group`,e.parent&&(t+=` under '${e.parent.name}'`),t+=" instead?"),f("warn",t);}else Hr(r,s,e,i);}e.layers.sort((e,t)=>{if(e.exclusive<t.exclusive)return 1;if(e.exclusive>t.exclusive)return -1;const i=e.exclusive?1:-1;return e.priority>t.priority?i:e.priority<t.priority?-i:e.full_name<t.full_name?i:e.full_name>t.full_name?-i:void 0});}(this,this.children_to_parse,this.styles),delete this.children_to_parse),!0)}}$r.id=0;class Vr extends $r{constructor(e){super(e),this.is_leaf=!0;}}class Br extends $r{constructor(e){super(e),this.is_tree=!0,this.layers=e.layers||[];}addLayer(e){this.layers.push(e);}buildDrawGroups(e){let t=[],i=[];if(function e(t,i,r,s){let n=!1;let o=!1;if(0===i.length)return;for(let a=0;a<i.length;a++){let l=i[a];if(l.is_leaf){if(l.doesMatch(t)&&(n=!0,r.push(l),s.push(l.id),l.exclusive))break}else if(l.is_tree&&l.doesMatch(t)&&(n=!0,(o=e(t,l.layers,r,s))||(r.push(l),s.push(l.id)),l.exclusive))break}return n}(e,[this],t,i),t.length>0){let e=function(e){if(e.length>1){for(var t=e[0],i=1;i<e.length;i++)t+="/"+e[i];return t}return e[0]}(i);if(void 0===Gr[e]){let i=t.map(e=>e&&!1!==e.visible&&e.calculatedDraw),r={};for(let e=0;e<i.length;e++){let t=i[e];if(t)for(let e=0;e<t.length;e++){let i=t[e];for(let e in i)r[e]=!0;}}for(let s in r)Gr[e]=Gr[e]||{},Gr[e][s]=Cr(i,s),Gr[e][s]?(Gr[e][s].key=e+"/"+s,Gr[e][s].layers=t.map(e=>e&&e.full_name),Gr[e][s].group=s):delete Gr[e][s];Gr[e]&&0===Object.keys(Gr[e]).length&&(Gr[e]=null);}return Gr[e]}}}const qr={rangeTransform:e=>"string"==typeof e&&"px2"===e.trim().slice(-3)?`${parseFloat(e)} * context.meters_per_pixel_sq`:e};function Xr(e){return Dr.indexOf(e)>-1}function Hr(e,t,i,r){let s={name:e,layer:t=null==t?{}:t,parent:i,styles:r},[n,o]=function(e){let t={},i={};for(let r in e)Xr(r)?t[r]=e[r]:i[r]=e[r];return [t,i]}(t),a=(l=o,0===Object.keys(l).length);var l;let u,h=new(u=a&&null!=i?Vr:Br)(Object.assign(s,n));return h.enabled&&(i&&i.addLayer(h),h.children_to_parse=a?null:o),h}let Wr=0,Yr=0;class Zr{constructor({coords:e,style_z:t,source:i,workers:r,view:s}){this.id=Wr++,this.view=s,this.source=i,this.generation=null,this.valid=!0,this.visible=!1,this.proxy_for=null,this.proxied_as=null,this.proxy_level=0,this.proxy_order_offset=0,this.fade_in=!0,this.loading=!1,this.loaded=!1,this.built=!1,this.labeled=!1,this.error=null,this.debug={},this.style_z=t,this.coords=Te.normalizedCoord(e,this.source),this.key=Te.key(this.coords,this.source,this.style_z),this.overzoom=Math.max(this.style_z-this.coords.z,0),this.overzoom2=Math.pow(2,this.overzoom),this.min=F.metersForTile(this.coords),this.max=F.metersForTile({x:this.coords.x+1,y:this.coords.y+1,z:this.coords.z}),this.span={x:this.max.x-this.min.x,y:-(this.max.y-this.min.y)},this.bounds={sw:{x:this.min.x,y:this.max.y},ne:{x:this.max.x,y:this.min.y}},this.meters_per_pixel=F.metersPerPixel(this.style_z),this.meters_per_pixel_sq=this.meters_per_pixel*this.meters_per_pixel,this.units_per_pixel=F.units_per_pixel/this.overzoom2,this.units_per_meter_overzoom=F.unitsPerMeter(this.coords.z)*this.overzoom2,this.preserve_tiles_within_zoom=this.source.preserve_tiles_within_zoom,this.meshes={},this.new_mesh_styles=[],this.pending_label_meshes=null,this.setWorker(r);}freeResources(){for(let e in this.meshes)this.meshes[e].forEach(e=>e.destroy());if(this.meshes={},this.pending_label_meshes)for(let e in this.pending_label_meshes)this.pending_label_meshes[e].forEach(e=>e.destroy());this.pending_label_meshes=null;}destroy(){b.removeForTile(this.id),this.workerMessage("self.removeTile",this.key),this.freeResources(),this.worker=null,this.valid=!1;}buildAsMessage(){return {id:this.id,key:this.key,source:this.source.name,coords:this.coords,min:this.min,max:this.max,units_per_pixel:this.units_per_pixel,meters_per_pixel:this.meters_per_pixel,meters_per_pixel_sq:this.meters_per_pixel_sq,units_per_meter_overzoom:this.units_per_meter_overzoom,style_z:this.style_z,overzoom:this.overzoom,overzoom2:this.overzoom2,generation:this.generation,debug:this.debug}}setWorker(e){this.source.tiled?this.worker_id=Math.abs(this.coords.x+this.coords.y+this.coords.z)%e.length:this.worker_id=this.source.id%e.length,this.worker=e[this.worker_id];}workerMessage(...e){return n.postMessage(this.worker,...e)}build(e,{fade_in:t=!0}={}){return this.generation=e,this.fade_in=t,this.loaded||(this.loading=!0,this.built=!1,this.labeled=!1),this.workerMessage("self.buildTile",{tile:this.buildAsMessage()}).catch(e=>{throw e})}static cancel(e){e&&(e.canceled=!0,e.source_data&&e.source_data.request_id&&(_.cancelRequest(e.source_data.request_id),e.source_data.request_id=null),Zr.abortBuild(e));}static buildGeometry(e,{scene_id:t,layers:i,styles:r,global:s}){let n=e.source_data;e.debug.building=+new Date,e.debug.feature_count=0,e.debug.layers=null,di.startTile(e.id,{apply_repeat_groups:!0});for(let t in i){let o=i[t];if(!o||!o.config_data){f("warn",`Layer ${t} was defined without a geometry data source and will not be rendered.`);continue}if(o.config_data.source!==e.source)continue;let a=Zr.getDataForSource(n,o.config_data,t);for(let i=0;i<a.length;i++){let n=a[i],l=n.geom;if(l)for(let i=0;i<l.features.length;i++){let a=l.features[i];if(null==a.geometry)continue;let u=q.getFeatureParseContext(a,e,s);u.winding=e.default_winding,u.source=e.source,u.layer=n.layer;let h=o.buildDrawGroups(u,!0);if(h){for(let e in h){let i=h[e],s=i.style||e,n=r[s];n?null!=(i=n.preprocess(i))&&!1!==i.visible&&(u.layers=i.layers,n.addFeature(a,i,u)):f("warn",`Style '${s}' not found, skipping layer '${t}':`,i,a);}e.debug.feature_count++;}}}}e.debug.building=+new Date-e.debug.building;let o=this.stylesForTile(e,r).map(e=>r[e]);Zr.buildStyleGroups(e,o,t,e=>e.collision?"collision":"non-collision");}static stylesForTile(e,t){let i=[];for(let r in t)t[r].hasDataForTile(e)&&i.push(r);return i}static buildStyleGroups(e,t,i,r){const s=t.reduce((e,t)=>{const i=r(t);return e[i]=e[i]||[],e[i].push(t),e},{});if(0===Object.keys(s).length)return n.postMessage(`TileManager_${i}.buildTileStylesCompleted`,n.withTransferables({tile:Zr.slice(e),progress:{start:!0,done:!0}})),void di.resetTile(e.id);const o={};for(const t in s)Zr.buildStyleGroup({group_name:t,groups:s,tile:e,progress:o,scene_id:i});}static async buildStyleGroup({group_name:e,groups:t,tile:r,progress:s,scene_id:o}){const a=t[e],l={};try{await Promise.all(a.map(async function(e){const t=await e.endData(r);t&&(l[e.name]=t);})),f("trace",`Finished style group '${e}' for tile ${r.key}`),t[e]=null,Object.keys(t).every(e=>null==t[e])&&(s.done=!0),n.postMessage(`TileManager_${o}.buildTileStylesCompleted`,n.withTransferables({tile:i({},Zr.slice(r),{mesh_data:l}),progress:s})),s.done&&di.resetTile(r.id);}catch(t){f("error",`Error for style group '${e}' for tile ${r.key}`,t&&t.stack||t);}}static getDataForSource(e,t,i){var r=[];if(null!=t&&null!=e&&null!=e.layers)if(!0===t.all_layers){if(null!=t.layer){f({level:"warn",once:!0},`Layer ${i} includes both 'all_layers: true' and an explicit `+"'layer' keyword in its 'data' block. 'all_layers: true' takes precedence, 'layer' will be ignored.");}for(const t in e.layers)r.push({layer:t,geom:e.layers[t]});}else !t.layer&&e.layers._default?r.push({geom:e.layers._default}):!t.layer&&i?r.push({layer:i,geom:e.layers[i]}):"string"==typeof t.layer?r.push({layer:t.layer,geom:e.layers[t.layer]}):Array.isArray(t.layer)&&t.layer.forEach(t=>{r.push({layer:t,geom:e.layers[t]});});return r}buildMeshes(e,t){if(this.error)return;this.build_id=Yr++,t.start&&(this.debug.geometry_count=0,this.debug.buffer_size=0);let i={},r=this.mesh_data;if(r)for(let t in r){for(let s in r[t].meshes){let n=r[t].meshes[s];if(n.vertex_data){if(!e[t]){f("warn",`Could not create mesh because style '${t}' not found, for tile ${this.key}, aborting tile`);break}let s=Object.assign({},r[t]);s.uniforms=Object.assign({},s.uniforms,n.uniforms),s.variant=n.variant,n.labels&&(s.retain=!0);let o=e[t].makeMesh(n.vertex_data,n.vertex_elements,s);o.variant=s.variant,o.labels=n.labels,i[t]=i[t]||[],i[t].push(o),null==o.variant.mesh_order&&(o.variant.mesh_order=i[t].length-1),this.debug.buffer_size+=o.buffer_size,this.debug.geometry_count+=o.geometry_count;}}i[t]&&i[t].sort((e,t)=>{let i=e.variant.mesh_order,r=t.variant.mesh_order;return null==i?1:null==r?-1:i<r?-1:1});}delete this.mesh_data;for(let t in i)e[t].collision?(this.pending_label_meshes=this.pending_label_meshes||{},this.pending_label_meshes[t]=i[t]):(this.meshes[t]&&this.meshes[t].forEach(e=>e.destroy()),this.meshes[t]=i[t],this.new_mesh_styles.push(t));if(t.done){for(let e in this.meshes)-1!==this.new_mesh_styles.indexOf(e)||this.pending_label_meshes&&null!=this.pending_label_meshes[e]||(this.meshes[e].forEach(e=>e.destroy()),delete this.meshes[e]);this.new_mesh_styles=[],this.debug.geometry_ratio=(this.debug.geometry_count/this.debug.feature_count).toFixed(1);}this.printDebug(t);}pendingLabelStyleCount(){return this.pending_label_meshes?Object.keys(this.pending_label_meshes).length:0}swapPendingLabels(){if(this.labeled=!0,this.pending_label_meshes){for(let e in this.pending_label_meshes)this.meshes[e]&&this.meshes[e].forEach(e=>e.destroy()),this.meshes[e]=this.pending_label_meshes[e];this.pending_label_meshes=null;}}static abortBuild(e){if(b.removeForTile(e.id),di.abortTile(e.id),e.mesh_data)for(let t in e.mesh_data){let i=e.mesh_data[t].textures;i&&i.forEach(t=>{let i=w.textures[t];i&&(f("trace",`releasing texture ${t} for tile ${e.key}`),i.release());});}}setProxyFor(e){e?(this.visible=!0,this.proxy_for=this.proxy_for||[],this.proxy_for.push(e),this.proxy_order_offset=1,e.proxied_as=e.style_z>this.style_z?"child":"parent",this.proxy_level=Math.abs(e.style_z-this.style_z)):(this.proxy_for=null,this.proxy_order_offset=0,this.proxy_level=0);}isProxy(){return null!=this.proxy_for}shouldProxyForStyle(e){return !this.proxy_for||this.proxy_for.some(t=>null==t.meshes[e])}setupProgram({model:e,model32:t},i){i.uniform("4fv","u_tile_origin",[this.min.x,this.min.y,this.style_z,this.coords.z]),i.uniform("1f","u_tile_proxy_order_offset",this.proxy_order_offset),Wi.identity(e),Wi.translate(e,e,Xi.fromValues(this.min.x,this.min.y,0)),Wi.scale(e,e,Xi.fromValues(this.span.x/F.tile_scale,this.span.y/F.tile_scale,1)),Wi.copy(t,e),i.uniform("Matrix4fv","u_model",t),i.uniform("1i","u_tile_fade_in",this.fade_in&&"child"!==this.proxied_as);}static slice(e,t){let i=["id","key","loading","loaded","generation","error","debug"];Array.isArray(t)&&i.push(...t);var r={};for(let t=0;t<i.length;t++){const s=i[t];r[s]=e[s];}return r}merge(e){return this.loading=e.loading,this.loaded=e.loaded,this.generation=e.generation,this.error=e.error,this.mesh_data=e.mesh_data,this.debug=I(this.debug,e.debug),this}printDebug(e){const t=["layers"];let i={};for(let e in this.debug)-1===t.indexOf(e)&&(i[e]=this.debug[e]);f("debug",`Tile ${e.done?"(done)":""}: debug for ${this.key}: [  ${JSON.stringify(i)} ]`);}}Zr.coord_children={};var Jr=function(e,t,i,r,s){var n,o,a=8*s-r-1,l=(1<<a)-1,u=l>>1,h=-7,c=i?s-1:0,d=i?-1:1,f=e[t+c];for(c+=d,n=f&(1<<-h)-1,f>>=-h,h+=a;h>0;n=256*n+e[t+c],c+=d,h-=8);for(o=n&(1<<-h)-1,n>>=-h,h+=r;h>0;o=256*o+e[t+c],c+=d,h-=8);if(0===n)n=1-u;else {if(n===l)return o?NaN:1/0*(f?-1:1);o+=Math.pow(2,r),n-=u;}return (f?-1:1)*o*Math.pow(2,n-r)},Kr=function(e,t,i,r,s,n){var o,a,l,u=8*n-s-1,h=(1<<u)-1,c=h>>1,d=23===s?Math.pow(2,-24)-Math.pow(2,-77):0,f=r?0:n-1,_=r?1:-1,p=t<0||0===t&&1/t<0?1:0;for(t=Math.abs(t),isNaN(t)||t===1/0?(a=isNaN(t)?1:0,o=h):(o=Math.floor(Math.log(t)/Math.LN2),t*(l=Math.pow(2,-o))<1&&(o--,l*=2),(t+=o+c>=1?d/l:d*Math.pow(2,1-c))*l>=2&&(o++,l/=2),o+c>=h?(a=0,o=h):o+c>=1?(a=(t*l-1)*Math.pow(2,s),o+=c):(a=t*Math.pow(2,c-1)*Math.pow(2,s),o=0));s>=8;e[i+f]=255&a,f+=_,a/=256,s-=8);for(o=o<<s|a,u+=s;u>0;e[i+f]=255&o,f+=_,o/=256,u-=8);e[i+f-_]|=128*p;},Qr=es;function es(e){this.buf=ArrayBuffer.isView&&ArrayBuffer.isView(e)?e:new Uint8Array(e||0),this.pos=0,this.type=0,this.length=this.buf.length;}es.Varint=0,es.Fixed64=1,es.Bytes=2,es.Fixed32=5;function ts(e){return e.type===es.Bytes?e.readVarint()+e.pos:e.pos+1}function is(e,t,i){return i?4294967296*t+(e>>>0):4294967296*(t>>>0)+(e>>>0)}function rs(e,t,i){var r=t<=16383?1:t<=2097151?2:t<=268435455?3:Math.ceil(Math.log(t)/(7*Math.LN2));i.realloc(r);for(var s=i.pos-1;s>=e;s--)i.buf[s+r]=i.buf[s];}function ss(e,t){for(var i=0;i<e.length;i++)t.writeVarint(e[i]);}function ns(e,t){for(var i=0;i<e.length;i++)t.writeSVarint(e[i]);}function os(e,t){for(var i=0;i<e.length;i++)t.writeFloat(e[i]);}function as(e,t){for(var i=0;i<e.length;i++)t.writeDouble(e[i]);}function ls(e,t){for(var i=0;i<e.length;i++)t.writeBoolean(e[i]);}function us(e,t){for(var i=0;i<e.length;i++)t.writeFixed32(e[i]);}function hs(e,t){for(var i=0;i<e.length;i++)t.writeSFixed32(e[i]);}function cs(e,t){for(var i=0;i<e.length;i++)t.writeFixed64(e[i]);}function ds(e,t){for(var i=0;i<e.length;i++)t.writeSFixed64(e[i]);}function fs(e,t){return (e[t]|e[t+1]<<8|e[t+2]<<16)+16777216*e[t+3]}function _s(e,t,i){e[i]=t,e[i+1]=t>>>8,e[i+2]=t>>>16,e[i+3]=t>>>24;}function ps(e,t){return (e[t]|e[t+1]<<8|e[t+2]<<16)+(e[t+3]<<24)}es.prototype={destroy:function(){this.buf=null;},readFields:function(e,t,i){for(i=i||this.length;this.pos<i;){var r=this.readVarint(),s=r>>3,n=this.pos;this.type=7&r,e(s,t,this),this.pos===n&&this.skip(r);}return t},readMessage:function(e,t){return this.readFields(e,t,this.readVarint()+this.pos)},readFixed32:function(){var e=fs(this.buf,this.pos);return this.pos+=4,e},readSFixed32:function(){var e=ps(this.buf,this.pos);return this.pos+=4,e},readFixed64:function(){var e=fs(this.buf,this.pos)+4294967296*fs(this.buf,this.pos+4);return this.pos+=8,e},readSFixed64:function(){var e=fs(this.buf,this.pos)+4294967296*ps(this.buf,this.pos+4);return this.pos+=8,e},readFloat:function(){var e=Jr(this.buf,this.pos,!0,23,4);return this.pos+=4,e},readDouble:function(){var e=Jr(this.buf,this.pos,!0,52,8);return this.pos+=8,e},readVarint:function(e){var t,i,r=this.buf;return t=127&(i=r[this.pos++]),i<128?t:(t|=(127&(i=r[this.pos++]))<<7,i<128?t:(t|=(127&(i=r[this.pos++]))<<14,i<128?t:(t|=(127&(i=r[this.pos++]))<<21,i<128?t:function(e,t,i){var r,s,n=i.buf;if(s=n[i.pos++],r=(112&s)>>4,s<128)return is(e,r,t);if(s=n[i.pos++],r|=(127&s)<<3,s<128)return is(e,r,t);if(s=n[i.pos++],r|=(127&s)<<10,s<128)return is(e,r,t);if(s=n[i.pos++],r|=(127&s)<<17,s<128)return is(e,r,t);if(s=n[i.pos++],r|=(127&s)<<24,s<128)return is(e,r,t);if(s=n[i.pos++],r|=(1&s)<<31,s<128)return is(e,r,t);throw new Error("Expected varint not more than 10 bytes")}(t|=(15&(i=r[this.pos]))<<28,e,this))))},readVarint64:function(){return this.readVarint(!0)},readSVarint:function(){var e=this.readVarint();return e%2==1?(e+1)/-2:e/2},readBoolean:function(){return Boolean(this.readVarint())},readString:function(){var e=this.readVarint()+this.pos,t=function(e,t,i){var r="",s=t;for(;s<i;){var n,o,a,l=e[s],u=null,h=l>239?4:l>223?3:l>191?2:1;if(s+h>i)break;1===h?l<128&&(u=l):2===h?128==(192&(n=e[s+1]))&&(u=(31&l)<<6|63&n)<=127&&(u=null):3===h?(n=e[s+1],o=e[s+2],128==(192&n)&&128==(192&o)&&((u=(15&l)<<12|(63&n)<<6|63&o)<=2047||u>=55296&&u<=57343)&&(u=null)):4===h&&(n=e[s+1],o=e[s+2],a=e[s+3],128==(192&n)&&128==(192&o)&&128==(192&a)&&((u=(15&l)<<18|(63&n)<<12|(63&o)<<6|63&a)<=65535||u>=1114112)&&(u=null)),null===u?(u=65533,h=1):u>65535&&(u-=65536,r+=String.fromCharCode(u>>>10&1023|55296),u=56320|1023&u),r+=String.fromCharCode(u),s+=h;}return r}(this.buf,this.pos,e);return this.pos=e,t},readBytes:function(){var e=this.readVarint()+this.pos,t=this.buf.subarray(this.pos,e);return this.pos=e,t},readPackedVarint:function(e,t){var i=ts(this);for(e=e||[];this.pos<i;)e.push(this.readVarint(t));return e},readPackedSVarint:function(e){var t=ts(this);for(e=e||[];this.pos<t;)e.push(this.readSVarint());return e},readPackedBoolean:function(e){var t=ts(this);for(e=e||[];this.pos<t;)e.push(this.readBoolean());return e},readPackedFloat:function(e){var t=ts(this);for(e=e||[];this.pos<t;)e.push(this.readFloat());return e},readPackedDouble:function(e){var t=ts(this);for(e=e||[];this.pos<t;)e.push(this.readDouble());return e},readPackedFixed32:function(e){var t=ts(this);for(e=e||[];this.pos<t;)e.push(this.readFixed32());return e},readPackedSFixed32:function(e){var t=ts(this);for(e=e||[];this.pos<t;)e.push(this.readSFixed32());return e},readPackedFixed64:function(e){var t=ts(this);for(e=e||[];this.pos<t;)e.push(this.readFixed64());return e},readPackedSFixed64:function(e){var t=ts(this);for(e=e||[];this.pos<t;)e.push(this.readSFixed64());return e},skip:function(e){var t=7&e;if(t===es.Varint)for(;this.buf[this.pos++]>127;);else if(t===es.Bytes)this.pos=this.readVarint()+this.pos;else if(t===es.Fixed32)this.pos+=4;else {if(t!==es.Fixed64)throw new Error("Unimplemented type: "+t);this.pos+=8;}},writeTag:function(e,t){this.writeVarint(e<<3|t);},realloc:function(e){for(var t=this.length||16;t<this.pos+e;)t*=2;if(t!==this.length){var i=new Uint8Array(t);i.set(this.buf),this.buf=i,this.length=t;}},finish:function(){return this.length=this.pos,this.pos=0,this.buf.subarray(0,this.length)},writeFixed32:function(e){this.realloc(4),_s(this.buf,e,this.pos),this.pos+=4;},writeSFixed32:function(e){this.realloc(4),_s(this.buf,e,this.pos),this.pos+=4;},writeFixed64:function(e){this.realloc(8),_s(this.buf,-1&e,this.pos),_s(this.buf,Math.floor(e*(1/4294967296)),this.pos+4),this.pos+=8;},writeSFixed64:function(e){this.realloc(8),_s(this.buf,-1&e,this.pos),_s(this.buf,Math.floor(e*(1/4294967296)),this.pos+4),this.pos+=8;},writeVarint:function(e){(e=+e||0)>268435455||e<0?function(e,t){var i,r;e>=0?(i=e%4294967296|0,r=e/4294967296|0):(r=~(-e/4294967296),4294967295^(i=~(-e%4294967296))?i=i+1|0:(i=0,r=r+1|0));if(e>=0x10000000000000000||e<-0x10000000000000000)throw new Error("Given varint doesn't fit into 10 bytes");t.realloc(10),function(e,t,i){i.buf[i.pos++]=127&e|128,e>>>=7,i.buf[i.pos++]=127&e|128,e>>>=7,i.buf[i.pos++]=127&e|128,e>>>=7,i.buf[i.pos++]=127&e|128,e>>>=7,i.buf[i.pos]=127&e;}(i,0,t),function(e,t){var i=(7&e)<<4;if(t.buf[t.pos++]|=i|((e>>>=3)?128:0),!e)return;if(t.buf[t.pos++]=127&e|((e>>>=7)?128:0),!e)return;if(t.buf[t.pos++]=127&e|((e>>>=7)?128:0),!e)return;if(t.buf[t.pos++]=127&e|((e>>>=7)?128:0),!e)return;if(t.buf[t.pos++]=127&e|((e>>>=7)?128:0),!e)return;t.buf[t.pos++]=127&e;}(r,t);}(e,this):(this.realloc(4),this.buf[this.pos++]=127&e|(e>127?128:0),e<=127||(this.buf[this.pos++]=127&(e>>>=7)|(e>127?128:0),e<=127||(this.buf[this.pos++]=127&(e>>>=7)|(e>127?128:0),e<=127||(this.buf[this.pos++]=e>>>7&127))));},writeSVarint:function(e){this.writeVarint(e<0?2*-e-1:2*e);},writeBoolean:function(e){this.writeVarint(Boolean(e));},writeString:function(e){e=String(e),this.realloc(4*e.length),this.pos++;var t=this.pos;this.pos=function(e,t,i){for(var r,s,n=0;n<t.length;n++){if((r=t.charCodeAt(n))>55295&&r<57344){if(!s){r>56319||n+1===t.length?(e[i++]=239,e[i++]=191,e[i++]=189):s=r;continue}if(r<56320){e[i++]=239,e[i++]=191,e[i++]=189,s=r;continue}r=s-55296<<10|r-56320|65536,s=null;}else s&&(e[i++]=239,e[i++]=191,e[i++]=189,s=null);r<128?e[i++]=r:(r<2048?e[i++]=r>>6|192:(r<65536?e[i++]=r>>12|224:(e[i++]=r>>18|240,e[i++]=r>>12&63|128),e[i++]=r>>6&63|128),e[i++]=63&r|128);}return i}(this.buf,e,this.pos);var i=this.pos-t;i>=128&&rs(t,i,this),this.pos=t-1,this.writeVarint(i),this.pos+=i;},writeFloat:function(e){this.realloc(4),Kr(this.buf,e,this.pos,!0,23,4),this.pos+=4;},writeDouble:function(e){this.realloc(8),Kr(this.buf,e,this.pos,!0,52,8),this.pos+=8;},writeBytes:function(e){var t=e.length;this.writeVarint(t),this.realloc(t);for(var i=0;i<t;i++)this.buf[this.pos++]=e[i];},writeRawMessage:function(e,t){this.pos++;var i=this.pos;e(t,this);var r=this.pos-i;r>=128&&rs(i,r,this),this.pos=i-1,this.writeVarint(r),this.pos+=r;},writeMessage:function(e,t,i){this.writeTag(e,es.Bytes),this.writeRawMessage(t,i);},writePackedVarint:function(e,t){this.writeMessage(e,ss,t);},writePackedSVarint:function(e,t){this.writeMessage(e,ns,t);},writePackedBoolean:function(e,t){this.writeMessage(e,ls,t);},writePackedFloat:function(e,t){this.writeMessage(e,os,t);},writePackedDouble:function(e,t){this.writeMessage(e,as,t);},writePackedFixed32:function(e,t){this.writeMessage(e,us,t);},writePackedSFixed32:function(e,t){this.writeMessage(e,hs,t);},writePackedFixed64:function(e,t){this.writeMessage(e,cs,t);},writePackedSFixed64:function(e,t){this.writeMessage(e,ds,t);},writeBytesField:function(e,t){this.writeTag(e,es.Bytes),this.writeBytes(t);},writeFixed32Field:function(e,t){this.writeTag(e,es.Fixed32),this.writeFixed32(t);},writeSFixed32Field:function(e,t){this.writeTag(e,es.Fixed32),this.writeSFixed32(t);},writeFixed64Field:function(e,t){this.writeTag(e,es.Fixed64),this.writeFixed64(t);},writeSFixed64Field:function(e,t){this.writeTag(e,es.Fixed64),this.writeSFixed64(t);},writeVarintField:function(e,t){this.writeTag(e,es.Varint),this.writeVarint(t);},writeSVarintField:function(e,t){this.writeTag(e,es.Varint),this.writeSVarint(t);},writeStringField:function(e,t){this.writeTag(e,es.Bytes),this.writeString(t);},writeFloatField:function(e,t){this.writeTag(e,es.Fixed32),this.writeFloat(t);},writeDoubleField:function(e,t){this.writeTag(e,es.Fixed64),this.writeDouble(t);},writeBooleanField:function(e,t){this.writeVarintField(e,Boolean(t));}};var ms=gs;function gs(e,t){this.x=e,this.y=t;}gs.prototype={clone:function(){return new gs(this.x,this.y)},add:function(e){return this.clone()._add(e)},sub:function(e){return this.clone()._sub(e)},multByPoint:function(e){return this.clone()._multByPoint(e)},divByPoint:function(e){return this.clone()._divByPoint(e)},mult:function(e){return this.clone()._mult(e)},div:function(e){return this.clone()._div(e)},rotate:function(e){return this.clone()._rotate(e)},rotateAround:function(e,t){return this.clone()._rotateAround(e,t)},matMult:function(e){return this.clone()._matMult(e)},unit:function(){return this.clone()._unit()},perp:function(){return this.clone()._perp()},round:function(){return this.clone()._round()},mag:function(){return Math.sqrt(this.x*this.x+this.y*this.y)},equals:function(e){return this.x===e.x&&this.y===e.y},dist:function(e){return Math.sqrt(this.distSqr(e))},distSqr:function(e){var t=e.x-this.x,i=e.y-this.y;return t*t+i*i},angle:function(){return Math.atan2(this.y,this.x)},angleTo:function(e){return Math.atan2(this.y-e.y,this.x-e.x)},angleWith:function(e){return this.angleWithSep(e.x,e.y)},angleWithSep:function(e,t){return Math.atan2(this.x*t-this.y*e,this.x*e+this.y*t)},_matMult:function(e){var t=e[0]*this.x+e[1]*this.y,i=e[2]*this.x+e[3]*this.y;return this.x=t,this.y=i,this},_add:function(e){return this.x+=e.x,this.y+=e.y,this},_sub:function(e){return this.x-=e.x,this.y-=e.y,this},_mult:function(e){return this.x*=e,this.y*=e,this},_div:function(e){return this.x/=e,this.y/=e,this},_multByPoint:function(e){return this.x*=e.x,this.y*=e.y,this},_divByPoint:function(e){return this.x/=e.x,this.y/=e.y,this},_unit:function(){return this._div(this.mag()),this},_perp:function(){var e=this.y;return this.y=this.x,this.x=-e,this},_rotate:function(e){var t=Math.cos(e),i=Math.sin(e),r=t*this.x-i*this.y,s=i*this.x+t*this.y;return this.x=r,this.y=s,this},_rotateAround:function(e,t){var i=Math.cos(e),r=Math.sin(e),s=t.x+i*(this.x-t.x)-r*(this.y-t.y),n=t.y+r*(this.x-t.x)+i*(this.y-t.y);return this.x=s,this.y=n,this},_round:function(){return this.x=Math.round(this.x),this.y=Math.round(this.y),this}},gs.convert=function(e){return e instanceof gs?e:Array.isArray(e)?new gs(e[0],e[1]):e};var xs=ys;function ys(e,t,i,r,s){this.properties={},this.extent=i,this.type=0,this._pbf=e,this._geometry=-1,this._keys=r,this._values=s,e.readFields(vs,this,t);}function vs(e,t,i){1==e?t.id=i.readVarint():2==e?function(e,t){var i=e.readVarint()+e.pos;for(;e.pos<i;){var r=t._keys[e.readVarint()],s=t._values[e.readVarint()];t.properties[r]=s;}}(i,t):3==e?t.type=i.readVarint():4==e&&(t._geometry=i.pos);}function bs(e){for(var t,i,r=0,s=0,n=e.length,o=n-1;s<n;o=s++)t=e[s],r+=((i=e[o]).x-t.x)*(t.y+i.y);return r}ys.types=["Unknown","Point","LineString","Polygon"],ys.prototype.loadGeometry=function(){var e=this._pbf;e.pos=this._geometry;for(var t,i=e.readVarint()+e.pos,r=1,s=0,n=0,o=0,a=[];e.pos<i;){if(!s){var l=e.readVarint();r=7&l,s=l>>3;}if(s--,1===r||2===r)n+=e.readSVarint(),o+=e.readSVarint(),1===r&&(t&&a.push(t),t=[]),t.push(new ms(n,o));else {if(7!==r)throw new Error("unknown command "+r);t&&t.push(t[0].clone());}}return t&&a.push(t),a},ys.prototype.bbox=function(){var e=this._pbf;e.pos=this._geometry;for(var t=e.readVarint()+e.pos,i=1,r=0,s=0,n=0,o=1/0,a=-1/0,l=1/0,u=-1/0;e.pos<t;){if(!r){var h=e.readVarint();i=7&h,r=h>>3;}if(r--,1===i||2===i)(s+=e.readSVarint())<o&&(o=s),s>a&&(a=s),(n+=e.readSVarint())<l&&(l=n),n>u&&(u=n);else if(7!==i)throw new Error("unknown command "+i)}return [o,l,a,u]},ys.prototype.toGeoJSON=function(e,t,i){var r,s,n=this.extent*Math.pow(2,i),o=this.extent*e,a=this.extent*t,l=this.loadGeometry(),u=ys.types[this.type];function h(e){for(var t=0;t<e.length;t++){var i=e[t],r=180-360*(i.y+a)/n;e[t]=[360*(i.x+o)/n-180,360/Math.PI*Math.atan(Math.exp(r*Math.PI/180))-90];}}switch(this.type){case 1:var c=[];for(r=0;r<l.length;r++)c[r]=l[r][0];h(l=c);break;case 2:for(r=0;r<l.length;r++)h(l[r]);break;case 3:for(l=function(e){var t=e.length;if(t<=1)return [e];for(var i,r,s=[],n=0;n<t;n++){var o=bs(e[n]);0!==o&&(void 0===r&&(r=o<0),r===o<0?(i&&s.push(i),i=[e[n]]):i.push(e[n]));}i&&s.push(i);return s}(l),r=0;r<l.length;r++)for(s=0;s<l[r].length;s++)h(l[r][s]);}1===l.length?l=l[0]:u="Multi"+u;var d={type:"Feature",geometry:{type:u,coordinates:l},properties:this.properties};return "id"in this&&(d.id=this.id),d};var As=Ts;function Ts(e,t){this.version=1,this.name=null,this.extent=4096,this.length=0,this._pbf=e,this._keys=[],this._values=[],this._features=[],e.readFields(ws,this,t),this.length=this._features.length;}function ws(e,t,i){15===e?t.version=i.readVarint():1===e?t.name=i.readString():5===e?t.extent=i.readVarint():2===e?t._features.push(i.pos):3===e?t._keys.push(i.readString()):4===e&&t._values.push(function(e){var t=null,i=e.readVarint()+e.pos;for(;e.pos<i;){var r=e.readVarint()>>3;t=1===r?e.readString():2===r?e.readFloat():3===r?e.readDouble():4===r?e.readVarint64():5===r?e.readVarint():6===r?e.readSVarint():7===r?e.readBoolean():null;}return t}(i));}function Es(e,t,i){if(3===e){var r=new As(i,i.readVarint()+i.pos);r.length&&(t[r.name]=r);}}Ts.prototype.feature=function(e){if(e<0||e>=this._features.length)throw new Error("feature index out of bounds");this._pbf.pos=this._features[e];var t=this._pbf.readVarint()+this._pbf.pos;return new xs(this._pbf,t,this.extent,this._keys,this._values)};var Rs=function(e,t){this.layers=e.readFields(Es,{},t);},Ms=xs;const zs={NONE:0,ALL:1,SOME:2},Ns=["{","["];class Ss extends Ae{constructor(e,t){if(super(e,t),this.response_type="arraybuffer",!0===e.parse_json)this.parse_json_type=zs.ALL;else if(Array.isArray(e.parse_json))this.parse_json_type=zs.SOME,this.parse_json_prop_list=e.parse_json;else {if(null!=e.parse_json){f({level:"warn",once:!0},`Data source '${this.name}': 'parse_json' parameter should be 'true', or an array of `+`property names (was '${JSON.stringify(e.parse_json)}')`);}this.parse_json_type=zs.NONE;}}parseSourceData(e,t,i){var r=new Uint8Array(i),s=new Qr(r);if(t.data=new Rs(s),t.layers=this.toGeoJSON(t.data),"function"==typeof this.transform){const i={min:Object.assign({},e.min),max:Object.assign({},e.max),coords:Object.assign({},e.coords)};t.layers=this.transform(t.layers,this.extra_data,i);}delete t.data;}toGeoJSON(e){var t={};for(var i in e.layers){for(var r=e.layers[i],s=F.tile_scale/r.extent,n={type:"FeatureCollection",features:[]},o=0;o<r.length;o++){var a=r.feature(o),l={type:"Feature",geometry:{},id:a.id,properties:a.properties};this.parseJSONProperties(l);for(var u=l.geometry,h=a.loadGeometry(),c=0;c<h.length;c++)for(var d=h[c],f=0;f<d.length;f++)d[f]=[d[f].x*s,d[f].y*s];u.coordinates=h,"Point"===Ms.types[a.type]?1===h.length?(u.type="Point",u.coordinates=u.coordinates[0][0]):(u.type="MultiPoint",u.coordinates=u.coordinates[0]):"LineString"===Ms.types[a.type]?1===h.length?(u.type="LineString",u.coordinates=u.coordinates[0]):u.type="MultiLineString":"Polygon"===Ms.types[a.type]&&(u=ks(u)),n.features.push(l);}t[i]=n;}return t}parseJSONProperties(e){if(this.parse_json_type!==zs.NONE){const t=e.properties;if(this.parse_json_type===zs.SOME)this.parse_json_prop_list.forEach(e=>{try{t[e]=JSON.parse(t[e]);}catch(e){}});else for(const e in t)if(Ns.indexOf(t[e][0])>-1)try{t[e]=JSON.parse(t[e]);}catch(e){}}}}function ks(e){let t,i=[],r=[];for(let s=0;s<e.coordinates.length;s++){let n=e.coordinates[s],o=F.ringWinding(n);null!=o&&(o===(t=t||o)&&r.length>0&&(i.push(r),r=[]),r.push(n));}return r.length>0&&i.push(r),1===i.length?(e.type="Polygon",e.coordinates=i[0]):i.length>1?(e.type="MultiPolygon",e.coordinates=i):e=null,e}function Ps(e,t,i,r,s,n){var o=s-i,a=n-r;if(0!==o||0!==a){var l=((e-i)*o+(t-r)*a)/(o*o+a*a);l>1?(i=s,r=n):l>0&&(i+=o*l,r+=a*l);}return (o=e-i)*o+(a=t-r)*a}function Ls(e,t,i,r){var s={id:void 0===e?null:e,type:t,geometry:i,tags:r,minX:1/0,minY:1/0,maxX:-1/0,maxY:-1/0};return function(e){var t=e.geometry,i=e.type;if("Point"===i||"MultiPoint"===i||"LineString"===i)Os(e,t);else if("Polygon"===i||"MultiLineString"===i)for(var r=0;r<t.length;r++)Os(e,t[r]);else if("MultiPolygon"===i)for(r=0;r<t.length;r++)for(var s=0;s<t[r].length;s++)Os(e,t[r][s]);}(s),s}function Os(e,t){for(var i=0;i<t.length;i+=3)e.minX=Math.min(e.minX,t[i]),e.minY=Math.min(e.minY,t[i+1]),e.maxX=Math.max(e.maxX,t[i]),e.maxY=Math.max(e.maxY,t[i+1]);}function Is(e,t,i,r){if(t.geometry){var s=t.geometry.coordinates,n=t.geometry.type,o=Math.pow(i.tolerance/((1<<i.maxZoom)*i.extent),2),a=[],l=t.id;if(i.promoteId?l=t.properties[i.promoteId]:i.generateId&&(l=r||0),"Point"===n)Fs(s,a);else if("MultiPoint"===n)for(var u=0;u<s.length;u++)Fs(s[u],a);else if("LineString"===n)Us(s,a,o,!1);else if("MultiLineString"===n){if(i.lineMetrics){for(u=0;u<s.length;u++)a=[],Us(s[u],a,o,!1),e.push(Ls(l,"LineString",a,t.properties));return}Ds(s,a,o,!1);}else if("Polygon"===n)Ds(s,a,o,!0);else {if("MultiPolygon"!==n){if("GeometryCollection"===n){for(u=0;u<t.geometry.geometries.length;u++)Is(e,{id:l,geometry:t.geometry.geometries[u],properties:t.properties},i,r);return}throw new Error("Input data is not a valid GeoJSON object.")}for(u=0;u<s.length;u++){var h=[];Ds(s[u],h,o,!0),a.push(h);}}e.push(Ls(l,n,a,t.properties));}}function Fs(e,t){t.push(Gs(e[0])),t.push(Cs(e[1])),t.push(0);}function Us(e,t,i,r){for(var s,n,o=0,a=0;a<e.length;a++){var l=Gs(e[a][0]),u=Cs(e[a][1]);t.push(l),t.push(u),t.push(0),a>0&&(o+=r?(s*u-l*n)/2:Math.sqrt(Math.pow(l-s,2)+Math.pow(u-n,2))),s=l,n=u;}var h=t.length-3;t[2]=1,function e(t,i,r,s){for(var n,o=s,a=r-i>>1,l=r-i,u=t[i],h=t[i+1],c=t[r],d=t[r+1],f=i+3;f<r;f+=3){var _=Ps(t[f],t[f+1],u,h,c,d);if(_>o)n=f,o=_;else if(_===o){var p=Math.abs(f-a);p<l&&(n=f,l=p);}}o>s&&(n-i>3&&e(t,i,n,s),t[n+2]=o,r-n>3&&e(t,n,r,s));}(t,0,h,i),t[h+2]=1,t.size=Math.abs(o),t.start=0,t.end=t.size;}function Ds(e,t,i,r){for(var s=0;s<e.length;s++){var n=[];Us(e[s],n,i,r),t.push(n);}}function Gs(e){return e/360+.5}function Cs(e){var t=Math.sin(e*Math.PI/180),i=.5-.25*Math.log((1+t)/(1-t))/Math.PI;return i<0?0:i>1?1:i}function js(e,t,i,r,s,n,o,a){if(r/=t,n>=(i/=t)&&o<r)return e;if(o<i||n>=r)return null;for(var l=[],u=0;u<e.length;u++){var h=e[u],c=h.geometry,d=h.type,f=0===s?h.minX:h.minY,_=0===s?h.maxX:h.maxY;if(f>=i&&_<r)l.push(h);else if(!(_<i||f>=r)){var p=[];if("Point"===d||"MultiPoint"===d)$s(c,p,i,r,s);else if("LineString"===d)Vs(c,p,i,r,s,!1,a.lineMetrics);else if("MultiLineString"===d)qs(c,p,i,r,s,!1);else if("Polygon"===d)qs(c,p,i,r,s,!0);else if("MultiPolygon"===d)for(var m=0;m<c.length;m++){var g=[];qs(c[m],g,i,r,s,!0),g.length&&p.push(g);}if(p.length){if(a.lineMetrics&&"LineString"===d){for(m=0;m<p.length;m++)l.push(Ls(h.id,d,p[m],h.tags));continue}"LineString"!==d&&"MultiLineString"!==d||(1===p.length?(d="LineString",p=p[0]):d="MultiLineString"),"Point"!==d&&"MultiPoint"!==d||(d=3===p.length?"Point":"MultiPoint"),l.push(Ls(h.id,d,p,h.tags));}}}return l.length?l:null}function $s(e,t,i,r,s){for(var n=0;n<e.length;n+=3){var o=e[n+s];o>=i&&o<=r&&(t.push(e[n]),t.push(e[n+1]),t.push(e[n+2]));}}function Vs(e,t,i,r,s,n,o){for(var a,l,u=Bs(e),h=0===s?Hs:Ws,c=e.start,d=0;d<e.length-3;d+=3){var f=e[d],_=e[d+1],p=e[d+2],m=e[d+3],g=e[d+4],x=0===s?f:_,y=0===s?m:g,v=!1;o&&(a=Math.sqrt(Math.pow(f-m,2)+Math.pow(_-g,2))),x<i?y>i&&(l=h(u,f,_,m,g,i),o&&(u.start=c+a*l)):x>r?y<r&&(l=h(u,f,_,m,g,r),o&&(u.start=c+a*l)):Xs(u,f,_,p),y<i&&x>=i&&(l=h(u,f,_,m,g,i),v=!0),y>r&&x<=r&&(l=h(u,f,_,m,g,r),v=!0),!n&&v&&(o&&(u.end=c+a*l),t.push(u),u=Bs(e)),o&&(c+=a);}var b=e.length-3;f=e[b],_=e[b+1],p=e[b+2],(x=0===s?f:_)>=i&&x<=r&&Xs(u,f,_,p),b=u.length-3,n&&b>=3&&(u[b]!==u[0]||u[b+1]!==u[1])&&Xs(u,u[0],u[1],u[2]),u.length&&t.push(u);}function Bs(e){var t=[];return t.size=e.size,t.start=e.start,t.end=e.end,t}function qs(e,t,i,r,s,n){for(var o=0;o<e.length;o++)Vs(e[o],t,i,r,s,n,!1);}function Xs(e,t,i,r){e.push(t),e.push(i),e.push(r);}function Hs(e,t,i,r,s,n){var o=(n-t)/(r-t);return e.push(n),e.push(i+(s-i)*o),e.push(1),o}function Ws(e,t,i,r,s,n){var o=(n-i)/(s-i);return e.push(t+(r-t)*o),e.push(n),e.push(1),o}function Ys(e,t){for(var i=[],r=0;r<e.length;r++){var s,n=e[r],o=n.type;if("Point"===o||"MultiPoint"===o||"LineString"===o)s=Zs(n.geometry,t);else if("MultiLineString"===o||"Polygon"===o){s=[];for(var a=0;a<n.geometry.length;a++)s.push(Zs(n.geometry[a],t));}else if("MultiPolygon"===o)for(s=[],a=0;a<n.geometry.length;a++){for(var l=[],u=0;u<n.geometry[a].length;u++)l.push(Zs(n.geometry[a][u],t));s.push(l);}i.push(Ls(n.id,o,s,n.tags));}return i}function Zs(e,t){var i=[];i.size=e.size,void 0!==e.start&&(i.start=e.start,i.end=e.end);for(var r=0;r<e.length;r+=3)i.push(e[r]+t,e[r+1],e[r+2]);return i}function Js(e,t){if(e.transformed)return e;var i,r,s,n=1<<e.z,o=e.x,a=e.y;for(i=0;i<e.features.length;i++){var l=e.features[i],u=l.geometry,h=l.type;if(l.geometry=[],1===h)for(r=0;r<u.length;r+=2)l.geometry.push(Ks(u[r],u[r+1],t,n,o,a));else for(r=0;r<u.length;r++){var c=[];for(s=0;s<u[r].length;s+=2)c.push(Ks(u[r][s],u[r][s+1],t,n,o,a));l.geometry.push(c);}}return e.transformed=!0,e}function Ks(e,t,i,r,s,n){return [Math.round(i*(e*r-s)),Math.round(i*(t*r-n))]}function Qs(e,t,i,r,s){for(var n=t===s.maxZoom?0:s.tolerance/((1<<t)*s.extent),o={features:[],numPoints:0,numSimplified:0,numFeatures:0,source:null,x:i,y:r,z:t,transformed:!1,minX:2,minY:1,maxX:-1,maxY:0},a=0;a<e.length;a++){o.numFeatures++,en(o,e[a],n,s);var l=e[a].minX,u=e[a].minY,h=e[a].maxX,c=e[a].maxY;l<o.minX&&(o.minX=l),u<o.minY&&(o.minY=u),h>o.maxX&&(o.maxX=h),c>o.maxY&&(o.maxY=c);}return o}function en(e,t,i,r){var s=t.geometry,n=t.type,o=[];if("Point"===n||"MultiPoint"===n)for(var a=0;a<s.length;a+=3)o.push(s[a]),o.push(s[a+1]),e.numPoints++,e.numSimplified++;else if("LineString"===n)tn(o,s,e,i,!1,!1);else if("MultiLineString"===n||"Polygon"===n)for(a=0;a<s.length;a++)tn(o,s[a],e,i,"Polygon"===n,0===a);else if("MultiPolygon"===n)for(var l=0;l<s.length;l++){var u=s[l];for(a=0;a<u.length;a++)tn(o,u[a],e,i,!0,0===a);}if(o.length){var h=t.tags||null;if("LineString"===n&&r.lineMetrics){for(var c in h={},t.tags)h[c]=t.tags[c];h.mapbox_clip_start=s.start/s.size,h.mapbox_clip_end=s.end/s.size;}var d={geometry:o,type:"Polygon"===n||"MultiPolygon"===n?3:"LineString"===n||"MultiLineString"===n?2:1,tags:h};null!==t.id&&(d.id=t.id),e.features.push(d);}}function tn(e,t,i,r,s,n){var o=r*r;if(r>0&&t.size<(s?o:r))i.numPoints+=t.length/3;else {for(var a=[],l=0;l<t.length;l+=3)(0===r||t[l+2]>o)&&(i.numSimplified++,a.push(t[l]),a.push(t[l+1])),i.numPoints++;s&&function(e,t){for(var i=0,r=0,s=e.length,n=s-2;r<s;n=r,r+=2)i+=(e[r]-e[n])*(e[r+1]+e[n+1]);if(i>0===t)for(r=0,s=e.length;r<s/2;r+=2){var o=e[r],a=e[r+1];e[r]=e[s-2-r],e[r+1]=e[s-1-r],e[s-2-r]=o,e[s-1-r]=a;}}(a,n),e.push(a);}}function rn(e,t){return new sn(e,t)}function sn(e,t){var i=(t=this.options=function(e,t){for(var i in t)e[i]=t[i];return e}(Object.create(this.options),t)).debug;if(i&&console.time("preprocess data"),t.maxZoom<0||t.maxZoom>24)throw new Error("maxZoom should be in the 0-24 range");if(t.promoteId&&t.generateId)throw new Error("promoteId and generateId cannot be used together.");var r=function(e,t){var i=[];if("FeatureCollection"===e.type)for(var r=0;r<e.features.length;r++)Is(i,e.features[r],t,r);else "Feature"===e.type?Is(i,e,t):Is(i,{geometry:e},t);return i}(e,t);this.tiles={},this.tileCoords=[],i&&(console.timeEnd("preprocess data"),console.log("index: maxZoom: %d, maxPoints: %d",t.indexMaxZoom,t.indexMaxPoints),console.time("generate tiles"),this.stats={},this.total=0),(r=function(e,t){var i=t.buffer/t.extent,r=e,s=js(e,1,-1-i,i,0,-1,2,t),n=js(e,1,1-i,2+i,0,-1,2,t);return (s||n)&&(r=js(e,1,-i,1+i,0,-1,2,t)||[],s&&(r=Ys(s,1).concat(r)),n&&(r=r.concat(Ys(n,-1)))),r}(r,t)).length&&this.splitTile(r,0,0,0),i&&(r.length&&console.log("features: %d, points: %d",this.tiles[0].numFeatures,this.tiles[0].numPoints),console.timeEnd("generate tiles"),console.log("tiles generated:",this.total,JSON.stringify(this.stats)));}function nn(e,t,i){return 32*((1<<e)*i+t)+e}ye.register("MVT",()=>Ss),sn.prototype.options={maxZoom:14,indexMaxZoom:5,indexMaxPoints:1e5,tolerance:3,extent:4096,buffer:64,lineMetrics:!1,promoteId:null,generateId:!1,debug:0},sn.prototype.splitTile=function(e,t,i,r,s,n,o){for(var a=[e,t,i,r],l=this.options,u=l.debug;a.length;){r=a.pop(),i=a.pop(),t=a.pop(),e=a.pop();var h=1<<t,c=nn(t,i,r),d=this.tiles[c];if(!d&&(u>1&&console.time("creation"),d=this.tiles[c]=Qs(e,t,i,r,l),this.tileCoords.push({z:t,x:i,y:r}),u)){u>1&&(console.log("tile z%d-%d-%d (features: %d, points: %d, simplified: %d)",t,i,r,d.numFeatures,d.numPoints,d.numSimplified),console.timeEnd("creation"));var f="z"+t;this.stats[f]=(this.stats[f]||0)+1,this.total++;}if(d.source=e,s){if(t===l.maxZoom||t===s)continue;var _=1<<s-t;if(i!==Math.floor(n/_)||r!==Math.floor(o/_))continue}else if(t===l.indexMaxZoom||d.numPoints<=l.indexMaxPoints)continue;if(d.source=null,0!==e.length){u>1&&console.time("clipping");var p,m,g,x,y,v,b=.5*l.buffer/l.extent,A=.5-b,T=.5+b,w=1+b;p=m=g=x=null,y=js(e,h,i-b,i+T,0,d.minX,d.maxX,l),v=js(e,h,i+A,i+w,0,d.minX,d.maxX,l),e=null,y&&(p=js(y,h,r-b,r+T,1,d.minY,d.maxY,l),m=js(y,h,r+A,r+w,1,d.minY,d.maxY,l),y=null),v&&(g=js(v,h,r-b,r+T,1,d.minY,d.maxY,l),x=js(v,h,r+A,r+w,1,d.minY,d.maxY,l),v=null),u>1&&console.timeEnd("clipping"),a.push(p||[],t+1,2*i,2*r),a.push(m||[],t+1,2*i,2*r+1),a.push(g||[],t+1,2*i+1,2*r),a.push(x||[],t+1,2*i+1,2*r+1);}}},sn.prototype.getTile=function(e,t,i){var r=this.options,s=r.extent,n=r.debug;if(e<0||e>24)return null;var o=1<<e,a=nn(e,t=(t%o+o)%o,i);if(this.tiles[a])return Js(this.tiles[a],s);n>1&&console.log("drilling down to z%d-%d-%d",e,t,i);for(var l,u=e,h=t,c=i;!l&&u>0;)u--,h=Math.floor(h/2),c=Math.floor(c/2),l=this.tiles[nn(u,h,c)];return l&&l.source?(n>1&&console.log("found parent tile z%d-%d-%d",u,h,c),n>1&&console.time("drilling down"),this.splitTile(l.source,u,h,c,e,t,i),n>1&&console.timeEnd("drilling down"),this.tiles[a]?Js(this.tiles[a],s):null):null};class on extends be{constructor(e,t){super(e,t),this.load_data=null,this.tile_indexes={},this.setTileSize(512),this.pad_scale=0;}_load(e){return this.load_data||(this.load_data=super._load({source_data:{layers:{}}}).then(e=>{e.source_data.error&&f("warn",`data source load error(s) for source '${this.name}', URL '${this.url}': ${e.source_data.error}`);let t=e.source_data.layers;for(let e in t)this.tile_indexes[e]=rn(t[e],{maxZoom:this.max_zoom,tolerance:1.5,extent:F.tile_scale,buffer:1e-4});return this.loaded=!0,e})),this.load_data.then(()=>{for(let t in this.tile_indexes)e.source_data.layers[t]=this.getTileFeatures(e,t);return e})}getTileFeatures(e,t){let i,r=F.wrapTile(e.coords,{x:!0}),s=this.tile_indexes[t].getTile(r.z,r.x,r.y);if(s&&s.features){i={type:"FeatureCollection",features:[]};for(let e=0;e<s.features.length;e++){const t=s.features[e];let r={type:"Feature",geometry:{},id:t.id,properties:t.tags};if(1===t.type)r.geometry.coordinates=t.geometry.map(e=>[e[0],e[1]]),r.geometry.type="MultiPoint";else {if(2!==t.type&&3!==t.type)continue;if(r.geometry.coordinates=t.geometry.map(e=>e.map(e=>[e[0],e[1]])),2===t.type)r.geometry.type="MultiLineString";else if(r.geometry=ks(r.geometry),null==r.geometry)continue}i.features.push(r);}}return i}formatURL(){return this.url}parseSourceData(e,t,i){let r="string"==typeof i?JSON.parse(i):i,s=this.getLayers(r);t.layers=this.preprocessLayers(s,e);}preprocessLayers(e,t){for(let t in e){let i=e[t];i.features=this.preprocessFeatures(i.features);}if("function"==typeof this.transform){const i={min:Object.assign({},t.min),max:Object.assign({},t.max),coords:Object.assign({},t.coords)};1===Object.keys(e).length&&e._default?e._default=this.transform(e._default,this.extra_data,i):e=this.transform(e,this.extra_data,i);}return e}preprocessFeatures(e){if(e=e.filter(e=>null!=e.geometry),this.config.generate_label_centroids){let t=[],i={label_placement:!0};e.forEach(e=>{let r,s;if("Polygon"===e.geometry.type)s=ln(r=e.geometry.coordinates,e.id,e.properties,i),t.push(s);else if("MultiPolygon"===e.geometry.type){r=e.geometry.coordinates;let n=-1/0,o=0;for(let e=0;e<r.length;e++){let t=F.polygonArea(r[e]);t>n&&(n=t,o=e);}s=ln(r[o],e.id,e.properties,i),t.push(s);}}),t=t.filter(e=>e),Array.prototype.push.apply(e,t);}return e}getLayers(e){return "Feature"===e.type?{_default:{type:"FeatureCollection",features:[e]}}:"FeatureCollection"===e.type?{_default:e}:e}}class an extends Ae{constructor(e,t){super(e,t);}parseSourceData(e,t,i){let r="string"==typeof i?JSON.parse(i):i;this.prepareGeoJSON(r,e,t);}prepareGeoJSON(e,t,i){if("function"==typeof this.transform){const i={min:Object.assign({},t.min),max:Object.assign({},t.max),coords:Object.assign({},t.coords)};e=this.transform(e,this.extra_data,i);}i.layers=on.prototype.getLayers(e);let r={coords:t.coords,min:F.metersForTile(F.wrapTile(t.coords,{x:!0}))};ye.projectData(i),ye.scaleData(i,r);}}function ln(e,t,i,r){let s=F.centroid(e);if(!s)return;let n={};return Object.assign(n,i,r),{type:"Feature",id:t,properties:n,geometry:{type:"Point",coordinates:s}}}function un(e){return e}function hn(e,t){var i=t.id,r=t.bbox,s=null==t.properties?{}:t.properties,n=function(e,t){var i=function(e){if(null==(t=e.transform))return un;var t,i,r,s=t.scale[0],n=t.scale[1],o=t.translate[0],a=t.translate[1];return function(e,t){return t||(i=r=0),e[0]=(i+=e[0])*s+o,e[1]=(r+=e[1])*n+a,e}}(e),r=e.arcs;function s(e,t){t.length&&t.pop();for(var s=r[e<0?~e:e],n=0,o=s.length;n<o;++n)t.push(i(s[n].slice(),n));e<0&&function(e,t){for(var i,r=e.length,s=r-t;s<--r;)i=e[s],e[s++]=e[r],e[r]=i;}(t,o);}function n(e){return i(e.slice())}function o(e){for(var t=[],i=0,r=e.length;i<r;++i)s(e[i],t);return t.length<2&&t.push(t[0].slice()),t}function a(e){for(var t=o(e);t.length<4;)t.push(t[0].slice());return t}function l(e){return e.map(a)}return function e(t){var i,r=t.type;switch(r){case"GeometryCollection":return {type:r,geometries:t.geometries.map(e)};case"Point":i=n(t.coordinates);break;case"MultiPoint":i=t.coordinates.map(n);break;case"LineString":i=o(t.arcs);break;case"MultiLineString":i=t.arcs.map(o);break;case"Polygon":i=l(t.arcs);break;case"MultiPolygon":i=t.arcs.map(l);break;default:return null}return {type:r,coordinates:i}}(t)}(e,t);return null==i&&null==r?{type:"Feature",properties:s,geometry:n}:null==r?{type:"Feature",id:i,properties:s,geometry:n}:{type:"Feature",id:i,bbox:r,properties:s,geometry:n}}ye.register("GeoJSON",e=>an.urlHasTilePattern(e.url)?an:on);class cn extends on{parseSourceData(e,t,i){let r="string"==typeof i?JSON.parse(i):i;r=this.toGeoJSON(r);let s=this.getLayers(r);super.preprocessLayers(s,e),t.layers=s;}toGeoJSON(e){if(e.objects&&1===Object.keys(e.objects).length){let t=Object.keys(e.objects)[0];e=dn(e,e.objects[t]);}else {let t={};for(let i in e.objects)t[i]=dn(e,e.objects[i]);e=t;}return e}}function dn(e,t){let i=function(e,t){return "GeometryCollection"===t.type?{type:"FeatureCollection",features:t.geometries.map(function(t){return hn(e,t)})}:hn(e,t)}(e,t);return "Feature"===i.type&&(i={type:"FeatureCollection",features:[i]}),i}class fn extends an{constructor(e,t){super(e,t);}parseSourceData(e,t,i){let r="string"==typeof i?JSON.parse(i):i;r=cn.prototype.toGeoJSON(r),this.prepareGeoJSON(r,e,t);}}ye.register("TopoJSON",e=>fn.urlHasTilePattern(e.url)?fn:cn),e.Collision=di,e.DataSource=ye,e.FeatureSelection=re,e.FilterOptions=qr,e.FontManager=Ti,e.GLSL=E,e.Geo=F,e.Label=li,e.LabelLineStraight=cr,e.LabelPoint=fi,e.Light=me,e.Material=ue,e.OBB=ai,e.ShaderProgram=P,e.Style=Re,e.StyleManager=class{constructor(){this.styles={},this.base_styles={},this.active_styles=[],this.active_blend_orders=[],this.register(Object.create(mt)),this.register(Object.create(Gt)),this.register(Object.create(tr)),this.register(Object.create(gr)),this.register(Object.create(xr));}init(){P.removeBlock("global"),P.removeBlock("setup"),P.addBlock("global",yr),P.addBlock("global",vr),P.replaceBlock("setup",br),P.defines.TANGRAM_EPSILON=1e-5,P.defines.TANGRAM_LAYER_DELTA=1/16384,P.defines.TANGRAM_TILE_SCALE=`vec3(${F.tile_scale}., ${F.tile_scale}., u_meters_per_pixel * ${F.tile_size}.)`,P.defines.TANGRAM_HEIGHT_SCALE=F.height_scale,P.defines.TANGRAM_ALPHA_TEST=.5;}destroy(e){Object.keys(this.styles).forEach(t=>{let i=this.styles[t];i.gl===e&&(f("trace",`StyleManager.destroy: destroying render style ${i.name}`),i.base&&this.remove(i.name),i.destroy());});}register(e){this.styles[e.name]=e,this.base_styles[e.name]=e;}remove(e){delete this.styles[e];}getActiveStyles(){return this.active_styles}updateActiveStyles(e){return this.active_styles=Object.keys(e.reduce((e,t)=>(Object.keys(t.meshes).forEach(t=>e[t]=!0),e),{})),this.active_styles}getActiveBlendOrders(){return this.active_blend_orders}updateActiveBlendOrders(e){const t=[];e.forEach(e=>{Object.entries(e.meshes).forEach(([e,i])=>{i.forEach(i=>{const r=i.variant.blend_order;let s=t.findIndex(e=>e.blend_order===r);s=s>-1?s:t.push({blend_order:r,styles:[]})-1,-1===t[s].styles.indexOf(e)&&t[s].styles.push(e);});});}),this.active_blend_orders=t.sort((e,t)=>e.blend_order-t.blend_order);}mix(e,t){if(e.mixed)return e;e.mixed={};let i=[];e.mix&&(Array.isArray(e.mix)?i.push(...e.mix):i.push(e.mix),(i=i.map(e=>t[e]).filter(t=>t&&t!==e)).forEach(t=>e.mixed[t.name]=!0)),i.push(e),e.animated=i.some(e=>e&&e.animated),e.texcoords=i.some(e=>e&&e.texcoords),e.base=i.map(e=>e.base).filter(e=>e).pop(),e.lighting=i.map(e=>e.lighting).filter(e=>null!=e).pop(),e.texture=i.map(e=>e.texture).filter(e=>e).pop(),e.raster=i.map(e=>e.raster).filter(e=>null!=e).pop(),e.dash=i.map(e=>e.dash).filter(e=>null!=e).pop(),e.dash_background_color=i.map(e=>e.dash_background_color).filter(e=>null!=e).pop(),i.some(e=>Object.prototype.hasOwnProperty.call(e,"blend")&&e.blend)&&(e.blend=i.map(e=>Object.prototype.hasOwnProperty.call(e,"blend")&&e.blend).filter(e=>e).pop()),e.blend_order=i.map(e=>e.blend_order).filter(e=>null!=e).pop(),e.defines=Object.assign({},...i.map(e=>e.defines).filter(e=>e)),e.material=Object.assign({},...i.map(e=>e.material).filter(e=>e));let r=i.map(e=>e.draw).filter(e=>e);return r.length>0&&(e.draw=I({},...r)),this.mixShaders(e,t,i),e}mixShaders(e,t,i){let r={},s=i.map(e=>e.shaders).filter(e=>e);if(r.defines=Object.assign({},...s.map(e=>e.defines).filter(e=>e)),r.attributes=Object.assign({},...s.map(e=>e.attributes).filter(e=>e)),r.uniforms={},r._uniforms=e.shaders&&e.shaders.uniforms||{},r._uniform_scopes={},i.filter(e=>e.shaders&&e.shaders.uniforms).forEach(e=>{for(let i in e.shaders.uniforms)r._uniform_scopes[i]=e.name,Object.defineProperty(r.uniforms,i,{enumerable:!0,configurable:!0,get:function(){return void 0!==r._uniforms[i]?r._uniforms[i]:t[r._uniform_scopes[i]].shaders.uniforms!==r.uniforms?t[r._uniform_scopes[i]].shaders.uniforms[i]:void 0},set:function(e){r._uniforms[i]=e;}});}),r.extensions=Object.keys(s.map(e=>e.extensions).filter(e=>e).reduce((e,t)=>("string"==typeof t?e[t]=!0:t.forEach(t=>e[t]=!0),e),{})||{}),e.shaders&&e.shaders.blocks){e.shaders.block_scopes=e.shaders.block_scopes||{};for(let t in e.shaders.blocks){let i=e.shaders.blocks[t];e.shaders.block_scopes[t]=e.shaders.block_scopes[t]||[],Array.isArray(i)?e.shaders.block_scopes[t].push(...i.map(()=>e.name)):e.shaders.block_scopes[t].push(e.name);}}let n={};return s.forEach(e=>{if(!e.blocks)return;r.blocks=r.blocks||{},r.block_scopes=r.block_scopes||{};let t={};for(let i in e.blocks){let s=e.blocks[i],o=e.block_scopes[i];r.blocks[i]=r.blocks[i]||[],r.block_scopes[i]=r.block_scopes[i]||[],s=Array.isArray(s)?s:[s],o=Array.isArray(o)?o:[o];for(let e=0;e<s.length;e++)n[o[e]]||(t[o[e]]=!0,r.blocks[i].push(s[e]),r.block_scopes[i].push(o[e]));}Object.assign(n,t);}),Object.assign(e.mixed,n),e.shaders=r,e}create(e,t,i={}){let r=I({},t);return r.name=e,(r=this.mix(r,i)).base&&this.base_styles[r.base]?this.styles[e]=r=Object.assign(Object.create(this.base_styles[r.base]),r):r.base=null,r}build(e){const t=i({},e);this.styles&&Object.values(this.styles).forEach(e=>n.removeTarget(e.main_thread_target));const r=["opaque","add","multiply","overlay","inlay","translucent"],s=["polygons","lines","points","text","raster"];for(const e of r)for(const i of s){const r=e+"_"+i;null==t[r]&&(t[r]={base:i,blend:e});}let o=Object.keys(t).sort((e,i)=>this.inheritanceDepth(e,t)-this.inheritanceDepth(i,t));for(let e in this.styles)this.base_styles[e]?this.styles[e].reset():delete this.styles[e];let a={};return o.forEach(e=>{a[e]=this.create(e,t[e],a);}),this.styles}initStyles(e={}){for(let t in this.styles)this.styles[t].init(e);}inheritanceDepth(e,t){let i=0;for(;;){let r=t[e];if(!r)break;if(!r.mix)break;if(i++,Array.isArray(r.mix)){i+=Math.max(...r.mix.map(i=>{if(e!==i)return this.inheritanceDepth(i,t)}));break}if(e===r.mix)break;e=r.mix;}return i}},e.StyleParser=q,e.Task=b,e.TextCanvas=$i,e.Texture=w,e.Thread=t,e.Tile=Zr,e.TileID=Te,e.Utils=_,e.Vector=ce,e.VertexArrayObject=O,e.VertexData=Pe,e.VertexElements=Se,e.View=class{constructor(e,t){A(this),this.scene=e,this.createMatrices(),this.zoom=null,this.center=null,this.bounds=null,this.meters_per_pixel=null,this.panning=!1,this.panning_stop_at=0,this.pan_snap_timer=0,this.zoom_direction=0,this.user_input_at=0,this.user_input_timeout=50,this.user_input_active=!1,this.size={css:{},device:{},meters:{}},this.aspect=null,this.buffer=0,this.continuous_zoom="boolean"!=typeof t.continuousZoom||t.continuousZoom,this.wrap=!1!==t.wrapView,this.preserve_tiles_within_zoom=1,this.reset();}reset(){this.createCamera();}createCamera(){let e=this.getActiveCamera();e&&(this.camera=Yi.create(e,this,this.scene.config.cameras[e]),this.camera.updateView());}getActiveCamera(){if(this.scene.config&&this.scene.config.cameras){for(let e in this.scene.config.cameras)if(this.scene.config.cameras[e].active)return e;let e=Object.keys(this.scene.config.cameras);return e.length&&e[0]}}setActiveCamera(e){let t=this.getActiveCamera();return t===e?e:(this.scene.config.cameras[e]&&(this.scene.config.cameras[e].active=!0,t&&this.scene.config.cameras[t]&&delete this.scene.config.cameras[t].active),this.scene.updateConfig({rebuild:!1,normalize:!1}),this.getActiveCamera())}update(){null!=this.camera&&this.ready()&&this.camera.update(),this.pan_snap_timer=(+new Date-this.panning_stop_at)/1e3,this.user_input_active=+new Date-this.user_input_at<this.user_input_timeout;}setViewportSize(e,t){this.size.css={width:e,height:t},this.size.device={width:Math.round(this.size.css.width*_.device_pixel_ratio),height:Math.round(this.size.css.height*_.device_pixel_ratio)},this.aspect=this.size.css.width/this.size.css.height,this.updateBounds();}setView({lng:e,lat:t,zoom:i}={}){var r=!1;return "number"==typeof e&&"number"==typeof t&&(this.center&&e===this.center.lng&&t===this.center.lat||(r=!0,this.center={lng:e,lat:t})),"number"==typeof i&&i!==this.zoom&&(r=!0,this.setZoom(i)),r&&this.updateBounds(),r}setZoom(e){let t=this.tile_zoom,i=this.baseZoom(e);this.continuous_zoom||(e=i),i!==t&&(this.zoom_direction=i>t?1:-1),this.zoom=e,this.tile_zoom=i,this.updateBounds(),this.scene.requestRedraw();}baseZoom(e){return Math.floor(e)}setPanning(e){this.panning=e,this.panning||(this.panning_stop_at=+new Date);}markUserInput(){this.user_input_at=+new Date;}ready(){return "number"==typeof this.size.css.width&&"number"==typeof this.size.css.height&&null!=this.center&&"number"==typeof this.zoom}updateBounds(){if(!this.ready())return;this.meters_per_pixel=F.metersPerPixel(this.zoom),this.size.meters={x:this.size.css.width*this.meters_per_pixel,y:this.size.css.height*this.meters_per_pixel};const e=F.latLngToMeters([this.center.lng,this.center.lat]);this.center.meters={x:e[0],y:e[1]},this.center.tile=F.tileForMeters([this.center.meters.x,this.center.meters.y],this.tile_zoom),this.bounds={sw:{x:this.center.meters.x-this.size.meters.x/2,y:this.center.meters.y-this.size.meters.y/2},ne:{x:this.center.meters.x+this.size.meters.x/2,y:this.center.meters.y+this.size.meters.y/2}},this.scene.tile_manager.updateTilesForView(),this.trigger("move"),this.scene.requestRedraw();}findVisibleTileCoordinates(){if(!this.bounds)return [];let e=this.tile_zoom,t=F.tileForMeters([this.bounds.sw.x,this.bounds.sw.y],e),i=F.tileForMeters([this.bounds.ne.x,this.bounds.ne.y],e),r=[t.x-this.buffer,i.x+this.buffer,i.y-this.buffer,t.y+this.buffer];if(!1===this.wrap){let t=(1<<e)-1;r=r.map(e=>Math.min(Math.max(0,e),t));}let s=[];for(let t=r[0];t<=r[1];t++)for(let i=r[2];i<=r[3];i++)s.push(Te.coord({x:t,y:i,z:e}));return s}pruneTilesForView(){this.ready()&&this.scene.tile_manager.removeTiles(e=>{if(e.visible||e.isProxy())return !1;if(e.loading&&e.style_z!==this.tile_zoom)return !0;if(Math.abs(e.style_z-this.tile_zoom)>(null!=e.preserve_tiles_within_zoom?e.preserve_tiles_within_zoom:this.preserve_tiles_within_zoom))return !0;const t=this.meters_per_pixel*F.tile_size,i=Te.coordAtZoom(F.tileForMeters([this.center.meters.x-this.size.meters.x/2-t,this.center.meters.y+this.size.meters.y/2+t],this.tile_zoom),e.coords.z),r=Te.coordAtZoom(F.tileForMeters([this.center.meters.x+this.size.meters.x/2+t,this.center.meters.y-this.size.meters.y/2-t],this.tile_zoom),e.coords.z);return (e.coords.x<i.x||e.coords.x>r.x||e.coords.y<i.y||e.coords.y>r.y)&&(f("trace",`View: remove tile ${e.key} (as ${e.coords.key}) `+`for being too far out of visible area (${i.key}, ${r.key})`),!0)});}createMatrices(){this.matrices={},this.matrices.model=new Float64Array(16),this.matrices.model32=new Float32Array(16),this.matrices.model_view=new Float64Array(16),this.matrices.model_view32=new Float32Array(16),this.matrices.normal=new Float64Array(9),this.matrices.normal32=new Float32Array(9),this.matrices.inverse_normal32=new Float32Array(9);}setupTile(e,t){e.setupProgram(this.matrices,t),this.camera.setupMatrices(this.matrices,t);}setupProgram(e){e.uniform("2fv","u_resolution",[this.size.device.width,this.size.device.height]),e.uniform("3fv","u_map_position",[this.center.meters.x,this.center.meters.y,this.zoom]),e.uniform("1f","u_meters_per_pixel",this.meters_per_pixel),e.uniform("1f","u_device_pixel_ratio",_.device_pixel_ratio),e.uniform("1f","u_view_pan_snap_timer",this.pan_snap_timer),e.uniform("1i","u_view_panning",this.panning),this.camera.setupProgram(e);}isAnimating(){return this.pan_snap_timer<=Qi}},e.WorkerBroker=n,e._extends=i,e.addBaseURL=function(e,t){if(!e||!x(e))return e;var i,r="/"!==e[0];if(t?(i=document.createElement("a")).href=t:i=window.location,r)e=g(i.href)+e;else {let t=i.origin;t||(t=i.protocol+"//"+i.host),e=t+e;}return e},e.buildFilter=Ur,e.cache=C,e.clearFunctionStringCache=function(){C.functions={},C.num_functions=0,C.num_cached=0;},e.commonjsRequire=function(){throw new Error("Dynamic requires are not currently supported by rollup-plugin-commonjs")},e.compileFunctionStrings=j,e.createCommonjsModule=V,e.createObjectURL=function(e){return void 0===y&&"function"!=typeof(y=window.URL&&window.URL.createObjectURL||window.webkitURL&&window.webkitURL.createObjectURL)&&(y=null,f("warn","window.URL.createObjectURL (or vendor prefix) not found, unable to create local blob URLs")),y?y(e):e},e.debugSettings=m,e.debugSumLayerStats=function(e){let t={},i={};return e.filter(e=>e.debug.layers).forEach(e=>{Object.keys(e.debug.layers.list).forEach(i=>{let r=e.debug.layers.list[i];Me(t,i,r.features,r.geoms,r.styles,r.base);}),function e(t,i){for(let r in t){let s=t[r];Me(i,r,s.features,s.geoms,s.styles,s.base),s.layers&&(i[r].layers=i[r].layers||{},e(s.layers,i[r].layers));}}(e.debug.layers.tree,i);}),{list:t,tree:i}},e.extensionForURL=function(e){let t=(e=e.split("/").pop()).lastIndexOf(".");if(t>-1)return e.substring(t+1)},e.flattenRelativeURL=function(e){let t=(e||"").split("/");for(let e=1;e<t.length;e++)"."===t[e]?(t.splice(e,1),e--):".."===t[e]&&(e+=0,t.splice(e-1,2),e--);return t.join("/")},e.isLocalURL=function(e){if("string"==typeof e)return e.search(/^(data|blob):/)>-1},e.isRelativeURL=x,e.isReserved=Xr,e.layerCache=function(){return Gr},e.log=f,e.mergeDebugSettings=function(e){Object.assign(p,e);},e.mergeObjects=I,e.parseLayers=function(e,t){Gr={};let i={};for(let r in e){let s=e[r];s&&(i[r]=Hr(r,s,null,t));}return i},e.pathForURL=g,e.sliceObject=T,e.subscribeMixin=A,e.version=s;});

define(["./shared"],function(e){"use strict";const t=Object.assign(self,{FeatureSelection:e.FeatureSelection,sources:{},styles:{},layers:{},tiles:{},init(t,r,i,s,o,l,n){return this.scene_id=t,this._worker_id=r,this.num_workers=i,e.log.setLevel(s),e.Utils.device_pixel_ratio=o,e.VertexElements.setElementIndexUint(l),e.FeatureSelection.setPrefix(this._worker_id),this.style_manager=new e.StyleManager,this.importExternalScripts(n),e.Label.id_prefix=r,e.Label.id_multiplier=i,r},importExternalScripts(t){if(0===t.length)return;e.log("debug","loading custom data source scripts in worker:",t);let r=Object.getOwnPropertyNames(window);importScripts(...t),Object.getOwnPropertyNames(window).forEach(e=>{-1===r.indexOf(e)&&(this[e]=window[e]);});},updateConfig({config:t,generation:r,introspection:i},s){return t=JSON.parse(t),e.mergeDebugSettings(s),this.generation=r,this.introspection=i,this.global=e.compileFunctionStrings(t.global),this.createDataSources(t),t.styles=e.compileFunctionStrings(t.styles,e.StyleParser.wrapFunction),this.styles=this.style_manager.build(t.styles),this.style_manager.initStyles({generation:this.generation,styles:this.styles,sources:this.sources,introspection:this.introspection}),this.layers=e.parseLayers(t.layers,this.style_manager.styles),this.syncing_textures=this.syncTextures(t.textures),this.configuring=this.syncing_textures.then(()=>{e.log("debug","updated config");}),this.configuring},createDataSources(t){this.last_config_sources=this.config_sources||{},this.config_sources=t.sources;let r=this.sources,i=[];this.sources={};for(let s in t.sources){if(JSON.stringify(this.last_config_sources[s])===JSON.stringify(t.sources[s])){this.sources[s]=r[s];continue}let o;t.sources[s]=e.compileFunctionStrings(t.sources[s]);try{o=e.DataSource.create(Object.assign({},t.sources[s],{name:s}),this.sources);}catch(e){continue}o&&(this.sources[s]=o,i.push(s));}i.forEach(e=>{for(let t in this.tiles)this.tiles[t].source===e&&delete this.tiles[t];});},awaitConfiguration(){return this.configuring},buildTile({tile:t}){if(null==this.getTile(t.key)||!0!==this.getTile(t.key).loading)return t=this.tiles[t.key]=Object.assign(this.getTile(t.key)||{},t),this.awaitConfiguration().then(()=>{if(!0!==t.loaded)t.loading=!0,t.loaded=!1,t.error=null,this.loadTileSourceData(t).then(()=>{this.getTile(t.key)?(t.source_data.error&&e.log("warn",`tile load error(s) for ${t.key}: ${t.source_data.error}`),t.loading=!1,t.loaded=!0,e.Tile.buildGeometry(t,this)):e.log("trace",`stop tile build after data source load because tile was removed: ${t.key}`);}).catch(r=>{t.loading=!1,t.loaded=!1,t.error=r.stack,e.log("error",`tile load error for ${t.key}: ${t.error}`),e.WorkerBroker.postMessage(`TileManager_${this.scene_id}.buildTileError`,e.Tile.slice(t));});else {e.log("trace",`used worker cache for tile ${t.key}`);try{e.Tile.buildGeometry(t,this);}catch(r){t.error=r.toString(),e.WorkerBroker.postMessage(`TileManager_${this.scene_id}.buildTileError`,e.Tile.slice(t));}}})},loadTileSourceData(e){const t=this.sources[e.source];if(t){for(const r in this.tiles){const i=this.tiles[r];if(i.source===e.source&&i.coords.key===e.coords.key&&i.loaded)return Promise.resolve(t.copyTileData(i,e))}return t.load(e)}return e.source_data={},Promise.resolve(e)},getTile(e){return this.tiles[e]},removeTile(t){var r=this.tiles[t];null!=r&&(!0===r.loading&&(e.log("trace",`cancel tile load for ${t}`),r.loading=!1,e.Tile.cancel(r)),e.FeatureSelection.clearTile(t),delete this.tiles[t],e.log("trace",`remove tile from cache for ${t}`));},queryFeatures({filter:t,visible:r,geometry:i,tile_keys:s}){let o=[],l=s.map(e=>this.tiles[e]).filter(e=>e&&e.loaded);return null!=t&&(t=["{","["].indexOf(t[0])>-1?JSON.parse(t):t,t=e.compileFunctionStrings(t,e.StyleParser.wrapFunction)),t=e.buildFilter(t,e.FilterOptions),l.forEach(s=>{for(let l in s.source_data.layers){let n=s.source_data.layers[l];if(null==n)return;n.features.forEach(n=>{const a=n.generation===this.generation;if(!0===r&&!a||!1===r&&a)return;let c=e.StyleParser.getFeatureParseContext(n,s,this.global);if(c.source=s.source,c.layer=l,c.id=n.id,!t(c))return;let u={type:n.type,id:n.id,properties:Object.assign({},n.properties,{$source:c.source,$layer:c.layer,$geometry:c.geometry,$visible:a})};!0===i&&(u.geometry=e.Geo.copyGeometry(n.geometry),e.Geo.tileSpaceToLatlng(u.geometry,s.coords.z,s.min)),o.push(u);});}}),o},getFeatureSelection({id:t,key:r}={}){var i=e.FeatureSelection.map[r];return {id:t,feature:i&&i.feature}},resetFeatureSelection(t=null){e.FeatureSelection.reset(t);},getFeatureSelectionMapSize:()=>e.FeatureSelection.getMapSize(),syncTextures(t){let r=[];return t&&r.push(...Object.keys(t)),e.log("trace","sync textures to worker:",r),r.length>0?e.Texture.syncTexturesToWorker(r):Promise.resolve()},updateDevicePixelRatio(t){e.Utils.device_pixel_ratio=t;},clearFunctionStringCache(){e.clearFunctionStringCache();},profile(e){console.profile(`worker ${this._worker_id}: ${e}`);},profileEnd(e){console.profileEnd(`worker ${this._worker_id}: ${e}`);},debug:{debugSettings:e.debugSettings,layerCache:e.layerCache,functionStringCache:e.cache}});e.WorkerBroker.addTarget("self",t);});

define(["./shared"],function(e){"use strict";var t,r=t={};let i=0;function n(e,t){var r;const i=t[t.length-1];return null==(r=o(e,t))?void 0:r[i]}function s(e,t,r){const i=t[t.length-1],n=o(e,t);n&&(n[i]=r);}function o(e,t){if(0===t.length)return;let r=e;for(let e=0;e<t.length-1;e++){if(null==(r=r[t[e]]))return}return r}t.getContext=function(e,r){var n=!1;null==e&&((e=document.createElement("canvas")).style.position="absolute",e.style.top=0,e.style.left=0,e.style.zIndex=-1,document.body.appendChild(e),n=!0),e.addEventListener("webglcontextlost",()=>{}),e.addEventListener("webglcontextrestored",()=>{});var s=e.getContext("webgl",r)||e.getContext("experimental-webgl",r);if(!s)throw new Error("Couldn't create WebGL context.");return s._tangram_id=i++,n?(t.resize(s,window.innerWidth,window.innerHeight,r.device_pixel_ratio),window.addEventListener("resize",function(){t.resize(s,window.innerWidth,window.innerHeight,r.device_pixel_ratio);})):t.resize(s,parseFloat(e.style.width),parseFloat(e.style.height),r.device_pixel_ratio),s},t.resize=function(e,t,r,i){i=i||window.devicePixelRatio||1,e.canvas.style.width=t+"px",e.canvas.style.height=r+"px",e.canvas.width=Math.round(t*i),e.canvas.height=Math.round(r*i),e.bindFramebuffer(e.FRAMEBUFFER,null),e.viewport(0,0,e.canvas.width,e.canvas.height);};const a="global.",l=a.length,u="__global_prop";function h(e){return (null==e?void 0:e.slice(0,l))===a}function c(e,t){var r;const i=Array.isArray(t)?t:[t],n=o(e,i),s=i[i.length-1];return void 0!==(null==n?void 0:null==(r=n[u])?void 0:r[s])}var f="undefined"!=typeof global?global:"undefined"!=typeof self?self:"undefined"!=typeof window?window:{},d=[],p=[],g="undefined"!=typeof Uint8Array?Uint8Array:Array,m=!1;function _(){m=!0;for(var e="ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/",t=0,r=e.length;t<r;++t)d[t]=e[t],p[e.charCodeAt(t)]=t;p["-".charCodeAt(0)]=62,p["_".charCodeAt(0)]=63;}function y(e,t,r){for(var i,n,s=[],o=t;o<r;o+=3)i=(e[o]<<16)+(e[o+1]<<8)+e[o+2],s.push(d[(n=i)>>18&63]+d[n>>12&63]+d[n>>6&63]+d[63&n]);return s.join("")}function b(e){var t;m||_();for(var r=e.length,i=r%3,n="",s=[],o=0,a=r-i;o<a;o+=16383)s.push(y(e,o,o+16383>a?a:o+16383));return 1===i?(t=e[r-1],n+=d[t>>2],n+=d[t<<4&63],n+="=="):2===i&&(t=(e[r-2]<<8)+e[r-1],n+=d[t>>10],n+=d[t>>4&63],n+=d[t<<2&63],n+="="),s.push(n),s.join("")}function v(e,t,r,i,n){var s,o,a=8*n-i-1,l=(1<<a)-1,u=l>>1,h=-7,c=r?n-1:0,f=r?-1:1,d=e[t+c];for(c+=f,s=d&(1<<-h)-1,d>>=-h,h+=a;h>0;s=256*s+e[t+c],c+=f,h-=8);for(o=s&(1<<-h)-1,s>>=-h,h+=i;h>0;o=256*o+e[t+c],c+=f,h-=8);if(0===s)s=1-u;else {if(s===l)return o?NaN:1/0*(d?-1:1);o+=Math.pow(2,i),s-=u;}return (d?-1:1)*o*Math.pow(2,s-i)}function w(e,t,r,i,n,s){var o,a,l,u=8*s-n-1,h=(1<<u)-1,c=h>>1,f=23===n?Math.pow(2,-24)-Math.pow(2,-77):0,d=i?0:s-1,p=i?1:-1,g=t<0||0===t&&1/t<0?1:0;for(t=Math.abs(t),isNaN(t)||t===1/0?(a=isNaN(t)?1:0,o=h):(o=Math.floor(Math.log(t)/Math.LN2),t*(l=Math.pow(2,-o))<1&&(o--,l*=2),(t+=o+c>=1?f/l:f*Math.pow(2,1-c))*l>=2&&(o++,l/=2),o+c>=h?(a=0,o=h):o+c>=1?(a=(t*l-1)*Math.pow(2,n),o+=c):(a=t*Math.pow(2,c-1)*Math.pow(2,n),o=0));n>=8;e[r+d]=255&a,d+=p,a/=256,n-=8);for(o=o<<n|a,u+=n;u>0;e[r+d]=255&o,d+=p,o/=256,u-=8);e[r+d-p]|=128*g;}var k={}.toString,S=Array.isArray||function(e){return "[object Array]"==k.call(e)};A.TYPED_ARRAY_SUPPORT=void 0===f.TYPED_ARRAY_SUPPORT||f.TYPED_ARRAY_SUPPORT;var x=C();function C(){return A.TYPED_ARRAY_SUPPORT?2147483647:1073741823}function E(e,t){if(C()<t)throw new RangeError("Invalid typed array length");return A.TYPED_ARRAY_SUPPORT?(e=new Uint8Array(t)).__proto__=A.prototype:(null===e&&(e=new A(t)),e.length=t),e}function A(e,t,r){if(!(A.TYPED_ARRAY_SUPPORT||this instanceof A))return new A(e,t,r);if("number"==typeof e){if("string"==typeof t)throw new Error("If encoding is specified then the first argument must be a string");return O(this,e)}return T(this,e,t,r)}function T(e,t,r,i){if("number"==typeof t)throw new TypeError('"value" argument must not be a number');return "undefined"!=typeof ArrayBuffer&&t instanceof ArrayBuffer?function(e,t,r,i){if(t.byteLength,r<0||t.byteLength<r)throw new RangeError("'offset' is out of bounds");if(t.byteLength<r+(i||0))throw new RangeError("'length' is out of bounds");t=void 0===r&&void 0===i?new Uint8Array(t):void 0===i?new Uint8Array(t,r):new Uint8Array(t,r,i);A.TYPED_ARRAY_SUPPORT?(e=t).__proto__=A.prototype:e=R(e,t);return e}(e,t,r,i):"string"==typeof t?function(e,t,r){"string"==typeof r&&""!==r||(r="utf8");if(!A.isEncoding(r))throw new TypeError('"encoding" must be a valid string encoding');var i=0|I(t,r),n=(e=E(e,i)).write(t,r);n!==i&&(e=e.slice(0,n));return e}(e,t,r):function(e,t){if(B(t)){var r=0|L(t.length);return 0===(e=E(e,r)).length?e:(t.copy(e,0,0,r),e)}if(t){if("undefined"!=typeof ArrayBuffer&&t.buffer instanceof ArrayBuffer||"length"in t)return "number"!=typeof t.length||(i=t.length)!=i?E(e,0):R(e,t);if("Buffer"===t.type&&S(t.data))return R(e,t.data)}var i;throw new TypeError("First argument must be a string, Buffer, ArrayBuffer, Array, or array-like object.")}(e,t)}function z(e){if("number"!=typeof e)throw new TypeError('"size" argument must be a number');if(e<0)throw new RangeError('"size" argument must not be negative')}function O(e,t){if(z(t),e=E(e,t<0?0:0|L(t)),!A.TYPED_ARRAY_SUPPORT)for(var r=0;r<t;++r)e[r]=0;return e}function R(e,t){var r=t.length<0?0:0|L(t.length);e=E(e,r);for(var i=0;i<r;i+=1)e[i]=255&t[i];return e}function L(e){if(e>=C())throw new RangeError("Attempt to allocate Buffer larger than maximum size: 0x"+C().toString(16)+" bytes");return 0|e}function B(e){return !(null==e||!e._isBuffer)}function I(e,t){if(B(e))return e.length;if("undefined"!=typeof ArrayBuffer&&"function"==typeof ArrayBuffer.isView&&(ArrayBuffer.isView(e)||e instanceof ArrayBuffer))return e.byteLength;"string"!=typeof e&&(e=""+e);var r=e.length;if(0===r)return 0;for(var i=!1;;)switch(t){case"ascii":case"latin1":case"binary":return r;case"utf8":case"utf-8":case void 0:return oe(e).length;case"ucs2":case"ucs-2":case"utf16le":case"utf-16le":return 2*r;case"hex":return r>>>1;case"base64":return ae(e).length;default:if(i)return oe(e).length;t=(""+t).toLowerCase(),i=!0;}}function F(e,t,r){var i=e[t];e[t]=e[r],e[r]=i;}function P(e,t,r,i,n){if(0===e.length)return -1;if("string"==typeof r?(i=r,r=0):r>2147483647?r=2147483647:r<-2147483648&&(r=-2147483648),r=+r,isNaN(r)&&(r=n?0:e.length-1),r<0&&(r=e.length+r),r>=e.length){if(n)return -1;r=e.length-1;}else if(r<0){if(!n)return -1;r=0;}if("string"==typeof t&&(t=A.from(t,i)),B(t))return 0===t.length?-1:M(e,t,r,i,n);if("number"==typeof t)return t&=255,A.TYPED_ARRAY_SUPPORT&&"function"==typeof Uint8Array.prototype.indexOf?n?Uint8Array.prototype.indexOf.call(e,t,r):Uint8Array.prototype.lastIndexOf.call(e,t,r):M(e,[t],r,i,n);throw new TypeError("val must be string, number or Buffer")}function M(e,t,r,i,n){var s,o=1,a=e.length,l=t.length;if(void 0!==i&&("ucs2"===(i=String(i).toLowerCase())||"ucs-2"===i||"utf16le"===i||"utf-16le"===i)){if(e.length<2||t.length<2)return -1;o=2,a/=2,l/=2,r/=2;}function u(e,t){return 1===o?e[t]:e.readUInt16BE(t*o)}if(n){var h=-1;for(s=r;s<a;s++)if(u(e,s)===u(t,-1===h?0:s-h)){if(-1===h&&(h=s),s-h+1===l)return h*o}else -1!==h&&(s-=s-h),h=-1;}else for(r+l>a&&(r=a-l),s=r;s>=0;s--){for(var c=!0,f=0;f<l;f++)if(u(e,s+f)!==u(t,f)){c=!1;break}if(c)return s}return -1}function U(e,t,r,i){r=Number(r)||0;var n=e.length-r;i?(i=Number(i))>n&&(i=n):i=n;var s=t.length;if(s%2!=0)throw new TypeError("Invalid hex string");i>s/2&&(i=s/2);for(var o=0;o<i;++o){var a=parseInt(t.substr(2*o,2),16);if(isNaN(a))return o;e[r+o]=a;}return o}function D(e,t,r,i){return le(oe(t,e.length-r),e,r,i)}function j(e,t,r,i){return le(function(e){for(var t=[],r=0;r<e.length;++r)t.push(255&e.charCodeAt(r));return t}(t),e,r,i)}function N(e,t,r,i){return j(e,t,r,i)}function Z(e,t,r,i){return le(ae(t),e,r,i)}function W(e,t,r,i){return le(function(e,t){for(var r,i,n,s=[],o=0;o<e.length&&!((t-=2)<0);++o)r=e.charCodeAt(o),i=r>>8,n=r%256,s.push(n),s.push(i);return s}(t,e.length-r),e,r,i)}function q(e,t,r){return 0===t&&r===e.length?b(e):b(e.slice(t,r))}function Y(e,t,r){r=Math.min(e.length,r);for(var i=[],n=t;n<r;){var s,o,a,l,u=e[n],h=null,c=u>239?4:u>223?3:u>191?2:1;if(n+c<=r)switch(c){case 1:u<128&&(h=u);break;case 2:128==(192&(s=e[n+1]))&&(l=(31&u)<<6|63&s)>127&&(h=l);break;case 3:s=e[n+1],o=e[n+2],128==(192&s)&&128==(192&o)&&(l=(15&u)<<12|(63&s)<<6|63&o)>2047&&(l<55296||l>57343)&&(h=l);break;case 4:s=e[n+1],o=e[n+2],a=e[n+3],128==(192&s)&&128==(192&o)&&128==(192&a)&&(l=(15&u)<<18|(63&s)<<12|(63&o)<<6|63&a)>65535&&l<1114112&&(h=l);}null===h?(h=65533,c=1):h>65535&&(h-=65536,i.push(h>>>10&1023|55296),h=56320|1023&h),i.push(h),n+=c;}return function(e){var t=e.length;if(t<=V)return String.fromCharCode.apply(String,e);var r="",i=0;for(;i<t;)r+=String.fromCharCode.apply(String,e.slice(i,i+=V));return r}(i)}A.poolSize=8192,A._augment=function(e){return e.__proto__=A.prototype,e},A.from=function(e,t,r){return T(null,e,t,r)},A.TYPED_ARRAY_SUPPORT&&(A.prototype.__proto__=Uint8Array.prototype,A.__proto__=Uint8Array),A.alloc=function(e,t,r){return function(e,t,r,i){return z(t),t<=0?E(e,t):void 0!==r?"string"==typeof i?E(e,t).fill(r,i):E(e,t).fill(r):E(e,t)}(null,e,t,r)},A.allocUnsafe=function(e){return O(null,e)},A.allocUnsafeSlow=function(e){return O(null,e)},A.isBuffer=ue,A.compare=function(e,t){if(!B(e)||!B(t))throw new TypeError("Arguments must be Buffers");if(e===t)return 0;for(var r=e.length,i=t.length,n=0,s=Math.min(r,i);n<s;++n)if(e[n]!==t[n]){r=e[n],i=t[n];break}return r<i?-1:i<r?1:0},A.isEncoding=function(e){switch(String(e).toLowerCase()){case"hex":case"utf8":case"utf-8":case"ascii":case"latin1":case"binary":case"base64":case"ucs2":case"ucs-2":case"utf16le":case"utf-16le":return !0;default:return !1}},A.concat=function(e,t){if(!S(e))throw new TypeError('"list" argument must be an Array of Buffers');if(0===e.length)return A.alloc(0);var r;if(void 0===t)for(t=0,r=0;r<e.length;++r)t+=e[r].length;var i=A.allocUnsafe(t),n=0;for(r=0;r<e.length;++r){var s=e[r];if(!B(s))throw new TypeError('"list" argument must be an Array of Buffers');s.copy(i,n),n+=s.length;}return i},A.byteLength=I,A.prototype._isBuffer=!0,A.prototype.swap16=function(){var e=this.length;if(e%2!=0)throw new RangeError("Buffer size must be a multiple of 16-bits");for(var t=0;t<e;t+=2)F(this,t,t+1);return this},A.prototype.swap32=function(){var e=this.length;if(e%4!=0)throw new RangeError("Buffer size must be a multiple of 32-bits");for(var t=0;t<e;t+=4)F(this,t,t+3),F(this,t+1,t+2);return this},A.prototype.swap64=function(){var e=this.length;if(e%8!=0)throw new RangeError("Buffer size must be a multiple of 64-bits");for(var t=0;t<e;t+=8)F(this,t,t+7),F(this,t+1,t+6),F(this,t+2,t+5),F(this,t+3,t+4);return this},A.prototype.toString=function(){var e=0|this.length;return 0===e?"":0===arguments.length?Y(this,0,e):function(e,t,r){var i=!1;if((void 0===t||t<0)&&(t=0),t>this.length)return "";if((void 0===r||r>this.length)&&(r=this.length),r<=0)return "";if((r>>>=0)<=(t>>>=0))return "";for(e||(e="utf8");;)switch(e){case"hex":return $(this,t,r);case"utf8":case"utf-8":return Y(this,t,r);case"ascii":return H(this,t,r);case"latin1":case"binary":return G(this,t,r);case"base64":return q(this,t,r);case"ucs2":case"ucs-2":case"utf16le":case"utf-16le":return K(this,t,r);default:if(i)throw new TypeError("Unknown encoding: "+e);e=(e+"").toLowerCase(),i=!0;}}.apply(this,arguments)},A.prototype.equals=function(e){if(!B(e))throw new TypeError("Argument must be a Buffer");return this===e||0===A.compare(this,e)},A.prototype.inspect=function(){var e="";return this.length>0&&(e=this.toString("hex",0,50).match(/.{2}/g).join(" "),this.length>50&&(e+=" ... ")),"<Buffer "+e+">"},A.prototype.compare=function(e,t,r,i,n){if(!B(e))throw new TypeError("Argument must be a Buffer");if(void 0===t&&(t=0),void 0===r&&(r=e?e.length:0),void 0===i&&(i=0),void 0===n&&(n=this.length),t<0||r>e.length||i<0||n>this.length)throw new RangeError("out of range index");if(i>=n&&t>=r)return 0;if(i>=n)return -1;if(t>=r)return 1;if(this===e)return 0;for(var s=(n>>>=0)-(i>>>=0),o=(r>>>=0)-(t>>>=0),a=Math.min(s,o),l=this.slice(i,n),u=e.slice(t,r),h=0;h<a;++h)if(l[h]!==u[h]){s=l[h],o=u[h];break}return s<o?-1:o<s?1:0},A.prototype.includes=function(e,t,r){return -1!==this.indexOf(e,t,r)},A.prototype.indexOf=function(e,t,r){return P(this,e,t,r,!0)},A.prototype.lastIndexOf=function(e,t,r){return P(this,e,t,r,!1)},A.prototype.write=function(e,t,r,i){if(void 0===t)i="utf8",r=this.length,t=0;else if(void 0===r&&"string"==typeof t)i=t,r=this.length,t=0;else {if(!isFinite(t))throw new Error("Buffer.write(string, encoding, offset[, length]) is no longer supported");t|=0,isFinite(r)?(r|=0,void 0===i&&(i="utf8")):(i=r,r=void 0);}var n=this.length-t;if((void 0===r||r>n)&&(r=n),e.length>0&&(r<0||t<0)||t>this.length)throw new RangeError("Attempt to write outside buffer bounds");i||(i="utf8");for(var s=!1;;)switch(i){case"hex":return U(this,e,t,r);case"utf8":case"utf-8":return D(this,e,t,r);case"ascii":return j(this,e,t,r);case"latin1":case"binary":return N(this,e,t,r);case"base64":return Z(this,e,t,r);case"ucs2":case"ucs-2":case"utf16le":case"utf-16le":return W(this,e,t,r);default:if(s)throw new TypeError("Unknown encoding: "+i);i=(""+i).toLowerCase(),s=!0;}},A.prototype.toJSON=function(){return {type:"Buffer",data:Array.prototype.slice.call(this._arr||this,0)}};var V=4096;function H(e,t,r){var i="";r=Math.min(e.length,r);for(var n=t;n<r;++n)i+=String.fromCharCode(127&e[n]);return i}function G(e,t,r){var i="";r=Math.min(e.length,r);for(var n=t;n<r;++n)i+=String.fromCharCode(e[n]);return i}function $(e,t,r){var i=e.length;(!t||t<0)&&(t=0),(!r||r<0||r>i)&&(r=i);for(var n="",s=t;s<r;++s)n+=se(e[s]);return n}function K(e,t,r){for(var i=e.slice(t,r),n="",s=0;s<i.length;s+=2)n+=String.fromCharCode(i[s]+256*i[s+1]);return n}function J(e,t,r){if(e%1!=0||e<0)throw new RangeError("offset is not uint");if(e+t>r)throw new RangeError("Trying to access beyond buffer length")}function X(e,t,r,i,n,s){if(!B(e))throw new TypeError('"buffer" argument must be a Buffer instance');if(t>n||t<s)throw new RangeError('"value" argument is out of bounds');if(r+i>e.length)throw new RangeError("Index out of range")}function Q(e,t,r,i){t<0&&(t=65535+t+1);for(var n=0,s=Math.min(e.length-r,2);n<s;++n)e[r+n]=(t&255<<8*(i?n:1-n))>>>8*(i?n:1-n);}function ee(e,t,r,i){t<0&&(t=4294967295+t+1);for(var n=0,s=Math.min(e.length-r,4);n<s;++n)e[r+n]=t>>>8*(i?n:3-n)&255;}function te(e,t,r,i,n,s){if(r+i>e.length)throw new RangeError("Index out of range");if(r<0)throw new RangeError("Index out of range")}function re(e,t,r,i,n){return n||te(e,0,r,4),w(e,t,r,i,23,4),r+4}function ie(e,t,r,i,n){return n||te(e,0,r,8),w(e,t,r,i,52,8),r+8}A.prototype.slice=function(e,t){var r,i=this.length;if((e=~~e)<0?(e+=i)<0&&(e=0):e>i&&(e=i),(t=void 0===t?i:~~t)<0?(t+=i)<0&&(t=0):t>i&&(t=i),t<e&&(t=e),A.TYPED_ARRAY_SUPPORT)(r=this.subarray(e,t)).__proto__=A.prototype;else {var n=t-e;r=new A(n,void 0);for(var s=0;s<n;++s)r[s]=this[s+e];}return r},A.prototype.readUIntLE=function(e,t,r){e|=0,t|=0,r||J(e,t,this.length);for(var i=this[e],n=1,s=0;++s<t&&(n*=256);)i+=this[e+s]*n;return i},A.prototype.readUIntBE=function(e,t,r){e|=0,t|=0,r||J(e,t,this.length);for(var i=this[e+--t],n=1;t>0&&(n*=256);)i+=this[e+--t]*n;return i},A.prototype.readUInt8=function(e,t){return t||J(e,1,this.length),this[e]},A.prototype.readUInt16LE=function(e,t){return t||J(e,2,this.length),this[e]|this[e+1]<<8},A.prototype.readUInt16BE=function(e,t){return t||J(e,2,this.length),this[e]<<8|this[e+1]},A.prototype.readUInt32LE=function(e,t){return t||J(e,4,this.length),(this[e]|this[e+1]<<8|this[e+2]<<16)+16777216*this[e+3]},A.prototype.readUInt32BE=function(e,t){return t||J(e,4,this.length),16777216*this[e]+(this[e+1]<<16|this[e+2]<<8|this[e+3])},A.prototype.readIntLE=function(e,t,r){e|=0,t|=0,r||J(e,t,this.length);for(var i=this[e],n=1,s=0;++s<t&&(n*=256);)i+=this[e+s]*n;return i>=(n*=128)&&(i-=Math.pow(2,8*t)),i},A.prototype.readIntBE=function(e,t,r){e|=0,t|=0,r||J(e,t,this.length);for(var i=t,n=1,s=this[e+--i];i>0&&(n*=256);)s+=this[e+--i]*n;return s>=(n*=128)&&(s-=Math.pow(2,8*t)),s},A.prototype.readInt8=function(e,t){return t||J(e,1,this.length),128&this[e]?-1*(255-this[e]+1):this[e]},A.prototype.readInt16LE=function(e,t){t||J(e,2,this.length);var r=this[e]|this[e+1]<<8;return 32768&r?4294901760|r:r},A.prototype.readInt16BE=function(e,t){t||J(e,2,this.length);var r=this[e+1]|this[e]<<8;return 32768&r?4294901760|r:r},A.prototype.readInt32LE=function(e,t){return t||J(e,4,this.length),this[e]|this[e+1]<<8|this[e+2]<<16|this[e+3]<<24},A.prototype.readInt32BE=function(e,t){return t||J(e,4,this.length),this[e]<<24|this[e+1]<<16|this[e+2]<<8|this[e+3]},A.prototype.readFloatLE=function(e,t){return t||J(e,4,this.length),v(this,e,!0,23,4)},A.prototype.readFloatBE=function(e,t){return t||J(e,4,this.length),v(this,e,!1,23,4)},A.prototype.readDoubleLE=function(e,t){return t||J(e,8,this.length),v(this,e,!0,52,8)},A.prototype.readDoubleBE=function(e,t){return t||J(e,8,this.length),v(this,e,!1,52,8)},A.prototype.writeUIntLE=function(e,t,r,i){(e=+e,t|=0,r|=0,i)||X(this,e,t,r,Math.pow(2,8*r)-1,0);var n=1,s=0;for(this[t]=255&e;++s<r&&(n*=256);)this[t+s]=e/n&255;return t+r},A.prototype.writeUIntBE=function(e,t,r,i){(e=+e,t|=0,r|=0,i)||X(this,e,t,r,Math.pow(2,8*r)-1,0);var n=r-1,s=1;for(this[t+n]=255&e;--n>=0&&(s*=256);)this[t+n]=e/s&255;return t+r},A.prototype.writeUInt8=function(e,t,r){return e=+e,t|=0,r||X(this,e,t,1,255,0),A.TYPED_ARRAY_SUPPORT||(e=Math.floor(e)),this[t]=255&e,t+1},A.prototype.writeUInt16LE=function(e,t,r){return e=+e,t|=0,r||X(this,e,t,2,65535,0),A.TYPED_ARRAY_SUPPORT?(this[t]=255&e,this[t+1]=e>>>8):Q(this,e,t,!0),t+2},A.prototype.writeUInt16BE=function(e,t,r){return e=+e,t|=0,r||X(this,e,t,2,65535,0),A.TYPED_ARRAY_SUPPORT?(this[t]=e>>>8,this[t+1]=255&e):Q(this,e,t,!1),t+2},A.prototype.writeUInt32LE=function(e,t,r){return e=+e,t|=0,r||X(this,e,t,4,4294967295,0),A.TYPED_ARRAY_SUPPORT?(this[t+3]=e>>>24,this[t+2]=e>>>16,this[t+1]=e>>>8,this[t]=255&e):ee(this,e,t,!0),t+4},A.prototype.writeUInt32BE=function(e,t,r){return e=+e,t|=0,r||X(this,e,t,4,4294967295,0),A.TYPED_ARRAY_SUPPORT?(this[t]=e>>>24,this[t+1]=e>>>16,this[t+2]=e>>>8,this[t+3]=255&e):ee(this,e,t,!1),t+4},A.prototype.writeIntLE=function(e,t,r,i){if(e=+e,t|=0,!i){var n=Math.pow(2,8*r-1);X(this,e,t,r,n-1,-n);}var s=0,o=1,a=0;for(this[t]=255&e;++s<r&&(o*=256);)e<0&&0===a&&0!==this[t+s-1]&&(a=1),this[t+s]=(e/o>>0)-a&255;return t+r},A.prototype.writeIntBE=function(e,t,r,i){if(e=+e,t|=0,!i){var n=Math.pow(2,8*r-1);X(this,e,t,r,n-1,-n);}var s=r-1,o=1,a=0;for(this[t+s]=255&e;--s>=0&&(o*=256);)e<0&&0===a&&0!==this[t+s+1]&&(a=1),this[t+s]=(e/o>>0)-a&255;return t+r},A.prototype.writeInt8=function(e,t,r){return e=+e,t|=0,r||X(this,e,t,1,127,-128),A.TYPED_ARRAY_SUPPORT||(e=Math.floor(e)),e<0&&(e=255+e+1),this[t]=255&e,t+1},A.prototype.writeInt16LE=function(e,t,r){return e=+e,t|=0,r||X(this,e,t,2,32767,-32768),A.TYPED_ARRAY_SUPPORT?(this[t]=255&e,this[t+1]=e>>>8):Q(this,e,t,!0),t+2},A.prototype.writeInt16BE=function(e,t,r){return e=+e,t|=0,r||X(this,e,t,2,32767,-32768),A.TYPED_ARRAY_SUPPORT?(this[t]=e>>>8,this[t+1]=255&e):Q(this,e,t,!1),t+2},A.prototype.writeInt32LE=function(e,t,r){return e=+e,t|=0,r||X(this,e,t,4,2147483647,-2147483648),A.TYPED_ARRAY_SUPPORT?(this[t]=255&e,this[t+1]=e>>>8,this[t+2]=e>>>16,this[t+3]=e>>>24):ee(this,e,t,!0),t+4},A.prototype.writeInt32BE=function(e,t,r){return e=+e,t|=0,r||X(this,e,t,4,2147483647,-2147483648),e<0&&(e=4294967295+e+1),A.TYPED_ARRAY_SUPPORT?(this[t]=e>>>24,this[t+1]=e>>>16,this[t+2]=e>>>8,this[t+3]=255&e):ee(this,e,t,!1),t+4},A.prototype.writeFloatLE=function(e,t,r){return re(this,e,t,!0,r)},A.prototype.writeFloatBE=function(e,t,r){return re(this,e,t,!1,r)},A.prototype.writeDoubleLE=function(e,t,r){return ie(this,e,t,!0,r)},A.prototype.writeDoubleBE=function(e,t,r){return ie(this,e,t,!1,r)},A.prototype.copy=function(e,t,r,i){if(r||(r=0),i||0===i||(i=this.length),t>=e.length&&(t=e.length),t||(t=0),i>0&&i<r&&(i=r),i===r)return 0;if(0===e.length||0===this.length)return 0;if(t<0)throw new RangeError("targetStart out of bounds");if(r<0||r>=this.length)throw new RangeError("sourceStart out of bounds");if(i<0)throw new RangeError("sourceEnd out of bounds");i>this.length&&(i=this.length),e.length-t<i-r&&(i=e.length-t+r);var n,s=i-r;if(this===e&&r<t&&t<i)for(n=s-1;n>=0;--n)e[n+t]=this[n+r];else if(s<1e3||!A.TYPED_ARRAY_SUPPORT)for(n=0;n<s;++n)e[n+t]=this[n+r];else Uint8Array.prototype.set.call(e,this.subarray(r,r+s),t);return s},A.prototype.fill=function(e,t,r,i){if("string"==typeof e){if("string"==typeof t?(i=t,t=0,r=this.length):"string"==typeof r&&(i=r,r=this.length),1===e.length){var n=e.charCodeAt(0);n<256&&(e=n);}if(void 0!==i&&"string"!=typeof i)throw new TypeError("encoding must be a string");if("string"==typeof i&&!A.isEncoding(i))throw new TypeError("Unknown encoding: "+i)}else "number"==typeof e&&(e&=255);if(t<0||this.length<t||this.length<r)throw new RangeError("Out of range index");if(r<=t)return this;var s;if(t>>>=0,r=void 0===r?this.length:r>>>0,e||(e=0),"number"==typeof e)for(s=t;s<r;++s)this[s]=e;else {var o=B(e)?e:oe(new A(e,i).toString()),a=o.length;for(s=0;s<r-t;++s)this[s+t]=o[s%a];}return this};var ne=/[^+\/0-9A-Za-z-_]/g;function se(e){return e<16?"0"+e.toString(16):e.toString(16)}function oe(e,t){var r;t=t||1/0;for(var i=e.length,n=null,s=[],o=0;o<i;++o){if((r=e.charCodeAt(o))>55295&&r<57344){if(!n){if(r>56319){(t-=3)>-1&&s.push(239,191,189);continue}if(o+1===i){(t-=3)>-1&&s.push(239,191,189);continue}n=r;continue}if(r<56320){(t-=3)>-1&&s.push(239,191,189),n=r;continue}r=65536+(n-55296<<10|r-56320);}else n&&(t-=3)>-1&&s.push(239,191,189);if(n=null,r<128){if((t-=1)<0)break;s.push(r);}else if(r<2048){if((t-=2)<0)break;s.push(r>>6|192,63&r|128);}else if(r<65536){if((t-=3)<0)break;s.push(r>>12|224,r>>6&63|128,63&r|128);}else {if(!(r<1114112))throw new Error("Invalid code point");if((t-=4)<0)break;s.push(r>>18|240,r>>12&63|128,r>>6&63|128,63&r|128);}}return s}function ae(e){return function(e){var t,r,i,n,s,o;m||_();var a=e.length;if(a%4>0)throw new Error("Invalid string. Length must be a multiple of 4");s="="===e[a-2]?2:"="===e[a-1]?1:0,o=new g(3*a/4-s),i=s>0?a-4:a;var l=0;for(t=0,r=0;t<i;t+=4,r+=3)n=p[e.charCodeAt(t)]<<18|p[e.charCodeAt(t+1)]<<12|p[e.charCodeAt(t+2)]<<6|p[e.charCodeAt(t+3)],o[l++]=n>>16&255,o[l++]=n>>8&255,o[l++]=255&n;return 2===s?(n=p[e.charCodeAt(t)]<<2|p[e.charCodeAt(t+1)]>>4,o[l++]=255&n):1===s&&(n=p[e.charCodeAt(t)]<<10|p[e.charCodeAt(t+1)]<<4|p[e.charCodeAt(t+2)]>>2,o[l++]=n>>8&255,o[l++]=255&n),o}(function(e){if((e=function(e){return e.trim?e.trim():e.replace(/^\s+|\s+$/g,"")}(e).replace(ne,"")).length<2)return "";for(;e.length%4!=0;)e+="=";return e}(e))}function le(e,t,r,i){for(var n=0;n<i&&!(n+r>=t.length||n>=e.length);++n)t[n+r]=e[n];return n}function ue(e){return null!=e&&(!!e._isBuffer||he(e)||function(e){return "function"==typeof e.readFloatLE&&"function"==typeof e.slice&&he(e.slice(0,0))}(e))}function he(e){return !!e.constructor&&"function"==typeof e.constructor.isBuffer&&e.constructor.isBuffer(e)}var ce=Object.freeze({__proto__:null,INSPECT_MAX_BYTES:50,kMaxLength:x,Buffer:A,SlowBuffer:function(e){return +e!=e&&(e=0),A.alloc(+e)},isBuffer:ue});function fe(){}function de(){de.init.call(this);}function pe(e){return void 0===e._maxListeners?de.defaultMaxListeners:e._maxListeners}function ge(e,t,r,i){var n,s,o,a;if("function"!=typeof r)throw new TypeError('"listener" argument must be a function');if((s=e._events)?(s.newListener&&(e.emit("newListener",t,r.listener?r.listener:r),s=e._events),o=s[t]):(s=e._events=new fe,e._eventsCount=0),o){if("function"==typeof o?o=s[t]=i?[r,o]:[o,r]:i?o.unshift(r):o.push(r),!o.warned&&(n=pe(e))&&n>0&&o.length>n){o.warned=!0;var l=new Error("Possible EventEmitter memory leak detected. "+o.length+" "+t+" listeners added. Use emitter.setMaxListeners() to increase limit");l.name="MaxListenersExceededWarning",l.emitter=e,l.type=t,l.count=o.length,a=l,"function"==typeof console.warn?console.warn(a):console.log(a);}}else o=s[t]=r,++e._eventsCount;return e}function me(e,t,r){var i=!1;function n(){e.removeListener(t,n),i||(i=!0,r.apply(e,arguments));}return n.listener=r,n}function _e(e){var t=this._events;if(t){var r=t[e];if("function"==typeof r)return 1;if(r)return r.length}return 0}function ye(e,t){for(var r=new Array(t);t--;)r[t]=e[t];return r}function be(){throw new Error("setTimeout has not been defined")}function ve(){throw new Error("clearTimeout has not been defined")}fe.prototype=Object.create(null),de.EventEmitter=de,de.usingDomains=!1,de.prototype.domain=void 0,de.prototype._events=void 0,de.prototype._maxListeners=void 0,de.defaultMaxListeners=10,de.init=function(){this.domain=null,de.usingDomains&&(void 0).active,this._events&&this._events!==Object.getPrototypeOf(this)._events||(this._events=new fe,this._eventsCount=0),this._maxListeners=this._maxListeners||void 0;},de.prototype.setMaxListeners=function(e){if("number"!=typeof e||e<0||isNaN(e))throw new TypeError('"n" argument must be a positive number');return this._maxListeners=e,this},de.prototype.getMaxListeners=function(){return pe(this)},de.prototype.emit=function(e){var t,r,i,n,s,o,a,l="error"===e;if(o=this._events)l=l&&null==o.error;else if(!l)return !1;if(a=this.domain,l){if(t=arguments[1],!a){if(t instanceof Error)throw t;var u=new Error('Uncaught, unspecified "error" event. ('+t+")");throw u.context=t,u}return t||(t=new Error('Uncaught, unspecified "error" event')),t.domainEmitter=this,t.domain=a,t.domainThrown=!1,a.emit("error",t),!1}if(!(r=o[e]))return !1;var h="function"==typeof r;switch(i=arguments.length){case 1:!function(e,t,r){if(t)e.call(r);else for(var i=e.length,n=ye(e,i),s=0;s<i;++s)n[s].call(r);}(r,h,this);break;case 2:!function(e,t,r,i){if(t)e.call(r,i);else for(var n=e.length,s=ye(e,n),o=0;o<n;++o)s[o].call(r,i);}(r,h,this,arguments[1]);break;case 3:!function(e,t,r,i,n){if(t)e.call(r,i,n);else for(var s=e.length,o=ye(e,s),a=0;a<s;++a)o[a].call(r,i,n);}(r,h,this,arguments[1],arguments[2]);break;case 4:!function(e,t,r,i,n,s){if(t)e.call(r,i,n,s);else for(var o=e.length,a=ye(e,o),l=0;l<o;++l)a[l].call(r,i,n,s);}(r,h,this,arguments[1],arguments[2],arguments[3]);break;default:for(n=new Array(i-1),s=1;s<i;s++)n[s-1]=arguments[s];!function(e,t,r,i){if(t)e.apply(r,i);else for(var n=e.length,s=ye(e,n),o=0;o<n;++o)s[o].apply(r,i);}(r,h,this,n);}return !0},de.prototype.addListener=function(e,t){return ge(this,e,t,!1)},de.prototype.on=de.prototype.addListener,de.prototype.prependListener=function(e,t){return ge(this,e,t,!0)},de.prototype.once=function(e,t){if("function"!=typeof t)throw new TypeError('"listener" argument must be a function');return this.on(e,me(this,e,t)),this},de.prototype.prependOnceListener=function(e,t){if("function"!=typeof t)throw new TypeError('"listener" argument must be a function');return this.prependListener(e,me(this,e,t)),this},de.prototype.removeListener=function(e,t){var r,i,n,s,o;if("function"!=typeof t)throw new TypeError('"listener" argument must be a function');if(!(i=this._events))return this;if(!(r=i[e]))return this;if(r===t||r.listener&&r.listener===t)0==--this._eventsCount?this._events=new fe:(delete i[e],i.removeListener&&this.emit("removeListener",e,r.listener||t));else if("function"!=typeof r){for(n=-1,s=r.length;s-- >0;)if(r[s]===t||r[s].listener&&r[s].listener===t){o=r[s].listener,n=s;break}if(n<0)return this;if(1===r.length){if(r[0]=void 0,0==--this._eventsCount)return this._events=new fe,this;delete i[e];}else !function(e,t){for(var r=t,i=r+1,n=e.length;i<n;r+=1,i+=1)e[r]=e[i];e.pop();}(r,n);i.removeListener&&this.emit("removeListener",e,o||t);}return this},de.prototype.removeAllListeners=function(e){var t,r;if(!(r=this._events))return this;if(!r.removeListener)return 0===arguments.length?(this._events=new fe,this._eventsCount=0):r[e]&&(0==--this._eventsCount?this._events=new fe:delete r[e]),this;if(0===arguments.length){for(var i,n=Object.keys(r),s=0;s<n.length;++s)"removeListener"!==(i=n[s])&&this.removeAllListeners(i);return this.removeAllListeners("removeListener"),this._events=new fe,this._eventsCount=0,this}if("function"==typeof(t=r[e]))this.removeListener(e,t);else if(t)do{this.removeListener(e,t[t.length-1]);}while(t[0]);return this},de.prototype.listeners=function(e){var t,r=this._events;return r&&(t=r[e])?"function"==typeof t?[t.listener||t]:function(e){for(var t=new Array(e.length),r=0;r<t.length;++r)t[r]=e[r].listener||e[r];return t}(t):[]},de.listenerCount=function(e,t){return "function"==typeof e.listenerCount?e.listenerCount(t):_e.call(e,t)},de.prototype.listenerCount=_e,de.prototype.eventNames=function(){return this._eventsCount>0?Reflect.ownKeys(this._events):[]};var we=be,ke=ve;function Se(e){if(we===setTimeout)return setTimeout(e,0);if((we===be||!we)&&setTimeout)return we=setTimeout,setTimeout(e,0);try{return we(e,0)}catch(t){try{return we.call(null,e,0)}catch(t){return we.call(this,e,0)}}}"function"==typeof f.setTimeout&&(we=setTimeout),"function"==typeof f.clearTimeout&&(ke=clearTimeout);var xe,Ce=[],Ee=!1,Ae=-1;function Te(){Ee&&xe&&(Ee=!1,xe.length?Ce=xe.concat(Ce):Ae=-1,Ce.length&&ze());}function ze(){if(!Ee){var e=Se(Te);Ee=!0;for(var t=Ce.length;t;){for(xe=Ce,Ce=[];++Ae<t;)xe&&xe[Ae].run();Ae=-1,t=Ce.length;}xe=null,Ee=!1,function(e){if(ke===clearTimeout)return clearTimeout(e);if((ke===ve||!ke)&&clearTimeout)return ke=clearTimeout,clearTimeout(e);try{ke(e);}catch(t){try{return ke.call(null,e)}catch(t){return ke.call(this,e)}}}(e);}}function Oe(e){var t=new Array(arguments.length-1);if(arguments.length>1)for(var r=1;r<arguments.length;r++)t[r-1]=arguments[r];Ce.push(new Re(e,t)),1!==Ce.length||Ee||Se(ze);}function Re(e,t){this.fun=e,this.array=t;}Re.prototype.run=function(){this.fun.apply(null,this.array);};function Le(){}var Be=Le,Ie=Le,Fe=Le,Pe=Le,Me=Le,Ue=Le,De=Le;var je=f.performance||{},Ne=je.now||je.mozNow||je.msNow||je.oNow||je.webkitNow||function(){return (new Date).getTime()};var Ze=new Date;var We={nextTick:Oe,title:"browser",browser:!0,env:{},argv:[],version:"",versions:{},on:Be,addListener:Ie,once:Fe,off:Pe,removeListener:Me,removeAllListeners:Ue,emit:De,binding:function(e){throw new Error("process.binding is not supported")},cwd:function(){return "/"},chdir:function(e){throw new Error("process.chdir is not supported")},umask:function(){return 0},hrtime:function(e){var t=.001*Ne.call(je),r=Math.floor(t),i=Math.floor(t%1*1e9);return e&&(r-=e[0],(i-=e[1])<0&&(r--,i+=1e9)),[r,i]},platform:"browser",release:{},config:{},uptime:function(){return (new Date-Ze)/1e3}},qe=function(e){return e&&"object"==typeof e&&"function"==typeof e.copy&&"function"==typeof e.fill&&"function"==typeof e.readUInt8},Ye=e.createCommonjsModule(function(e){"function"==typeof Object.create?e.exports=function(e,t){e.super_=t,e.prototype=Object.create(t.prototype,{constructor:{value:e,enumerable:!1,writable:!0,configurable:!0}});}:e.exports=function(e,t){e.super_=t;var r=function(){};r.prototype=t.prototype,e.prototype=new r,e.prototype.constructor=e;};}),Ve=e.createCommonjsModule(function(e,t){var r=/%[sdj%]/g;t.format=function(e){if(!m(e)){for(var t=[],i=0;i<arguments.length;i++)t.push(s(arguments[i]));return t.join(" ")}i=1;for(var n=arguments,o=n.length,a=String(e).replace(r,function(e){if("%%"===e)return "%";if(i>=o)return e;switch(e){case"%s":return String(n[i++]);case"%d":return Number(n[i++]);case"%j":try{return JSON.stringify(n[i++])}catch(e){return "[Circular]"}default:return e}}),l=n[i];i<o;l=n[++i])p(l)||!b(l)?a+=" "+l:a+=" "+s(l);return a},t.deprecate=function(e,r){if(_(f.process))return function(){return t.deprecate(e,r).apply(this,arguments)};var i=!1;return function(){return i||(console.error(r),i=!0),e.apply(this,arguments)}};var i,n={};function s(e,r){var i={seen:[],stylize:a};return arguments.length>=3&&(i.depth=arguments[2]),arguments.length>=4&&(i.colors=arguments[3]),d(r)?i.showHidden=r:r&&t._extend(i,r),_(i.showHidden)&&(i.showHidden=!1),_(i.depth)&&(i.depth=2),_(i.colors)&&(i.colors=!1),_(i.customInspect)&&(i.customInspect=!0),i.colors&&(i.stylize=o),l(i,e,i.depth)}function o(e,t){var r=s.styles[t];return r?"["+s.colors[r][0]+"m"+e+"["+s.colors[r][1]+"m":e}function a(e,t){return e}function l(e,r,i){if(e.customInspect&&r&&k(r.inspect)&&r.inspect!==t.inspect&&(!r.constructor||r.constructor.prototype!==r)){var n=r.inspect(i,e);return m(n)||(n=l(e,n,i)),n}var s=function(e,t){if(_(t))return e.stylize("undefined","undefined");if(m(t)){var r="'"+JSON.stringify(t).replace(/^"|"$/g,"").replace(/'/g,"\\'").replace(/\\"/g,'"')+"'";return e.stylize(r,"string")}if(g(t))return e.stylize(""+t,"number");if(d(t))return e.stylize(""+t,"boolean");if(p(t))return e.stylize("null","null")}(e,r);if(s)return s;var o=Object.keys(r),a=function(e){var t={};return e.forEach(function(e,r){t[e]=!0;}),t}(o);if(e.showHidden&&(o=Object.getOwnPropertyNames(r)),w(r)&&(o.indexOf("message")>=0||o.indexOf("description")>=0))return u(r);if(0===o.length){if(k(r)){var f=r.name?": "+r.name:"";return e.stylize("[Function"+f+"]","special")}if(y(r))return e.stylize(RegExp.prototype.toString.call(r),"regexp");if(v(r))return e.stylize(Date.prototype.toString.call(r),"date");if(w(r))return u(r)}var b,S="",x=!1,C=["{","}"];(c(r)&&(x=!0,C=["[","]"]),k(r))&&(S=" [Function"+(r.name?": "+r.name:"")+"]");return y(r)&&(S=" "+RegExp.prototype.toString.call(r)),v(r)&&(S=" "+Date.prototype.toUTCString.call(r)),w(r)&&(S=" "+u(r)),0!==o.length||x&&0!=r.length?i<0?y(r)?e.stylize(RegExp.prototype.toString.call(r),"regexp"):e.stylize("[Object]","special"):(e.seen.push(r),b=x?function(e,t,r,i,n){for(var s=[],o=0,a=t.length;o<a;++o)E(t,String(o))?s.push(h(e,t,r,i,String(o),!0)):s.push("");return n.forEach(function(n){n.match(/^\d+$/)||s.push(h(e,t,r,i,n,!0));}),s}(e,r,i,a,o):o.map(function(t){return h(e,r,i,a,t,x)}),e.seen.pop(),function(e,t,r){if(e.reduce(function(e,t){return t.indexOf("\n"),e+t.replace(/\u001b\[\d\d?m/g,"").length+1},0)>60)return r[0]+(""===t?"":t+"\n ")+" "+e.join(",\n  ")+" "+r[1];return r[0]+t+" "+e.join(", ")+" "+r[1]}(b,S,C)):C[0]+S+C[1]}function u(e){return "["+Error.prototype.toString.call(e)+"]"}function h(e,t,r,i,n,s){var o,a,u;if((u=Object.getOwnPropertyDescriptor(t,n)||{value:t[n]}).get?a=u.set?e.stylize("[Getter/Setter]","special"):e.stylize("[Getter]","special"):u.set&&(a=e.stylize("[Setter]","special")),E(i,n)||(o="["+n+"]"),a||(e.seen.indexOf(u.value)<0?(a=p(r)?l(e,u.value,null):l(e,u.value,r-1)).indexOf("\n")>-1&&(a=s?a.split("\n").map(function(e){return "  "+e}).join("\n").substr(2):"\n"+a.split("\n").map(function(e){return "   "+e}).join("\n")):a=e.stylize("[Circular]","special")),_(o)){if(s&&n.match(/^\d+$/))return a;(o=JSON.stringify(""+n)).match(/^"([a-zA-Z_][a-zA-Z_0-9]*)"$/)?(o=o.substr(1,o.length-2),o=e.stylize(o,"name")):(o=o.replace(/'/g,"\\'").replace(/\\"/g,'"').replace(/(^"|"$)/g,"'"),o=e.stylize(o,"string"));}return o+": "+a}function c(e){return Array.isArray(e)}function d(e){return "boolean"==typeof e}function p(e){return null===e}function g(e){return "number"==typeof e}function m(e){return "string"==typeof e}function _(e){return void 0===e}function y(e){return b(e)&&"[object RegExp]"===S(e)}function b(e){return "object"==typeof e&&null!==e}function v(e){return b(e)&&"[object Date]"===S(e)}function w(e){return b(e)&&("[object Error]"===S(e)||e instanceof Error)}function k(e){return "function"==typeof e}function S(e){return Object.prototype.toString.call(e)}function x(e){return e<10?"0"+e.toString(10):e.toString(10)}t.debuglog=function(e){if(_(i)&&(i=""),e=e.toUpperCase(),!n[e])if(new RegExp("\\b"+e+"\\b","i").test(i)){var r=We.pid;n[e]=function(){var i=t.format.apply(t,arguments);console.error("%s %d: %s",e,r,i);};}else n[e]=function(){};return n[e]},t.inspect=s,s.colors={bold:[1,22],italic:[3,23],underline:[4,24],inverse:[7,27],white:[37,39],grey:[90,39],black:[30,39],blue:[34,39],cyan:[36,39],green:[32,39],magenta:[35,39],red:[31,39],yellow:[33,39]},s.styles={special:"cyan",number:"yellow",boolean:"yellow",undefined:"grey",null:"bold",string:"green",date:"magenta",regexp:"red"},t.isArray=c,t.isBoolean=d,t.isNull=p,t.isNullOrUndefined=function(e){return null==e},t.isNumber=g,t.isString=m,t.isSymbol=function(e){return "symbol"==typeof e},t.isUndefined=_,t.isRegExp=y,t.isObject=b,t.isDate=v,t.isError=w,t.isFunction=k,t.isPrimitive=function(e){return null===e||"boolean"==typeof e||"number"==typeof e||"string"==typeof e||"symbol"==typeof e||void 0===e},t.isBuffer=qe;var C=["Jan","Feb","Mar","Apr","May","Jun","Jul","Aug","Sep","Oct","Nov","Dec"];function E(e,t){return Object.prototype.hasOwnProperty.call(e,t)}t.log=function(){var e,r;console.log("%s - %s",(e=new Date,r=[x(e.getHours()),x(e.getMinutes()),x(e.getSeconds())].join(":"),[e.getDate(),C[e.getMonth()],r].join(" ")),t.format.apply(t,arguments));},t.inherits=Ye,t._extend=function(e,t){if(!t||!b(t))return e;for(var r=Object.keys(t),i=r.length;i--;)e[r[i]]=t[r[i]];return e};}),He=(Ve.format,Ve.deprecate),Ge=Ve.debuglog,$e=(Ve.inspect,Ve.isArray,Ve.isBoolean,Ve.isNull,Ve.isNullOrUndefined,Ve.isNumber,Ve.isString,Ve.isSymbol,Ve.isUndefined,Ve.isRegExp,Ve.isObject,Ve.isDate,Ve.isError,Ve.isFunction,Ve.isPrimitive,Ve.isBuffer,Ve.log,Ve.inherits);Ve._extend;function Ke(){this.head=null,this.tail=null,this.length=0;}Ke.prototype.push=function(e){var t={data:e,next:null};this.length>0?this.tail.next=t:this.head=t,this.tail=t,++this.length;},Ke.prototype.unshift=function(e){var t={data:e,next:this.head};0===this.length&&(this.tail=t),this.head=t,++this.length;},Ke.prototype.shift=function(){if(0!==this.length){var e=this.head.data;return 1===this.length?this.head=this.tail=null:this.head=this.head.next,--this.length,e}},Ke.prototype.clear=function(){this.head=this.tail=null,this.length=0;},Ke.prototype.join=function(e){if(0===this.length)return "";for(var t=this.head,r=""+t.data;t=t.next;)r+=e+t.data;return r},Ke.prototype.concat=function(e){if(0===this.length)return A.alloc(0);if(1===this.length)return this.head.data;for(var t=A.allocUnsafe(e>>>0),r=this.head,i=0;r;)r.data.copy(t,i),i+=r.data.length,r=r.next;return t};var Je=e.createCommonjsModule(function(e,t){var r=ce.Buffer;function i(e,t){for(var r in e)t[r]=e[r];}function n(e,t,i){return r(e,t,i)}r.from&&r.alloc&&r.allocUnsafe&&r.allocUnsafeSlow?e.exports=ce:(i(ce,t),t.Buffer=n),i(r,n),n.from=function(e,t,i){if("number"==typeof e)throw new TypeError("Argument must not be a number");return r(e,t,i)},n.alloc=function(e,t,i){if("number"!=typeof e)throw new TypeError("Argument must be a number");var n=r(e);return void 0!==t?"string"==typeof i?n.fill(t,i):n.fill(t):n.fill(0),n},n.allocUnsafe=function(e){if("number"!=typeof e)throw new TypeError("Argument must be a number");return r(e)},n.allocUnsafeSlow=function(e){if("number"!=typeof e)throw new TypeError("Argument must be a number");return ce.SlowBuffer(e)};}),Xe=(Je.Buffer,Je.Buffer),Qe=Xe.isEncoding||function(e){switch((e=""+e)&&e.toLowerCase()){case"hex":case"utf8":case"utf-8":case"ascii":case"binary":case"base64":case"ucs2":case"ucs-2":case"utf16le":case"utf-16le":case"raw":return !0;default:return !1}};var et=tt;function tt(e){var t;switch(this.encoding=function(e){var t=function(e){if(!e)return "utf8";for(var t;;)switch(e){case"utf8":case"utf-8":return "utf8";case"ucs2":case"ucs-2":case"utf16le":case"utf-16le":return "utf16le";case"latin1":case"binary":return "latin1";case"base64":case"ascii":case"hex":return e;default:if(t)return;e=(""+e).toLowerCase(),t=!0;}}(e);if("string"!=typeof t&&(Xe.isEncoding===Qe||!Qe(e)))throw new Error("Unknown encoding: "+e);return t||e}(e),this.encoding){case"utf16le":this.text=nt,this.end=st,t=4;break;case"utf8":this.fillLast=it,t=4;break;case"base64":this.text=ot,this.end=at,t=3;break;default:return this.write=lt,void(this.end=ut)}this.lastNeed=0,this.lastTotal=0,this.lastChar=Xe.allocUnsafe(t);}function rt(e){return e<=127?0:e>>5==6?2:e>>4==14?3:e>>3==30?4:-1}function it(e){var t=this.lastTotal-this.lastNeed,r=function(e,t,r){if(128!=(192&t[0]))return e.lastNeed=0,"�".repeat(r);if(e.lastNeed>1&&t.length>1){if(128!=(192&t[1]))return e.lastNeed=1,"�".repeat(r+1);if(e.lastNeed>2&&t.length>2&&128!=(192&t[2]))return e.lastNeed=2,"�".repeat(r+2)}}(this,e,t);return void 0!==r?r:this.lastNeed<=e.length?(e.copy(this.lastChar,t,0,this.lastNeed),this.lastChar.toString(this.encoding,0,this.lastTotal)):(e.copy(this.lastChar,t,0,e.length),void(this.lastNeed-=e.length))}function nt(e,t){if((e.length-t)%2==0){var r=e.toString("utf16le",t);if(r){var i=r.charCodeAt(r.length-1);if(i>=55296&&i<=56319)return this.lastNeed=2,this.lastTotal=4,this.lastChar[0]=e[e.length-2],this.lastChar[1]=e[e.length-1],r.slice(0,-1)}return r}return this.lastNeed=1,this.lastTotal=2,this.lastChar[0]=e[e.length-1],e.toString("utf16le",t,e.length-1)}function st(e){var t=e&&e.length?this.write(e):"";if(this.lastNeed){var r=this.lastTotal-this.lastNeed;return t+this.lastChar.toString("utf16le",0,r)}return t}function ot(e,t){var r=(e.length-t)%3;return 0===r?e.toString("base64",t):(this.lastNeed=3-r,this.lastTotal=3,1===r?this.lastChar[0]=e[e.length-1]:(this.lastChar[0]=e[e.length-2],this.lastChar[1]=e[e.length-1]),e.toString("base64",t,e.length-r))}function at(e){var t=e&&e.length?this.write(e):"";return this.lastNeed?t+this.lastChar.toString("base64",0,3-this.lastNeed):t}function lt(e){return e.toString(this.encoding)}function ut(e){return e&&e.length?this.write(e):""}tt.prototype.write=function(e){if(0===e.length)return "";var t,r;if(this.lastNeed){if(void 0===(t=this.fillLast(e)))return "";r=this.lastNeed,this.lastNeed=0;}else r=0;return r<e.length?t?t+this.text(e,r):this.text(e,r):t||""},tt.prototype.end=function(e){var t=e&&e.length?this.write(e):"";return this.lastNeed?t+"�".repeat(this.lastTotal-this.lastNeed):t},tt.prototype.text=function(e,t){var r=function(e,t,r){var i=t.length-1;if(i<r)return 0;var n=rt(t[i]);if(n>=0)return n>0&&(e.lastNeed=n-1),n;if(--i<r)return 0;if((n=rt(t[i]))>=0)return n>0&&(e.lastNeed=n-2),n;if(--i<r)return 0;if((n=rt(t[i]))>=0)return n>0&&(2===n?n=0:e.lastNeed=n-3),n;return 0}(this,e,t);if(!this.lastNeed)return e.toString("utf8",t);this.lastTotal=r;var i=e.length-(r-this.lastNeed);return e.copy(this.lastChar,0,i),e.toString("utf8",t,i)},tt.prototype.fillLast=function(e){if(this.lastNeed<=e.length)return e.copy(this.lastChar,this.lastTotal-this.lastNeed,0,this.lastNeed),this.lastChar.toString(this.encoding,0,this.lastTotal);e.copy(this.lastChar,this.lastTotal-this.lastNeed,0,e.length),this.lastNeed-=e.length;},ft.ReadableState=ct;var ht=Ge("stream");function ct(e,t){e=e||{},this.objectMode=!!e.objectMode,t instanceof jt&&(this.objectMode=this.objectMode||!!e.readableObjectMode);var r=e.highWaterMark,i=this.objectMode?16:16384;this.highWaterMark=r||0===r?r:i,this.highWaterMark=~~this.highWaterMark,this.buffer=new Ke,this.length=0,this.pipes=null,this.pipesCount=0,this.flowing=null,this.ended=!1,this.endEmitted=!1,this.reading=!1,this.sync=!0,this.needReadable=!1,this.emittedReadable=!1,this.readableListening=!1,this.resumeScheduled=!1,this.defaultEncoding=e.defaultEncoding||"utf8",this.ranOut=!1,this.awaitDrain=0,this.readingMore=!1,this.decoder=null,this.encoding=null,e.encoding&&(this.decoder=new et(e.encoding),this.encoding=e.encoding);}function ft(e){if(!(this instanceof ft))return new ft(e);this._readableState=new ct(e,this),this.readable=!0,e&&"function"==typeof e.read&&(this._read=e.read),de.call(this);}function dt(e,t,r,i,n){var s=function(e,t){var r=null;ue(t)||"string"==typeof t||null==t||e.objectMode||(r=new TypeError("Invalid non-string/buffer chunk"));return r}(t,r);if(s)e.emit("error",s);else if(null===r)t.reading=!1,function(e,t){if(t.ended)return;if(t.decoder){var r=t.decoder.end();r&&r.length&&(t.buffer.push(r),t.length+=t.objectMode?1:r.length);}t.ended=!0,mt(e);}(e,t);else if(t.objectMode||r&&r.length>0)if(t.ended&&!n){var o=new Error("stream.push() after EOF");e.emit("error",o);}else if(t.endEmitted&&n){var a=new Error("stream.unshift() after end event");e.emit("error",a);}else {var l;!t.decoder||n||i||(r=t.decoder.write(r),l=!t.objectMode&&0===r.length),n||(t.reading=!1),l||(t.flowing&&0===t.length&&!t.sync?(e.emit("data",r),e.read(0)):(t.length+=t.objectMode?1:r.length,n?t.buffer.unshift(r):t.buffer.push(r),t.needReadable&&mt(e))),function(e,t){t.readingMore||(t.readingMore=!0,Oe(yt,e,t));}(e,t);}else n||(t.reading=!1);return function(e){return !e.ended&&(e.needReadable||e.length<e.highWaterMark||0===e.length)}(t)}$e(ft,de),ft.prototype.push=function(e,t){var r=this._readableState;return r.objectMode||"string"!=typeof e||(t=t||r.defaultEncoding)!==r.encoding&&(e=A.from(e,t),t=""),dt(this,r,e,t,!1)},ft.prototype.unshift=function(e){return dt(this,this._readableState,e,"",!0)},ft.prototype.isPaused=function(){return !1===this._readableState.flowing},ft.prototype.setEncoding=function(e){return this._readableState.decoder=new et(e),this._readableState.encoding=e,this};var pt=8388608;function gt(e,t){return e<=0||0===t.length&&t.ended?0:t.objectMode?1:e!=e?t.flowing&&t.length?t.buffer.head.data.length:t.length:(e>t.highWaterMark&&(t.highWaterMark=function(e){return e>=pt?e=pt:(e--,e|=e>>>1,e|=e>>>2,e|=e>>>4,e|=e>>>8,e|=e>>>16,e++),e}(e)),e<=t.length?e:t.ended?t.length:(t.needReadable=!0,0))}function mt(e){var t=e._readableState;t.needReadable=!1,t.emittedReadable||(ht("emitReadable",t.flowing),t.emittedReadable=!0,t.sync?Oe(_t,e):_t(e));}function _t(e){ht("emit readable"),e.emit("readable"),wt(e);}function yt(e,t){for(var r=t.length;!t.reading&&!t.flowing&&!t.ended&&t.length<t.highWaterMark&&(ht("maybeReadMore read 0"),e.read(0),r!==t.length);)r=t.length;t.readingMore=!1;}function bt(e){ht("readable nexttick read 0"),e.read(0);}function vt(e,t){t.reading||(ht("resume read 0"),e.read(0)),t.resumeScheduled=!1,t.awaitDrain=0,e.emit("resume"),wt(e),t.flowing&&!t.reading&&e.read(0);}function wt(e){var t=e._readableState;for(ht("flow",t.flowing);t.flowing&&null!==e.read(););}function kt(e,t){return 0===t.length?null:(t.objectMode?r=t.buffer.shift():!e||e>=t.length?(r=t.decoder?t.buffer.join(""):1===t.buffer.length?t.buffer.head.data:t.buffer.concat(t.length),t.buffer.clear()):r=function(e,t,r){var i;e<t.head.data.length?(i=t.head.data.slice(0,e),t.head.data=t.head.data.slice(e)):i=e===t.head.data.length?t.shift():r?function(e,t){var r=t.head,i=1,n=r.data;e-=n.length;for(;r=r.next;){var s=r.data,o=e>s.length?s.length:e;if(o===s.length?n+=s:n+=s.slice(0,e),0===(e-=o)){o===s.length?(++i,r.next?t.head=r.next:t.head=t.tail=null):(t.head=r,r.data=s.slice(o));break}++i;}return t.length-=i,n}(e,t):function(e,t){var r=A.allocUnsafe(e),i=t.head,n=1;i.data.copy(r),e-=i.data.length;for(;i=i.next;){var s=i.data,o=e>s.length?s.length:e;if(s.copy(r,r.length-e,0,o),0===(e-=o)){o===s.length?(++n,i.next?t.head=i.next:t.head=t.tail=null):(t.head=i,i.data=s.slice(o));break}++n;}return t.length-=n,r}(e,t);return i}(e,t.buffer,t.decoder),r);var r;}function St(e){var t=e._readableState;if(t.length>0)throw new Error('"endReadable()" called on non-empty stream');t.endEmitted||(t.ended=!0,Oe(xt,t,e));}function xt(e,t){e.endEmitted||0!==e.length||(e.endEmitted=!0,t.readable=!1,t.emit("end"));}function Ct(e,t){for(var r=0,i=e.length;r<i;r++)if(e[r]===t)return r;return -1}function Et(){}function At(e,t,r){this.chunk=e,this.encoding=t,this.callback=r,this.next=null;}function Tt(e,t){Object.defineProperty(this,"buffer",{get:He(function(){return this.getBuffer()},"_writableState.buffer is deprecated. Use _writableState.getBuffer instead.")}),e=e||{},this.objectMode=!!e.objectMode,t instanceof jt&&(this.objectMode=this.objectMode||!!e.writableObjectMode);var r=e.highWaterMark,i=this.objectMode?16:16384;this.highWaterMark=r||0===r?r:i,this.highWaterMark=~~this.highWaterMark,this.needDrain=!1,this.ending=!1,this.ended=!1,this.finished=!1;var n=!1===e.decodeStrings;this.decodeStrings=!n,this.defaultEncoding=e.defaultEncoding||"utf8",this.length=0,this.writing=!1,this.corked=0,this.sync=!0,this.bufferProcessing=!1,this.onwrite=function(e){!function(e,t){var r=e._writableState,i=r.sync,n=r.writecb;if(function(e){e.writing=!1,e.writecb=null,e.length-=e.writelen,e.writelen=0;}(r),t)!function(e,t,r,i,n){--t.pendingcb,r?Oe(n,i):n(i);e._writableState.errorEmitted=!0,e.emit("error",i);}(e,r,i,t,n);else {var s=Bt(r);s||r.corked||r.bufferProcessing||!r.bufferedRequest||Lt(e,r),i?Oe(Rt,e,r,s,n):Rt(e,r,s,n);}}(t,e);},this.writecb=null,this.writelen=0,this.bufferedRequest=null,this.lastBufferedRequest=null,this.pendingcb=0,this.prefinished=!1,this.errorEmitted=!1,this.bufferedRequestCount=0,this.corkedRequestsFree=new Pt(this);}function zt(e){if(!(this instanceof zt||this instanceof jt))return new zt(e);this._writableState=new Tt(e,this),this.writable=!0,e&&("function"==typeof e.write&&(this._write=e.write),"function"==typeof e.writev&&(this._writev=e.writev)),de.call(this);}function Ot(e,t,r,i,n,s,o){t.writelen=i,t.writecb=o,t.writing=!0,t.sync=!0,r?e._writev(n,t.onwrite):e._write(n,s,t.onwrite),t.sync=!1;}function Rt(e,t,r,i){r||function(e,t){0===t.length&&t.needDrain&&(t.needDrain=!1,e.emit("drain"));}(e,t),t.pendingcb--,i(),Ft(e,t);}function Lt(e,t){t.bufferProcessing=!0;var r=t.bufferedRequest;if(e._writev&&r&&r.next){var i=t.bufferedRequestCount,n=new Array(i),s=t.corkedRequestsFree;s.entry=r;for(var o=0;r;)n[o]=r,r=r.next,o+=1;Ot(e,t,!0,t.length,n,"",s.finish),t.pendingcb++,t.lastBufferedRequest=null,s.next?(t.corkedRequestsFree=s.next,s.next=null):t.corkedRequestsFree=new Pt(t);}else {for(;r;){var a=r.chunk,l=r.encoding,u=r.callback;if(Ot(e,t,!1,t.objectMode?1:a.length,a,l,u),r=r.next,t.writing)break}null===r&&(t.lastBufferedRequest=null);}t.bufferedRequestCount=0,t.bufferedRequest=r,t.bufferProcessing=!1;}function Bt(e){return e.ending&&0===e.length&&null===e.bufferedRequest&&!e.finished&&!e.writing}function It(e,t){t.prefinished||(t.prefinished=!0,e.emit("prefinish"));}function Ft(e,t){var r=Bt(t);return r&&(0===t.pendingcb?(It(e,t),t.finished=!0,e.emit("finish")):It(e,t)),r}function Pt(e){var t=this;this.next=null,this.entry=null,this.finish=function(r){var i=t.entry;for(t.entry=null;i;){var n=i.callback;e.pendingcb--,n(r),i=i.next;}e.corkedRequestsFree?e.corkedRequestsFree.next=t:e.corkedRequestsFree=t;};}ft.prototype.read=function(e){ht("read",e),e=parseInt(e,10);var t=this._readableState,r=e;if(0!==e&&(t.emittedReadable=!1),0===e&&t.needReadable&&(t.length>=t.highWaterMark||t.ended))return ht("read: emitReadable",t.length,t.ended),0===t.length&&t.ended?St(this):mt(this),null;if(0===(e=gt(e,t))&&t.ended)return 0===t.length&&St(this),null;var i,n=t.needReadable;return ht("need readable",n),(0===t.length||t.length-e<t.highWaterMark)&&ht("length less than watermark",n=!0),t.ended||t.reading?ht("reading or ended",n=!1):n&&(ht("do read"),t.reading=!0,t.sync=!0,0===t.length&&(t.needReadable=!0),this._read(t.highWaterMark),t.sync=!1,t.reading||(e=gt(r,t))),null===(i=e>0?kt(e,t):null)?(t.needReadable=!0,e=0):t.length-=e,0===t.length&&(t.ended||(t.needReadable=!0),r!==e&&t.ended&&St(this)),null!==i&&this.emit("data",i),i},ft.prototype._read=function(e){this.emit("error",new Error("not implemented"));},ft.prototype.pipe=function(e,t){var r=this,i=this._readableState;switch(i.pipesCount){case 0:i.pipes=e;break;case 1:i.pipes=[i.pipes,e];break;default:i.pipes.push(e);}i.pipesCount+=1,ht("pipe count=%d opts=%j",i.pipesCount,t);var n=!t||!1!==t.end?o:u;function s(e){ht("onunpipe"),e===r&&u();}function o(){ht("onend"),e.end();}i.endEmitted?Oe(n):r.once("end",n),e.on("unpipe",s);var a=function(e){return function(){var t=e._readableState;ht("pipeOnDrain",t.awaitDrain),t.awaitDrain&&t.awaitDrain--,0===t.awaitDrain&&e.listeners("data").length&&(t.flowing=!0,wt(e));}}(r);e.on("drain",a);var l=!1;function u(){ht("cleanup"),e.removeListener("close",d),e.removeListener("finish",p),e.removeListener("drain",a),e.removeListener("error",f),e.removeListener("unpipe",s),r.removeListener("end",o),r.removeListener("end",u),r.removeListener("data",c),l=!0,!i.awaitDrain||e._writableState&&!e._writableState.needDrain||a();}var h=!1;function c(t){ht("ondata"),h=!1,!1!==e.write(t)||h||((1===i.pipesCount&&i.pipes===e||i.pipesCount>1&&-1!==Ct(i.pipes,e))&&!l&&(ht("false write response, pause",r._readableState.awaitDrain),r._readableState.awaitDrain++,h=!0),r.pause());}function f(t){var r;ht("onerror",t),g(),e.removeListener("error",f),0===(r="error",e.listeners(r).length)&&e.emit("error",t);}function d(){e.removeListener("finish",p),g();}function p(){ht("onfinish"),e.removeListener("close",d),g();}function g(){ht("unpipe"),r.unpipe(e);}return r.on("data",c),function(e,t,r){if("function"==typeof e.prependListener)return e.prependListener(t,r);e._events&&e._events[t]?Array.isArray(e._events[t])?e._events[t].unshift(r):e._events[t]=[r,e._events[t]]:e.on(t,r);}(e,"error",f),e.once("close",d),e.once("finish",p),e.emit("pipe",r),i.flowing||(ht("pipe resume"),r.resume()),e},ft.prototype.unpipe=function(e){var t=this._readableState;if(0===t.pipesCount)return this;if(1===t.pipesCount)return e&&e!==t.pipes?this:(e||(e=t.pipes),t.pipes=null,t.pipesCount=0,t.flowing=!1,e&&e.emit("unpipe",this),this);if(!e){var r=t.pipes,i=t.pipesCount;t.pipes=null,t.pipesCount=0,t.flowing=!1;for(var n=0;n<i;n++)r[n].emit("unpipe",this);return this}var s=Ct(t.pipes,e);return -1===s?this:(t.pipes.splice(s,1),t.pipesCount-=1,1===t.pipesCount&&(t.pipes=t.pipes[0]),e.emit("unpipe",this),this)},ft.prototype.on=function(e,t){var r=de.prototype.on.call(this,e,t);if("data"===e)!1!==this._readableState.flowing&&this.resume();else if("readable"===e){var i=this._readableState;i.endEmitted||i.readableListening||(i.readableListening=i.needReadable=!0,i.emittedReadable=!1,i.reading?i.length&&mt(this):Oe(bt,this));}return r},ft.prototype.addListener=ft.prototype.on,ft.prototype.resume=function(){var e=this._readableState;return e.flowing||(ht("resume"),e.flowing=!0,function(e,t){t.resumeScheduled||(t.resumeScheduled=!0,Oe(vt,e,t));}(this,e)),this},ft.prototype.pause=function(){return ht("call pause flowing=%j",this._readableState.flowing),!1!==this._readableState.flowing&&(ht("pause"),this._readableState.flowing=!1,this.emit("pause")),this},ft.prototype.wrap=function(e){var t=this._readableState,r=!1,i=this;for(var n in e.on("end",function(){if(ht("wrapped end"),t.decoder&&!t.ended){var e=t.decoder.end();e&&e.length&&i.push(e);}i.push(null);}),e.on("data",function(n){(ht("wrapped data"),t.decoder&&(n=t.decoder.write(n)),t.objectMode&&null==n)||(t.objectMode||n&&n.length)&&(i.push(n)||(r=!0,e.pause()));}),e)void 0===this[n]&&"function"==typeof e[n]&&(this[n]=function(t){return function(){return e[t].apply(e,arguments)}}(n));return function(e,t){for(var r=0,i=e.length;r<i;r++)t(e[r],r);}(["error","close","destroy","pause","resume"],function(t){e.on(t,i.emit.bind(i,t));}),i._read=function(t){ht("wrapped _read",t),r&&(r=!1,e.resume());},i},ft._fromList=kt,zt.WritableState=Tt,$e(zt,de),Tt.prototype.getBuffer=function(){for(var e=this.bufferedRequest,t=[];e;)t.push(e),e=e.next;return t},zt.prototype.pipe=function(){this.emit("error",new Error("Cannot pipe, not readable"));},zt.prototype.write=function(e,t,r){var i=this._writableState,n=!1;return "function"==typeof t&&(r=t,t=null),A.isBuffer(e)?t="buffer":t||(t=i.defaultEncoding),"function"!=typeof r&&(r=Et),i.ended?function(e,t){var r=new Error("write after end");e.emit("error",r),Oe(t,r);}(this,r):function(e,t,r,i){var n=!0,s=!1;return null===r?s=new TypeError("May not write null values to stream"):A.isBuffer(r)||"string"==typeof r||void 0===r||t.objectMode||(s=new TypeError("Invalid non-string/buffer chunk")),s&&(e.emit("error",s),Oe(i,s),n=!1),n}(this,i,e,r)&&(i.pendingcb++,n=function(e,t,r,i,n){r=function(e,t,r){return e.objectMode||!1===e.decodeStrings||"string"!=typeof t||(t=A.from(t,r)),t}(t,r,i),A.isBuffer(r)&&(i="buffer");var s=t.objectMode?1:r.length;t.length+=s;var o=t.length<t.highWaterMark;o||(t.needDrain=!0);if(t.writing||t.corked){var a=t.lastBufferedRequest;t.lastBufferedRequest=new At(r,i,n),a?a.next=t.lastBufferedRequest:t.bufferedRequest=t.lastBufferedRequest,t.bufferedRequestCount+=1;}else Ot(e,t,!1,s,r,i,n);return o}(this,i,e,t,r)),n},zt.prototype.cork=function(){this._writableState.corked++;},zt.prototype.uncork=function(){var e=this._writableState;e.corked&&(e.corked--,e.writing||e.corked||e.finished||e.bufferProcessing||!e.bufferedRequest||Lt(this,e));},zt.prototype.setDefaultEncoding=function(e){if("string"==typeof e&&(e=e.toLowerCase()),!(["hex","utf8","utf-8","ascii","binary","base64","ucs2","ucs-2","utf16le","utf-16le","raw"].indexOf((e+"").toLowerCase())>-1))throw new TypeError("Unknown encoding: "+e);return this._writableState.defaultEncoding=e,this},zt.prototype._write=function(e,t,r){r(new Error("not implemented"));},zt.prototype._writev=null,zt.prototype.end=function(e,t,r){var i=this._writableState;"function"==typeof e?(r=e,e=null,t=null):"function"==typeof t&&(r=t,t=null),null!=e&&this.write(e,t),i.corked&&(i.corked=1,this.uncork()),i.ending||i.finished||function(e,t,r){t.ending=!0,Ft(e,t),r&&(t.finished?Oe(r):e.once("finish",r));t.ended=!0,e.writable=!1;}(this,i,r);},$e(jt,ft);for(var Mt=Object.keys(zt.prototype),Ut=0;Ut<Mt.length;Ut++){var Dt=Mt[Ut];jt.prototype[Dt]||(jt.prototype[Dt]=zt.prototype[Dt]);}function jt(e){if(!(this instanceof jt))return new jt(e);ft.call(this,e),zt.call(this,e),e&&!1===e.readable&&(this.readable=!1),e&&!1===e.writable&&(this.writable=!1),this.allowHalfOpen=!0,e&&!1===e.allowHalfOpen&&(this.allowHalfOpen=!1),this.once("end",Nt);}function Nt(){this.allowHalfOpen||this._writableState.ended||Oe(Zt,this);}function Zt(e){e.end();}function Wt(e){this.afterTransform=function(t,r){return function(e,t,r){var i=e._transformState;i.transforming=!1;var n=i.writecb;if(!n)return e.emit("error",new Error("no writecb in Transform class"));i.writechunk=null,i.writecb=null,null!=r&&e.push(r);n(t);var s=e._readableState;s.reading=!1,(s.needReadable||s.length<s.highWaterMark)&&e._read(s.highWaterMark);}(e,t,r)},this.needTransform=!1,this.transforming=!1,this.writecb=null,this.writechunk=null,this.writeencoding=null;}function qt(e){if(!(this instanceof qt))return new qt(e);jt.call(this,e),this._transformState=new Wt(this);var t=this;this._readableState.needReadable=!0,this._readableState.sync=!1,e&&("function"==typeof e.transform&&(this._transform=e.transform),"function"==typeof e.flush&&(this._flush=e.flush)),this.once("prefinish",function(){"function"==typeof this._flush?this._flush(function(e){Yt(t,e);}):Yt(t);});}function Yt(e,t){if(t)return e.emit("error",t);var r=e._writableState,i=e._transformState;if(r.length)throw new Error("Calling transform done when ws.length != 0");if(i.transforming)throw new Error("Calling transform done when still transforming");return e.push(null)}function Vt(e){if(!(this instanceof Vt))return new Vt(e);qt.call(this,e);}function Ht(){de.call(this);}$e(qt,jt),qt.prototype.push=function(e,t){return this._transformState.needTransform=!1,jt.prototype.push.call(this,e,t)},qt.prototype._transform=function(e,t,r){throw new Error("Not implemented")},qt.prototype._write=function(e,t,r){var i=this._transformState;if(i.writecb=r,i.writechunk=e,i.writeencoding=t,!i.transforming){var n=this._readableState;(i.needTransform||n.needReadable||n.length<n.highWaterMark)&&this._read(n.highWaterMark);}},qt.prototype._read=function(e){var t=this._transformState;null!==t.writechunk&&t.writecb&&!t.transforming?(t.transforming=!0,this._transform(t.writechunk,t.writeencoding,t.afterTransform)):t.needTransform=!0;},$e(Vt,qt),Vt.prototype._transform=function(e,t,r){r(null,e);},$e(Ht,de),Ht.Readable=ft,Ht.Writable=zt,Ht.Duplex=jt,Ht.Transform=qt,Ht.PassThrough=Vt,Ht.Stream=Ht,Ht.prototype.pipe=function(e,t){var r=this;function i(t){e.writable&&!1===e.write(t)&&r.pause&&r.pause();}function n(){r.readable&&r.resume&&r.resume();}r.on("data",i),e.on("drain",n),e._isStdio||t&&!1===t.end||(r.on("end",o),r.on("close",a));var s=!1;function o(){s||(s=!0,e.end());}function a(){s||(s=!0,"function"==typeof e.destroy&&e.destroy());}function l(e){if(u(),0===de.listenerCount(this,"error"))throw e}function u(){r.removeListener("data",i),e.removeListener("drain",n),r.removeListener("end",o),r.removeListener("close",a),r.removeListener("error",l),e.removeListener("error",l),r.removeListener("end",u),r.removeListener("close",u),e.removeListener("close",u);}return r.on("error",l),e.on("error",l),r.on("end",u),r.on("close",u),e.on("close",u),e.emit("pipe",r),e};var Gt=Ht,$t=e.createCommonjsModule(function(e,t){if(t.base64=!0,t.array=!0,t.string=!0,t.arraybuffer="undefined"!=typeof ArrayBuffer&&"undefined"!=typeof Uint8Array,t.nodebuffer=!0,t.uint8array="undefined"!=typeof Uint8Array,"undefined"==typeof ArrayBuffer)t.blob=!1;else {var r=new ArrayBuffer(0);try{t.blob=0===new Blob([r],{type:"application/zip"}).size;}catch(e){try{var i=new(self.BlobBuilder||self.WebKitBlobBuilder||self.MozBlobBuilder||self.MSBlobBuilder);i.append(r),t.blob=0===i.getBlob("application/zip").size;}catch(e){t.blob=!1;}}}try{t.nodestream=!!Gt.Readable;}catch(e){t.nodestream=!1;}}),Kt=($t.base64,$t.array,$t.string,$t.arraybuffer,$t.nodebuffer,$t.uint8array,$t.blob,$t.nodestream,"ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/="),Jt={encode:function(e){for(var t,r,i,n,s,o,a,l=[],u=0,h=e.length,c=h,f="string"!==ni.getTypeOf(e);u<e.length;)c=h-u,f?(t=e[u++],r=u<h?e[u++]:0,i=u<h?e[u++]:0):(t=e.charCodeAt(u++),r=u<h?e.charCodeAt(u++):0,i=u<h?e.charCodeAt(u++):0),n=t>>2,s=(3&t)<<4|r>>4,o=c>1?(15&r)<<2|i>>6:64,a=c>2?63&i:64,l.push(Kt.charAt(n)+Kt.charAt(s)+Kt.charAt(o)+Kt.charAt(a));return l.join("")},decode:function(e){var t,r,i,n,s,o,a=0,l=0;if("data:"===e.substr(0,"data:".length))throw new Error("Invalid base64 input, it looks like a data url.");var u,h=3*(e=e.replace(/[^A-Za-z0-9\+\/\=]/g,"")).length/4;if(e.charAt(e.length-1)===Kt.charAt(64)&&h--,e.charAt(e.length-2)===Kt.charAt(64)&&h--,h%1!=0)throw new Error("Invalid base64 input, bad content length.");for(u=$t.uint8array?new Uint8Array(0|h):new Array(0|h);a<e.length;)t=Kt.indexOf(e.charAt(a++))<<2|(n=Kt.indexOf(e.charAt(a++)))>>4,r=(15&n)<<4|(s=Kt.indexOf(e.charAt(a++)))>>2,i=(3&s)<<6|(o=Kt.indexOf(e.charAt(a++))),u[l++]=t,64!==s&&(u[l++]=r),64!==o&&(u[l++]=i);return u}},Xt=!0,Qt=function(e,t){return new A(e,t)},er=function(e){return A.alloc?A.alloc(e):new A(e)},tr=function(e){return ue(e)},rr=function(e){return e&&"function"==typeof e.on&&"function"==typeof e.pause&&"function"==typeof e.resume},ir=e.createCommonjsModule(function(e){var t=e.exports="undefined"!=typeof window&&window.Math==Math?window:"undefined"!=typeof self&&self.Math==Math?self:Function("return this")();"number"==typeof __g&&(__g=t);}),nr=e.createCommonjsModule(function(e){var t=e.exports={version:"2.3.0"};"number"==typeof __e&&(__e=t);}),sr=(nr.version,function(e,t,r){if(function(e){if("function"!=typeof e)throw TypeError(e+" is not a function!")}(e),void 0===t)return e;switch(r){case 1:return function(r){return e.call(t,r)};case 2:return function(r,i){return e.call(t,r,i)};case 3:return function(r,i,n){return e.call(t,r,i,n)}}return function(){return e.apply(t,arguments)}}),or=function(e){return "object"==typeof e?null!==e:"function"==typeof e},ar=function(e){if(!or(e))throw TypeError(e+" is not an object!");return e},lr=function(e){try{return !!e()}catch(e){return !0}},ur=!lr(function(){return 7!=Object.defineProperty({},"a",{get:function(){return 7}}).a}),hr=ir.document,cr=or(hr)&&or(hr.createElement),fr=function(e){return cr?hr.createElement(e):{}},dr=!ur&&!lr(function(){return 7!=Object.defineProperty(fr("div"),"a",{get:function(){return 7}}).a}),pr=Object.defineProperty,gr={f:ur?Object.defineProperty:function(e,t,r){if(ar(e),t=function(e,t){if(!or(e))return e;var r,i;if(t&&"function"==typeof(r=e.toString)&&!or(i=r.call(e)))return i;if("function"==typeof(r=e.valueOf)&&!or(i=r.call(e)))return i;if(!t&&"function"==typeof(r=e.toString)&&!or(i=r.call(e)))return i;throw TypeError("Can't convert object to primitive value")}(t,!0),ar(r),dr)try{return pr(e,t,r)}catch(e){}if("get"in r||"set"in r)throw TypeError("Accessors not supported!");return "value"in r&&(e[t]=r.value),e}},mr=ur?function(e,t,r){return gr.f(e,t,function(e,t){return {enumerable:!(1&e),configurable:!(2&e),writable:!(4&e),value:t}}(1,r))}:function(e,t,r){return e[t]=r,e},_r=function(e,t,r){var i,n,s,o=e&_r.F,a=e&_r.G,l=e&_r.S,u=e&_r.P,h=e&_r.B,c=e&_r.W,f=a?nr:nr[t]||(nr[t]={}),d=f.prototype,p=a?ir:l?ir[t]:(ir[t]||{}).prototype;for(i in a&&(r=t),r)(n=!o&&p&&void 0!==p[i])&&i in f||(s=n?p[i]:r[i],f[i]=a&&"function"!=typeof p[i]?r[i]:h&&n?sr(s,ir):c&&p[i]==s?function(e){var t=function(t,r,i){if(this instanceof e){switch(arguments.length){case 0:return new e;case 1:return new e(t);case 2:return new e(t,r)}return new e(t,r,i)}return e.apply(this,arguments)};return t.prototype=e.prototype,t}(s):u&&"function"==typeof s?sr(Function.call,s):s,u&&((f.virtual||(f.virtual={}))[i]=s,e&_r.R&&d&&!d[i]&&mr(d,i,s)));};_r.F=1,_r.G=2,_r.S=4,_r.P=8,_r.B=16,_r.W=32,_r.U=64,_r.R=128;var yr,br,vr,wr,kr=_r,Sr=ir.document&&document.documentElement,xr={}.toString,Cr=ir.process,Er=ir.setImmediate,Ar=ir.clearImmediate,Tr=ir.MessageChannel,zr=0,Or={},Rr=function(){var e=+this;if(Or.hasOwnProperty(e)){var t=Or[e];delete Or[e],t();}},Lr=function(e){Rr.call(e.data);};Er&&Ar||(Er=function(e){for(var t=[],r=1;arguments.length>r;)t.push(arguments[r++]);return Or[++zr]=function(){!function(e,t,r){var i=void 0===r;switch(t.length){case 0:return i?e():e.call(r);case 1:return i?e(t[0]):e.call(r,t[0]);case 2:return i?e(t[0],t[1]):e.call(r,t[0],t[1]);case 3:return i?e(t[0],t[1],t[2]):e.call(r,t[0],t[1],t[2]);case 4:return i?e(t[0],t[1],t[2],t[3]):e.call(r,t[0],t[1],t[2],t[3])}e.apply(r,t);}("function"==typeof e?e:Function(e),t);},yr(zr),zr},Ar=function(e){delete Or[e];},"process"==(wr=Cr,xr.call(wr).slice(8,-1))?yr=function(e){Cr.nextTick(sr(Rr,e,1));}:Tr?(vr=(br=new Tr).port2,br.port1.onmessage=Lr,yr=sr(vr.postMessage,vr,1)):ir.addEventListener&&"function"==typeof postMessage&&!ir.importScripts?(yr=function(e){ir.postMessage(e+"","*");},ir.addEventListener("message",Lr,!1)):yr="onreadystatechange"in fr("script")?function(e){Sr.appendChild(fr("script")).onreadystatechange=function(){Sr.removeChild(this),Rr.call(e);};}:function(e){setTimeout(sr(Rr,e,1),0);});var Br={set:Er,clear:Ar};kr(kr.G+kr.B,{setImmediate:Br.set,clearImmediate:Br.clear});var Ir,Fr,Pr=nr.setImmediate,Mr=f.MutationObserver||f.WebKitMutationObserver;if(Mr){var Ur=0,Dr=new Mr(Wr),jr=f.document.createTextNode("");Dr.observe(jr,{characterData:!0}),Ir=function(){jr.data=Ur=++Ur%2;};}else if(f.setImmediate||void 0===f.MessageChannel)Ir="document"in f&&"onreadystatechange"in f.document.createElement("script")?function(){var e=f.document.createElement("script");e.onreadystatechange=function(){Wr(),e.onreadystatechange=null,e.parentNode.removeChild(e),e=null;},f.document.documentElement.appendChild(e);}:function(){setTimeout(Wr,0);};else {var Nr=new f.MessageChannel;Nr.port1.onmessage=Wr,Ir=function(){Nr.port2.postMessage(0);};}var Zr=[];function Wr(){var e,t;Fr=!0;for(var r=Zr.length;r;){for(t=Zr,Zr=[],e=-1;++e<r;)t[e]();r=Zr.length;}Fr=!1;}var qr=function(e){1!==Zr.push(e)||Fr||Ir();};function Yr(){}var Vr={},Hr=["REJECTED"],Gr=["FULFILLED"],$r=["PENDING"],Kr=Jr;function Jr(e){if("function"!=typeof e)throw new TypeError("resolver must be a function");this.state=$r,this.queue=[],this.outcome=void 0,e!==Yr&&ti(this,e);}function Xr(e,t,r){this.promise=e,"function"==typeof t&&(this.onFulfilled=t,this.callFulfilled=this.otherCallFulfilled),"function"==typeof r&&(this.onRejected=r,this.callRejected=this.otherCallRejected);}function Qr(e,t,r){qr(function(){var i;try{i=t(r);}catch(t){return Vr.reject(e,t)}i===e?Vr.reject(e,new TypeError("Cannot resolve promise with itself")):Vr.resolve(e,i);});}function ei(e){var t=e&&e.then;if(e&&("object"==typeof e||"function"==typeof e)&&"function"==typeof t)return function(){t.apply(e,arguments);}}function ti(e,t){var r=!1;function i(t){r||(r=!0,Vr.reject(e,t));}function n(t){r||(r=!0,Vr.resolve(e,t));}var s=ri(function(){t(n,i);});"error"===s.status&&i(s.value);}function ri(e,t){var r={};try{r.value=e(t),r.status="success";}catch(e){r.status="error",r.value=e;}return r}Jr.prototype.catch=function(e){return this.then(null,e)},Jr.prototype.then=function(e,t){if("function"!=typeof e&&this.state===Gr||"function"!=typeof t&&this.state===Hr)return this;var r=new this.constructor(Yr);this.state!==$r?Qr(r,this.state===Gr?e:t,this.outcome):this.queue.push(new Xr(r,e,t));return r},Xr.prototype.callFulfilled=function(e){Vr.resolve(this.promise,e);},Xr.prototype.otherCallFulfilled=function(e){Qr(this.promise,this.onFulfilled,e);},Xr.prototype.callRejected=function(e){Vr.reject(this.promise,e);},Xr.prototype.otherCallRejected=function(e){Qr(this.promise,this.onRejected,e);},Vr.resolve=function(e,t){var r=ri(ei,t);if("error"===r.status)return Vr.reject(e,r.value);var i=r.value;if(i)ti(e,i);else {e.state=Gr,e.outcome=t;for(var n=-1,s=e.queue.length;++n<s;)e.queue[n].callFulfilled(t);}return e},Vr.reject=function(e,t){e.state=Hr,e.outcome=t;for(var r=-1,i=e.queue.length;++r<i;)e.queue[r].callRejected(t);return e},Jr.resolve=function(e){if(e instanceof this)return e;return Vr.resolve(new this(Yr),e)},Jr.reject=function(e){var t=new this(Yr);return Vr.reject(t,e)},Jr.all=function(e){var t=this;if("[object Array]"!==Object.prototype.toString.call(e))return this.reject(new TypeError("must be an array"));var r=e.length,i=!1;if(!r)return this.resolve([]);var n=new Array(r),s=0,o=-1,a=new this(Yr);for(;++o<r;)l(e[o],o);return a;function l(e,o){t.resolve(e).then(function(e){n[o]=e,++s!==r||i||(i=!0,Vr.resolve(a,n));},function(e){i||(i=!0,Vr.reject(a,e));});}},Jr.race=function(e){var t=this;if("[object Array]"!==Object.prototype.toString.call(e))return this.reject(new TypeError("must be an array"));var r=e.length,i=!1;if(!r)return this.resolve([]);var n=-1,s=new this(Yr);for(;++n<r;)o=e[n],t.resolve(o).then(function(e){i||(i=!0,Vr.resolve(s,e));},function(e){i||(i=!0,Vr.reject(s,e));});var o;return s};var ii={Promise:"undefined"!=typeof Promise?Promise:Kr},ni=e.createCommonjsModule(function(e,t){function r(e){return e}function i(e,t){for(var r=0;r<e.length;++r)t[r]=255&e.charCodeAt(r);return t}t.newBlob=function(e,r){t.checkSupport("blob");try{return new Blob([e],{type:r})}catch(t){try{var i=new(self.BlobBuilder||self.WebKitBlobBuilder||self.MozBlobBuilder||self.MSBlobBuilder);return i.append(e),i.getBlob(r)}catch(e){throw new Error("Bug : can't construct the Blob.")}}};var n={stringifyByChunk:function(e,t,r){var i=[],n=0,s=e.length;if(s<=r)return String.fromCharCode.apply(null,e);for(;n<s;)"array"===t||"nodebuffer"===t?i.push(String.fromCharCode.apply(null,e.slice(n,Math.min(n+r,s)))):i.push(String.fromCharCode.apply(null,e.subarray(n,Math.min(n+r,s)))),n+=r;return i.join("")},stringifyByChar:function(e){for(var t="",r=0;r<e.length;r++)t+=String.fromCharCode(e[r]);return t},applyCanBeUsed:{uint8array:function(){try{return $t.uint8array&&1===String.fromCharCode.apply(null,new Uint8Array(1)).length}catch(e){return !1}}(),nodebuffer:function(){try{return $t.nodebuffer&&1===String.fromCharCode.apply(null,er(1)).length}catch(e){return !1}}()}};function s(e){var r=65536,i=t.getTypeOf(e),s=!0;if("uint8array"===i?s=n.applyCanBeUsed.uint8array:"nodebuffer"===i&&(s=n.applyCanBeUsed.nodebuffer),s)for(;r>1;)try{return n.stringifyByChunk(e,i,r)}catch(e){r=Math.floor(r/2);}return n.stringifyByChar(e)}function o(e,t){for(var r=0;r<e.length;r++)t[r]=e[r];return t}t.applyFromCharCode=s;var a={};a.string={string:r,array:function(e){return i(e,new Array(e.length))},arraybuffer:function(e){return a.string.uint8array(e).buffer},uint8array:function(e){return i(e,new Uint8Array(e.length))},nodebuffer:function(e){return i(e,er(e.length))}},a.array={string:s,array:r,arraybuffer:function(e){return new Uint8Array(e).buffer},uint8array:function(e){return new Uint8Array(e)},nodebuffer:function(e){return Qt(e)}},a.arraybuffer={string:function(e){return s(new Uint8Array(e))},array:function(e){return o(new Uint8Array(e),new Array(e.byteLength))},arraybuffer:r,uint8array:function(e){return new Uint8Array(e)},nodebuffer:function(e){return Qt(new Uint8Array(e))}},a.uint8array={string:s,array:function(e){return o(e,new Array(e.length))},arraybuffer:function(e){return e.buffer},uint8array:r,nodebuffer:function(e){return Qt(e)}},a.nodebuffer={string:s,array:function(e){return o(e,new Array(e.length))},arraybuffer:function(e){return a.nodebuffer.uint8array(e).buffer},uint8array:function(e){return o(e,new Uint8Array(e.length))},nodebuffer:r},t.transformTo=function(e,r){if(r||(r=""),!e)return r;t.checkSupport(e);var i=t.getTypeOf(r);return a[i][e](r)},t.getTypeOf=function(e){return "string"==typeof e?"string":"[object Array]"===Object.prototype.toString.call(e)?"array":$t.nodebuffer&&tr(e)?"nodebuffer":$t.uint8array&&e instanceof Uint8Array?"uint8array":$t.arraybuffer&&e instanceof ArrayBuffer?"arraybuffer":void 0},t.checkSupport=function(e){if(!$t[e.toLowerCase()])throw new Error(e+" is not supported by this platform")},t.MAX_VALUE_16BITS=65535,t.MAX_VALUE_32BITS=-1,t.pretty=function(e){var t,r,i="";for(r=0;r<(e||"").length;r++)i+="\\x"+((t=e.charCodeAt(r))<16?"0":"")+t.toString(16).toUpperCase();return i},t.delay=function(e,t,r){Pr(function(){e.apply(r||null,t||[]);});},t.inherits=function(e,t){var r=function(){};r.prototype=t.prototype,e.prototype=new r;},t.extend=function(){var e,t,r={};for(e=0;e<arguments.length;e++)for(t in arguments[e])arguments[e].hasOwnProperty(t)&&void 0===r[t]&&(r[t]=arguments[e][t]);return r},t.prepareContent=function(e,r,n,s,o){return ii.Promise.resolve(r).then(function(e){return $t.blob&&(e instanceof Blob||-1!==["[object File]","[object Blob]"].indexOf(Object.prototype.toString.call(e)))&&"undefined"!=typeof FileReader?new ii.Promise(function(t,r){var i=new FileReader;i.onload=function(e){t(e.target.result);},i.onerror=function(e){r(e.target.error);},i.readAsArrayBuffer(e);}):e}).then(function(r){var a,l=t.getTypeOf(r);return l?("arraybuffer"===l?r=t.transformTo("uint8array",r):"string"===l&&(o?r=Jt.decode(r):n&&!0!==s&&(r=i(a=r,$t.uint8array?new Uint8Array(a.length):new Array(a.length)))),r):ii.Promise.reject(new Error("Can't read the data of '"+e+"'. Is it in a supported JavaScript type (String, Blob, ArrayBuffer, etc) ?"))})};});ni.newBlob,ni.applyFromCharCode,ni.transformTo,ni.getTypeOf,ni.checkSupport,ni.MAX_VALUE_16BITS,ni.MAX_VALUE_32BITS,ni.pretty,ni.delay,ni.inherits,ni.extend,ni.prepareContent;function si(e){this.name=e||"default",this.streamInfo={},this.generatedError=null,this.extraStreamInfo={},this.isPaused=!0,this.isFinished=!1,this.isLocked=!1,this._listeners={data:[],end:[],error:[]},this.previous=null;}si.prototype={push:function(e){this.emit("data",e);},end:function(){if(this.isFinished)return !1;this.flush();try{this.emit("end"),this.cleanUp(),this.isFinished=!0;}catch(e){this.emit("error",e);}return !0},error:function(e){return !this.isFinished&&(this.isPaused?this.generatedError=e:(this.isFinished=!0,this.emit("error",e),this.previous&&this.previous.error(e),this.cleanUp()),!0)},on:function(e,t){return this._listeners[e].push(t),this},cleanUp:function(){this.streamInfo=this.generatedError=this.extraStreamInfo=null,this._listeners=[];},emit:function(e,t){if(this._listeners[e])for(var r=0;r<this._listeners[e].length;r++)this._listeners[e][r].call(this,t);},pipe:function(e){return e.registerPrevious(this)},registerPrevious:function(e){if(this.isLocked)throw new Error("The stream '"+this+"' has already been used.");this.streamInfo=e.streamInfo,this.mergeStreamInfo(),this.previous=e;var t=this;return e.on("data",function(e){t.processChunk(e);}),e.on("end",function(){t.end();}),e.on("error",function(e){t.error(e);}),this},pause:function(){return !this.isPaused&&!this.isFinished&&(this.isPaused=!0,this.previous&&this.previous.pause(),!0)},resume:function(){if(!this.isPaused||this.isFinished)return !1;this.isPaused=!1;var e=!1;return this.generatedError&&(this.error(this.generatedError),e=!0),this.previous&&this.previous.resume(),!e},flush:function(){},processChunk:function(e){this.push(e);},withStreamInfo:function(e,t){return this.extraStreamInfo[e]=t,this.mergeStreamInfo(),this},mergeStreamInfo:function(){for(var e in this.extraStreamInfo)this.extraStreamInfo.hasOwnProperty(e)&&(this.streamInfo[e]=this.extraStreamInfo[e]);},lock:function(){if(this.isLocked)throw new Error("The stream '"+this+"' has already been used.");this.isLocked=!0,this.previous&&this.previous.lock();},toString:function(){var e="Worker "+this.name;return this.previous?this.previous+" -> "+e:e}};var oi=si,ai=e.createCommonjsModule(function(e,t){for(var r=new Array(256),i=0;i<256;i++)r[i]=i>=252?6:i>=248?5:i>=240?4:i>=224?3:i>=192?2:1;r[254]=r[254]=1;function n(){oi.call(this,"utf-8 decode"),this.leftOver=null;}function s(){oi.call(this,"utf-8 encode");}t.utf8encode=function(e){return $t.nodebuffer?Qt(e,"utf-8"):function(e){var t,r,i,n,s,o=e.length,a=0;for(n=0;n<o;n++)55296==(64512&(r=e.charCodeAt(n)))&&n+1<o&&56320==(64512&(i=e.charCodeAt(n+1)))&&(r=65536+(r-55296<<10)+(i-56320),n++),a+=r<128?1:r<2048?2:r<65536?3:4;for(t=$t.uint8array?new Uint8Array(a):new Array(a),s=0,n=0;s<a;n++)55296==(64512&(r=e.charCodeAt(n)))&&n+1<o&&56320==(64512&(i=e.charCodeAt(n+1)))&&(r=65536+(r-55296<<10)+(i-56320),n++),r<128?t[s++]=r:r<2048?(t[s++]=192|r>>>6,t[s++]=128|63&r):r<65536?(t[s++]=224|r>>>12,t[s++]=128|r>>>6&63,t[s++]=128|63&r):(t[s++]=240|r>>>18,t[s++]=128|r>>>12&63,t[s++]=128|r>>>6&63,t[s++]=128|63&r);return t}(e)},t.utf8decode=function(e){return $t.nodebuffer?ni.transformTo("nodebuffer",e).toString("utf-8"):function(e){var t,i,n,s,o=e.length,a=new Array(2*o);for(i=0,t=0;t<o;)if((n=e[t++])<128)a[i++]=n;else if((s=r[n])>4)a[i++]=65533,t+=s-1;else {for(n&=2===s?31:3===s?15:7;s>1&&t<o;)n=n<<6|63&e[t++],s--;s>1?a[i++]=65533:n<65536?a[i++]=n:(n-=65536,a[i++]=55296|n>>10&1023,a[i++]=56320|1023&n);}return a.length!==i&&(a.subarray?a=a.subarray(0,i):a.length=i),ni.applyFromCharCode(a)}(e=ni.transformTo($t.uint8array?"uint8array":"array",e))},ni.inherits(n,oi),n.prototype.processChunk=function(e){var i=ni.transformTo($t.uint8array?"uint8array":"array",e.data);if(this.leftOver&&this.leftOver.length){if($t.uint8array){var n=i;(i=new Uint8Array(n.length+this.leftOver.length)).set(this.leftOver,0),i.set(n,this.leftOver.length);}else i=this.leftOver.concat(i);this.leftOver=null;}var s=function(e,t){var i;for((t=t||e.length)>e.length&&(t=e.length),i=t-1;i>=0&&128==(192&e[i]);)i--;return i<0?t:0===i?t:i+r[e[i]]>t?i:t}(i),o=i;s!==i.length&&($t.uint8array?(o=i.subarray(0,s),this.leftOver=i.subarray(s,i.length)):(o=i.slice(0,s),this.leftOver=i.slice(s,i.length))),this.push({data:t.utf8decode(o),meta:e.meta});},n.prototype.flush=function(){this.leftOver&&this.leftOver.length&&(this.push({data:t.utf8decode(this.leftOver),meta:{}}),this.leftOver=null);},t.Utf8DecodeWorker=n,ni.inherits(s,oi),s.prototype.processChunk=function(e){this.push({data:t.utf8encode(e.data),meta:e.meta});},t.Utf8EncodeWorker=s;});ai.utf8encode,ai.utf8decode,ai.Utf8DecodeWorker,ai.Utf8EncodeWorker;function li(e){oi.call(this,"ConvertWorker to "+e),this.destType=e;}ni.inherits(li,oi),li.prototype.processChunk=function(e){this.push({data:ni.transformTo(this.destType,e.data),meta:e.meta});};var ui=li,hi=Gt.Readable;function ci(e,t,r){hi.call(this,t),this._helper=e;var i=this;e.on("data",function(e,t){i.push(e)||i._helper.pause(),r&&r(t);}).on("error",function(e){i.emit("error",e);}).on("end",function(){i.push(null);});}ni.inherits(ci,hi),ci.prototype._read=function(){this._helper.resume();};var fi=ci,di=null;if($t.nodestream)try{di=fi;}catch(e){}function pi(e,t){return new ii.Promise(function(r,i){var n=[],s=e._internalType,o=e._outputType,a=e._mimeType;e.on("data",function(e,r){n.push(e),t&&t(r);}).on("error",function(e){n=[],i(e);}).on("end",function(){try{var e=function(e,t,r){switch(e){case"blob":return ni.newBlob(ni.transformTo("arraybuffer",t),r);case"base64":return Jt.encode(t);default:return ni.transformTo(e,t)}}(o,function(e,t){var r,i=0,n=null,s=0;for(r=0;r<t.length;r++)s+=t[r].length;switch(e){case"string":return t.join("");case"array":return Array.prototype.concat.apply([],t);case"uint8array":for(n=new Uint8Array(s),r=0;r<t.length;r++)n.set(t[r],i),i+=t[r].length;return n;case"nodebuffer":return A.concat(t);default:throw new Error("concat : unsupported type '"+e+"'")}}(s,n),a);r(e);}catch(e){i(e);}n=[];}).resume();})}function gi(e,t,r){var i=t;switch(t){case"blob":case"arraybuffer":i="uint8array";break;case"base64":i="string";}try{this._internalType=i,this._outputType=t,this._mimeType=r,ni.checkSupport(i),this._worker=e.pipe(new ui(i)),e.lock();}catch(e){this._worker=new oi("error"),this._worker.error(e);}}gi.prototype={accumulate:function(e){return pi(this,e)},on:function(e,t){var r=this;return "data"===e?this._worker.on(e,function(e){t.call(r,e.data,e.meta);}):this._worker.on(e,function(){ni.delay(t,arguments,r);}),this},resume:function(){return ni.delay(this._worker.resume,[],this._worker),this},pause:function(){return this._worker.pause(),this},toNodejsStream:function(e){if(ni.checkSupport("nodestream"),"nodebuffer"!==this._outputType)throw new Error(this._outputType+" is not supported by this method");return new di(this,{objectMode:"nodebuffer"!==this._outputType},e)}};var mi=gi,_i={base64:!1,binary:!1,dir:!1,createFolders:!0,date:null,compression:null,compressionOptions:null,comment:null,unixPermissions:null,dosPermissions:null};function yi(e){oi.call(this,"DataWorker");var t=this;this.dataIsReady=!1,this.index=0,this.max=0,this.data=null,this.type="",this._tickScheduled=!1,e.then(function(e){t.dataIsReady=!0,t.data=e,t.max=e&&e.length||0,t.type=ni.getTypeOf(e),t.isPaused||t._tickAndRepeat();},function(e){t.error(e);});}ni.inherits(yi,oi),yi.prototype.cleanUp=function(){oi.prototype.cleanUp.call(this),this.data=null;},yi.prototype.resume=function(){return !!oi.prototype.resume.call(this)&&(!this._tickScheduled&&this.dataIsReady&&(this._tickScheduled=!0,ni.delay(this._tickAndRepeat,[],this)),!0)},yi.prototype._tickAndRepeat=function(){this._tickScheduled=!1,this.isPaused||this.isFinished||(this._tick(),this.isFinished||(ni.delay(this._tickAndRepeat,[],this),this._tickScheduled=!0));},yi.prototype._tick=function(){if(this.isPaused||this.isFinished)return !1;var e=null,t=Math.min(this.max,this.index+16384);if(this.index>=this.max)return this.end();switch(this.type){case"string":e=this.data.substring(this.index,t);break;case"uint8array":e=this.data.subarray(this.index,t);break;case"array":case"nodebuffer":e=this.data.slice(this.index,t);}return this.index=t,this.push({data:e,meta:{percent:this.max?this.index/this.max*100:0}})};var bi=yi;function vi(e){oi.call(this,"DataLengthProbe for "+e),this.propName=e,this.withStreamInfo(e,0);}ni.inherits(vi,oi),vi.prototype.processChunk=function(e){if(e){var t=this.streamInfo[this.propName]||0;this.streamInfo[this.propName]=t+e.data.length;}oi.prototype.processChunk.call(this,e);};var wi=vi;var ki=function(){for(var e,t=[],r=0;r<256;r++){e=r;for(var i=0;i<8;i++)e=1&e?3988292384^e>>>1:e>>>1;t[r]=e;}return t}();var Si=function(e,t){return void 0!==e&&e.length?"string"!==ni.getTypeOf(e)?function(e,t,r,i){var n=ki,s=i+r;e^=-1;for(var o=i;o<s;o++)e=e>>>8^n[255&(e^t[o])];return -1^e}(0|t,e,e.length,0):function(e,t,r,i){var n=ki,s=i+r;e^=-1;for(var o=i;o<s;o++)e=e>>>8^n[255&(e^t.charCodeAt(o))];return -1^e}(0|t,e,e.length,0):0};function xi(){oi.call(this,"Crc32Probe"),this.withStreamInfo("crc32",0);}ni.inherits(xi,oi),xi.prototype.processChunk=function(e){this.streamInfo.crc32=Si(e.data,this.streamInfo.crc32||0),this.push(e);};var Ci=xi;function Ei(e,t,r,i,n){this.compressedSize=e,this.uncompressedSize=t,this.crc32=r,this.compression=i,this.compressedContent=n;}Ei.prototype={getContentWorker:function(){var e=new bi(ii.Promise.resolve(this.compressedContent)).pipe(this.compression.uncompressWorker()).pipe(new wi("data_length")),t=this;return e.on("end",function(){if(this.streamInfo.data_length!==t.uncompressedSize)throw new Error("Bug : uncompressed data size mismatch")}),e},getCompressedWorker:function(){return new bi(ii.Promise.resolve(this.compressedContent)).withStreamInfo("compressedSize",this.compressedSize).withStreamInfo("uncompressedSize",this.uncompressedSize).withStreamInfo("crc32",this.crc32).withStreamInfo("compression",this.compression)}},Ei.createWorkerFrom=function(e,t,r){return e.pipe(new Ci).pipe(new wi("uncompressedSize")).pipe(t.compressWorker(r)).pipe(new wi("compressedSize")).withStreamInfo("compression",t)};var Ai=Ei,Ti=function(e,t,r){this.name=e,this.dir=r.dir,this.date=r.date,this.comment=r.comment,this.unixPermissions=r.unixPermissions,this.dosPermissions=r.dosPermissions,this._data=t,this._dataBinary=r.binary,this.options={compression:r.compression,compressionOptions:r.compressionOptions};};Ti.prototype={internalStream:function(e){var t=null,r="string";try{if(!e)throw new Error("No output type specified.");var i="string"===(r=e.toLowerCase())||"text"===r;"binarystring"!==r&&"text"!==r||(r="string"),t=this._decompressWorker();var n=!this._dataBinary;n&&!i&&(t=t.pipe(new ai.Utf8EncodeWorker)),!n&&i&&(t=t.pipe(new ai.Utf8DecodeWorker));}catch(e){(t=new oi("error")).error(e);}return new mi(t,r,"")},async:function(e,t){return this.internalStream(e).accumulate(t)},nodeStream:function(e,t){return this.internalStream(e||"nodebuffer").toNodejsStream(t)},_compressWorker:function(e,t){if(this._data instanceof Ai&&this._data.compression.magic===e.magic)return this._data.getCompressedWorker();var r=this._decompressWorker();return this._dataBinary||(r=r.pipe(new ai.Utf8EncodeWorker)),Ai.createWorkerFrom(r,e,t)},_decompressWorker:function(){return this._data instanceof Ai?this._data.getContentWorker():this._data instanceof oi?this._data:new bi(this._data)}};for(var zi=["asText","asBinary","asNodeBuffer","asUint8Array","asArrayBuffer"],Oi=function(){throw new Error("This method has been removed in JSZip 3.0, please check the upgrade guide.")},Ri=0;Ri<zi.length;Ri++)Ti.prototype[zi[Ri]]=Oi;var Li=Ti,Bi=e.createCommonjsModule(function(e,t){var r="undefined"!=typeof Uint8Array&&"undefined"!=typeof Uint16Array&&"undefined"!=typeof Int32Array;function i(e,t){return Object.prototype.hasOwnProperty.call(e,t)}t.assign=function(e){for(var t=Array.prototype.slice.call(arguments,1);t.length;){var r=t.shift();if(r){if("object"!=typeof r)throw new TypeError(r+"must be non-object");for(var n in r)i(r,n)&&(e[n]=r[n]);}}return e},t.shrinkBuf=function(e,t){return e.length===t?e:e.subarray?e.subarray(0,t):(e.length=t,e)};var n={arraySet:function(e,t,r,i,n){if(t.subarray&&e.subarray)e.set(t.subarray(r,r+i),n);else for(var s=0;s<i;s++)e[n+s]=t[r+s];},flattenChunks:function(e){var t,r,i,n,s,o;for(i=0,t=0,r=e.length;t<r;t++)i+=e[t].length;for(o=new Uint8Array(i),n=0,t=0,r=e.length;t<r;t++)s=e[t],o.set(s,n),n+=s.length;return o}},s={arraySet:function(e,t,r,i,n){for(var s=0;s<i;s++)e[n+s]=t[r+s];},flattenChunks:function(e){return [].concat.apply([],e)}};t.setTyped=function(e){e?(t.Buf8=Uint8Array,t.Buf16=Uint16Array,t.Buf32=Int32Array,t.assign(t,n)):(t.Buf8=Array,t.Buf16=Array,t.Buf32=Array,t.assign(t,s));},t.setTyped(r);}),Ii=(Bi.assign,Bi.shrinkBuf,Bi.setTyped,Bi.Buf8,Bi.Buf16,Bi.Buf32,4),Fi=0,Pi=1,Mi=2;function Ui(e){for(var t=e.length;--t>=0;)e[t]=0;}var Di=0,ji=1,Ni=2,Zi=29,Wi=256,qi=Wi+1+Zi,Yi=30,Vi=19,Hi=2*qi+1,Gi=15,$i=16,Ki=7,Ji=256,Xi=16,Qi=17,en=18,tn=[0,0,0,0,0,0,0,0,1,1,1,1,2,2,2,2,3,3,3,3,4,4,4,4,5,5,5,5,0],rn=[0,0,0,0,1,1,2,2,3,3,4,4,5,5,6,6,7,7,8,8,9,9,10,10,11,11,12,12,13,13],nn=[0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,3,7],sn=[16,17,18,0,8,7,9,6,10,5,11,4,12,3,13,2,14,1,15],on=new Array(2*(qi+2));Ui(on);var an=new Array(2*Yi);Ui(an);var ln=new Array(512);Ui(ln);var un=new Array(256);Ui(un);var hn=new Array(Zi);Ui(hn);var cn,fn,dn,pn=new Array(Yi);function gn(e,t,r,i,n){this.static_tree=e,this.extra_bits=t,this.extra_base=r,this.elems=i,this.max_length=n,this.has_stree=e&&e.length;}function mn(e,t){this.dyn_tree=e,this.max_code=0,this.stat_desc=t;}function _n(e){return e<256?ln[e]:ln[256+(e>>>7)]}function yn(e,t){e.pending_buf[e.pending++]=255&t,e.pending_buf[e.pending++]=t>>>8&255;}function bn(e,t,r){e.bi_valid>$i-r?(e.bi_buf|=t<<e.bi_valid&65535,yn(e,e.bi_buf),e.bi_buf=t>>$i-e.bi_valid,e.bi_valid+=r-$i):(e.bi_buf|=t<<e.bi_valid&65535,e.bi_valid+=r);}function vn(e,t,r){bn(e,r[2*t],r[2*t+1]);}function wn(e,t){var r=0;do{r|=1&e,e>>>=1,r<<=1;}while(--t>0);return r>>>1}function kn(e,t,r){var i,n,s=new Array(Gi+1),o=0;for(i=1;i<=Gi;i++)s[i]=o=o+r[i-1]<<1;for(n=0;n<=t;n++){var a=e[2*n+1];0!==a&&(e[2*n]=wn(s[a]++,a));}}function Sn(e){var t;for(t=0;t<qi;t++)e.dyn_ltree[2*t]=0;for(t=0;t<Yi;t++)e.dyn_dtree[2*t]=0;for(t=0;t<Vi;t++)e.bl_tree[2*t]=0;e.dyn_ltree[2*Ji]=1,e.opt_len=e.static_len=0,e.last_lit=e.matches=0;}function xn(e){e.bi_valid>8?yn(e,e.bi_buf):e.bi_valid>0&&(e.pending_buf[e.pending++]=e.bi_buf),e.bi_buf=0,e.bi_valid=0;}function Cn(e,t,r,i){var n=2*t,s=2*r;return e[n]<e[s]||e[n]===e[s]&&i[t]<=i[r]}function En(e,t,r){for(var i=e.heap[r],n=r<<1;n<=e.heap_len&&(n<e.heap_len&&Cn(t,e.heap[n+1],e.heap[n],e.depth)&&n++,!Cn(t,i,e.heap[n],e.depth));)e.heap[r]=e.heap[n],r=n,n<<=1;e.heap[r]=i;}function An(e,t,r){var i,n,s,o,a=0;if(0!==e.last_lit)do{i=e.pending_buf[e.d_buf+2*a]<<8|e.pending_buf[e.d_buf+2*a+1],n=e.pending_buf[e.l_buf+a],a++,0===i?vn(e,n,t):(vn(e,(s=un[n])+Wi+1,t),0!==(o=tn[s])&&bn(e,n-=hn[s],o),vn(e,s=_n(--i),r),0!==(o=rn[s])&&bn(e,i-=pn[s],o));}while(a<e.last_lit);vn(e,Ji,t);}function Tn(e,t){var r,i,n,s=t.dyn_tree,o=t.stat_desc.static_tree,a=t.stat_desc.has_stree,l=t.stat_desc.elems,u=-1;for(e.heap_len=0,e.heap_max=Hi,r=0;r<l;r++)0!==s[2*r]?(e.heap[++e.heap_len]=u=r,e.depth[r]=0):s[2*r+1]=0;for(;e.heap_len<2;)s[2*(n=e.heap[++e.heap_len]=u<2?++u:0)]=1,e.depth[n]=0,e.opt_len--,a&&(e.static_len-=o[2*n+1]);for(t.max_code=u,r=e.heap_len>>1;r>=1;r--)En(e,s,r);n=l;do{r=e.heap[1],e.heap[1]=e.heap[e.heap_len--],En(e,s,1),i=e.heap[1],e.heap[--e.heap_max]=r,e.heap[--e.heap_max]=i,s[2*n]=s[2*r]+s[2*i],e.depth[n]=(e.depth[r]>=e.depth[i]?e.depth[r]:e.depth[i])+1,s[2*r+1]=s[2*i+1]=n,e.heap[1]=n++,En(e,s,1);}while(e.heap_len>=2);e.heap[--e.heap_max]=e.heap[1],function(e,t){var r,i,n,s,o,a,l=t.dyn_tree,u=t.max_code,h=t.stat_desc.static_tree,c=t.stat_desc.has_stree,f=t.stat_desc.extra_bits,d=t.stat_desc.extra_base,p=t.stat_desc.max_length,g=0;for(s=0;s<=Gi;s++)e.bl_count[s]=0;for(l[2*e.heap[e.heap_max]+1]=0,r=e.heap_max+1;r<Hi;r++)(s=l[2*l[2*(i=e.heap[r])+1]+1]+1)>p&&(s=p,g++),l[2*i+1]=s,i>u||(e.bl_count[s]++,o=0,i>=d&&(o=f[i-d]),a=l[2*i],e.opt_len+=a*(s+o),c&&(e.static_len+=a*(h[2*i+1]+o)));if(0!==g){do{for(s=p-1;0===e.bl_count[s];)s--;e.bl_count[s]--,e.bl_count[s+1]+=2,e.bl_count[p]--,g-=2;}while(g>0);for(s=p;0!==s;s--)for(i=e.bl_count[s];0!==i;)(n=e.heap[--r])>u||(l[2*n+1]!==s&&(e.opt_len+=(s-l[2*n+1])*l[2*n],l[2*n+1]=s),i--);}}(e,t),kn(s,u,e.bl_count);}function zn(e,t,r){var i,n,s=-1,o=t[1],a=0,l=7,u=4;for(0===o&&(l=138,u=3),t[2*(r+1)+1]=65535,i=0;i<=r;i++)n=o,o=t[2*(i+1)+1],++a<l&&n===o||(a<u?e.bl_tree[2*n]+=a:0!==n?(n!==s&&e.bl_tree[2*n]++,e.bl_tree[2*Xi]++):a<=10?e.bl_tree[2*Qi]++:e.bl_tree[2*en]++,a=0,s=n,0===o?(l=138,u=3):n===o?(l=6,u=3):(l=7,u=4));}function On(e,t,r){var i,n,s=-1,o=t[1],a=0,l=7,u=4;for(0===o&&(l=138,u=3),i=0;i<=r;i++)if(n=o,o=t[2*(i+1)+1],!(++a<l&&n===o)){if(a<u)do{vn(e,n,e.bl_tree);}while(0!=--a);else 0!==n?(n!==s&&(vn(e,n,e.bl_tree),a--),vn(e,Xi,e.bl_tree),bn(e,a-3,2)):a<=10?(vn(e,Qi,e.bl_tree),bn(e,a-3,3)):(vn(e,en,e.bl_tree),bn(e,a-11,7));a=0,s=n,0===o?(l=138,u=3):n===o?(l=6,u=3):(l=7,u=4);}}Ui(pn);var Rn=!1;function Ln(e,t,r,i){bn(e,(Di<<1)+(i?1:0),3),function(e,t,r,i){xn(e),i&&(yn(e,r),yn(e,~r)),Bi.arraySet(e.pending_buf,e.window,t,r,e.pending),e.pending+=r;}(e,t,r,!0);}var Bn={_tr_init:function(e){Rn||(function(){var e,t,r,i,n,s=new Array(Gi+1);for(r=0,i=0;i<Zi-1;i++)for(hn[i]=r,e=0;e<1<<tn[i];e++)un[r++]=i;for(un[r-1]=i,n=0,i=0;i<16;i++)for(pn[i]=n,e=0;e<1<<rn[i];e++)ln[n++]=i;for(n>>=7;i<Yi;i++)for(pn[i]=n<<7,e=0;e<1<<rn[i]-7;e++)ln[256+n++]=i;for(t=0;t<=Gi;t++)s[t]=0;for(e=0;e<=143;)on[2*e+1]=8,e++,s[8]++;for(;e<=255;)on[2*e+1]=9,e++,s[9]++;for(;e<=279;)on[2*e+1]=7,e++,s[7]++;for(;e<=287;)on[2*e+1]=8,e++,s[8]++;for(kn(on,qi+1,s),e=0;e<Yi;e++)an[2*e+1]=5,an[2*e]=wn(e,5);cn=new gn(on,tn,Wi+1,qi,Gi),fn=new gn(an,rn,0,Yi,Gi),dn=new gn(new Array(0),nn,0,Vi,Ki);}(),Rn=!0),e.l_desc=new mn(e.dyn_ltree,cn),e.d_desc=new mn(e.dyn_dtree,fn),e.bl_desc=new mn(e.bl_tree,dn),e.bi_buf=0,e.bi_valid=0,Sn(e);},_tr_stored_block:Ln,_tr_flush_block:function(e,t,r,i){var n,s,o=0;e.level>0?(e.strm.data_type===Mi&&(e.strm.data_type=function(e){var t,r=4093624447;for(t=0;t<=31;t++,r>>>=1)if(1&r&&0!==e.dyn_ltree[2*t])return Fi;if(0!==e.dyn_ltree[18]||0!==e.dyn_ltree[20]||0!==e.dyn_ltree[26])return Pi;for(t=32;t<Wi;t++)if(0!==e.dyn_ltree[2*t])return Pi;return Fi}(e)),Tn(e,e.l_desc),Tn(e,e.d_desc),o=function(e){var t;for(zn(e,e.dyn_ltree,e.l_desc.max_code),zn(e,e.dyn_dtree,e.d_desc.max_code),Tn(e,e.bl_desc),t=Vi-1;t>=3&&0===e.bl_tree[2*sn[t]+1];t--);return e.opt_len+=3*(t+1)+5+5+4,t}(e),n=e.opt_len+3+7>>>3,(s=e.static_len+3+7>>>3)<=n&&(n=s)):n=s=r+5,r+4<=n&&-1!==t?Ln(e,t,r,i):e.strategy===Ii||s===n?(bn(e,(ji<<1)+(i?1:0),3),An(e,on,an)):(bn(e,(Ni<<1)+(i?1:0),3),function(e,t,r,i){var n;for(bn(e,t-257,5),bn(e,r-1,5),bn(e,i-4,4),n=0;n<i;n++)bn(e,e.bl_tree[2*sn[n]+1],3);On(e,e.dyn_ltree,t-1),On(e,e.dyn_dtree,r-1);}(e,e.l_desc.max_code+1,e.d_desc.max_code+1,o+1),An(e,e.dyn_ltree,e.dyn_dtree)),Sn(e),i&&xn(e);},_tr_tally:function(e,t,r){return e.pending_buf[e.d_buf+2*e.last_lit]=t>>>8&255,e.pending_buf[e.d_buf+2*e.last_lit+1]=255&t,e.pending_buf[e.l_buf+e.last_lit]=255&r,e.last_lit++,0===t?e.dyn_ltree[2*r]++:(e.matches++,t--,e.dyn_ltree[2*(un[r]+Wi+1)]++,e.dyn_dtree[2*_n(t)]++),e.last_lit===e.lit_bufsize-1},_tr_align:function(e){bn(e,ji<<1,3),vn(e,Ji,on),function(e){16===e.bi_valid?(yn(e,e.bi_buf),e.bi_buf=0,e.bi_valid=0):e.bi_valid>=8&&(e.pending_buf[e.pending++]=255&e.bi_buf,e.bi_buf>>=8,e.bi_valid-=8);}(e);}};var In=function(e,t,r,i){for(var n=65535&e|0,s=e>>>16&65535|0,o=0;0!==r;){r-=o=r>2e3?2e3:r;do{s=s+(n=n+t[i++]|0)|0;}while(--o);n%=65521,s%=65521;}return n|s<<16|0};var Fn=function(){for(var e,t=[],r=0;r<256;r++){e=r;for(var i=0;i<8;i++)e=1&e?3988292384^e>>>1:e>>>1;t[r]=e;}return t}();var Pn,Mn=function(e,t,r,i){var n=Fn,s=i+r;e^=-1;for(var o=i;o<s;o++)e=e>>>8^n[255&(e^t[o])];return -1^e},Un={2:"need dictionary",1:"stream end",0:"","-1":"file error","-2":"stream error","-3":"data error","-4":"insufficient memory","-5":"buffer error","-6":"incompatible version"},Dn=0,jn=1,Nn=3,Zn=4,Wn=5,qn=0,Yn=1,Vn=-2,Hn=-3,Gn=-5,$n=-1,Kn=1,Jn=2,Xn=3,Qn=4,es=0,ts=2,rs=8,is=9,ns=15,ss=8,os=286,as=30,ls=19,us=2*os+1,hs=15,cs=3,fs=258,ds=fs+cs+1,ps=32,gs=42,ms=69,_s=73,ys=91,bs=103,vs=113,ws=666,ks=1,Ss=2,xs=3,Cs=4,Es=3;function As(e,t){return e.msg=Un[t],t}function Ts(e){return (e<<1)-(e>4?9:0)}function zs(e){for(var t=e.length;--t>=0;)e[t]=0;}function Os(e){var t=e.state,r=t.pending;r>e.avail_out&&(r=e.avail_out),0!==r&&(Bi.arraySet(e.output,t.pending_buf,t.pending_out,r,e.next_out),e.next_out+=r,t.pending_out+=r,e.total_out+=r,e.avail_out-=r,t.pending-=r,0===t.pending&&(t.pending_out=0));}function Rs(e,t){Bn._tr_flush_block(e,e.block_start>=0?e.block_start:-1,e.strstart-e.block_start,t),e.block_start=e.strstart,Os(e.strm);}function Ls(e,t){e.pending_buf[e.pending++]=t;}function Bs(e,t){e.pending_buf[e.pending++]=t>>>8&255,e.pending_buf[e.pending++]=255&t;}function Is(e,t){var r,i,n=e.max_chain_length,s=e.strstart,o=e.prev_length,a=e.nice_match,l=e.strstart>e.w_size-ds?e.strstart-(e.w_size-ds):0,u=e.window,h=e.w_mask,c=e.prev,f=e.strstart+fs,d=u[s+o-1],p=u[s+o];e.prev_length>=e.good_match&&(n>>=2),a>e.lookahead&&(a=e.lookahead);do{if(u[(r=t)+o]===p&&u[r+o-1]===d&&u[r]===u[s]&&u[++r]===u[s+1]){s+=2,r++;do{}while(u[++s]===u[++r]&&u[++s]===u[++r]&&u[++s]===u[++r]&&u[++s]===u[++r]&&u[++s]===u[++r]&&u[++s]===u[++r]&&u[++s]===u[++r]&&u[++s]===u[++r]&&s<f);if(i=fs-(f-s),s=f-fs,i>o){if(e.match_start=t,o=i,i>=a)break;d=u[s+o-1],p=u[s+o];}}}while((t=c[t&h])>l&&0!=--n);return o<=e.lookahead?o:e.lookahead}function Fs(e){var t,r,i,n,s,o,a,l,u,h,c=e.w_size;do{if(n=e.window_size-e.lookahead-e.strstart,e.strstart>=c+(c-ds)){Bi.arraySet(e.window,e.window,c,c,0),e.match_start-=c,e.strstart-=c,e.block_start-=c,t=r=e.hash_size;do{i=e.head[--t],e.head[t]=i>=c?i-c:0;}while(--r);t=r=c;do{i=e.prev[--t],e.prev[t]=i>=c?i-c:0;}while(--r);n+=c;}if(0===e.strm.avail_in)break;if(o=e.strm,a=e.window,l=e.strstart+e.lookahead,u=n,h=void 0,(h=o.avail_in)>u&&(h=u),r=0===h?0:(o.avail_in-=h,Bi.arraySet(a,o.input,o.next_in,h,l),1===o.state.wrap?o.adler=In(o.adler,a,h,l):2===o.state.wrap&&(o.adler=Mn(o.adler,a,h,l)),o.next_in+=h,o.total_in+=h,h),e.lookahead+=r,e.lookahead+e.insert>=cs)for(s=e.strstart-e.insert,e.ins_h=e.window[s],e.ins_h=(e.ins_h<<e.hash_shift^e.window[s+1])&e.hash_mask;e.insert&&(e.ins_h=(e.ins_h<<e.hash_shift^e.window[s+cs-1])&e.hash_mask,e.prev[s&e.w_mask]=e.head[e.ins_h],e.head[e.ins_h]=s,s++,e.insert--,!(e.lookahead+e.insert<cs)););}while(e.lookahead<ds&&0!==e.strm.avail_in)}function Ps(e,t){for(var r,i;;){if(e.lookahead<ds){if(Fs(e),e.lookahead<ds&&t===Dn)return ks;if(0===e.lookahead)break}if(r=0,e.lookahead>=cs&&(e.ins_h=(e.ins_h<<e.hash_shift^e.window[e.strstart+cs-1])&e.hash_mask,r=e.prev[e.strstart&e.w_mask]=e.head[e.ins_h],e.head[e.ins_h]=e.strstart),0!==r&&e.strstart-r<=e.w_size-ds&&(e.match_length=Is(e,r)),e.match_length>=cs)if(i=Bn._tr_tally(e,e.strstart-e.match_start,e.match_length-cs),e.lookahead-=e.match_length,e.match_length<=e.max_lazy_match&&e.lookahead>=cs){e.match_length--;do{e.strstart++,e.ins_h=(e.ins_h<<e.hash_shift^e.window[e.strstart+cs-1])&e.hash_mask,r=e.prev[e.strstart&e.w_mask]=e.head[e.ins_h],e.head[e.ins_h]=e.strstart;}while(0!=--e.match_length);e.strstart++;}else e.strstart+=e.match_length,e.match_length=0,e.ins_h=e.window[e.strstart],e.ins_h=(e.ins_h<<e.hash_shift^e.window[e.strstart+1])&e.hash_mask;else i=Bn._tr_tally(e,0,e.window[e.strstart]),e.lookahead--,e.strstart++;if(i&&(Rs(e,!1),0===e.strm.avail_out))return ks}return e.insert=e.strstart<cs-1?e.strstart:cs-1,t===Zn?(Rs(e,!0),0===e.strm.avail_out?xs:Cs):e.last_lit&&(Rs(e,!1),0===e.strm.avail_out)?ks:Ss}function Ms(e,t){for(var r,i,n;;){if(e.lookahead<ds){if(Fs(e),e.lookahead<ds&&t===Dn)return ks;if(0===e.lookahead)break}if(r=0,e.lookahead>=cs&&(e.ins_h=(e.ins_h<<e.hash_shift^e.window[e.strstart+cs-1])&e.hash_mask,r=e.prev[e.strstart&e.w_mask]=e.head[e.ins_h],e.head[e.ins_h]=e.strstart),e.prev_length=e.match_length,e.prev_match=e.match_start,e.match_length=cs-1,0!==r&&e.prev_length<e.max_lazy_match&&e.strstart-r<=e.w_size-ds&&(e.match_length=Is(e,r),e.match_length<=5&&(e.strategy===Kn||e.match_length===cs&&e.strstart-e.match_start>4096)&&(e.match_length=cs-1)),e.prev_length>=cs&&e.match_length<=e.prev_length){n=e.strstart+e.lookahead-cs,i=Bn._tr_tally(e,e.strstart-1-e.prev_match,e.prev_length-cs),e.lookahead-=e.prev_length-1,e.prev_length-=2;do{++e.strstart<=n&&(e.ins_h=(e.ins_h<<e.hash_shift^e.window[e.strstart+cs-1])&e.hash_mask,r=e.prev[e.strstart&e.w_mask]=e.head[e.ins_h],e.head[e.ins_h]=e.strstart);}while(0!=--e.prev_length);if(e.match_available=0,e.match_length=cs-1,e.strstart++,i&&(Rs(e,!1),0===e.strm.avail_out))return ks}else if(e.match_available){if((i=Bn._tr_tally(e,0,e.window[e.strstart-1]))&&Rs(e,!1),e.strstart++,e.lookahead--,0===e.strm.avail_out)return ks}else e.match_available=1,e.strstart++,e.lookahead--;}return e.match_available&&(i=Bn._tr_tally(e,0,e.window[e.strstart-1]),e.match_available=0),e.insert=e.strstart<cs-1?e.strstart:cs-1,t===Zn?(Rs(e,!0),0===e.strm.avail_out?xs:Cs):e.last_lit&&(Rs(e,!1),0===e.strm.avail_out)?ks:Ss}function Us(e,t,r,i,n){this.good_length=e,this.max_lazy=t,this.nice_length=r,this.max_chain=i,this.func=n;}function Ds(){this.strm=null,this.status=0,this.pending_buf=null,this.pending_buf_size=0,this.pending_out=0,this.pending=0,this.wrap=0,this.gzhead=null,this.gzindex=0,this.method=rs,this.last_flush=-1,this.w_size=0,this.w_bits=0,this.w_mask=0,this.window=null,this.window_size=0,this.prev=null,this.head=null,this.ins_h=0,this.hash_size=0,this.hash_bits=0,this.hash_mask=0,this.hash_shift=0,this.block_start=0,this.match_length=0,this.prev_match=0,this.match_available=0,this.strstart=0,this.match_start=0,this.lookahead=0,this.prev_length=0,this.max_chain_length=0,this.max_lazy_match=0,this.level=0,this.strategy=0,this.good_match=0,this.nice_match=0,this.dyn_ltree=new Bi.Buf16(2*us),this.dyn_dtree=new Bi.Buf16(2*(2*as+1)),this.bl_tree=new Bi.Buf16(2*(2*ls+1)),zs(this.dyn_ltree),zs(this.dyn_dtree),zs(this.bl_tree),this.l_desc=null,this.d_desc=null,this.bl_desc=null,this.bl_count=new Bi.Buf16(hs+1),this.heap=new Bi.Buf16(2*os+1),zs(this.heap),this.heap_len=0,this.heap_max=0,this.depth=new Bi.Buf16(2*os+1),zs(this.depth),this.l_buf=0,this.lit_bufsize=0,this.last_lit=0,this.d_buf=0,this.opt_len=0,this.static_len=0,this.matches=0,this.insert=0,this.bi_buf=0,this.bi_valid=0;}function js(e){var t;return e&&e.state?(e.total_in=e.total_out=0,e.data_type=ts,(t=e.state).pending=0,t.pending_out=0,t.wrap<0&&(t.wrap=-t.wrap),t.status=t.wrap?gs:vs,e.adler=2===t.wrap?0:1,t.last_flush=Dn,Bn._tr_init(t),qn):As(e,Vn)}function Ns(e){var t,r=js(e);return r===qn&&((t=e.state).window_size=2*t.w_size,zs(t.head),t.max_lazy_match=Pn[t.level].max_lazy,t.good_match=Pn[t.level].good_length,t.nice_match=Pn[t.level].nice_length,t.max_chain_length=Pn[t.level].max_chain,t.strstart=0,t.block_start=0,t.lookahead=0,t.insert=0,t.match_length=t.prev_length=cs-1,t.match_available=0,t.ins_h=0),r}function Zs(e,t,r,i,n,s){if(!e)return Vn;var o=1;if(t===$n&&(t=6),i<0?(o=0,i=-i):i>15&&(o=2,i-=16),n<1||n>is||r!==rs||i<8||i>15||t<0||t>9||s<0||s>Qn)return As(e,Vn);8===i&&(i=9);var a=new Ds;return e.state=a,a.strm=e,a.wrap=o,a.gzhead=null,a.w_bits=i,a.w_size=1<<a.w_bits,a.w_mask=a.w_size-1,a.hash_bits=n+7,a.hash_size=1<<a.hash_bits,a.hash_mask=a.hash_size-1,a.hash_shift=~~((a.hash_bits+cs-1)/cs),a.window=new Bi.Buf8(2*a.w_size),a.head=new Bi.Buf16(a.hash_size),a.prev=new Bi.Buf16(a.w_size),a.lit_bufsize=1<<n+6,a.pending_buf_size=4*a.lit_bufsize,a.pending_buf=new Bi.Buf8(a.pending_buf_size),a.d_buf=1*a.lit_bufsize,a.l_buf=3*a.lit_bufsize,a.level=t,a.strategy=s,a.method=r,Ns(e)}Pn=[new Us(0,0,0,0,function(e,t){var r=65535;for(r>e.pending_buf_size-5&&(r=e.pending_buf_size-5);;){if(e.lookahead<=1){if(Fs(e),0===e.lookahead&&t===Dn)return ks;if(0===e.lookahead)break}e.strstart+=e.lookahead,e.lookahead=0;var i=e.block_start+r;if((0===e.strstart||e.strstart>=i)&&(e.lookahead=e.strstart-i,e.strstart=i,Rs(e,!1),0===e.strm.avail_out))return ks;if(e.strstart-e.block_start>=e.w_size-ds&&(Rs(e,!1),0===e.strm.avail_out))return ks}return e.insert=0,t===Zn?(Rs(e,!0),0===e.strm.avail_out?xs:Cs):(e.strstart>e.block_start&&(Rs(e,!1),e.strm.avail_out),ks)}),new Us(4,4,8,4,Ps),new Us(4,5,16,8,Ps),new Us(4,6,32,32,Ps),new Us(4,4,16,16,Ms),new Us(8,16,32,32,Ms),new Us(8,16,128,128,Ms),new Us(8,32,128,256,Ms),new Us(32,128,258,1024,Ms),new Us(32,258,258,4096,Ms)];var Ws={deflateInit:function(e,t){return Zs(e,t,rs,ns,ss,es)},deflateInit2:Zs,deflateReset:Ns,deflateResetKeep:js,deflateSetHeader:function(e,t){return e&&e.state?2!==e.state.wrap?Vn:(e.state.gzhead=t,qn):Vn},deflate:function(e,t){var r,i,n,s;if(!e||!e.state||t>Wn||t<0)return e?As(e,Vn):Vn;if(i=e.state,!e.output||!e.input&&0!==e.avail_in||i.status===ws&&t!==Zn)return As(e,0===e.avail_out?Gn:Vn);if(i.strm=e,r=i.last_flush,i.last_flush=t,i.status===gs)if(2===i.wrap)e.adler=0,Ls(i,31),Ls(i,139),Ls(i,8),i.gzhead?(Ls(i,(i.gzhead.text?1:0)+(i.gzhead.hcrc?2:0)+(i.gzhead.extra?4:0)+(i.gzhead.name?8:0)+(i.gzhead.comment?16:0)),Ls(i,255&i.gzhead.time),Ls(i,i.gzhead.time>>8&255),Ls(i,i.gzhead.time>>16&255),Ls(i,i.gzhead.time>>24&255),Ls(i,9===i.level?2:i.strategy>=Jn||i.level<2?4:0),Ls(i,255&i.gzhead.os),i.gzhead.extra&&i.gzhead.extra.length&&(Ls(i,255&i.gzhead.extra.length),Ls(i,i.gzhead.extra.length>>8&255)),i.gzhead.hcrc&&(e.adler=Mn(e.adler,i.pending_buf,i.pending,0)),i.gzindex=0,i.status=ms):(Ls(i,0),Ls(i,0),Ls(i,0),Ls(i,0),Ls(i,0),Ls(i,9===i.level?2:i.strategy>=Jn||i.level<2?4:0),Ls(i,Es),i.status=vs);else {var o=rs+(i.w_bits-8<<4)<<8;o|=(i.strategy>=Jn||i.level<2?0:i.level<6?1:6===i.level?2:3)<<6,0!==i.strstart&&(o|=ps),o+=31-o%31,i.status=vs,Bs(i,o),0!==i.strstart&&(Bs(i,e.adler>>>16),Bs(i,65535&e.adler)),e.adler=1;}if(i.status===ms)if(i.gzhead.extra){for(n=i.pending;i.gzindex<(65535&i.gzhead.extra.length)&&(i.pending!==i.pending_buf_size||(i.gzhead.hcrc&&i.pending>n&&(e.adler=Mn(e.adler,i.pending_buf,i.pending-n,n)),Os(e),n=i.pending,i.pending!==i.pending_buf_size));)Ls(i,255&i.gzhead.extra[i.gzindex]),i.gzindex++;i.gzhead.hcrc&&i.pending>n&&(e.adler=Mn(e.adler,i.pending_buf,i.pending-n,n)),i.gzindex===i.gzhead.extra.length&&(i.gzindex=0,i.status=_s);}else i.status=_s;if(i.status===_s)if(i.gzhead.name){n=i.pending;do{if(i.pending===i.pending_buf_size&&(i.gzhead.hcrc&&i.pending>n&&(e.adler=Mn(e.adler,i.pending_buf,i.pending-n,n)),Os(e),n=i.pending,i.pending===i.pending_buf_size)){s=1;break}s=i.gzindex<i.gzhead.name.length?255&i.gzhead.name.charCodeAt(i.gzindex++):0,Ls(i,s);}while(0!==s);i.gzhead.hcrc&&i.pending>n&&(e.adler=Mn(e.adler,i.pending_buf,i.pending-n,n)),0===s&&(i.gzindex=0,i.status=ys);}else i.status=ys;if(i.status===ys)if(i.gzhead.comment){n=i.pending;do{if(i.pending===i.pending_buf_size&&(i.gzhead.hcrc&&i.pending>n&&(e.adler=Mn(e.adler,i.pending_buf,i.pending-n,n)),Os(e),n=i.pending,i.pending===i.pending_buf_size)){s=1;break}s=i.gzindex<i.gzhead.comment.length?255&i.gzhead.comment.charCodeAt(i.gzindex++):0,Ls(i,s);}while(0!==s);i.gzhead.hcrc&&i.pending>n&&(e.adler=Mn(e.adler,i.pending_buf,i.pending-n,n)),0===s&&(i.status=bs);}else i.status=bs;if(i.status===bs&&(i.gzhead.hcrc?(i.pending+2>i.pending_buf_size&&Os(e),i.pending+2<=i.pending_buf_size&&(Ls(i,255&e.adler),Ls(i,e.adler>>8&255),e.adler=0,i.status=vs)):i.status=vs),0!==i.pending){if(Os(e),0===e.avail_out)return i.last_flush=-1,qn}else if(0===e.avail_in&&Ts(t)<=Ts(r)&&t!==Zn)return As(e,Gn);if(i.status===ws&&0!==e.avail_in)return As(e,Gn);if(0!==e.avail_in||0!==i.lookahead||t!==Dn&&i.status!==ws){var a=i.strategy===Jn?function(e,t){for(var r;;){if(0===e.lookahead&&(Fs(e),0===e.lookahead)){if(t===Dn)return ks;break}if(e.match_length=0,r=Bn._tr_tally(e,0,e.window[e.strstart]),e.lookahead--,e.strstart++,r&&(Rs(e,!1),0===e.strm.avail_out))return ks}return e.insert=0,t===Zn?(Rs(e,!0),0===e.strm.avail_out?xs:Cs):e.last_lit&&(Rs(e,!1),0===e.strm.avail_out)?ks:Ss}(i,t):i.strategy===Xn?function(e,t){for(var r,i,n,s,o=e.window;;){if(e.lookahead<=fs){if(Fs(e),e.lookahead<=fs&&t===Dn)return ks;if(0===e.lookahead)break}if(e.match_length=0,e.lookahead>=cs&&e.strstart>0&&(i=o[n=e.strstart-1])===o[++n]&&i===o[++n]&&i===o[++n]){s=e.strstart+fs;do{}while(i===o[++n]&&i===o[++n]&&i===o[++n]&&i===o[++n]&&i===o[++n]&&i===o[++n]&&i===o[++n]&&i===o[++n]&&n<s);e.match_length=fs-(s-n),e.match_length>e.lookahead&&(e.match_length=e.lookahead);}if(e.match_length>=cs?(r=Bn._tr_tally(e,1,e.match_length-cs),e.lookahead-=e.match_length,e.strstart+=e.match_length,e.match_length=0):(r=Bn._tr_tally(e,0,e.window[e.strstart]),e.lookahead--,e.strstart++),r&&(Rs(e,!1),0===e.strm.avail_out))return ks}return e.insert=0,t===Zn?(Rs(e,!0),0===e.strm.avail_out?xs:Cs):e.last_lit&&(Rs(e,!1),0===e.strm.avail_out)?ks:Ss}(i,t):Pn[i.level].func(i,t);if(a!==xs&&a!==Cs||(i.status=ws),a===ks||a===xs)return 0===e.avail_out&&(i.last_flush=-1),qn;if(a===Ss&&(t===jn?Bn._tr_align(i):t!==Wn&&(Bn._tr_stored_block(i,0,0,!1),t===Nn&&(zs(i.head),0===i.lookahead&&(i.strstart=0,i.block_start=0,i.insert=0))),Os(e),0===e.avail_out))return i.last_flush=-1,qn}return t!==Zn?qn:i.wrap<=0?Yn:(2===i.wrap?(Ls(i,255&e.adler),Ls(i,e.adler>>8&255),Ls(i,e.adler>>16&255),Ls(i,e.adler>>24&255),Ls(i,255&e.total_in),Ls(i,e.total_in>>8&255),Ls(i,e.total_in>>16&255),Ls(i,e.total_in>>24&255)):(Bs(i,e.adler>>>16),Bs(i,65535&e.adler)),Os(e),i.wrap>0&&(i.wrap=-i.wrap),0!==i.pending?qn:Yn)},deflateEnd:function(e){var t;return e&&e.state?(t=e.state.status)!==gs&&t!==ms&&t!==_s&&t!==ys&&t!==bs&&t!==vs&&t!==ws?As(e,Vn):(e.state=null,t===vs?As(e,Hn):qn):Vn},deflateSetDictionary:function(e,t){var r,i,n,s,o,a,l,u,h=t.length;if(!e||!e.state)return Vn;if(2===(s=(r=e.state).wrap)||1===s&&r.status!==gs||r.lookahead)return Vn;for(1===s&&(e.adler=In(e.adler,t,h,0)),r.wrap=0,h>=r.w_size&&(0===s&&(zs(r.head),r.strstart=0,r.block_start=0,r.insert=0),u=new Bi.Buf8(r.w_size),Bi.arraySet(u,t,h-r.w_size,r.w_size,0),t=u,h=r.w_size),o=e.avail_in,a=e.next_in,l=e.input,e.avail_in=h,e.next_in=0,e.input=t,Fs(r);r.lookahead>=cs;){i=r.strstart,n=r.lookahead-(cs-1);do{r.ins_h=(r.ins_h<<r.hash_shift^r.window[i+cs-1])&r.hash_mask,r.prev[i&r.w_mask]=r.head[r.ins_h],r.head[r.ins_h]=i,i++;}while(--n);r.strstart=i,r.lookahead=cs-1,Fs(r);}return r.strstart+=r.lookahead,r.block_start=r.strstart,r.insert=r.lookahead,r.lookahead=0,r.match_length=r.prev_length=cs-1,r.match_available=0,e.next_in=a,e.input=l,e.avail_in=o,r.wrap=s,qn},deflateInfo:"pako deflate (from Nodeca project)"},qs=!0,Ys=!0;try{String.fromCharCode.apply(null,[0]);}catch(e){qs=!1;}try{String.fromCharCode.apply(null,new Uint8Array(1));}catch(e){Ys=!1;}for(var Vs=new Bi.Buf8(256),Hs=0;Hs<256;Hs++)Vs[Hs]=Hs>=252?6:Hs>=248?5:Hs>=240?4:Hs>=224?3:Hs>=192?2:1;Vs[254]=Vs[254]=1;function Gs(e,t){if(t<65537&&(e.subarray&&Ys||!e.subarray&&qs))return String.fromCharCode.apply(null,Bi.shrinkBuf(e,t));for(var r="",i=0;i<t;i++)r+=String.fromCharCode(e[i]);return r}var $s={string2buf:function(e){var t,r,i,n,s,o=e.length,a=0;for(n=0;n<o;n++)55296==(64512&(r=e.charCodeAt(n)))&&n+1<o&&56320==(64512&(i=e.charCodeAt(n+1)))&&(r=65536+(r-55296<<10)+(i-56320),n++),a+=r<128?1:r<2048?2:r<65536?3:4;for(t=new Bi.Buf8(a),s=0,n=0;s<a;n++)55296==(64512&(r=e.charCodeAt(n)))&&n+1<o&&56320==(64512&(i=e.charCodeAt(n+1)))&&(r=65536+(r-55296<<10)+(i-56320),n++),r<128?t[s++]=r:r<2048?(t[s++]=192|r>>>6,t[s++]=128|63&r):r<65536?(t[s++]=224|r>>>12,t[s++]=128|r>>>6&63,t[s++]=128|63&r):(t[s++]=240|r>>>18,t[s++]=128|r>>>12&63,t[s++]=128|r>>>6&63,t[s++]=128|63&r);return t},buf2binstring:function(e){return Gs(e,e.length)},binstring2buf:function(e){for(var t=new Bi.Buf8(e.length),r=0,i=t.length;r<i;r++)t[r]=e.charCodeAt(r);return t},buf2string:function(e,t){var r,i,n,s,o=t||e.length,a=new Array(2*o);for(i=0,r=0;r<o;)if((n=e[r++])<128)a[i++]=n;else if((s=Vs[n])>4)a[i++]=65533,r+=s-1;else {for(n&=2===s?31:3===s?15:7;s>1&&r<o;)n=n<<6|63&e[r++],s--;s>1?a[i++]=65533:n<65536?a[i++]=n:(n-=65536,a[i++]=55296|n>>10&1023,a[i++]=56320|1023&n);}return Gs(a,i)},utf8border:function(e,t){var r;for((t=t||e.length)>e.length&&(t=e.length),r=t-1;r>=0&&128==(192&e[r]);)r--;return r<0?t:0===r?t:r+Vs[e[r]]>t?r:t}};var Ks=function(){this.input=null,this.next_in=0,this.avail_in=0,this.total_in=0,this.output=null,this.next_out=0,this.avail_out=0,this.total_out=0,this.msg="",this.state=null,this.data_type=2,this.adler=0;},Js=Object.prototype.toString,Xs=0,Qs=-1,eo=0,to=8;function ro(e){if(!(this instanceof ro))return new ro(e);this.options=Bi.assign({level:Qs,method:to,chunkSize:16384,windowBits:15,memLevel:8,strategy:eo,to:""},e||{});var t=this.options;t.raw&&t.windowBits>0?t.windowBits=-t.windowBits:t.gzip&&t.windowBits>0&&t.windowBits<16&&(t.windowBits+=16),this.err=0,this.msg="",this.ended=!1,this.chunks=[],this.strm=new Ks,this.strm.avail_out=0;var r=Ws.deflateInit2(this.strm,t.level,t.method,t.windowBits,t.memLevel,t.strategy);if(r!==Xs)throw new Error(Un[r]);if(t.header&&Ws.deflateSetHeader(this.strm,t.header),t.dictionary){var i;if(i="string"==typeof t.dictionary?$s.string2buf(t.dictionary):"[object ArrayBuffer]"===Js.call(t.dictionary)?new Uint8Array(t.dictionary):t.dictionary,(r=Ws.deflateSetDictionary(this.strm,i))!==Xs)throw new Error(Un[r]);this._dict_set=!0;}}function io(e,t){var r=new ro(t);if(r.push(e,!0),r.err)throw r.msg||Un[r.err];return r.result}ro.prototype.push=function(e,t){var r,i,n=this.strm,s=this.options.chunkSize;if(this.ended)return !1;i=t===~~t?t:!0===t?4:0,"string"==typeof e?n.input=$s.string2buf(e):"[object ArrayBuffer]"===Js.call(e)?n.input=new Uint8Array(e):n.input=e,n.next_in=0,n.avail_in=n.input.length;do{if(0===n.avail_out&&(n.output=new Bi.Buf8(s),n.next_out=0,n.avail_out=s),1!==(r=Ws.deflate(n,i))&&r!==Xs)return this.onEnd(r),this.ended=!0,!1;0!==n.avail_out&&(0!==n.avail_in||4!==i&&2!==i)||("string"===this.options.to?this.onData($s.buf2binstring(Bi.shrinkBuf(n.output,n.next_out))):this.onData(Bi.shrinkBuf(n.output,n.next_out)));}while((n.avail_in>0||0===n.avail_out)&&1!==r);return 4===i?(r=Ws.deflateEnd(this.strm),this.onEnd(r),this.ended=!0,r===Xs):2!==i||(this.onEnd(Xs),n.avail_out=0,!0)},ro.prototype.onData=function(e){this.chunks.push(e);},ro.prototype.onEnd=function(e){e===Xs&&("string"===this.options.to?this.result=this.chunks.join(""):this.result=Bi.flattenChunks(this.chunks)),this.chunks=[],this.err=e,this.msg=this.strm.msg;};var no={Deflate:ro,deflate:io,deflateRaw:function(e,t){return (t=t||{}).raw=!0,io(e,t)},gzip:function(e,t){return (t=t||{}).gzip=!0,io(e,t)}},so=function(e,t){var r,i,n,s,o,a,l,u,h,c,f,d,p,g,m,_,y,b,v,w,k,S,x,C,E;r=e.state,i=e.next_in,C=e.input,n=i+(e.avail_in-5),s=e.next_out,E=e.output,o=s-(t-e.avail_out),a=s+(e.avail_out-257),l=r.dmax,u=r.wsize,h=r.whave,c=r.wnext,f=r.window,d=r.hold,p=r.bits,g=r.lencode,m=r.distcode,_=(1<<r.lenbits)-1,y=(1<<r.distbits)-1;e:do{p<15&&(d+=C[i++]<<p,p+=8,d+=C[i++]<<p,p+=8),b=g[d&_];t:for(;;){if(d>>>=v=b>>>24,p-=v,0===(v=b>>>16&255))E[s++]=65535&b;else {if(!(16&v)){if(0==(64&v)){b=g[(65535&b)+(d&(1<<v)-1)];continue t}if(32&v){r.mode=12;break e}e.msg="invalid literal/length code",r.mode=30;break e}w=65535&b,(v&=15)&&(p<v&&(d+=C[i++]<<p,p+=8),w+=d&(1<<v)-1,d>>>=v,p-=v),p<15&&(d+=C[i++]<<p,p+=8,d+=C[i++]<<p,p+=8),b=m[d&y];r:for(;;){if(d>>>=v=b>>>24,p-=v,!(16&(v=b>>>16&255))){if(0==(64&v)){b=m[(65535&b)+(d&(1<<v)-1)];continue r}e.msg="invalid distance code",r.mode=30;break e}if(k=65535&b,p<(v&=15)&&(d+=C[i++]<<p,(p+=8)<v&&(d+=C[i++]<<p,p+=8)),(k+=d&(1<<v)-1)>l){e.msg="invalid distance too far back",r.mode=30;break e}if(d>>>=v,p-=v,k>(v=s-o)){if((v=k-v)>h&&r.sane){e.msg="invalid distance too far back",r.mode=30;break e}if(S=0,x=f,0===c){if(S+=u-v,v<w){w-=v;do{E[s++]=f[S++];}while(--v);S=s-k,x=E;}}else if(c<v){if(S+=u+c-v,(v-=c)<w){w-=v;do{E[s++]=f[S++];}while(--v);if(S=0,c<w){w-=v=c;do{E[s++]=f[S++];}while(--v);S=s-k,x=E;}}}else if(S+=c-v,v<w){w-=v;do{E[s++]=f[S++];}while(--v);S=s-k,x=E;}for(;w>2;)E[s++]=x[S++],E[s++]=x[S++],E[s++]=x[S++],w-=3;w&&(E[s++]=x[S++],w>1&&(E[s++]=x[S++]));}else {S=s-k;do{E[s++]=E[S++],E[s++]=E[S++],E[s++]=E[S++],w-=3;}while(w>2);w&&(E[s++]=E[S++],w>1&&(E[s++]=E[S++]));}break}}break}}while(i<n&&s<a);i-=w=p>>3,d&=(1<<(p-=w<<3))-1,e.next_in=i,e.next_out=s,e.avail_in=i<n?n-i+5:5-(i-n),e.avail_out=s<a?a-s+257:257-(s-a),r.hold=d,r.bits=p;},oo=[3,4,5,6,7,8,9,10,11,13,15,17,19,23,27,31,35,43,51,59,67,83,99,115,131,163,195,227,258,0,0],ao=[16,16,16,16,16,16,16,16,17,17,17,17,18,18,18,18,19,19,19,19,20,20,20,20,21,21,21,21,16,72,78],lo=[1,2,3,4,5,7,9,13,17,25,33,49,65,97,129,193,257,385,513,769,1025,1537,2049,3073,4097,6145,8193,12289,16385,24577,0,0],uo=[16,16,16,16,17,17,18,18,19,19,20,20,21,21,22,22,23,23,24,24,25,25,26,26,27,27,28,28,29,29,64,64],ho=function(e,t,r,i,n,s,o,a){var l,u,h,c,f,d,p,g,m,_=a.bits,y=0,b=0,v=0,w=0,k=0,S=0,x=0,C=0,E=0,A=0,T=null,z=0,O=new Bi.Buf16(16),R=new Bi.Buf16(16),L=null,B=0;for(y=0;y<=15;y++)O[y]=0;for(b=0;b<i;b++)O[t[r+b]]++;for(k=_,w=15;w>=1&&0===O[w];w--);if(k>w&&(k=w),0===w)return n[s++]=20971520,n[s++]=20971520,a.bits=1,0;for(v=1;v<w&&0===O[v];v++);for(k<v&&(k=v),C=1,y=1;y<=15;y++)if(C<<=1,(C-=O[y])<0)return -1;if(C>0&&(0===e||1!==w))return -1;for(R[1]=0,y=1;y<15;y++)R[y+1]=R[y]+O[y];for(b=0;b<i;b++)0!==t[r+b]&&(o[R[t[r+b]]++]=b);if(0===e?(T=L=o,d=19):1===e?(T=oo,z-=257,L=ao,B-=257,d=256):(T=lo,L=uo,d=-1),A=0,b=0,y=v,f=s,S=k,x=0,h=-1,c=(E=1<<k)-1,1===e&&E>852||2===e&&E>592)return 1;for(;;){p=y-x,o[b]<d?(g=0,m=o[b]):o[b]>d?(g=L[B+o[b]],m=T[z+o[b]]):(g=96,m=0),l=1<<y-x,v=u=1<<S;do{n[f+(A>>x)+(u-=l)]=p<<24|g<<16|m|0;}while(0!==u);for(l=1<<y-1;A&l;)l>>=1;if(0!==l?(A&=l-1,A+=l):A=0,b++,0==--O[y]){if(y===w)break;y=t[r+o[b]];}if(y>k&&(A&c)!==h){for(0===x&&(x=k),f+=v,C=1<<(S=y-x);S+x<w&&!((C-=O[S+x])<=0);)S++,C<<=1;if(E+=1<<S,1===e&&E>852||2===e&&E>592)return 1;n[h=A&c]=k<<24|S<<16|f-s|0;}}return 0!==A&&(n[f+A]=y-x<<24|64<<16|0),a.bits=k,0},co=0,fo=1,po=2,go=4,mo=5,_o=6,yo=0,bo=1,vo=2,wo=-2,ko=-3,So=-4,xo=-5,Co=8,Eo=1,Ao=2,To=3,zo=4,Oo=5,Ro=6,Lo=7,Bo=8,Io=9,Fo=10,Po=11,Mo=12,Uo=13,Do=14,jo=15,No=16,Zo=17,Wo=18,qo=19,Yo=20,Vo=21,Ho=22,Go=23,$o=24,Ko=25,Jo=26,Xo=27,Qo=28,ea=29,ta=30,ra=31,ia=32,na=852,sa=592,oa=15;function aa(e){return (e>>>24&255)+(e>>>8&65280)+((65280&e)<<8)+((255&e)<<24)}function la(){this.mode=0,this.last=!1,this.wrap=0,this.havedict=!1,this.flags=0,this.dmax=0,this.check=0,this.total=0,this.head=null,this.wbits=0,this.wsize=0,this.whave=0,this.wnext=0,this.window=null,this.hold=0,this.bits=0,this.length=0,this.offset=0,this.extra=0,this.lencode=null,this.distcode=null,this.lenbits=0,this.distbits=0,this.ncode=0,this.nlen=0,this.ndist=0,this.have=0,this.next=null,this.lens=new Bi.Buf16(320),this.work=new Bi.Buf16(288),this.lendyn=null,this.distdyn=null,this.sane=0,this.back=0,this.was=0;}function ua(e){var t;return e&&e.state?(t=e.state,e.total_in=e.total_out=t.total=0,e.msg="",t.wrap&&(e.adler=1&t.wrap),t.mode=Eo,t.last=0,t.havedict=0,t.dmax=32768,t.head=null,t.hold=0,t.bits=0,t.lencode=t.lendyn=new Bi.Buf32(na),t.distcode=t.distdyn=new Bi.Buf32(sa),t.sane=1,t.back=-1,yo):wo}function ha(e){var t;return e&&e.state?((t=e.state).wsize=0,t.whave=0,t.wnext=0,ua(e)):wo}function ca(e,t){var r,i;return e&&e.state?(i=e.state,t<0?(r=0,t=-t):(r=1+(t>>4),t<48&&(t&=15)),t&&(t<8||t>15)?wo:(null!==i.window&&i.wbits!==t&&(i.window=null),i.wrap=r,i.wbits=t,ha(e))):wo}function fa(e,t){var r,i;return e?(i=new la,e.state=i,i.window=null,(r=ca(e,t))!==yo&&(e.state=null),r):wo}var da,pa,ga=!0;function ma(e){if(ga){var t;for(da=new Bi.Buf32(512),pa=new Bi.Buf32(32),t=0;t<144;)e.lens[t++]=8;for(;t<256;)e.lens[t++]=9;for(;t<280;)e.lens[t++]=7;for(;t<288;)e.lens[t++]=8;for(ho(fo,e.lens,0,288,da,0,e.work,{bits:9}),t=0;t<32;)e.lens[t++]=5;ho(po,e.lens,0,32,pa,0,e.work,{bits:5}),ga=!1;}e.lencode=da,e.lenbits=9,e.distcode=pa,e.distbits=5;}function _a(e,t,r,i){var n,s=e.state;return null===s.window&&(s.wsize=1<<s.wbits,s.wnext=0,s.whave=0,s.window=new Bi.Buf8(s.wsize)),i>=s.wsize?(Bi.arraySet(s.window,t,r-s.wsize,s.wsize,0),s.wnext=0,s.whave=s.wsize):((n=s.wsize-s.wnext)>i&&(n=i),Bi.arraySet(s.window,t,r-i,n,s.wnext),(i-=n)?(Bi.arraySet(s.window,t,r-i,i,0),s.wnext=i,s.whave=s.wsize):(s.wnext+=n,s.wnext===s.wsize&&(s.wnext=0),s.whave<s.wsize&&(s.whave+=n))),0}var ya={inflateReset:ha,inflateReset2:ca,inflateResetKeep:ua,inflateInit:function(e){return fa(e,oa)},inflateInit2:fa,inflate:function(e,t){var r,i,n,s,o,a,l,u,h,c,f,d,p,g,m,_,y,b,v,w,k,S,x,C,E=0,A=new Bi.Buf8(4),T=[16,17,18,0,8,7,9,6,10,5,11,4,12,3,13,2,14,1,15];if(!e||!e.state||!e.output||!e.input&&0!==e.avail_in)return wo;(r=e.state).mode===Mo&&(r.mode=Uo),o=e.next_out,n=e.output,l=e.avail_out,s=e.next_in,i=e.input,a=e.avail_in,u=r.hold,h=r.bits,c=a,f=l,S=yo;e:for(;;)switch(r.mode){case Eo:if(0===r.wrap){r.mode=Uo;break}for(;h<16;){if(0===a)break e;a--,u+=i[s++]<<h,h+=8;}if(2&r.wrap&&35615===u){r.check=0,A[0]=255&u,A[1]=u>>>8&255,r.check=Mn(r.check,A,2,0),u=0,h=0,r.mode=Ao;break}if(r.flags=0,r.head&&(r.head.done=!1),!(1&r.wrap)||(((255&u)<<8)+(u>>8))%31){e.msg="incorrect header check",r.mode=ta;break}if((15&u)!==Co){e.msg="unknown compression method",r.mode=ta;break}if(h-=4,k=8+(15&(u>>>=4)),0===r.wbits)r.wbits=k;else if(k>r.wbits){e.msg="invalid window size",r.mode=ta;break}r.dmax=1<<k,e.adler=r.check=1,r.mode=512&u?Fo:Mo,u=0,h=0;break;case Ao:for(;h<16;){if(0===a)break e;a--,u+=i[s++]<<h,h+=8;}if(r.flags=u,(255&r.flags)!==Co){e.msg="unknown compression method",r.mode=ta;break}if(57344&r.flags){e.msg="unknown header flags set",r.mode=ta;break}r.head&&(r.head.text=u>>8&1),512&r.flags&&(A[0]=255&u,A[1]=u>>>8&255,r.check=Mn(r.check,A,2,0)),u=0,h=0,r.mode=To;case To:for(;h<32;){if(0===a)break e;a--,u+=i[s++]<<h,h+=8;}r.head&&(r.head.time=u),512&r.flags&&(A[0]=255&u,A[1]=u>>>8&255,A[2]=u>>>16&255,A[3]=u>>>24&255,r.check=Mn(r.check,A,4,0)),u=0,h=0,r.mode=zo;case zo:for(;h<16;){if(0===a)break e;a--,u+=i[s++]<<h,h+=8;}r.head&&(r.head.xflags=255&u,r.head.os=u>>8),512&r.flags&&(A[0]=255&u,A[1]=u>>>8&255,r.check=Mn(r.check,A,2,0)),u=0,h=0,r.mode=Oo;case Oo:if(1024&r.flags){for(;h<16;){if(0===a)break e;a--,u+=i[s++]<<h,h+=8;}r.length=u,r.head&&(r.head.extra_len=u),512&r.flags&&(A[0]=255&u,A[1]=u>>>8&255,r.check=Mn(r.check,A,2,0)),u=0,h=0;}else r.head&&(r.head.extra=null);r.mode=Ro;case Ro:if(1024&r.flags&&((d=r.length)>a&&(d=a),d&&(r.head&&(k=r.head.extra_len-r.length,r.head.extra||(r.head.extra=new Array(r.head.extra_len)),Bi.arraySet(r.head.extra,i,s,d,k)),512&r.flags&&(r.check=Mn(r.check,i,d,s)),a-=d,s+=d,r.length-=d),r.length))break e;r.length=0,r.mode=Lo;case Lo:if(2048&r.flags){if(0===a)break e;d=0;do{k=i[s+d++],r.head&&k&&r.length<65536&&(r.head.name+=String.fromCharCode(k));}while(k&&d<a);if(512&r.flags&&(r.check=Mn(r.check,i,d,s)),a-=d,s+=d,k)break e}else r.head&&(r.head.name=null);r.length=0,r.mode=Bo;case Bo:if(4096&r.flags){if(0===a)break e;d=0;do{k=i[s+d++],r.head&&k&&r.length<65536&&(r.head.comment+=String.fromCharCode(k));}while(k&&d<a);if(512&r.flags&&(r.check=Mn(r.check,i,d,s)),a-=d,s+=d,k)break e}else r.head&&(r.head.comment=null);r.mode=Io;case Io:if(512&r.flags){for(;h<16;){if(0===a)break e;a--,u+=i[s++]<<h,h+=8;}if(u!==(65535&r.check)){e.msg="header crc mismatch",r.mode=ta;break}u=0,h=0;}r.head&&(r.head.hcrc=r.flags>>9&1,r.head.done=!0),e.adler=r.check=0,r.mode=Mo;break;case Fo:for(;h<32;){if(0===a)break e;a--,u+=i[s++]<<h,h+=8;}e.adler=r.check=aa(u),u=0,h=0,r.mode=Po;case Po:if(0===r.havedict)return e.next_out=o,e.avail_out=l,e.next_in=s,e.avail_in=a,r.hold=u,r.bits=h,vo;e.adler=r.check=1,r.mode=Mo;case Mo:if(t===mo||t===_o)break e;case Uo:if(r.last){u>>>=7&h,h-=7&h,r.mode=Xo;break}for(;h<3;){if(0===a)break e;a--,u+=i[s++]<<h,h+=8;}switch(r.last=1&u,h-=1,3&(u>>>=1)){case 0:r.mode=Do;break;case 1:if(ma(r),r.mode=Yo,t===_o){u>>>=2,h-=2;break e}break;case 2:r.mode=Zo;break;case 3:e.msg="invalid block type",r.mode=ta;}u>>>=2,h-=2;break;case Do:for(u>>>=7&h,h-=7&h;h<32;){if(0===a)break e;a--,u+=i[s++]<<h,h+=8;}if((65535&u)!=(u>>>16^65535)){e.msg="invalid stored block lengths",r.mode=ta;break}if(r.length=65535&u,u=0,h=0,r.mode=jo,t===_o)break e;case jo:r.mode=No;case No:if(d=r.length){if(d>a&&(d=a),d>l&&(d=l),0===d)break e;Bi.arraySet(n,i,s,d,o),a-=d,s+=d,l-=d,o+=d,r.length-=d;break}r.mode=Mo;break;case Zo:for(;h<14;){if(0===a)break e;a--,u+=i[s++]<<h,h+=8;}if(r.nlen=257+(31&u),u>>>=5,h-=5,r.ndist=1+(31&u),u>>>=5,h-=5,r.ncode=4+(15&u),u>>>=4,h-=4,r.nlen>286||r.ndist>30){e.msg="too many length or distance symbols",r.mode=ta;break}r.have=0,r.mode=Wo;case Wo:for(;r.have<r.ncode;){for(;h<3;){if(0===a)break e;a--,u+=i[s++]<<h,h+=8;}r.lens[T[r.have++]]=7&u,u>>>=3,h-=3;}for(;r.have<19;)r.lens[T[r.have++]]=0;if(r.lencode=r.lendyn,r.lenbits=7,x={bits:r.lenbits},S=ho(co,r.lens,0,19,r.lencode,0,r.work,x),r.lenbits=x.bits,S){e.msg="invalid code lengths set",r.mode=ta;break}r.have=0,r.mode=qo;case qo:for(;r.have<r.nlen+r.ndist;){for(;_=(E=r.lencode[u&(1<<r.lenbits)-1])>>>16&255,y=65535&E,!((m=E>>>24)<=h);){if(0===a)break e;a--,u+=i[s++]<<h,h+=8;}if(y<16)u>>>=m,h-=m,r.lens[r.have++]=y;else {if(16===y){for(C=m+2;h<C;){if(0===a)break e;a--,u+=i[s++]<<h,h+=8;}if(u>>>=m,h-=m,0===r.have){e.msg="invalid bit length repeat",r.mode=ta;break}k=r.lens[r.have-1],d=3+(3&u),u>>>=2,h-=2;}else if(17===y){for(C=m+3;h<C;){if(0===a)break e;a--,u+=i[s++]<<h,h+=8;}h-=m,k=0,d=3+(7&(u>>>=m)),u>>>=3,h-=3;}else {for(C=m+7;h<C;){if(0===a)break e;a--,u+=i[s++]<<h,h+=8;}h-=m,k=0,d=11+(127&(u>>>=m)),u>>>=7,h-=7;}if(r.have+d>r.nlen+r.ndist){e.msg="invalid bit length repeat",r.mode=ta;break}for(;d--;)r.lens[r.have++]=k;}}if(r.mode===ta)break;if(0===r.lens[256]){e.msg="invalid code -- missing end-of-block",r.mode=ta;break}if(r.lenbits=9,x={bits:r.lenbits},S=ho(fo,r.lens,0,r.nlen,r.lencode,0,r.work,x),r.lenbits=x.bits,S){e.msg="invalid literal/lengths set",r.mode=ta;break}if(r.distbits=6,r.distcode=r.distdyn,x={bits:r.distbits},S=ho(po,r.lens,r.nlen,r.ndist,r.distcode,0,r.work,x),r.distbits=x.bits,S){e.msg="invalid distances set",r.mode=ta;break}if(r.mode=Yo,t===_o)break e;case Yo:r.mode=Vo;case Vo:if(a>=6&&l>=258){e.next_out=o,e.avail_out=l,e.next_in=s,e.avail_in=a,r.hold=u,r.bits=h,so(e,f),o=e.next_out,n=e.output,l=e.avail_out,s=e.next_in,i=e.input,a=e.avail_in,u=r.hold,h=r.bits,r.mode===Mo&&(r.back=-1);break}for(r.back=0;_=(E=r.lencode[u&(1<<r.lenbits)-1])>>>16&255,y=65535&E,!((m=E>>>24)<=h);){if(0===a)break e;a--,u+=i[s++]<<h,h+=8;}if(_&&0==(240&_)){for(b=m,v=_,w=y;_=(E=r.lencode[w+((u&(1<<b+v)-1)>>b)])>>>16&255,y=65535&E,!(b+(m=E>>>24)<=h);){if(0===a)break e;a--,u+=i[s++]<<h,h+=8;}u>>>=b,h-=b,r.back+=b;}if(u>>>=m,h-=m,r.back+=m,r.length=y,0===_){r.mode=Jo;break}if(32&_){r.back=-1,r.mode=Mo;break}if(64&_){e.msg="invalid literal/length code",r.mode=ta;break}r.extra=15&_,r.mode=Ho;case Ho:if(r.extra){for(C=r.extra;h<C;){if(0===a)break e;a--,u+=i[s++]<<h,h+=8;}r.length+=u&(1<<r.extra)-1,u>>>=r.extra,h-=r.extra,r.back+=r.extra;}r.was=r.length,r.mode=Go;case Go:for(;_=(E=r.distcode[u&(1<<r.distbits)-1])>>>16&255,y=65535&E,!((m=E>>>24)<=h);){if(0===a)break e;a--,u+=i[s++]<<h,h+=8;}if(0==(240&_)){for(b=m,v=_,w=y;_=(E=r.distcode[w+((u&(1<<b+v)-1)>>b)])>>>16&255,y=65535&E,!(b+(m=E>>>24)<=h);){if(0===a)break e;a--,u+=i[s++]<<h,h+=8;}u>>>=b,h-=b,r.back+=b;}if(u>>>=m,h-=m,r.back+=m,64&_){e.msg="invalid distance code",r.mode=ta;break}r.offset=y,r.extra=15&_,r.mode=$o;case $o:if(r.extra){for(C=r.extra;h<C;){if(0===a)break e;a--,u+=i[s++]<<h,h+=8;}r.offset+=u&(1<<r.extra)-1,u>>>=r.extra,h-=r.extra,r.back+=r.extra;}if(r.offset>r.dmax){e.msg="invalid distance too far back",r.mode=ta;break}r.mode=Ko;case Ko:if(0===l)break e;if(d=f-l,r.offset>d){if((d=r.offset-d)>r.whave&&r.sane){e.msg="invalid distance too far back",r.mode=ta;break}d>r.wnext?(d-=r.wnext,p=r.wsize-d):p=r.wnext-d,d>r.length&&(d=r.length),g=r.window;}else g=n,p=o-r.offset,d=r.length;d>l&&(d=l),l-=d,r.length-=d;do{n[o++]=g[p++];}while(--d);0===r.length&&(r.mode=Vo);break;case Jo:if(0===l)break e;n[o++]=r.length,l--,r.mode=Vo;break;case Xo:if(r.wrap){for(;h<32;){if(0===a)break e;a--,u|=i[s++]<<h,h+=8;}if(f-=l,e.total_out+=f,r.total+=f,f&&(e.adler=r.check=r.flags?Mn(r.check,n,f,o-f):In(r.check,n,f,o-f)),f=l,(r.flags?u:aa(u))!==r.check){e.msg="incorrect data check",r.mode=ta;break}u=0,h=0;}r.mode=Qo;case Qo:if(r.wrap&&r.flags){for(;h<32;){if(0===a)break e;a--,u+=i[s++]<<h,h+=8;}if(u!==(4294967295&r.total)){e.msg="incorrect length check",r.mode=ta;break}u=0,h=0;}r.mode=ea;case ea:S=bo;break e;case ta:S=ko;break e;case ra:return So;case ia:default:return wo}return e.next_out=o,e.avail_out=l,e.next_in=s,e.avail_in=a,r.hold=u,r.bits=h,(r.wsize||f!==e.avail_out&&r.mode<ta&&(r.mode<Xo||t!==go))&&_a(e,e.output,e.next_out,f-e.avail_out),c-=e.avail_in,f-=e.avail_out,e.total_in+=c,e.total_out+=f,r.total+=f,r.wrap&&f&&(e.adler=r.check=r.flags?Mn(r.check,n,f,e.next_out-f):In(r.check,n,f,e.next_out-f)),e.data_type=r.bits+(r.last?64:0)+(r.mode===Mo?128:0)+(r.mode===Yo||r.mode===jo?256:0),(0===c&&0===f||t===go)&&S===yo&&(S=xo),S},inflateEnd:function(e){if(!e||!e.state)return wo;var t=e.state;return t.window&&(t.window=null),e.state=null,yo},inflateGetHeader:function(e,t){var r;return e&&e.state?0==(2&(r=e.state).wrap)?wo:(r.head=t,t.done=!1,yo):wo},inflateSetDictionary:function(e,t){var r,i=t.length;return e&&e.state?0!==(r=e.state).wrap&&r.mode!==Po?wo:r.mode===Po&&In(1,t,i,0)!==r.check?ko:_a(e,t,i,i)?(r.mode=ra,So):(r.havedict=1,yo):wo},inflateInfo:"pako inflate (from Nodeca project)"},ba={Z_NO_FLUSH:0,Z_PARTIAL_FLUSH:1,Z_SYNC_FLUSH:2,Z_FULL_FLUSH:3,Z_FINISH:4,Z_BLOCK:5,Z_TREES:6,Z_OK:0,Z_STREAM_END:1,Z_NEED_DICT:2,Z_ERRNO:-1,Z_STREAM_ERROR:-2,Z_DATA_ERROR:-3,Z_BUF_ERROR:-5,Z_NO_COMPRESSION:0,Z_BEST_SPEED:1,Z_BEST_COMPRESSION:9,Z_DEFAULT_COMPRESSION:-1,Z_FILTERED:1,Z_HUFFMAN_ONLY:2,Z_RLE:3,Z_FIXED:4,Z_DEFAULT_STRATEGY:0,Z_BINARY:0,Z_TEXT:1,Z_UNKNOWN:2,Z_DEFLATED:8};var va=function(){this.text=0,this.time=0,this.xflags=0,this.os=0,this.extra=null,this.extra_len=0,this.name="",this.comment="",this.hcrc=0,this.done=!1;},wa=Object.prototype.toString;function ka(e){if(!(this instanceof ka))return new ka(e);this.options=Bi.assign({chunkSize:16384,windowBits:0,to:""},e||{});var t=this.options;t.raw&&t.windowBits>=0&&t.windowBits<16&&(t.windowBits=-t.windowBits,0===t.windowBits&&(t.windowBits=-15)),!(t.windowBits>=0&&t.windowBits<16)||e&&e.windowBits||(t.windowBits+=32),t.windowBits>15&&t.windowBits<48&&0==(15&t.windowBits)&&(t.windowBits|=15),this.err=0,this.msg="",this.ended=!1,this.chunks=[],this.strm=new Ks,this.strm.avail_out=0;var r=ya.inflateInit2(this.strm,t.windowBits);if(r!==ba.Z_OK)throw new Error(Un[r]);this.header=new va,ya.inflateGetHeader(this.strm,this.header);}function Sa(e,t){var r=new ka(t);if(r.push(e,!0),r.err)throw r.msg||Un[r.err];return r.result}ka.prototype.push=function(e,t){var r,i,n,s,o,a,l=this.strm,u=this.options.chunkSize,h=this.options.dictionary,c=!1;if(this.ended)return !1;i=t===~~t?t:!0===t?ba.Z_FINISH:ba.Z_NO_FLUSH,"string"==typeof e?l.input=$s.binstring2buf(e):"[object ArrayBuffer]"===wa.call(e)?l.input=new Uint8Array(e):l.input=e,l.next_in=0,l.avail_in=l.input.length;do{if(0===l.avail_out&&(l.output=new Bi.Buf8(u),l.next_out=0,l.avail_out=u),(r=ya.inflate(l,ba.Z_NO_FLUSH))===ba.Z_NEED_DICT&&h&&(a="string"==typeof h?$s.string2buf(h):"[object ArrayBuffer]"===wa.call(h)?new Uint8Array(h):h,r=ya.inflateSetDictionary(this.strm,a)),r===ba.Z_BUF_ERROR&&!0===c&&(r=ba.Z_OK,c=!1),r!==ba.Z_STREAM_END&&r!==ba.Z_OK)return this.onEnd(r),this.ended=!0,!1;l.next_out&&(0!==l.avail_out&&r!==ba.Z_STREAM_END&&(0!==l.avail_in||i!==ba.Z_FINISH&&i!==ba.Z_SYNC_FLUSH)||("string"===this.options.to?(n=$s.utf8border(l.output,l.next_out),s=l.next_out-n,o=$s.buf2string(l.output,n),l.next_out=s,l.avail_out=u-s,s&&Bi.arraySet(l.output,l.output,n,s,0),this.onData(o)):this.onData(Bi.shrinkBuf(l.output,l.next_out)))),0===l.avail_in&&0===l.avail_out&&(c=!0);}while((l.avail_in>0||0===l.avail_out)&&r!==ba.Z_STREAM_END);return r===ba.Z_STREAM_END&&(i=ba.Z_FINISH),i===ba.Z_FINISH?(r=ya.inflateEnd(this.strm),this.onEnd(r),this.ended=!0,r===ba.Z_OK):i!==ba.Z_SYNC_FLUSH||(this.onEnd(ba.Z_OK),l.avail_out=0,!0)},ka.prototype.onData=function(e){this.chunks.push(e);},ka.prototype.onEnd=function(e){e===ba.Z_OK&&("string"===this.options.to?this.result=this.chunks.join(""):this.result=Bi.flattenChunks(this.chunks)),this.chunks=[],this.err=e,this.msg=this.strm.msg;};var xa={Inflate:ka,inflate:Sa,inflateRaw:function(e,t){return (t=t||{}).raw=!0,Sa(e,t)},ungzip:Sa},Ca={};(0,Bi.assign)(Ca,no,xa,ba);var Ea=Ca,Aa="undefined"!=typeof Uint8Array&&"undefined"!=typeof Uint16Array&&"undefined"!=typeof Uint32Array?"uint8array":"array";function Ta(e,t){oi.call(this,"FlateWorker/"+e),this._pako=null,this._pakoAction=e,this._pakoOptions=t,this.meta={};}ni.inherits(Ta,oi),Ta.prototype.processChunk=function(e){this.meta=e.meta,null===this._pako&&this._createPako(),this._pako.push(ni.transformTo(Aa,e.data),!1);},Ta.prototype.flush=function(){oi.prototype.flush.call(this),null===this._pako&&this._createPako(),this._pako.push([],!0);},Ta.prototype.cleanUp=function(){oi.prototype.cleanUp.call(this),this._pako=null;},Ta.prototype._createPako=function(){this._pako=new Ea[this._pakoAction]({raw:!0,level:this._pakoOptions.level||-1});var e=this;this._pako.onData=function(t){e.push({data:t,meta:e.meta});};};var za={STORE:{magic:"\0\0",compressWorker:function(e){return new oi("STORE compression")},uncompressWorker:function(){return new oi("STORE decompression")}},DEFLATE:{magic:"\b\0",compressWorker:function(e){return new Ta("Deflate",e)},uncompressWorker:function(){return new Ta("Inflate",{})}}},Oa="PK",Ra="PK",La="PK",Ba="PK",Ia="PK",Fa="PK\b",Pa=function(e,t){var r,i="";for(r=0;r<t;r++)i+=String.fromCharCode(255&e),e>>>=8;return i},Ma=function(e,t,r,i,n,s){var o,a,l=e.file,u=e.compression,h=s!==ai.utf8encode,c=ni.transformTo("string",s(l.name)),f=ni.transformTo("string",ai.utf8encode(l.name)),d=l.comment,p=ni.transformTo("string",s(d)),g=ni.transformTo("string",ai.utf8encode(d)),m=f.length!==l.name.length,_=g.length!==d.length,y="",b="",v="",w=l.dir,k=l.date,S={crc32:0,compressedSize:0,uncompressedSize:0};t&&!r||(S.crc32=e.crc32,S.compressedSize=e.compressedSize,S.uncompressedSize=e.uncompressedSize);var x=0;t&&(x|=8),h||!m&&!_||(x|=2048);var C,E,A,T=0,z=0;w&&(T|=16),"UNIX"===n?(z=798,T|=(C=l.unixPermissions,E=w,A=C,C||(A=E?16893:33204),(65535&A)<<16)):(z=20,T|=63&(l.dosPermissions||0)),o=k.getUTCHours(),o<<=6,o|=k.getUTCMinutes(),o<<=5,o|=k.getUTCSeconds()/2,a=k.getUTCFullYear()-1980,a<<=4,a|=k.getUTCMonth()+1,a<<=5,a|=k.getUTCDate(),m&&(b=Pa(1,1)+Pa(Si(c),4)+f,y+="up"+Pa(b.length,2)+b),_&&(v=Pa(1,1)+Pa(Si(p),4)+g,y+="uc"+Pa(v.length,2)+v);var O="";return O+="\n\0",O+=Pa(x,2),O+=u.magic,O+=Pa(o,2),O+=Pa(a,2),O+=Pa(S.crc32,4),O+=Pa(S.compressedSize,4),O+=Pa(S.uncompressedSize,4),O+=Pa(c.length,2),O+=Pa(y.length,2),{fileRecord:Oa+O+c+y,dirRecord:Ra+Pa(z,2)+O+Pa(p.length,2)+"\0\0\0\0"+Pa(T,4)+Pa(i,4)+c+y+p}},Ua=function(e){return Fa+Pa(e.crc32,4)+Pa(e.compressedSize,4)+Pa(e.uncompressedSize,4)};function Da(e,t,r,i){oi.call(this,"ZipFileWorker"),this.bytesWritten=0,this.zipComment=t,this.zipPlatform=r,this.encodeFileName=i,this.streamFiles=e,this.accumulate=!1,this.contentBuffer=[],this.dirRecords=[],this.currentSourceOffset=0,this.entriesCount=0,this.currentFile=null,this._sources=[];}ni.inherits(Da,oi),Da.prototype.push=function(e){var t=e.meta.percent||0,r=this.entriesCount,i=this._sources.length;this.accumulate?this.contentBuffer.push(e):(this.bytesWritten+=e.data.length,oi.prototype.push.call(this,{data:e.data,meta:{currentFile:this.currentFile,percent:r?(t+100*(r-i-1))/r:100}}));},Da.prototype.openedSource=function(e){this.currentSourceOffset=this.bytesWritten,this.currentFile=e.file.name;var t=this.streamFiles&&!e.file.dir;if(t){var r=Ma(e,t,!1,this.currentSourceOffset,this.zipPlatform,this.encodeFileName);this.push({data:r.fileRecord,meta:{percent:0}});}else this.accumulate=!0;},Da.prototype.closedSource=function(e){this.accumulate=!1;var t=this.streamFiles&&!e.file.dir,r=Ma(e,t,!0,this.currentSourceOffset,this.zipPlatform,this.encodeFileName);if(this.dirRecords.push(r.dirRecord),t)this.push({data:Ua(e),meta:{percent:100}});else for(this.push({data:r.fileRecord,meta:{percent:0}});this.contentBuffer.length;)this.push(this.contentBuffer.shift());this.currentFile=null;},Da.prototype.flush=function(){for(var e=this.bytesWritten,t=0;t<this.dirRecords.length;t++)this.push({data:this.dirRecords[t],meta:{percent:100}});var r=this.bytesWritten-e,i=function(e,t,r,i,n){var s=ni.transformTo("string",n(i));return La+"\0\0\0\0"+Pa(e,2)+Pa(e,2)+Pa(t,4)+Pa(r,4)+Pa(s.length,2)+s}(this.dirRecords.length,r,e,this.zipComment,this.encodeFileName);this.push({data:i,meta:{percent:100}});},Da.prototype.prepareNextSource=function(){this.previous=this._sources.shift(),this.openedSource(this.previous.streamInfo),this.isPaused?this.previous.pause():this.previous.resume();},Da.prototype.registerPrevious=function(e){this._sources.push(e);var t=this;return e.on("data",function(e){t.processChunk(e);}),e.on("end",function(){t.closedSource(t.previous.streamInfo),t._sources.length?t.prepareNextSource():t.end();}),e.on("error",function(e){t.error(e);}),this},Da.prototype.resume=function(){return !!oi.prototype.resume.call(this)&&(!this.previous&&this._sources.length?(this.prepareNextSource(),!0):this.previous||this._sources.length||this.generatedError?void 0:(this.end(),!0))},Da.prototype.error=function(e){var t=this._sources;if(!oi.prototype.error.call(this,e))return !1;for(var r=0;r<t.length;r++)try{t[r].error(e);}catch(e){}return !0},Da.prototype.lock=function(){oi.prototype.lock.call(this);for(var e=this._sources,t=0;t<e.length;t++)e[t].lock();};var ja=Da,Na=function(e,t,r){var i=new ja(t.streamFiles,r,t.platform,t.encodeFileName),n=0;try{e.forEach(function(e,r){n++;var s=function(e,t){var r=e||t,i=za[r];if(!i)throw new Error(r+" is not a valid compression method !");return i}(r.options.compression,t.compression),o=r.options.compressionOptions||t.compressionOptions||{},a=r.dir,l=r.date;r._compressWorker(s,o).withStreamInfo("file",{name:e,dir:a,date:l,comment:r.comment||"",unixPermissions:r.unixPermissions,dosPermissions:r.dosPermissions}).pipe(i);}),i.entriesCount=n;}catch(e){i.error(e);}return i};function Za(e,t){oi.call(this,"Nodejs stream input adapter for "+e),this._upstreamEnded=!1,this._bindStream(t);}ni.inherits(Za,oi),Za.prototype._bindStream=function(e){var t=this;this._stream=e,e.pause(),e.on("data",function(e){t.push({data:e,meta:{percent:0}});}).on("error",function(e){t.isPaused?this.generatedError=e:t.error(e);}).on("end",function(){t.isPaused?t._upstreamEnded=!0:t.end();});},Za.prototype.pause=function(){return !!oi.prototype.pause.call(this)&&(this._stream.pause(),!0)},Za.prototype.resume=function(){return !!oi.prototype.resume.call(this)&&(this._upstreamEnded?this.end():this._stream.resume(),!0)};var Wa=Za,qa=function(e,t,r){var i,n=ni.getTypeOf(t),s=ni.extend(r||{},_i);s.date=s.date||new Date,null!==s.compression&&(s.compression=s.compression.toUpperCase()),"string"==typeof s.unixPermissions&&(s.unixPermissions=parseInt(s.unixPermissions,8)),s.unixPermissions&&16384&s.unixPermissions&&(s.dir=!0),s.dosPermissions&&16&s.dosPermissions&&(s.dir=!0),s.dir&&(e=Va(e)),s.createFolders&&(i=Ya(e))&&Ha.call(this,i,!0);var o="string"===n&&!1===s.binary&&!1===s.base64;r&&void 0!==r.binary||(s.binary=!o),(t instanceof Ai&&0===t.uncompressedSize||s.dir||!t||0===t.length)&&(s.base64=!1,s.binary=!0,t="",s.compression="STORE",n="string");var a=null;a=t instanceof Ai||t instanceof oi?t:Xt&&rr(t)?new Wa(e,t):ni.prepareContent(e,t,s.binary,s.optimizedBinaryString,s.base64);var l=new Li(e,a,s);this.files[e]=l;},Ya=function(e){"/"===e.slice(-1)&&(e=e.substring(0,e.length-1));var t=e.lastIndexOf("/");return t>0?e.substring(0,t):""},Va=function(e){return "/"!==e.slice(-1)&&(e+="/"),e},Ha=function(e,t){return t=void 0!==t?t:_i.createFolders,e=Va(e),this.files[e]||qa.call(this,e,null,{dir:!0,createFolders:t}),this.files[e]};function Ga(e){return "[object RegExp]"===Object.prototype.toString.call(e)}var $a={load:function(){throw new Error("This method has been removed in JSZip 3.0, please check the upgrade guide.")},forEach:function(e){var t,r,i;for(t in this.files)this.files.hasOwnProperty(t)&&(i=this.files[t],(r=t.slice(this.root.length,t.length))&&t.slice(0,this.root.length)===this.root&&e(r,i));},filter:function(e){var t=[];return this.forEach(function(r,i){e(r,i)&&t.push(i);}),t},file:function(e,t,r){if(1===arguments.length){if(Ga(e)){var i=e;return this.filter(function(e,t){return !t.dir&&i.test(e)})}var n=this.files[this.root+e];return n&&!n.dir?n:null}return e=this.root+e,qa.call(this,e,t,r),this},folder:function(e){if(!e)return this;if(Ga(e))return this.filter(function(t,r){return r.dir&&e.test(t)});var t=this.root+e,r=Ha.call(this,t),i=this.clone();return i.root=r.name,i},remove:function(e){e=this.root+e;var t=this.files[e];if(t||("/"!==e.slice(-1)&&(e+="/"),t=this.files[e]),t&&!t.dir)delete this.files[e];else for(var r=this.filter(function(t,r){return r.name.slice(0,e.length)===e}),i=0;i<r.length;i++)delete this.files[r[i].name];return this},generate:function(e){throw new Error("This method has been removed in JSZip 3.0, please check the upgrade guide.")},generateInternalStream:function(e){var t,r={};try{if((r=ni.extend(e||{},{streamFiles:!1,compression:"STORE",compressionOptions:null,type:"",platform:"DOS",comment:null,mimeType:"application/zip",encodeFileName:ai.utf8encode})).type=r.type.toLowerCase(),r.compression=r.compression.toUpperCase(),"binarystring"===r.type&&(r.type="string"),!r.type)throw new Error("No output type specified.");ni.checkSupport(r.type),"darwin"!==r.platform&&"freebsd"!==r.platform&&"linux"!==r.platform&&"sunos"!==r.platform||(r.platform="UNIX"),"win32"===r.platform&&(r.platform="DOS");var i=r.comment||this.comment||"";t=Na(this,r,i);}catch(e){(t=new oi("error")).error(e);}return new mi(t,r.type||"string",r.mimeType)},generateAsync:function(e,t){return this.generateInternalStream(e).accumulate(t)},generateNodeStream:function(e,t){return (e=e||{}).type||(e.type="nodebuffer"),this.generateInternalStream(e).toNodejsStream(t)}};function Ka(e){this.data=e,this.length=e.length,this.index=0,this.zero=0;}Ka.prototype={checkOffset:function(e){this.checkIndex(this.index+e);},checkIndex:function(e){if(this.length<this.zero+e||e<0)throw new Error("End of data reached (data length = "+this.length+", asked index = "+e+"). Corrupted zip ?")},setIndex:function(e){this.checkIndex(e),this.index=e;},skip:function(e){this.setIndex(this.index+e);},byteAt:function(e){},readInt:function(e){var t,r=0;for(this.checkOffset(e),t=this.index+e-1;t>=this.index;t--)r=(r<<8)+this.byteAt(t);return this.index+=e,r},readString:function(e){return ni.transformTo("string",this.readData(e))},readData:function(e){},lastIndexOfSignature:function(e){},readAndCheckSignature:function(e){},readDate:function(){var e=this.readInt(4);return new Date(Date.UTC(1980+(e>>25&127),(e>>21&15)-1,e>>16&31,e>>11&31,e>>5&63,(31&e)<<1))}};var Ja=Ka;function Xa(e){Ja.call(this,e);for(var t=0;t<this.data.length;t++)e[t]=255&e[t];}ni.inherits(Xa,Ja),Xa.prototype.byteAt=function(e){return this.data[this.zero+e]},Xa.prototype.lastIndexOfSignature=function(e){for(var t=e.charCodeAt(0),r=e.charCodeAt(1),i=e.charCodeAt(2),n=e.charCodeAt(3),s=this.length-4;s>=0;--s)if(this.data[s]===t&&this.data[s+1]===r&&this.data[s+2]===i&&this.data[s+3]===n)return s-this.zero;return -1},Xa.prototype.readAndCheckSignature=function(e){var t=e.charCodeAt(0),r=e.charCodeAt(1),i=e.charCodeAt(2),n=e.charCodeAt(3),s=this.readData(4);return t===s[0]&&r===s[1]&&i===s[2]&&n===s[3]},Xa.prototype.readData=function(e){if(this.checkOffset(e),0===e)return [];var t=this.data.slice(this.zero+this.index,this.zero+this.index+e);return this.index+=e,t};var Qa=Xa;function el(e){Ja.call(this,e);}ni.inherits(el,Ja),el.prototype.byteAt=function(e){return this.data.charCodeAt(this.zero+e)},el.prototype.lastIndexOfSignature=function(e){return this.data.lastIndexOf(e)-this.zero},el.prototype.readAndCheckSignature=function(e){return e===this.readData(4)},el.prototype.readData=function(e){this.checkOffset(e);var t=this.data.slice(this.zero+this.index,this.zero+this.index+e);return this.index+=e,t};var tl=el;function rl(e){Qa.call(this,e);}ni.inherits(rl,Qa),rl.prototype.readData=function(e){if(this.checkOffset(e),0===e)return new Uint8Array(0);var t=this.data.subarray(this.zero+this.index,this.zero+this.index+e);return this.index+=e,t};var il=rl;function nl(e){il.call(this,e);}ni.inherits(nl,il),nl.prototype.readData=function(e){this.checkOffset(e);var t=this.data.slice(this.zero+this.index,this.zero+this.index+e);return this.index+=e,t};var sl=nl,ol=function(e){var t=ni.getTypeOf(e);return ni.checkSupport(t),"string"!==t||$t.uint8array?"nodebuffer"===t?new sl(e):$t.uint8array?new il(ni.transformTo("uint8array",e)):new Qa(ni.transformTo("array",e)):new tl(e)};function al(e,t){this.options=e,this.loadOptions=t;}al.prototype={isEncrypted:function(){return 1==(1&this.bitFlag)},useUTF8:function(){return 2048==(2048&this.bitFlag)},readLocalPart:function(e){var t,r;if(e.skip(22),this.fileNameLength=e.readInt(2),r=e.readInt(2),this.fileName=e.readData(this.fileNameLength),e.skip(r),-1===this.compressedSize||-1===this.uncompressedSize)throw new Error("Bug or corrupted zip : didn't get enough informations from the central directory (compressedSize === -1 || uncompressedSize === -1)");if(null===(t=function(e){for(var t in za)if(za.hasOwnProperty(t)&&za[t].magic===e)return za[t];return null}(this.compressionMethod)))throw new Error("Corrupted zip : compression "+ni.pretty(this.compressionMethod)+" unknown (inner file : "+ni.transformTo("string",this.fileName)+")");this.decompressed=new Ai(this.compressedSize,this.uncompressedSize,this.crc32,t,e.readData(this.compressedSize));},readCentralPart:function(e){this.versionMadeBy=e.readInt(2),e.skip(2),this.bitFlag=e.readInt(2),this.compressionMethod=e.readString(2),this.date=e.readDate(),this.crc32=e.readInt(4),this.compressedSize=e.readInt(4),this.uncompressedSize=e.readInt(4);var t=e.readInt(2);if(this.extraFieldsLength=e.readInt(2),this.fileCommentLength=e.readInt(2),this.diskNumberStart=e.readInt(2),this.internalFileAttributes=e.readInt(2),this.externalFileAttributes=e.readInt(4),this.localHeaderOffset=e.readInt(4),this.isEncrypted())throw new Error("Encrypted zip are not supported");e.skip(t),this.readExtraFields(e),this.parseZIP64ExtraField(e),this.fileComment=e.readData(this.fileCommentLength);},processAttributes:function(){this.unixPermissions=null,this.dosPermissions=null;var e=this.versionMadeBy>>8;this.dir=!!(16&this.externalFileAttributes),0===e&&(this.dosPermissions=63&this.externalFileAttributes),3===e&&(this.unixPermissions=this.externalFileAttributes>>16&65535),this.dir||"/"!==this.fileNameStr.slice(-1)||(this.dir=!0);},parseZIP64ExtraField:function(e){if(this.extraFields[1]){var t=ol(this.extraFields[1].value);this.uncompressedSize===ni.MAX_VALUE_32BITS&&(this.uncompressedSize=t.readInt(8)),this.compressedSize===ni.MAX_VALUE_32BITS&&(this.compressedSize=t.readInt(8)),this.localHeaderOffset===ni.MAX_VALUE_32BITS&&(this.localHeaderOffset=t.readInt(8)),this.diskNumberStart===ni.MAX_VALUE_32BITS&&(this.diskNumberStart=t.readInt(4));}},readExtraFields:function(e){var t,r,i,n=e.index+this.extraFieldsLength;for(this.extraFields||(this.extraFields={});e.index<n;)t=e.readInt(2),r=e.readInt(2),i=e.readData(r),this.extraFields[t]={id:t,length:r,value:i};},handleUTF8:function(){var e=$t.uint8array?"uint8array":"array";if(this.useUTF8())this.fileNameStr=ai.utf8decode(this.fileName),this.fileCommentStr=ai.utf8decode(this.fileComment);else {var t=this.findExtraFieldUnicodePath();if(null!==t)this.fileNameStr=t;else {var r=ni.transformTo(e,this.fileName);this.fileNameStr=this.loadOptions.decodeFileName(r);}var i=this.findExtraFieldUnicodeComment();if(null!==i)this.fileCommentStr=i;else {var n=ni.transformTo(e,this.fileComment);this.fileCommentStr=this.loadOptions.decodeFileName(n);}}},findExtraFieldUnicodePath:function(){var e=this.extraFields[28789];if(e){var t=ol(e.value);return 1!==t.readInt(1)?null:Si(this.fileName)!==t.readInt(4)?null:ai.utf8decode(t.readData(e.length-5))}return null},findExtraFieldUnicodeComment:function(){var e=this.extraFields[25461];if(e){var t=ol(e.value);return 1!==t.readInt(1)?null:Si(this.fileComment)!==t.readInt(4)?null:ai.utf8decode(t.readData(e.length-5))}return null}};var ll=al;function ul(e){this.files=[],this.loadOptions=e;}ul.prototype={checkSignature:function(e){if(!this.reader.readAndCheckSignature(e)){this.reader.index-=4;var t=this.reader.readString(4);throw new Error("Corrupted zip or bug: unexpected signature ("+ni.pretty(t)+", expected "+ni.pretty(e)+")")}},isSignature:function(e,t){var r=this.reader.index;this.reader.setIndex(e);var i=this.reader.readString(4)===t;return this.reader.setIndex(r),i},readBlockEndOfCentral:function(){this.diskNumber=this.reader.readInt(2),this.diskWithCentralDirStart=this.reader.readInt(2),this.centralDirRecordsOnThisDisk=this.reader.readInt(2),this.centralDirRecords=this.reader.readInt(2),this.centralDirSize=this.reader.readInt(4),this.centralDirOffset=this.reader.readInt(4),this.zipCommentLength=this.reader.readInt(2);var e=this.reader.readData(this.zipCommentLength),t=$t.uint8array?"uint8array":"array",r=ni.transformTo(t,e);this.zipComment=this.loadOptions.decodeFileName(r);},readBlockZip64EndOfCentral:function(){this.zip64EndOfCentralSize=this.reader.readInt(8),this.reader.skip(4),this.diskNumber=this.reader.readInt(4),this.diskWithCentralDirStart=this.reader.readInt(4),this.centralDirRecordsOnThisDisk=this.reader.readInt(8),this.centralDirRecords=this.reader.readInt(8),this.centralDirSize=this.reader.readInt(8),this.centralDirOffset=this.reader.readInt(8),this.zip64ExtensibleData={};for(var e,t,r,i=this.zip64EndOfCentralSize-44;0<i;)e=this.reader.readInt(2),t=this.reader.readInt(4),r=this.reader.readData(t),this.zip64ExtensibleData[e]={id:e,length:t,value:r};},readBlockZip64EndOfCentralLocator:function(){if(this.diskWithZip64CentralDirStart=this.reader.readInt(4),this.relativeOffsetEndOfZip64CentralDir=this.reader.readInt(8),this.disksCount=this.reader.readInt(4),this.disksCount>1)throw new Error("Multi-volumes zip are not supported")},readLocalFiles:function(){var e,t;for(e=0;e<this.files.length;e++)t=this.files[e],this.reader.setIndex(t.localHeaderOffset),this.checkSignature(Oa),t.readLocalPart(this.reader),t.handleUTF8(),t.processAttributes();},readCentralDir:function(){var e;for(this.reader.setIndex(this.centralDirOffset);this.reader.readAndCheckSignature(Ra);)(e=new ll({zip64:this.zip64},this.loadOptions)).readCentralPart(this.reader),this.files.push(e);if(this.centralDirRecords!==this.files.length&&0!==this.centralDirRecords&&0===this.files.length)throw new Error("Corrupted zip or bug: expected "+this.centralDirRecords+" records in central dir, got "+this.files.length)},readEndOfCentral:function(){var e=this.reader.lastIndexOfSignature(La);if(e<0)throw !this.isSignature(0,Oa)?new Error("Can't find end of central directory : is this a zip file ? If it is, see https://stuk.github.io/jszip/documentation/howto/read_zip.html"):new Error("Corrupted zip: can't find end of central directory");this.reader.setIndex(e);var t=e;if(this.checkSignature(La),this.readBlockEndOfCentral(),this.diskNumber===ni.MAX_VALUE_16BITS||this.diskWithCentralDirStart===ni.MAX_VALUE_16BITS||this.centralDirRecordsOnThisDisk===ni.MAX_VALUE_16BITS||this.centralDirRecords===ni.MAX_VALUE_16BITS||this.centralDirSize===ni.MAX_VALUE_32BITS||this.centralDirOffset===ni.MAX_VALUE_32BITS){if(this.zip64=!0,(e=this.reader.lastIndexOfSignature(Ba))<0)throw new Error("Corrupted zip: can't find the ZIP64 end of central directory locator");if(this.reader.setIndex(e),this.checkSignature(Ba),this.readBlockZip64EndOfCentralLocator(),!this.isSignature(this.relativeOffsetEndOfZip64CentralDir,Ia)&&(this.relativeOffsetEndOfZip64CentralDir=this.reader.lastIndexOfSignature(Ia),this.relativeOffsetEndOfZip64CentralDir<0))throw new Error("Corrupted zip: can't find the ZIP64 end of central directory");this.reader.setIndex(this.relativeOffsetEndOfZip64CentralDir),this.checkSignature(Ia),this.readBlockZip64EndOfCentral();}var r=this.centralDirOffset+this.centralDirSize;this.zip64&&(r+=20,r+=12+this.zip64EndOfCentralSize);var i=t-r;if(i>0)this.isSignature(t,Ra)||(this.reader.zero=i);else if(i<0)throw new Error("Corrupted zip: missing "+Math.abs(i)+" bytes.")},prepareReader:function(e){this.reader=ol(e);},load:function(e){this.prepareReader(e),this.readEndOfCentral(),this.readCentralDir(),this.readLocalFiles();}};var hl=ul;function cl(e){return new ii.Promise(function(t,r){var i=e.decompressed.getContentWorker().pipe(new Ci);i.on("error",function(e){r(e);}).on("end",function(){i.streamInfo.crc32!==e.decompressed.crc32?r(new Error("Corrupted zip : CRC32 mismatch")):t();}).resume();})}function fl(){if(!(this instanceof fl))return new fl;if(arguments.length)throw new Error("The constructor with parameters has been removed in JSZip 3.0, please check the upgrade guide.");this.files={},this.comment=null,this.root="",this.clone=function(){var e=new fl;for(var t in this)"function"!=typeof this[t]&&(e[t]=this[t]);return e};}fl.prototype=$a,fl.prototype.loadAsync=function(e,t){var r=this;return t=ni.extend(t||{},{base64:!1,checkCRC32:!1,optimizedBinaryString:!1,createFolders:!1,decodeFileName:ai.utf8decode}),Xt&&rr(e)?ii.Promise.reject(new Error("JSZip can't accept a stream when loading a zip file.")):ni.prepareContent("the loaded zip file",e,!0,t.optimizedBinaryString,t.base64).then(function(e){var r=new hl(t);return r.load(e),r}).then(function(e){var r=[ii.Promise.resolve(e)],i=e.files;if(t.checkCRC32)for(var n=0;n<i.length;n++)r.push(cl(i[n]));return ii.Promise.all(r)}).then(function(e){for(var i=e.shift(),n=i.files,s=0;s<n.length;s++){var o=n[s];r.file(o.fileNameStr,o.decompressed,{binary:!0,optimizedBinaryString:!0,date:o.date,dir:o.dir,comment:o.fileCommentStr.length?o.fileCommentStr:null,unixPermissions:o.unixPermissions,dosPermissions:o.dosPermissions,createFolders:t.createFolders});}return i.zipComment.length&&(r.comment=i.zipComment),r})},fl.support=$t,fl.defaults=_i,fl.version="3.1.5",fl.loadAsync=function(e,t){return (new fl).loadAsync(e,t)},fl.external=ii;var dl=fl;function pl(e){return null==e}var gl={isNothing:pl,isObject:function(e){return "object"==typeof e&&null!==e},toArray:function(e){return Array.isArray(e)?e:pl(e)?[]:[e]},repeat:function(e,t){var r,i="";for(r=0;r<t;r+=1)i+=e;return i},isNegativeZero:function(e){return 0===e&&Number.NEGATIVE_INFINITY===1/e},extend:function(e,t){var r,i,n,s;if(t)for(r=0,i=(s=Object.keys(t)).length;r<i;r+=1)e[n=s[r]]=t[n];return e}};function ml(e,t){Error.call(this),Error.captureStackTrace?Error.captureStackTrace(this,this.constructor):this.stack=(new Error).stack||"",this.name="YAMLException",this.reason=e,this.mark=t,this.message=(this.reason||"(unknown reason)")+(this.mark?" "+this.mark.toString():"");}ml.prototype=Object.create(Error.prototype),ml.prototype.constructor=ml,ml.prototype.toString=function(e){var t=this.name+": ";return t+=this.reason||"(unknown reason)",!e&&this.mark&&(t+=" "+this.mark.toString()),t};var _l=ml;function yl(e,t,r,i,n){this.name=e,this.buffer=t,this.position=r,this.line=i,this.column=n;}yl.prototype.getSnippet=function(e,t){var r,i,n,s,o;if(!this.buffer)return null;for(e=e||4,t=t||75,r="",i=this.position;i>0&&-1==="\0\r\n\u2028\u2029".indexOf(this.buffer.charAt(i-1));)if(i-=1,this.position-i>t/2-1){r=" ... ",i+=5;break}for(n="",s=this.position;s<this.buffer.length&&-1==="\0\r\n\u2028\u2029".indexOf(this.buffer.charAt(s));)if((s+=1)-this.position>t/2-1){n=" ... ",s-=5;break}return o=this.buffer.slice(i,s),gl.repeat(" ",e)+r+o+n+"\n"+gl.repeat(" ",e+this.position-i+r.length)+"^"},yl.prototype.toString=function(e){var t,r="";return this.name&&(r+='in "'+this.name+'" '),r+="at line "+(this.line+1)+", column "+(this.column+1),e||(t=this.getSnippet())&&(r+=":\n"+t),r};var bl=yl,vl=["kind","resolve","construct","instanceOf","predicate","represent","defaultStyle","styleAliases"],wl=["scalar","sequence","mapping"];var kl=function(e,t){var r,i;if(t=t||{},Object.keys(t).forEach(function(t){if(-1===vl.indexOf(t))throw new _l('Unknown option "'+t+'" is met in definition of "'+e+'" YAML type.')}),this.tag=e,this.kind=t.kind||null,this.resolve=t.resolve||function(){return !0},this.construct=t.construct||function(e){return e},this.instanceOf=t.instanceOf||null,this.predicate=t.predicate||null,this.represent=t.represent||null,this.defaultStyle=t.defaultStyle||null,this.styleAliases=(r=t.styleAliases||null,i={},null!==r&&Object.keys(r).forEach(function(e){r[e].forEach(function(t){i[String(t)]=e;});}),i),-1===wl.indexOf(this.kind))throw new _l('Unknown kind "'+this.kind+'" is specified for "'+e+'" YAML type.')};function Sl(e,t,r){var i=[];return e.include.forEach(function(e){r=Sl(e,t,r);}),e[t].forEach(function(e){r.forEach(function(t,r){t.tag===e.tag&&i.push(r);}),r.push(e);}),r.filter(function(e,t){return -1===i.indexOf(t)})}function xl(e){this.include=e.include||[],this.implicit=e.implicit||[],this.explicit=e.explicit||[],this.implicit.forEach(function(e){if(e.loadKind&&"scalar"!==e.loadKind)throw new _l("There is a non-scalar type in the implicit list of a schema. Implicit resolving of such types is not supported.")}),this.compiledImplicit=Sl(this,"implicit",[]),this.compiledExplicit=Sl(this,"explicit",[]),this.compiledTypeMap=function(){var e,t,r={};function i(e){r[e.tag]=e;}for(e=0,t=arguments.length;e<t;e+=1)arguments[e].forEach(i);return r}(this.compiledImplicit,this.compiledExplicit);}xl.DEFAULT=null,xl.create=function(){var e,t;switch(arguments.length){case 1:e=xl.DEFAULT,t=arguments[0];break;case 2:e=arguments[0],t=arguments[1];break;default:throw new _l("Wrong number of arguments for Schema.create function")}if(e=gl.toArray(e),t=gl.toArray(t),!e.every(function(e){return e instanceof xl}))throw new _l("Specified list of super schemas (or a single Schema object) contains a non-Schema object.");if(!t.every(function(e){return e instanceof kl}))throw new _l("Specified list of YAML types (or a single Type object) contains a non-Type object.");return new xl({include:e,explicit:t})};var Cl=xl,El=new Cl({explicit:[new kl("tag:yaml.org,2002:str",{kind:"scalar",construct:function(e){return null!==e?e:""}}),new kl("tag:yaml.org,2002:seq",{kind:"sequence",construct:function(e){return null!==e?e:[]}}),new kl("tag:yaml.org,2002:map",{kind:"mapping",construct:function(e){return null!==e?e:{}}})]});var Al=new kl("tag:yaml.org,2002:null",{kind:"scalar",resolve:function(e){if(null===e)return !0;var t=e.length;return 1===t&&"~"===e||4===t&&("null"===e||"Null"===e||"NULL"===e)},construct:function(){return null},predicate:function(e){return null===e},represent:{canonical:function(){return "~"},lowercase:function(){return "null"},uppercase:function(){return "NULL"},camelcase:function(){return "Null"}},defaultStyle:"lowercase"});var Tl=new kl("tag:yaml.org,2002:bool",{kind:"scalar",resolve:function(e){if(null===e)return !1;var t=e.length;return 4===t&&("true"===e||"True"===e||"TRUE"===e)||5===t&&("false"===e||"False"===e||"FALSE"===e)},construct:function(e){return "true"===e||"True"===e||"TRUE"===e},predicate:function(e){return "[object Boolean]"===Object.prototype.toString.call(e)},represent:{lowercase:function(e){return e?"true":"false"},uppercase:function(e){return e?"TRUE":"FALSE"},camelcase:function(e){return e?"True":"False"}},defaultStyle:"lowercase"});function zl(e){return 48<=e&&e<=55}function Ol(e){return 48<=e&&e<=57}var Rl=new kl("tag:yaml.org,2002:int",{kind:"scalar",resolve:function(e){if(null===e)return !1;var t,r,i=e.length,n=0,s=!1;if(!i)return !1;if("-"!==(t=e[n])&&"+"!==t||(t=e[++n]),"0"===t){if(n+1===i)return !0;if("b"===(t=e[++n])){for(n++;n<i;n++)if("_"!==(t=e[n])){if("0"!==t&&"1"!==t)return !1;s=!0;}return s}if("x"===t){for(n++;n<i;n++)if("_"!==(t=e[n])){if(!(48<=(r=e.charCodeAt(n))&&r<=57||65<=r&&r<=70||97<=r&&r<=102))return !1;s=!0;}return s}for(;n<i;n++)if("_"!==(t=e[n])){if(!zl(e.charCodeAt(n)))return !1;s=!0;}return s}for(;n<i;n++)if("_"!==(t=e[n])){if(":"===t)break;if(!Ol(e.charCodeAt(n)))return !1;s=!0;}return !!s&&(":"!==t||/^(:[0-5]?[0-9])+$/.test(e.slice(n)))},construct:function(e){var t,r,i=e,n=1,s=[];return -1!==i.indexOf("_")&&(i=i.replace(/_/g,"")),"-"!==(t=i[0])&&"+"!==t||("-"===t&&(n=-1),t=(i=i.slice(1))[0]),"0"===i?0:"0"===t?"b"===i[1]?n*parseInt(i.slice(2),2):"x"===i[1]?n*parseInt(i,16):n*parseInt(i,8):-1!==i.indexOf(":")?(i.split(":").forEach(function(e){s.unshift(parseInt(e,10));}),i=0,r=1,s.forEach(function(e){i+=e*r,r*=60;}),n*i):n*parseInt(i,10)},predicate:function(e){return "[object Number]"===Object.prototype.toString.call(e)&&e%1==0&&!gl.isNegativeZero(e)},represent:{binary:function(e){return "0b"+e.toString(2)},octal:function(e){return "0"+e.toString(8)},decimal:function(e){return e.toString(10)},hexadecimal:function(e){return "0x"+e.toString(16).toUpperCase()}},defaultStyle:"decimal",styleAliases:{binary:[2,"bin"],octal:[8,"oct"],decimal:[10,"dec"],hexadecimal:[16,"hex"]}}),Ll=new RegExp("^(?:[-+]?(?:[0-9][0-9_]*)\\.[0-9_]*(?:[eE][-+][0-9]+)?|\\.[0-9_]+(?:[eE][-+][0-9]+)?|[-+]?[0-9][0-9_]*(?::[0-5]?[0-9])+\\.[0-9_]*|[-+]?\\.(?:inf|Inf|INF)|\\.(?:nan|NaN|NAN))$");var Bl=/^[-+]?[0-9]+e/;var Il=new Cl({include:[El],implicit:[Al,Tl,Rl,new kl("tag:yaml.org,2002:float",{kind:"scalar",resolve:function(e){return null!==e&&!!Ll.test(e)},construct:function(e){var t,r,i,n;return r="-"===(t=e.replace(/_/g,"").toLowerCase())[0]?-1:1,n=[],"+-".indexOf(t[0])>=0&&(t=t.slice(1)),".inf"===t?1===r?Number.POSITIVE_INFINITY:Number.NEGATIVE_INFINITY:".nan"===t?NaN:t.indexOf(":")>=0?(t.split(":").forEach(function(e){n.unshift(parseFloat(e,10));}),t=0,i=1,n.forEach(function(e){t+=e*i,i*=60;}),r*t):r*parseFloat(t,10)},predicate:function(e){return "[object Number]"===Object.prototype.toString.call(e)&&(e%1!=0||gl.isNegativeZero(e))},represent:function(e,t){var r;if(isNaN(e))switch(t){case"lowercase":return ".nan";case"uppercase":return ".NAN";case"camelcase":return ".NaN"}else if(Number.POSITIVE_INFINITY===e)switch(t){case"lowercase":return ".inf";case"uppercase":return ".INF";case"camelcase":return ".Inf"}else if(Number.NEGATIVE_INFINITY===e)switch(t){case"lowercase":return "-.inf";case"uppercase":return "-.INF";case"camelcase":return "-.Inf"}else if(gl.isNegativeZero(e))return "-0.0";return r=e.toString(10),Bl.test(r)?r.replace("e",".e"):r},defaultStyle:"lowercase"})]}),Fl=new Cl({include:[Il]}),Pl=new RegExp("^([0-9][0-9][0-9][0-9])-([0-9][0-9]?)-([0-9][0-9]?)(?:(?:[Tt]|[ \\t]+)([0-9][0-9]?):([0-9][0-9]):([0-9][0-9])(?:\\.([0-9]*))?(?:[ \\t]*(Z|([-+])([0-9][0-9]?)(?::([0-9][0-9]))?))?)?$");var Ml=new kl("tag:yaml.org,2002:timestamp",{kind:"scalar",resolve:function(e){return null!==e&&null!==Pl.exec(e)},construct:function(e){var t,r,i,n,s,o,a,l,u=0,h=null;if(null===(t=Pl.exec(e)))throw new Error("Date resolve error");if(r=+t[1],i=+t[2]-1,n=+t[3],!t[4])return new Date(Date.UTC(r,i,n));if(s=+t[4],o=+t[5],a=+t[6],t[7]){for(u=t[7].slice(0,3);u.length<3;)u+="0";u=+u;}return t[9]&&(h=6e4*(60*+t[10]+ +(t[11]||0)),"-"===t[9]&&(h=-h)),l=new Date(Date.UTC(r,i,n,s,o,a,u)),h&&l.setTime(l.getTime()-h),l},instanceOf:Date,represent:function(e){return e.toISOString()}});var Ul=new kl("tag:yaml.org,2002:merge",{kind:"scalar",resolve:function(e){return "<<"===e||null===e}}),Dl={}.Buffer,jl="ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/=\n\r";var Nl=new kl("tag:yaml.org,2002:binary",{kind:"scalar",resolve:function(e){if(null===e)return !1;var t,r,i=0,n=e.length,s=jl;for(r=0;r<n;r++)if(!((t=s.indexOf(e.charAt(r)))>64)){if(t<0)return !1;i+=6;}return i%8==0},construct:function(e){var t,r,i=e.replace(/[\r\n=]/g,""),n=i.length,s=jl,o=0,a=[];for(t=0;t<n;t++)t%4==0&&t&&(a.push(o>>16&255),a.push(o>>8&255),a.push(255&o)),o=o<<6|s.indexOf(i.charAt(t));return 0==(r=n%4*6)?(a.push(o>>16&255),a.push(o>>8&255),a.push(255&o)):18===r?(a.push(o>>10&255),a.push(o>>2&255)):12===r&&a.push(o>>4&255),a},predicate:function(e){return Dl},represent:function(e){var t,r,i="",n=0,s=e.length,o=jl;for(t=0;t<s;t++)t%3==0&&t&&(i+=o[n>>18&63],i+=o[n>>12&63],i+=o[n>>6&63],i+=o[63&n]),n=(n<<8)+e[t];return 0==(r=s%3)?(i+=o[n>>18&63],i+=o[n>>12&63],i+=o[n>>6&63],i+=o[63&n]):2===r?(i+=o[n>>10&63],i+=o[n>>4&63],i+=o[n<<2&63],i+=o[64]):1===r&&(i+=o[n>>2&63],i+=o[n<<4&63],i+=o[64],i+=o[64]),i}}),Zl=Object.prototype.hasOwnProperty,Wl=Object.prototype.toString;var ql=new kl("tag:yaml.org,2002:omap",{kind:"sequence",resolve:function(e){if(null===e)return !0;var t,r,i,n,s,o=[],a=e;for(t=0,r=a.length;t<r;t+=1){if(i=a[t],s=!1,"[object Object]"!==Wl.call(i))return !1;for(n in i)if(Zl.call(i,n)){if(s)return !1;s=!0;}if(!s)return !1;if(-1!==o.indexOf(n))return !1;o.push(n);}return !0},construct:function(e){return null!==e?e:[]}}),Yl=Object.prototype.toString;var Vl=new kl("tag:yaml.org,2002:pairs",{kind:"sequence",resolve:function(e){if(null===e)return !0;var t,r,i,n,s,o=e;for(s=new Array(o.length),t=0,r=o.length;t<r;t+=1){if(i=o[t],"[object Object]"!==Yl.call(i))return !1;if(1!==(n=Object.keys(i)).length)return !1;s[t]=[n[0],i[n[0]]];}return !0},construct:function(e){if(null===e)return [];var t,r,i,n,s,o=e;for(s=new Array(o.length),t=0,r=o.length;t<r;t+=1)i=o[t],n=Object.keys(i),s[t]=[n[0],i[n[0]]];return s}}),Hl=Object.prototype.hasOwnProperty;var Gl=new Cl({include:[Fl],implicit:[Ml,Ul],explicit:[Nl,ql,Vl,new kl("tag:yaml.org,2002:set",{kind:"mapping",resolve:function(e){if(null===e)return !0;var t,r=e;for(t in r)if(Hl.call(r,t)&&null!==r[t])return !1;return !0},construct:function(e){return null!==e?e:{}}})]});var $l=new kl("tag:yaml.org,2002:js/undefined",{kind:"scalar",resolve:function(){return !0},construct:function(){},predicate:function(e){return void 0===e},represent:function(){return ""}});var Kl,Jl=new kl("tag:yaml.org,2002:js/regexp",{kind:"scalar",resolve:function(e){if(null===e)return !1;if(0===e.length)return !1;var t=e,r=/\/([gim]*)$/.exec(e),i="";if("/"===t[0]){if(r&&(i=r[1]),i.length>3)return !1;if("/"!==t[t.length-i.length-1])return !1}return !0},construct:function(e){var t=e,r=/\/([gim]*)$/.exec(e),i="";return "/"===t[0]&&(r&&(i=r[1]),t=t.slice(1,t.length-i.length-1)),new RegExp(t,i)},predicate:function(e){return "[object RegExp]"===Object.prototype.toString.call(e)},represent:function(e){var t="/"+e.source+"/";return e.global&&(t+="g"),e.multiline&&(t+="m"),e.ignoreCase&&(t+="i"),t}});try{var Xl=e.commonjsRequire;Kl=Xl("esprima");}catch(e){"undefined"!=typeof window&&(Kl=window.esprima);}var Ql=new kl("tag:yaml.org,2002:js/function",{kind:"scalar",resolve:function(e){if(null===e)return !1;try{var t="("+e+")",r=Kl.parse(t,{range:!0});return "Program"===r.type&&1===r.body.length&&"ExpressionStatement"===r.body[0].type&&"FunctionExpression"===r.body[0].expression.type}catch(e){return !1}},construct:function(e){var t,r="("+e+")",i=Kl.parse(r,{range:!0}),n=[];if("Program"!==i.type||1!==i.body.length||"ExpressionStatement"!==i.body[0].type||"FunctionExpression"!==i.body[0].expression.type)throw new Error("Failed to resolve function");return i.body[0].expression.params.forEach(function(e){n.push(e.name);}),t=i.body[0].expression.body.range,new Function(n,r.slice(t[0]+1,t[1]-1))},predicate:function(e){return "[object Function]"===Object.prototype.toString.call(e)},represent:function(e){return e.toString()}}),eu=Cl.DEFAULT=new Cl({include:[Gl],explicit:[$l,Jl,Ql]}),tu=Object.prototype.hasOwnProperty,ru=1,iu=2,nu=3,su=4,ou=1,au=2,lu=3,uu=/[\x00-\x08\x0B\x0C\x0E-\x1F\x7F-\x84\x86-\x9F\uFFFE\uFFFF]|[\uD800-\uDBFF](?![\uDC00-\uDFFF])|(?:[^\uD800-\uDBFF]|^)[\uDC00-\uDFFF]/,hu=/[\x85\u2028\u2029]/,cu=/[,\[\]\{\}]/,fu=/^(?:!|!!|![a-z\-]+!)$/i,du=/^(?:!|[^,\[\]\{\}])(?:%[0-9a-f]{2}|[0-9a-z\-#;\/\?:@&=\+\$,_\.!~\*'\(\)\[\]])*$/i;function pu(e){return 10===e||13===e}function gu(e){return 9===e||32===e}function mu(e){return 9===e||32===e||10===e||13===e}function _u(e){return 44===e||91===e||93===e||123===e||125===e}function yu(e){var t;return 48<=e&&e<=57?e-48:97<=(t=32|e)&&t<=102?t-97+10:-1}function bu(e){return 48===e?"\0":97===e?"":98===e?"\b":116===e?"\t":9===e?"\t":110===e?"\n":118===e?"\v":102===e?"\f":114===e?"\r":101===e?"":32===e?" ":34===e?'"':47===e?"/":92===e?"\\":78===e?"":95===e?" ":76===e?"\u2028":80===e?"\u2029":""}function vu(e){return e<=65535?String.fromCharCode(e):String.fromCharCode(55296+(e-65536>>10),56320+(e-65536&1023))}for(var wu=new Array(256),ku=new Array(256),Su=0;Su<256;Su++)wu[Su]=bu(Su)?1:0,ku[Su]=bu(Su);function xu(e,t){this.input=e,this.filename=t.filename||null,this.schema=t.schema||eu,this.onWarning=t.onWarning||null,this.legacy=t.legacy||!1,this.json=t.json||!1,this.listener=t.listener||null,this.implicitTypes=this.schema.compiledImplicit,this.typeMap=this.schema.compiledTypeMap,this.length=e.length,this.position=0,this.line=0,this.lineStart=0,this.lineIndent=0,this.documents=[];}function Cu(e,t){return new _l(t,new bl(e.filename,e.input,e.position,e.line,e.position-e.lineStart))}function Eu(e,t){throw Cu(e,t)}function Au(e,t){e.onWarning&&e.onWarning.call(null,Cu(e,t));}var Tu={YAML:function(e,t,r){var i,n,s;null!==e.version&&Eu(e,"duplication of %YAML directive"),1!==r.length&&Eu(e,"YAML directive accepts exactly one argument"),null===(i=/^([0-9]+)\.([0-9]+)$/.exec(r[0]))&&Eu(e,"ill-formed argument of the YAML directive"),n=parseInt(i[1],10),s=parseInt(i[2],10),1!==n&&Eu(e,"unacceptable YAML version of the document"),e.version=r[0],e.checkLineBreaks=s<2,1!==s&&2!==s&&Au(e,"unsupported YAML version of the document");},TAG:function(e,t,r){var i,n;2!==r.length&&Eu(e,"TAG directive accepts exactly two arguments"),i=r[0],n=r[1],fu.test(i)||Eu(e,"ill-formed tag handle (first argument) of the TAG directive"),tu.call(e.tagMap,i)&&Eu(e,'there is a previously declared suffix for "'+i+'" tag handle'),du.test(n)||Eu(e,"ill-formed tag prefix (second argument) of the TAG directive"),e.tagMap[i]=n;}};function zu(e,t,r,i){var n,s,o,a;if(t<r){if(a=e.input.slice(t,r),i)for(n=0,s=a.length;n<s;n+=1)9===(o=a.charCodeAt(n))||32<=o&&o<=1114111||Eu(e,"expected valid JSON character");else uu.test(a)&&Eu(e,"the stream contains non-printable characters");e.result+=a;}}function Ou(e,t,r,i){var n,s,o,a;for(gl.isObject(r)||Eu(e,"cannot merge mappings; the provided source object is unacceptable"),o=0,a=(n=Object.keys(r)).length;o<a;o+=1)s=n[o],tu.call(t,s)||(t[s]=r[s],i[s]=!0);}function Ru(e,t,r,i,n,s){var o,a;if(n=String(n),null===t&&(t={}),"tag:yaml.org,2002:merge"===i)if(Array.isArray(s))for(o=0,a=s.length;o<a;o+=1)Ou(e,t,s[o],r);else Ou(e,t,s,r);else e.json||tu.call(r,n)||!tu.call(t,n)||Eu(e,"duplicated mapping key"),t[n]=s,delete r[n];return t}function Lu(e){var t;10===(t=e.input.charCodeAt(e.position))?e.position++:13===t?(e.position++,10===e.input.charCodeAt(e.position)&&e.position++):Eu(e,"a line break is expected"),e.line+=1,e.lineStart=e.position;}function Bu(e,t,r){for(var i=0,n=e.input.charCodeAt(e.position);0!==n;){for(;gu(n);)n=e.input.charCodeAt(++e.position);if(t&&35===n)do{n=e.input.charCodeAt(++e.position);}while(10!==n&&13!==n&&0!==n);if(!pu(n))break;for(Lu(e),n=e.input.charCodeAt(e.position),i++,e.lineIndent=0;32===n;)e.lineIndent++,n=e.input.charCodeAt(++e.position);}return -1!==r&&0!==i&&e.lineIndent<r&&Au(e,"deficient indentation"),i}function Iu(e){var t,r=e.position;return !(45!==(t=e.input.charCodeAt(r))&&46!==t||t!==e.input.charCodeAt(r+1)||t!==e.input.charCodeAt(r+2)||(r+=3,0!==(t=e.input.charCodeAt(r))&&!mu(t)))}function Fu(e,t){1===t?e.result+=" ":t>1&&(e.result+=gl.repeat("\n",t-1));}function Pu(e,t){var r,i,n=e.tag,s=e.anchor,o=[],a=!1;for(null!==e.anchor&&(e.anchorMap[e.anchor]=o),i=e.input.charCodeAt(e.position);0!==i&&45===i&&mu(e.input.charCodeAt(e.position+1));)if(a=!0,e.position++,Bu(e,!0,-1)&&e.lineIndent<=t)o.push(null),i=e.input.charCodeAt(e.position);else if(r=e.line,Du(e,t,nu,!1,!0),o.push(e.result),Bu(e,!0,-1),i=e.input.charCodeAt(e.position),(e.line===r||e.lineIndent>t)&&0!==i)Eu(e,"bad indentation of a sequence entry");else if(e.lineIndent<t)break;return !!a&&(e.tag=n,e.anchor=s,e.kind="sequence",e.result=o,!0)}function Mu(e){var t,r,i,n,s=!1,o=!1;if(33!==(n=e.input.charCodeAt(e.position)))return !1;if(null!==e.tag&&Eu(e,"duplication of a tag property"),60===(n=e.input.charCodeAt(++e.position))?(s=!0,n=e.input.charCodeAt(++e.position)):33===n?(o=!0,r="!!",n=e.input.charCodeAt(++e.position)):r="!",t=e.position,s){do{n=e.input.charCodeAt(++e.position);}while(0!==n&&62!==n);e.position<e.length?(i=e.input.slice(t,e.position),n=e.input.charCodeAt(++e.position)):Eu(e,"unexpected end of the stream within a verbatim tag");}else {for(;0!==n&&!mu(n);)33===n&&(o?Eu(e,"tag suffix cannot contain exclamation marks"):(r=e.input.slice(t-1,e.position+1),fu.test(r)||Eu(e,"named tag handle cannot contain such characters"),o=!0,t=e.position+1)),n=e.input.charCodeAt(++e.position);i=e.input.slice(t,e.position),cu.test(i)&&Eu(e,"tag suffix cannot contain flow indicator characters");}return i&&!du.test(i)&&Eu(e,"tag name cannot contain such characters: "+i),s?e.tag=i:tu.call(e.tagMap,r)?e.tag=e.tagMap[r]+i:"!"===r?e.tag="!"+i:"!!"===r?e.tag="tag:yaml.org,2002:"+i:Eu(e,'undeclared tag handle "'+r+'"'),!0}function Uu(e){var t,r;if(38!==(r=e.input.charCodeAt(e.position)))return !1;for(null!==e.anchor&&Eu(e,"duplication of an anchor property"),r=e.input.charCodeAt(++e.position),t=e.position;0!==r&&!mu(r)&&!_u(r);)r=e.input.charCodeAt(++e.position);return e.position===t&&Eu(e,"name of an anchor node must contain at least one character"),e.anchor=e.input.slice(t,e.position),!0}function Du(e,t,r,i,n){var s,o,a,l,u,h,c,f,d=1,p=!1,g=!1;if(null!==e.listener&&e.listener("open",e),e.tag=null,e.anchor=null,e.kind=null,e.result=null,s=o=a=su===r||nu===r,i&&Bu(e,!0,-1)&&(p=!0,e.lineIndent>t?d=1:e.lineIndent===t?d=0:e.lineIndent<t&&(d=-1)),1===d)for(;Mu(e)||Uu(e);)Bu(e,!0,-1)?(p=!0,a=s,e.lineIndent>t?d=1:e.lineIndent===t?d=0:e.lineIndent<t&&(d=-1)):a=!1;if(a&&(a=p||n),1!==d&&su!==r||(c=ru===r||iu===r?t:t+1,f=e.position-e.lineStart,1===d?a&&(Pu(e,f)||function(e,t,r){var i,n,s,o,a=e.tag,l=e.anchor,u={},h={},c=null,f=null,d=null,p=!1,g=!1;for(null!==e.anchor&&(e.anchorMap[e.anchor]=u),o=e.input.charCodeAt(e.position);0!==o;){if(i=e.input.charCodeAt(e.position+1),s=e.line,63!==o&&58!==o||!mu(i)){if(!Du(e,r,iu,!1,!0))break;if(e.line===s){for(o=e.input.charCodeAt(e.position);gu(o);)o=e.input.charCodeAt(++e.position);if(58===o)mu(o=e.input.charCodeAt(++e.position))||Eu(e,"a whitespace character is expected after the key-value separator within a block mapping"),p&&(Ru(e,u,h,c,f,null),c=f=d=null),g=!0,p=!1,n=!1,c=e.tag,f=e.result;else {if(!g)return e.tag=a,e.anchor=l,!0;Eu(e,"can not read an implicit mapping pair; a colon is missed");}}else {if(!g)return e.tag=a,e.anchor=l,!0;Eu(e,"can not read a block mapping entry; a multiline key may not be an implicit key");}}else 63===o?(p&&(Ru(e,u,h,c,f,null),c=f=d=null),g=!0,p=!0,n=!0):p?(p=!1,n=!0):Eu(e,"incomplete explicit mapping pair; a key node is missed"),e.position+=1,o=i;if((e.line===s||e.lineIndent>t)&&(Du(e,t,su,!0,n)&&(p?f=e.result:d=e.result),p||(Ru(e,u,h,c,f,d),c=f=d=null),Bu(e,!0,-1),o=e.input.charCodeAt(e.position)),e.lineIndent>t&&0!==o)Eu(e,"bad indentation of a mapping entry");else if(e.lineIndent<t)break}return p&&Ru(e,u,h,c,f,null),g&&(e.tag=a,e.anchor=l,e.kind="mapping",e.result=u),g}(e,f,c))||function(e,t){var r,i,n,s,o,a,l,u,h,c,f=!0,d=e.tag,p=e.anchor,g={};if(91===(c=e.input.charCodeAt(e.position)))n=93,a=!1,i=[];else {if(123!==c)return !1;n=125,a=!0,i={};}for(null!==e.anchor&&(e.anchorMap[e.anchor]=i),c=e.input.charCodeAt(++e.position);0!==c;){if(Bu(e,!0,t),(c=e.input.charCodeAt(e.position))===n)return e.position++,e.tag=d,e.anchor=p,e.kind=a?"mapping":"sequence",e.result=i,!0;f||Eu(e,"missed comma between flow collection entries"),h=null,s=o=!1,63===c&&mu(e.input.charCodeAt(e.position+1))&&(s=o=!0,e.position++,Bu(e,!0,t)),r=e.line,Du(e,t,ru,!1,!0),u=e.tag,l=e.result,Bu(e,!0,t),c=e.input.charCodeAt(e.position),!o&&e.line!==r||58!==c||(s=!0,c=e.input.charCodeAt(++e.position),Bu(e,!0,t),Du(e,t,ru,!1,!0),h=e.result),a?Ru(e,i,g,u,l,h):s?i.push(Ru(e,null,g,u,l,h)):i.push(l),Bu(e,!0,t),44===(c=e.input.charCodeAt(e.position))?(f=!0,c=e.input.charCodeAt(++e.position)):f=!1;}Eu(e,"unexpected end of the stream within a flow collection");}(e,c)?g=!0:(o&&function(e,t){var r,i,n,s,o,a=ou,l=!1,u=t,h=0,c=!1;if(124===(s=e.input.charCodeAt(e.position)))i=!1;else {if(62!==s)return !1;i=!0;}for(e.kind="scalar",e.result="";0!==s;)if(43===(s=e.input.charCodeAt(++e.position))||45===s)ou===a?a=43===s?lu:au:Eu(e,"repeat of a chomping mode identifier");else {if(!((n=48<=(o=s)&&o<=57?o-48:-1)>=0))break;0===n?Eu(e,"bad explicit indentation width of a block scalar; it cannot be less than one"):l?Eu(e,"repeat of an indentation width identifier"):(u=t+n-1,l=!0);}if(gu(s)){do{s=e.input.charCodeAt(++e.position);}while(gu(s));if(35===s)do{s=e.input.charCodeAt(++e.position);}while(!pu(s)&&0!==s)}for(;0!==s;){for(Lu(e),e.lineIndent=0,s=e.input.charCodeAt(e.position);(!l||e.lineIndent<u)&&32===s;)e.lineIndent++,s=e.input.charCodeAt(++e.position);if(!l&&e.lineIndent>u&&(u=e.lineIndent),pu(s))h++;else {if(e.lineIndent<u){a===lu?e.result+=gl.repeat("\n",h):a===ou&&l&&(e.result+="\n");break}for(i?gu(s)?(c=!0,e.result+=gl.repeat("\n",h+1)):c?(c=!1,e.result+=gl.repeat("\n",h+1)):0===h?l&&(e.result+=" "):e.result+=gl.repeat("\n",h):e.result+=l?gl.repeat("\n",h+1):gl.repeat("\n",h),l=!0,h=0,r=e.position;!pu(s)&&0!==s;)s=e.input.charCodeAt(++e.position);zu(e,r,e.position,!1);}}return !0}(e,c)||function(e,t){var r,i,n;if(39!==(r=e.input.charCodeAt(e.position)))return !1;for(e.kind="scalar",e.result="",e.position++,i=n=e.position;0!==(r=e.input.charCodeAt(e.position));)if(39===r){if(zu(e,i,e.position,!0),39!==(r=e.input.charCodeAt(++e.position)))return !0;i=n=e.position,e.position++;}else pu(r)?(zu(e,i,n,!0),Fu(e,Bu(e,!1,t)),i=n=e.position):e.position===e.lineStart&&Iu(e)?Eu(e,"unexpected end of the document within a single quoted scalar"):(e.position++,n=e.position);Eu(e,"unexpected end of the stream within a single quoted scalar");}(e,c)||function(e,t){var r,i,n,s,o,a,l;if(34!==(a=e.input.charCodeAt(e.position)))return !1;for(e.kind="scalar",e.result="",e.position++,r=i=e.position;0!==(a=e.input.charCodeAt(e.position));){if(34===a)return zu(e,r,e.position,!0),e.position++,!0;if(92===a){if(zu(e,r,e.position,!0),pu(a=e.input.charCodeAt(++e.position)))Bu(e,!1,t);else if(a<256&&wu[a])e.result+=ku[a],e.position++;else if((o=120===(l=a)?2:117===l?4:85===l?8:0)>0){for(n=o,s=0;n>0;n--)(o=yu(a=e.input.charCodeAt(++e.position)))>=0?s=(s<<4)+o:Eu(e,"expected hexadecimal character");e.result+=vu(s),e.position++;}else Eu(e,"unknown escape sequence");r=i=e.position;}else pu(a)?(zu(e,r,i,!0),Fu(e,Bu(e,!1,t)),r=i=e.position):e.position===e.lineStart&&Iu(e)?Eu(e,"unexpected end of the document within a double quoted scalar"):(e.position++,i=e.position);}Eu(e,"unexpected end of the stream within a double quoted scalar");}(e,c)?g=!0:!function(e){var t,r,i;if(42!==(i=e.input.charCodeAt(e.position)))return !1;for(i=e.input.charCodeAt(++e.position),t=e.position;0!==i&&!mu(i)&&!_u(i);)i=e.input.charCodeAt(++e.position);return e.position===t&&Eu(e,"name of an alias node must contain at least one character"),r=e.input.slice(t,e.position),e.anchorMap.hasOwnProperty(r)||Eu(e,'unidentified alias "'+r+'"'),e.result=e.anchorMap[r],Bu(e,!0,-1),!0}(e)?function(e,t,r){var i,n,s,o,a,l,u,h,c=e.kind,f=e.result;if(mu(h=e.input.charCodeAt(e.position))||_u(h)||35===h||38===h||42===h||33===h||124===h||62===h||39===h||34===h||37===h||64===h||96===h)return !1;if((63===h||45===h)&&(mu(i=e.input.charCodeAt(e.position+1))||r&&_u(i)))return !1;for(e.kind="scalar",e.result="",n=s=e.position,o=!1;0!==h;){if(58===h){if(mu(i=e.input.charCodeAt(e.position+1))||r&&_u(i))break}else if(35===h){if(mu(e.input.charCodeAt(e.position-1)))break}else {if(e.position===e.lineStart&&Iu(e)||r&&_u(h))break;if(pu(h)){if(a=e.line,l=e.lineStart,u=e.lineIndent,Bu(e,!1,-1),e.lineIndent>=t){o=!0,h=e.input.charCodeAt(e.position);continue}e.position=s,e.line=a,e.lineStart=l,e.lineIndent=u;break}}o&&(zu(e,n,s,!1),Fu(e,e.line-a),n=s=e.position,o=!1),gu(h)||(s=e.position+1),h=e.input.charCodeAt(++e.position);}return zu(e,n,s,!1),!!e.result||(e.kind=c,e.result=f,!1)}(e,c,ru===r)&&(g=!0,null===e.tag&&(e.tag="?")):(g=!0,null===e.tag&&null===e.anchor||Eu(e,"alias node should not have any properties")),null!==e.anchor&&(e.anchorMap[e.anchor]=e.result)):0===d&&(g=a&&Pu(e,f))),null!==e.tag&&"!"!==e.tag)if("?"===e.tag){for(l=0,u=e.implicitTypes.length;l<u;l+=1)if((h=e.implicitTypes[l]).resolve(e.result)){e.result=h.construct(e.result),e.tag=h.tag,null!==e.anchor&&(e.anchorMap[e.anchor]=e.result);break}}else tu.call(e.typeMap,e.tag)?(h=e.typeMap[e.tag],null!==e.result&&h.kind!==e.kind&&Eu(e,"unacceptable node kind for !<"+e.tag+'> tag; it should be "'+h.kind+'", not "'+e.kind+'"'),h.resolve(e.result)?(e.result=h.construct(e.result),null!==e.anchor&&(e.anchorMap[e.anchor]=e.result)):Eu(e,"cannot resolve a node with !<"+e.tag+"> explicit tag")):Eu(e,"unknown tag !<"+e.tag+">");return null!==e.listener&&e.listener("close",e),null!==e.tag||null!==e.anchor||g}function ju(e){var t,r,i,n,s=e.position,o=!1;for(e.version=null,e.checkLineBreaks=e.legacy,e.tagMap={},e.anchorMap={};0!==(n=e.input.charCodeAt(e.position))&&(Bu(e,!0,-1),n=e.input.charCodeAt(e.position),!(e.lineIndent>0||37!==n));){for(o=!0,n=e.input.charCodeAt(++e.position),t=e.position;0!==n&&!mu(n);)n=e.input.charCodeAt(++e.position);for(i=[],(r=e.input.slice(t,e.position)).length<1&&Eu(e,"directive name must not be less than one character in length");0!==n;){for(;gu(n);)n=e.input.charCodeAt(++e.position);if(35===n){do{n=e.input.charCodeAt(++e.position);}while(0!==n&&!pu(n));break}if(pu(n))break;for(t=e.position;0!==n&&!mu(n);)n=e.input.charCodeAt(++e.position);i.push(e.input.slice(t,e.position));}0!==n&&Lu(e),tu.call(Tu,r)?Tu[r](e,r,i):Au(e,'unknown document directive "'+r+'"');}Bu(e,!0,-1),0===e.lineIndent&&45===e.input.charCodeAt(e.position)&&45===e.input.charCodeAt(e.position+1)&&45===e.input.charCodeAt(e.position+2)?(e.position+=3,Bu(e,!0,-1)):o&&Eu(e,"directives end mark is expected"),Du(e,e.lineIndent-1,su,!1,!0),Bu(e,!0,-1),e.checkLineBreaks&&hu.test(e.input.slice(s,e.position))&&Au(e,"non-ASCII line breaks are interpreted as content"),e.documents.push(e.result),e.position===e.lineStart&&Iu(e)?46===e.input.charCodeAt(e.position)&&(e.position+=3,Bu(e,!0,-1)):e.position<e.length-1&&Eu(e,"end of the stream or a document separator is expected");}function Nu(e,t){t=t||{},0!==(e=String(e)).length&&(10!==e.charCodeAt(e.length-1)&&13!==e.charCodeAt(e.length-1)&&(e+="\n"),65279===e.charCodeAt(0)&&(e=e.slice(1)));var r=new xu(e,t);for(r.input+="\0";32===r.input.charCodeAt(r.position);)r.lineIndent+=1,r.position+=1;for(;r.position<r.length-1;)ju(r);return r.documents}function Zu(e,t,r){var i,n,s=Nu(e,r);for(i=0,n=s.length;i<n;i+=1)t(s[i]);}function Wu(e,t){var r=Nu(e,t);if(0!==r.length){if(1===r.length)return r[0];throw new _l("expected a single document in the stream, but found more")}}var qu={loadAll:Zu,load:Wu,safeLoadAll:function(e,t,r){Zu(e,t,gl.extend({schema:Gl},r));},safeLoad:function(e,t){return Wu(e,gl.extend({schema:Gl},t))}};function Yu(e){return function(){throw new Error("Function "+e+" is deprecated and cannot be used.")}}var Vu={Type:kl,Schema:Cl,FAILSAFE_SCHEMA:El,JSON_SCHEMA:Il,CORE_SCHEMA:Fl,DEFAULT_SAFE_SCHEMA:Gl,DEFAULT_FULL_SCHEMA:eu,load:qu.load,loadAll:qu.loadAll,safeLoad:qu.safeLoad,safeLoadAll:qu.safeLoadAll,YAMLException:_l,MINIMAL_SCHEMA:El,SAFE_SCHEMA:Gl,DEFAULT_SCHEMA:eu,scan:Yu("scan"),parse:Yu("parse"),compose:Yu("compose"),addConstructor:Yu("addConstructor")};class Hu{constructor(t,r,i=null){this.url=t,!r||e.isRelativeURL(r)&&!e.isRelativeURL(this.url)?this.path=e.pathForURL(this.url):this.path=r,this.path_for_parent=r||this.path,this.parent=i,this.container=null,this.parent&&(this.parent.container?this.container=this.parent.container:this.parent.isContainer()&&(this.container=this.parent));}load(){return $u(this.url)}resourceFor(e){return {url:this.urlFor(e),path:this.pathFor(e),type:this.typeFor(e)}}urlFor(t){return h(t)?t:e.isRelativeURL(t)&&this.container?this.parent.urlFor(this.path_for_parent+t):e.addBaseURL(t,this.path)}pathFor(t){return e.pathForURL(t)}typeFor(t){return e.extensionForURL(t)}isContainer(){return !1}}class Gu extends Hu{constructor(e,t,r){super(e,t,r),this.zip=null,this.files={},this.root=null,this.path="";}isContainer(){return !0}async load(){if(this.zip=new dl,"string"==typeof this.url){const{body:t}=await e.Utils.io(this.url,6e4,"arraybuffer");return await this.zip.loadAsync(t),await this.parseZipFiles(),this.loadRoot()}return this}urlFor(t){return h(t)?t:e.isRelativeURL(t)?this.urlForZipFile(e.flattenRelativeURL(t)):super.urlFor(t)}typeFor(t){return e.isRelativeURL(t)?this.typeForZipFile(t):super.typeFor(t)}loadRoot(){return this.findRoot(),$u(this.urlForZipFile(this.root))}findRoot(){const t=Object.keys(this.files).filter(e=>0===this.files[e].depth).filter(t=>"yaml"===e.extensionForURL(t));if(1===t.length&&(this.root=t[0]),!this.root){let e=`Could not find root scene for bundle '${this.url}': `;throw e+="The zip archive's root level must contain a single scene file with the '.yaml' extension. ",t.length>0?e+=`Found multiple YAML files at the root level: ${t.map(e=>"'"+e+"'").join(", ")}.`:e+="Found NO YAML files at the root level.",Error(e)}}async parseZipFiles(){let t=[],r=[];this.zip.forEach((e,i)=>{i.dir||(t.push(e),r.push(i.async("arraybuffer")));});const i=await Promise.all(r);for(let r=0;r<i.length;r++){let n=t[r],s=n.split("/").length-1;this.files[n]={data:i[r],type:e.extensionForURL(n),depth:s};}}urlForZipFile(t){if(this.files[t])return this.files[t].url||(this.files[t].url=e.createObjectURL(new Blob([this.files[t].data]))),this.files[t].url}typeForZipFile(e){return this.files[e]&&this.files[e].type}}function $u(t){return new Promise((r,i)=>{"string"==typeof t?e.Utils.io(t).then(({body:e})=>{try{r(function(e){return Vu.safeLoad(e,{json:!0})}(e));}catch(e){i(e);}},i):(t=Object.assign({},t),r(t));})}const Ku={async loadScene(t,{path:r,type:i}={}){const n=[],s={},o=await this.loadSceneRecursive({url:t,path:r,type:i},null,s,n),{config:a,bundle:l}=this.finalize(o);if(!a)throw n[0];return n.length>0&&n.forEach(t=>{const r=`Failed to import scene: ${t.url}`;e.log("error",r,t),this.trigger("error",{type:"scene_import",message:r,error:t,url:t.url});}),{config:a,bundle:l,texture_nodes:s}},async loadSceneRecursive({url:t,path:r,type:i},n,s={},o=[]){if(!t)return {};const a=function(t,r,i,n=null){return null!=n&&"zip"===n||"string"==typeof t&&!e.isLocalURL(t)&&"zip"===e.extensionForURL(t)?new Gu(t,r,i):new Hu(t,r,i)}(t,r,n,i);try{let r=await a.load();if(null==r.import)return this.normalize(r,a,s),{config:r,bundle:a};Array.isArray(r.import)||(r.import=[r.import]);const i=[];r.import.forEach(t=>{"object"==typeof t&&(t=e.createObjectURL(new Blob([JSON.stringify(t)]))),i.push(a.resourceFor(t));}),delete r.import;const n=i.map(e=>this.loadSceneRecursive(e,a,s,o)),l=(await Promise.all(n)).map(e=>this.normalize(e.config,e.bundle,s)).map(e=>e.config);return this.normalize(r,a,s),{config:r=e.mergeObjects(...l,r),bundle:a,texture_nodes:s}}catch(e){return e.url=t,o.push(e),{}}},normalize(e,t,r={}){return this.normalizeDataSources(e,t),this.normalizeFonts(e,t),this.normalizeTextures(e,t),this.collectTextures(e,t,r),{config:e,bundle:t,texture_nodes:r}},normalizeDataSources(e,t){e.sources=e.sources||{};for(const r in e.sources)this.normalizeDataSource(e.sources[r],t);return e},normalizeDataSource(e,t){if(e.url=t.urlFor(e.url),Array.isArray(e.composite)&&e.composite.forEach(e=>e.url=t.urlFor(e.url)),e.scripts){Array.isArray(e.scripts)&&(e.scripts=e.scripts.reduce((e,t)=>(e[t]=t,e),{}));for(const r in e.scripts)e.scripts[r]=t.urlFor(e.scripts[r]);}return e},normalizeFonts(e,t){e.fonts=e.fonts||{};for(const r in e.fonts)if(Array.isArray(e.fonts[r]))e.fonts[r].forEach(e=>{e.url=e.url&&t.urlFor(e.url);});else {const i=e.fonts[r];i.url=i.url&&t.urlFor(i.url);}return e},normalizeTextures(e,t){if(e.textures=e.textures||{},e.textures)for(const r in e.textures){const i=e.textures[r];i.url&&(i.url=t.urlFor(i.url));}},collectTextures(t,r,i){if(t.styles)for(const e in t.styles){const n=t.styles[e],s=n.texture;if("string"==typeof s&&!t.textures[s]){const t=["styles",e,"texture"];this.addTextureNode(t,r,i);}n.material&&["emission","ambient","diffuse","specular","normal"].forEach(s=>{const o=null!=n.material[s]&&n.material[s].texture;if("string"==typeof o&&!t.textures[o]){const t=["styles",e,"material",s,"texture"];this.addTextureNode(t,r,i);}});}if(t.styles)for(const n in t.styles){const s=t.styles[n];s.shaders&&s.shaders.uniforms&&e.GLSL.parseUniforms(s.shaders.uniforms).forEach(({type:e,value:s,key:o})=>{if("sampler2D"===e&&"string"==typeof s&&!t.textures[s]){const e=["styles",n,"shaders","uniforms",o];this.addTextureNode(e,r,i);}});}if(t.layers){const n=[t.layers],s=[["layers"]];for(;n.length>0;){const o=n.pop(),a=s.pop();if("object"==typeof o&&!Array.isArray(o))for(const l in o)if("draw"===l){const e=o[l];for(const n in e){if(e[n].texture){const s=e[n].texture;if("string"==typeof s&&!t.textures[s]){const e=[...a,l,"draw",n,"texture"];this.addTextureNode(e,r,i);}}if(e[n].outline&&e[n].outline.texture){const s=e[n].outline.texture;if("string"==typeof s&&!t.textures[s]){const e=[...a,l,"draw",n,"outline","texture"];this.addTextureNode(e,r,i);}}}}else {if(e.isReserved(l))continue;n.push(o[l]),s.push([...a,l]);}}}},addTextureNode(e,t,r){r[JSON.stringify(e)]={path:e,bundle:t};},hoistTextureNodes(e,t,r={}){for(const{path:i,bundle:o}of Object.values(r)){const r=n(e,i);if("string"==typeof r&&null==e.textures[r])if(c(e,i)){const i=t.urlFor(r);e.textures[r]={url:i};}else {const t=o.urlFor(r);e.textures[t]={url:t},s(e,i,t);}}},applyGlobalProperties(t){if(!t.global||0===Object.keys(t.global).length)return t;return function t(r,i,n,s){var o;let h;if((null==n?void 0:null==(o=n[u])?void 0:o[s])?h=n[u][s]:"string"==typeof i&&i.slice(0,l)===a&&(h=i),h){null==n[u]&&Object.defineProperty(n,u,{value:{}}),n[u][s]=h;let t,i=r[h];for(;"string"==typeof i&&i.slice(0,l)===a;){if((t=t||[h]).indexOf(i)>-1){e.log({level:"warn",once:!0},"Global properties: cyclical reference detected",t),i=null;break}t.push(i),i=r[i];}Object.defineProperty(n,s,{enumerable:!0,get:function(){return i},set:function(e){delete n[u][s],delete n[s],n[s]=e;}});}else if(Array.isArray(i))for(let e=0;e<i.length;e++)t(r,i[e],i,e);else if("object"==typeof i)for(const e in i)t(r,i[e],i,e);return i}(function e(t,r=null,i={}){r=r?r+".":a;for(const n in t){const s=r+n,o=t[n];i[s]=o,"object"!=typeof o||Array.isArray(o)||e(o,s,i);}return i}(t.global),t)},finalize:({config:e,bundle:t})=>e?(e.global=e.global||{},e.scene=e.scene||{},e.cameras=e.cameras||{},e.lights=e.lights||{},e.styles=e.styles||{},e.layers=e.layers||{},e.camera&&(e.cameras.default=e.camera),0===Object.keys(e.cameras).length&&(e.cameras.default={}),(0===Object.keys(e.lights).length||Object.keys(e.lights).every(t=>!1===e.lights[t].visible))&&(e.lights.default_light={type:"directional"}),{config:e,bundle:t}):{}};e.subscribeMixin(Ku);class Ju{constructor(){this.tiles={},this.max_proxy_descendant_depth=6,this.max_proxy_ancestor_depth=7,this.children_cache={};}addTile(t){for(this.tiles[t.key]=this.tiles[t.key]||{descendants:0},this.tiles[t.key].tile=t;t.style_z>=0;){if(!(t=e.TileID.parent(t)))return;this.tiles[t.key]||(this.tiles[t.key]={descendants:0}),this.tiles[t.key].descendants++;}}removeTile(t){for(this.tiles[t.key]&&(delete this.tiles[t.key].tile,0===this.tiles[t.key].descendants&&delete this.tiles[t.key]);t.style_z>=0;){if(!(t=e.TileID.parent(t)))return;this.tiles[t.key]&&this.tiles[t.key].descendants>0&&(this.tiles[t.key].descendants--,0!==this.tiles[t.key].descendants||this.tiles[t.key].tile||delete this.tiles[t.key]);}}getAncestor(t){let r=0;for(;r<this.max_proxy_ancestor_depth;){if(!(t=e.TileID.parent(t)))return;if(this.tiles[t.key]&&this.tiles[t.key].tile&&this.tiles[t.key].tile.loaded)return this.tiles[t.key].tile;r++;}}getDescendants(t,r=0){let i=[];if(r<this.max_proxy_descendant_depth){let n=e.TileID.children(t,this.children_cache);if(!n)return;n.forEach(e=>{this.tiles[e.key]&&(this.tiles[e.key].tile&&this.tiles[e.key].tile.loaded?i.push(this.tiles[e.key].tile):this.tiles[e.key].descendants>0&&i.push(...this.getDescendants(e,r+1)));});}return i}}let Xu={},Qu={};async function eh(t,r,i=!1){Qu=Xu,Xu={};let n=function(t,r){const i={};let n={};t.forEach(t=>{const s=e.Geo.unitsPerMeter(t.coords.z),o=Math.pow(2,r-t.style_z),a=s*o,l=e.Geo.metersPerPixel(r),u=Object.assign({},t.meshes,t.pending_label_meshes);for(let r in u){const o=u[r];o.forEach(r=>{if(r.labels)for(let o in r.labels){if(t.isProxy()&&!Qu[o])continue;const u=r.labels[o].container.label,h=r.labels[o].container.linked,c=r.labels[o].ranges;let f=i[o]={};if(f.discard=th.bind(f),f.build_id=t.build_id,Object.assign(f,u),f.layout=Object.assign({},u.layout),f.layout.repeat_scale=.75,f.layout.repeat_distance=f.layout.repeat_distance||0,f.layout.repeat_distance/=a,f.position=[f.position[0]/s+t.min.x,f.position[1]/s+t.min.y],f.unit_scale=l,"point"===f.type)e.LabelPoint.prototype.updateBBoxes.call(f);else if("straight"===f.type)e.LabelLineStraight.prototype.updateBBoxes.call(f,f.position,f.size,f.angle,f.angle,f.offset);else if(u.obbs){const r=u.obbs.map(r=>{let{x:i,y:n,a:o,w:l,h:u}=r;return i=i/s+t.min.x,n=n/s+t.min.y,l/=a,u/=a,new e.OBB(i,n,o,l,u)});f.obbs=r,f.aabbs=r.map(e=>e.getExtent());}n[o]={label:f,linked:h,ranges:c,mesh:r};}});}});for(let e in n){const t=n[e];t.linked&&(t.linked=n[t.linked]);}return n=Object.keys(n).map(e=>n[e])}(t,r);e.Collision.startTile("main",{apply_repeat_groups:!0,return_hidden:!0}),e.Collision.addStyle("main","main");const s=Math.max(0,...Object.values(t).map(e=>Object.values(e.meshes)).flat().map(e=>Math.max(0,...e.map(e=>e.labels?Object.keys(e.labels).length:0)))),o=Math.floor(s/e.Geo.tile_size);o>0?e.Collision.initGrid({anchor:{x:Math.min(...t.map(e=>e.min.x)),y:Math.min(...t.map(e=>e.min.y))},span:t[0].span.x/o}):e.Collision.initGrid();const a=await e.Collision.collide(n,"main","main");let l=[];return a.forEach(e=>{let t=0;!0!==e.show||i&&e.label.breach&&!Qu[e.label.id]||(t=1),t&&(Xu[e.label.id]=!0);let r=!0;e.ranges.forEach(i=>{if(!r)return;let n=e.mesh;if(!n.valid)return;let s=n.vertex_layout.offset.a_shape,o=n.vertex_layout.stride;for(let e=0;e<i[1];e++){if(n.vertex_data[i[0]+e*o+s+6]===t)return void(r=!1);n.vertex_data[i[0]+e*o+s+6]=t;}-1===l.indexOf(n)&&l.push(n);});}),l.forEach(e=>e.upload()),t.forEach(e=>e.swapPendingLabels()),{labels:a,containers:n}}function th(t,r=null){if(this.obb)return e.Label.prototype.occluded.call(this,t,r);if(this.obbs)for(let i=0;i<this.obbs.length;i++){let n={aabb:this.aabbs[i],obb:this.obbs[i]};if(e.Label.prototype.occluded.call(n,t,r))return !0}return !1}class rh{constructor({scene:t}){this.scene=t,this.tiles={},this.pyramid=new Ju,this.visible_coords={},this.queued_coords=[],this.building_tiles=null,this.renderable_tiles=[],this.collision={tile_keys:null,mesh_set:null,zoom:null,zoom_steps:3},this.main_thread_target=["TileManager",this.scene.id].join("_"),e.WorkerBroker.addTarget(this.main_thread_target,this);}destroy(){this.forEachTile(e=>e.destroy()),this.tiles={},this.pyramid=null,this.visible_coords={},this.queued_coords=[],this.scene=null,e.WorkerBroker.removeTarget(this.main_thread_target);}get view(){return this.scene.view}get style_manager(){return this.scene.style_manager}keepTile(e){this.tiles[e.key]=e,this.pyramid.addTile(e);}hasTile(e){return void 0!==this.tiles[e]}forgetTile(e){if(this.hasTile(e)){let t=this.tiles[e];this.pyramid.removeTile(t);}delete this.tiles[e],this.tileBuildStop(e);}removeTile(t){e.log("trace",`tile unload for ${t}`);var r=this.tiles[t];null!=r&&r.destroy(),this.forgetTile(r.key),this.scene.requestRedraw();}forEachTile(e){for(let t in this.tiles)e(this.tiles[t]);}removeTiles(e){let t=[];for(let r in this.tiles){e(this.tiles[r])&&t.push(r);}for(let e=0;e<t.length;e++){let r=t[e];this.removeTile(r);}}updateTilesForView(){this.visible_coords={};let e=this.view.findVisibleTileCoordinates();for(let t=0;t<e.length;t++){const r=e[t];this.queueCoordinate(r),this.visible_coords[r.key]=r;}this.updateTileStates();}updateTileStates(){return this.forEachTile(e=>{this.updateVisibility(e);}),this.loadQueuedCoordinates(),this.updateProxyTiles(),this.view.pruneTilesForView(),this.updateRenderableTiles(),this.style_manager.updateActiveStyles(this.renderable_tiles),this.style_manager.updateActiveBlendOrders(this.renderable_tiles),this.updateLabels()}updateLabels(){var t=this;if(this.scene.building&&!this.scene.building.initial)return Promise.resolve({});const r=this.renderable_tiles.filter(e=>e.valid).filter(e=>e.built);return 0===r.length?Promise.resolve({}):(r.sort((e,t)=>e.build_id<t.build_id?-1:e.build_id>t.build_id?1:0),this.collision.zoom===ih(this.view.zoom,this.collision.zoom_steps)&&this.collision.tile_keys===JSON.stringify(r.map(e=>e.key))&&this.collision.mesh_set===nh(r)?Promise.resolve({}):(this.collision.task||(this.collision.zoom=ih(this.view.zoom,this.collision.zoom_steps),this.collision.tile_keys=JSON.stringify(r.map(e=>e.key)),this.collision.mesh_set=nh(r),this.collision.task={type:"tileManagerUpdateLabels",run:async function(i){const n=await eh(r,t.collision.zoom,t.isLoadingVisibleTiles());t.scene.requestRedraw(),t.collision.task=null,e.Task.finish(i,n),t.updateTileStates();},immediate:!0},e.Task.add(this.collision.task)),this.collision.task.promise))}updateProxyTiles(){if(0===this.view.zoom_direction)return;this.forEachTile(e=>e.setProxyFor(null));let e=!1;this.forEachTile(t=>{if(t.visible&&!t.labeled){const r=this.pyramid.getAncestor(t);if(r)r.setProxyFor(t),e=!0;else {const r=this.pyramid.getDescendants(t);for(let i=0;i<r.length;i++)r[i].setProxyFor(t),e=!0;}}}),e||(this.view.zoom_direction=0);}updateVisibility(t){if(t.visible=!1,t.style_z===this.view.tile_zoom)if(this.visible_coords[t.coords.key])t.visible=!0;else for(let r in this.visible_coords)if(e.TileID.isDescendant(t.coords,this.visible_coords[r])){t.visible=!0;break}}pruneToVisibleTiles(){this.removeTiles(e=>!e.visible);}getRenderableTiles(){return this.renderable_tiles}updateRenderableTiles(){this.renderable_tiles=[];for(let e in this.tiles){let t=this.tiles[e];t.visible&&t.loaded&&this.renderable_tiles.push(t);}return this.renderable_tiles}isLoadingVisibleTiles(){return Object.keys(this.tiles).some(e=>this.tiles[e].visible&&!this.tiles[e].built)}allVisibleTilesLabeled(){return this.renderable_tiles.every(e=>e.labeled)}queueCoordinate(e){this.queued_coords[this.queued_coords.length]=e;}loadQueuedCoordinates(){0!==this.queued_coords.length&&(this.queued_coords.sort((t,r)=>{let i=this.view.center.meters,n=e.Geo.metersPerTile(t.z)/2,s=e.Geo.metersForTile(t);s.x+=n,s.y-=n;let o=e.Geo.metersForTile(r);o.x+=n,o.y-=n;let a=Math.abs(i.x-s.x)+Math.abs(i.y-s.y),l=Math.abs(i.x-o.x)+Math.abs(i.y-o.y);return t.center_dist=a,r.center_dist=l,l>a?-1:l===a?0:1}),this.queued_coords.forEach(e=>this.loadCoordinate(e)),this.queued_coords=[]);}loadCoordinate(t){if(t.z===this.view.center.tile.z)for(let r in this.scene.sources){let i=this.scene.sources[r];if(!i.builds_geometry_tiles||!i.includesTile(t,this.view.tile_zoom))continue;let n=e.TileID.normalizedKey(t,i,this.view.tile_zoom);if(n&&!this.hasTile(n)){e.log("trace",`load tile ${n}, distance from view center: ${t.center_dist}`);let r=new e.Tile({source:i,coords:t,workers:this.scene.workers,style_z:this.view.baseZoom(t.z),view:this.view});this.keepTile(r),this.buildTile(r);}}}buildTile(e,t){this.tileBuildStart(e.key),this.updateVisibility(e),e.build(this.scene.generation,t);}buildTileStylesCompleted({tile:t,progress:r}){if(null==this.tiles[t.key])e.log("trace",`discarded tile ${t.key} in TileManager.buildTileStylesCompleted because previously removed`),e.Tile.abortBuild(t),this.updateTileStates();else if(t.generation!==this.scene.generation)e.log("trace",`discarded tile ${t.key} in TileManager.buildTileStylesCompleted because built with `+`scene config gen ${t.generation}, current ${this.scene.generation}`),e.Tile.abortBuild(t),this.updateTileStates();else {if(this.tiles[t.key]){if(t.id<this.tiles[t.key].id)return e.log("trace",`discarded tile ${t.key} for id ${t.id} in TileManager.buildTileStylesCompleted because built for discarded tile id`),void e.Tile.abortBuild(t);t=this.tiles[t.key].merge(t);}r.done&&(t.built=!0),t.buildMeshes(this.scene.styles,r),this.updateTileStates(),this.scene.requestRedraw();}r.done&&this.tileBuildStop(t.key);}buildTileError(t){e.log("error",`Error building tile ${t.key}:`,t.error),this.forgetTile(t.key),e.Tile.abortBuild(t);}tileBuildStart(t){this.building_tiles=this.building_tiles||{},this.building_tiles[t]=!0,e.log("trace",`tileBuildStart for ${t}: ${Object.keys(this.building_tiles).length}`);}tileBuildStop(t){this.building_tiles&&(e.log("trace",`tileBuildStop for ${t}: ${Object.keys(this.building_tiles).length}`),delete this.building_tiles[t],this.checkBuildQueue());}checkBuildQueue(){this.building_tiles&&0!==Object.keys(this.building_tiles).length||(this.building_tiles=null,this.scene.tileManagerBuildDone());}getDebugProp(e,t){var r=[];for(var i in this.tiles)null==this.tiles[i].debug[e]||"function"==typeof t&&!0!==t(this.tiles[i])||r.push(this.tiles[i].debug[e]);return r}getDebugSum(e,t){var r=0;for(var i in this.tiles)null==this.tiles[i].debug[e]||"function"==typeof t&&!0!==t(this.tiles[i])||(r+=this.tiles[i].debug[e]);return r}getDebugAverage(e,t){return this.getDebugSum(e,t)/Object.keys(this.tiles).length}}function ih(e,t,r=2){return (Math.floor(e*t)/t).toFixed(r)}function nh(e){return JSON.stringify(Object.entries(e).map(([,e])=>Object.entries(e.meshes).map(([,e])=>e.map(e=>e.created_at))))}class sh{constructor(e,t){t(e),this.value=e,this.setup=t;}set(e){JSON.stringify(this.value)!==JSON.stringify(e)&&(this.setup(e),this.value=e);}}class oh{constructor(e){this.defaults={},this.defaults.culling=!0,this.defaults.culling_face=e.BACK,this.defaults.blending=!1,this.defaults.blending_src=e.ONE_MINUS_SRC_ALPHA,this.defaults.blending_dst=e.ONE_MINUS_SRC_ALPHA,this.defaults.blending_src_alpha=e.ONE,this.defaults.blending_dst_alpha=e.ONE_MINUS_SRC_ALPHA,this.defaults.depth_write=!0,this.defaults.depth_test=!0,e.depthFunc(e.LESS),this.culling=new sh({cull:this.defaults.culling,face:this.defaults.culling_face},t=>{t.cull?(e.enable(e.CULL_FACE),e.cullFace(t.face)):e.disable(e.CULL_FACE);}),this.blending=new sh({blend:this.defaults.blending,src:this.defaults.blending_src,dst:this.defaults.blending_dst,src_alpha:this.defaults.blending_src_alpha,dst_alpha:this.defaults.blending_dst_alpha},t=>{t.blend?(e.enable(e.BLEND),t.src_alpha&&t.dst_alpha?e.blendFuncSeparate(t.src,t.dst,t.src_alpha,t.dst_alpha):e.blendFunc(t.src,t.dst)):e.disable(e.BLEND);}),this.depth_write=new sh({depth_write:this.defaults.depth_write},t=>{e.depthMask(t.depth_write);}),this.depth_test=new sh({depth_test:this.defaults.depth_test},t=>{t.depth_test?e.enable(e.DEPTH_TEST):e.disable(e.DEPTH_TEST);});}}class ah{constructor(){this.canvas=null,this.gl=null,this.screenshot_canvas=null,this.screenshot_context=null,this.queue_screenshot=null,this.video_capture=null;}setCanvas(e,t){this.canvas=e,this.gl=t;}screenshot({background:e}={}){return null!=this.queue_screenshot?this.queue_screenshot.promise:(this.queue_screenshot={background:e},this.queue_screenshot.promise=new Promise((e,t)=>{this.queue_screenshot.resolve=e,this.queue_screenshot.reject=t;}),this.queue_screenshot.promise)}completeScreenshot(){if(null!=this.queue_screenshot){let t=this.canvas.width,r=this.canvas.height,i=new Uint8Array(t*r*4);this.gl.readPixels(0,0,t,r,this.gl.RGBA,this.gl.UNSIGNED_BYTE,i);let n=this.queue_screenshot.background;n=n&&"transparent"!==n?e.StyleParser.parseColor(n).slice(0,3).map(e=>255*e):null;let s=new Uint8ClampedArray(t*r*4);for(let e=0;e<r;e++)for(let o=0;o<t;o++){let a=4*((r-e-1)*t+o),l=4*(e*t+o),u=i[a+3];s[l+0]=255*i[a+0]/u,s[l+1]=255*i[a+1]/u,s[l+2]=255*i[a+2]/u,s[l+3]=u,n&&(u/=255,s[l+0]=s[l+0]*u+n[0]*(1-u),s[l+1]=s[l+1]*u+n[1]*(1-u),s[l+2]=s[l+2]*u+n[2]*(1-u),s[l+3]=255);}this.screenshot_canvas=this.screenshot_canvas||document.createElement("canvas");let o=this.screenshot_canvas;o.width=t,o.height=r,this.screenshot_context=this.screenshot_context||o.getContext("2d");let a=this.screenshot_context,l=new ImageData(s,t,r);a.putImageData(l,0,0);const u=o.toDataURL("image/png"),h=atob(u.slice(22)),c=new Uint8Array(h.length);for(let e=0;e<h.length;++e)c[e]=h.charCodeAt(e);const f=new Blob([c],{type:"image/png"});this.queue_screenshot.resolve({url:u,blob:f,type:"png"}),this.queue_screenshot=null;}}startVideoCapture(){if("function"!=typeof window.MediaRecorder||!this.canvas||"function"!=typeof this.canvas.captureStream)return e.log("warn","Video capture (Canvas.captureStream and/or MediaRecorder APIs) not supported by browser"),!1;if(this.video_capture)return e.log("warn","Video capture already in progress, call Scene.stopVideoCapture() first"),!1;try{let t=this.video_capture={};t.chunks=[],t.stream=this.canvas.captureStream(),t.options={mimeType:"video/webm"},t.media_recorder=new MediaRecorder(t.stream,t.options),t.media_recorder.ondataavailable=(r=>{if(r.data.size>0&&t.chunks.push(r.data),t.resolve){let r=new Blob(t.chunks,{type:t.options.mimeType}),i=e.createObjectURL(r);if(t.stream){(t.stream.getTracks()||[]).forEach(e=>{e.stop(),t.stream.removeTrack(e);});}t.stream=null,t.media_recorder=null,this.video_capture=null,t.resolve({url:i,blob:r,type:"webm"});}}),t.media_recorder.start();}catch(t){return this.video_capture=null,e.log("error","Scene video capture failed",t),!1}return !0}stopVideoCapture(){return this.video_capture?(this.video_capture.promise=new Promise((e,t)=>{this.video_capture.resolve=e,this.video_capture.reject=t;}),this.video_capture.media_recorder.stop(),this.video_capture.promise):(e.log("warn","No scene video capture in progress, call Scene.startVideoCapture() first"),Promise.resolve({}))}}class lh{constructor(t,r){var i;r=r||{},e.subscribeMixin(this),this.id=lh.id++,this.initialized=!1,this.initializing=null,this.sources={},this.view=new e.View(this,r),this.tile_manager=new rh({scene:this}),this.num_workers=r.numWorkers||2,!0===r.disableVertexArrayObjects&&(e.VertexArrayObject.disabled=!0),e.Utils.use_high_density_display=void 0===r.highDensityDisplay||r.highDensityDisplay,e.Utils.updateDevicePixelRatio(),this.config=null,this.config_source=t,this.config_bundle=null,this.last_valid_config_source=null,this.styles=null,this.style_manager=new e.StyleManager,this.building=null,this.dirty=!0,r.preUpdate&&this.subscribe({pre_update:r.preUpdate}),r.postUpdate&&this.subscribe({post_update:r.postUpdate}),this.render_loop=!r.disableRenderLoop,this.render_loop_active=!1,this.render_loop_stop=!1,this.render_count=0,this.last_render_count=0,this.render_count_changed=!1,this.frame=0,this.last_main_render=-1,this.last_selection_render=-1,this.media_capture=new ah,this.selection=null,this.selection_feature_count=0,this.fetching_selection_map=null,this.prev_textures=null,this.introspection=!0===r.introspection,this.times={},this.resetTime(),this.container=r.container,this.canvas=null,this.contextOptions=r.webGLContextOptions,this.lights=null,this.background=null,this.createListeners(),this.updating=0,this.generation=lh.generation,this.last_complete_generation=lh.generation,(i=this).debug={profile(t){console.profile(`main thread: ${t}`),e.WorkerBroker.postMessage(i.workers,"self.profile",t);},profileEnd(t){console.profileEnd(`main thread: ${t}`),e.WorkerBroker.postMessage(i.workers,"self.profileEnd",t);},timeRebuild(t=1,r={}){let n=[],s=()=>{let o=+new Date;i.rebuild(r).then(()=>{if(n.push(+new Date-o),n.length<t)s();else {let r=~~(n.reduce((e,t)=>e+t)/n.length);e.log("info",`Profiled rebuild ${t} times: ${r} avg (${Math.min(...n)} min, ${Math.max(...n)} max)`);}});};s();},geometryCountByStyle(){let e={};return i.tile_manager.getRenderableTiles().forEach(t=>{for(let r in t.meshes)e[r]=e[r]||0,t.meshes[r].forEach(t=>{e[r]+=t.geometry_count;});}),e},geometryCountByBaseStyle(){let e=i.debug.geometryCountByStyle(),t={};for(let r in e){let n=i.styles[r].baseStyle();t[n]=t[n]||0,t[n]+=e[r];}return t},geometryCountTotal(){const e=i.debug.geometryCountByStyle();return Object.keys(e).reduce((t,r)=>e[r]+t,0)},geometrySizeByStyle(){let e={};return i.tile_manager.getRenderableTiles().forEach(t=>{for(let r in t.meshes)e[r]=e[r]||0,t.meshes[r].forEach(t=>{e[r]+=t.buffer_size;});}),e},geometrySizeByBaseStyle(){let e=i.debug.geometrySizeByStyle(),t={};for(let r in e){let n=i.styles[r].baseStyle();t[n]=t[n]||0,t[n]+=e[r];}return t},geometrySizeTotal(){const e=i.debug.geometrySizeByStyle();return Object.keys(e).reduce((t,r)=>e[r]+t,0)},textureSizeTotal:()=>Object.values(e.Texture.textures).map(e=>e.byteSize()).reduce((e,t)=>e+t),layerStats:()=>e.debugSettings.layer_stats?e.debugSumLayerStats(i.tile_manager.getRenderableTiles()):(e.log("warn","Enable the 'layer_stats' debug setting to collect layer stats"),{}),renderableTilesCount:()=>i.tile_manager.getRenderableTiles().length},this.log_level=r.logLevel||"warn",e.log.setLevel(this.log_level),e.log.reset();}static create(e,t={}){return new lh(e,t)}load(t=null,r={}){var i=this;return this.initializing?this.initializing:(e.log.reset(),this.updating++,this.initialized=!1,this.view_complete=!1,this.times.frame=null,this.times.build=null,(r="string"==typeof r?{base_path:r}:r).blocking=void 0===r.blocking||r.blocking,!1!==this.render_loop&&this.setupRenderLoop(),this.createCanvas(),this.prev_textures=this.config&&Object.keys(this.config.textures),this.initializing=this.loadScene(t,r).then(async function({texture_nodes:t}){await i.createWorkers(),i.destroyFeatureSelection(),e.WorkerBroker.postMessage(i.workers,"self.clearFunctionStringCache");const n="object"==typeof i.config_source||i.hasSubscribersFor("load"),s=i.updateConfig({texture_nodes:t,serialize_funcs:n,normalize:!1,loading:!0,fade_in:!0});!0===r.blocking&&await s,i.freePreviousTextures(),i.updating--,i.initializing=null,i.initialized=!0,i.last_valid_config_source=i.config_source,i.last_valid_options={base_path:r.base_path,file_type:r.file_type},i.requestRedraw();}).catch(t=>{let r,i;if(this.initializing=null,this.updating=0,"YAMLException"===t.name?(r="yaml",i="Error parsing scene YAML"):i="Error initializing scene",this.trigger("error",{type:r,message:i,error:t,url:this.config_source}),i=`Scene.load() failed to load ${JSON.stringify(this.config_source)}: ${t.message}`,this.last_valid_config_source)return e.log("warn",i,t),e.log("info","Scene.load() reverting to last valid configuration"),this.load(this.last_valid_config_source,this.last_valid_base_path);throw e.log("error",i,t),t}),this.initializing)}destroy(){if(this.initialized=!1,this.render_loop_stop=!0,this.destroyListeners(),this.destroyFeatureSelection(),this.canvas&&this.canvas.parentNode&&(this.canvas.parentNode.removeChild(this.canvas),this.canvas=null),this.container=null,this.gl){e.Texture.destroy(this.gl),this.style_manager.destroy(this.gl),this.styles={},e.ShaderProgram.reset();let t=this.gl.getExtension("WEBGL_lose_context");t&&t.loseContext(),this.gl=null;}this.sources={},this.destroyWorkers(),this.tile_manager.destroy(),this.tile_manager=null,e.log.reset();}createCanvas(){if(!this.canvas){this.container=this.container||document.body,this.canvas=document.createElement("canvas"),this.canvas.style.position="absolute",this.canvas.style.top=0,this.canvas.style.left=0,this.container.style.backgroundColor="transparent",this.container.appendChild(this.canvas);try{this.gl=r.getContext(this.canvas,Object.assign({alpha:!0,premultipliedAlpha:!0,stencil:!0,device_pixel_ratio:e.Utils.device_pixel_ratio,powerPreference:"high-performance"},this.contextOptions));}catch(e){throw new Error("Couldn't create WebGL context. Your browser may not support WebGL, or it's turned off? Visit http://webglreport.com/ for more info.")}this.resizeMap(this.container.clientWidth,this.container.clientHeight),e.VertexArrayObject.init(this.gl),this.render_states=new oh(this.gl),this.media_capture.setCanvas(this.canvas,this.gl);}}updateExternalScripts(){let e=[...this.external_scripts||[]],t=[];if(this.config.scene.scripts)for(let e in this.config.scene.scripts)-1===t.indexOf(this.config.scene.scripts[e])&&t.push(this.config.scene.scripts[e]);for(let e in this.config.sources){let r=this.config.sources[e];if(r.scripts)for(let e in r.scripts)-1===t.indexOf(r.scripts[e])&&t.push(r.scripts[e]);}return this.external_scripts=t,!(this.external_scripts.length===e.length&&this.external_scripts.every((t,r)=>t===e[r]))}createWorkers(){return this.updateExternalScripts()&&this.destroyWorkers(),this.workers?Promise.resolve():this.makeWorkers()}makeWorkers(){let t=!!this.gl.getExtension("OES_element_index_uint"),r=[];this.workers=[];for(let i=0;i<this.num_workers;i++){let n=new Worker(Tangram.workerURL);this.workers[i]=n,e.WorkerBroker.addWorker(n),e.log("debug",`Scene.makeWorkers: initializing worker ${i}`);let s=i;r.push(e.WorkerBroker.postMessage(n,"self.init",this.id,i,this.num_workers,this.log_level,e.Utils.device_pixel_ratio,t,this.external_scripts).then(t=>(e.log("debug",`Scene.makeWorkers: initialized worker ${t}`),t),t=>(e.log("error",`Scene.makeWorkers: failed to initialize worker ${s}:`,t),Promise.reject(t))));}return this.next_worker=0,Promise.all(r).then(()=>{e.log.setWorkers(this.workers);})}destroyWorkers(){this.selection=null,Array.isArray(this.workers)&&(e.log.setWorkers(null),this.workers.forEach(e=>{e.terminate();}),this.workers=null);}ready(){return !(!this.view.ready()||0===Object.keys(this.sources).length)}updateDevicePixelRatio(){e.Utils.updateDevicePixelRatio()&&e.WorkerBroker.postMessage(this.workers,"self.updateDevicePixelRatio",e.Utils.device_pixel_ratio).then(()=>this.rebuild()).then(()=>this.resizeMap(this.view.size.css.width,this.view.size.css.height));}resizeMap(t,i){0===t&&0===i||(this.dirty=!0,this.view.setViewportSize(t,i),this.gl&&r.resize(this.gl,t,i,e.Utils.device_pixel_ratio));}requestRedraw(){this.dirty=!0;}immediateRedraw(){this.dirty=!0,this.update();}renderLoop(){this.render_loop_active=!0,this.update(),e.Task.setState({user_moving_view:this.view.user_input_active}),e.Task.processAll(),this.render_loop_stop?(this.render_loop_stop=!1,this.render_loop_active=!1):window.requestAnimationFrame(this.renderLoop.bind(this));}setupRenderLoop(){this.render_loop_active||setTimeout(()=>{this.renderLoop();},0);}update(){let t=this.dirty,r=!!this.selection&&this.selection.hasPendingRequests();var i=!(!1===t&&!1===r||!1===this.initialized||this.updating>0||!1===this.ready());return this.trigger("pre_update",i),this.view.update(),!!i&&(this.dirty=!1,this.updateDevicePixelRatio(),this.render({main:t,selection:r}),this.updateViewComplete(),this.media_capture.completeScreenshot(),this.trigger("post_update",i),(!0===this.animated||this.view.isAnimating())&&(this.dirty=!0),this.frame++,e.log("trace","Scene.render()"),!0)}render({main:t,selection:r}){var i=this.gl;if(this.updateBackground(),Object.keys(this.lights).forEach(e=>this.lights[e].update()),this.render_count_changed=!1,t&&(this.render_count=this.renderPass(),this.last_main_render=this.frame,this.render_count!==this.last_render_count&&(this.render_count_changed=!0,this.logFirstFrame(),this.getFeatureSelectionMapSize().then(t=>{this.selection_feature_count=t,e.log("info",`Scene: rendered ${this.render_count} primitives (${t} features in selection map)`);})),this.last_render_count=this.render_count),r){if(this.view.panning||this.view.user_input_active)return void this.selection.clearPendingRequests();!this.selection.locked&&this.last_selection_render<this.last_main_render&&(this.selection.bind(),this.renderPass("selection_program",{allow_blend:!1}),i.bindFramebuffer(i.FRAMEBUFFER,null),i.viewport(0,0,this.canvas.width,this.canvas.height),i.clearColor(...this.background.computed_color),this.last_selection_render=this.frame),this.selection.read();}return !0}renderPass(t="program",{allow_blend:r}={}){r=null==r||r,this.clearFrame();let i,n=0;const s=this.style_manager.getActiveBlendOrders();for(const{blend_order:o,styles:a}of s)for(let s=0;s<a.length;s++){let l=this.styles[a[s]];if(null==l)continue;if(l.blend!==i){let t=Object.assign({},e.Style.render_states[l.blend],{blend:r&&l.blend});this.setRenderState(t);}const u=r&&l.blend;if("translucent"===u)this.gl.colorMask(!1,!1,!1,!1),this.renderStyle(l.name,t,o),this.gl.colorMask(!0,!0,!0,!0),this.gl.depthFunc(this.gl.EQUAL),this.gl.enable(this.gl.STENCIL_TEST),this.gl.clearStencil(0),this.gl.clear(this.gl.STENCIL_BUFFER_BIT),this.gl.stencilFunc(this.gl.EQUAL,this.gl.ZERO,255),this.gl.stencilOp(this.gl.KEEP,this.gl.KEEP,this.gl.INCR),n+=this.renderStyle(l.name,t,o),this.gl.disable(this.gl.STENCIL_TEST),this.gl.depthFunc(this.gl.LESS);else if("opaque"!==u&&!0===l.stencil_proxy_tiles){const e=this.tile_manager.getRenderableTiles().filter(e=>e.meshes[l.name]).map(e=>e.proxy_level).reduce((e,t)=>(e.indexOf(t)>-1||e.push(t),e),[]).sort();if(e.length>1){this.gl.enable(this.gl.STENCIL_TEST),this.gl.clearStencil(0),this.gl.clear(this.gl.STENCIL_BUFFER_BIT),this.gl.stencilOp(this.gl.KEEP,this.gl.KEEP,this.gl.REPLACE);for(let r=0;r<e.length;r++)this.gl.stencilFunc(this.gl.GEQUAL,e.length-r,255),n+=this.renderStyle(l.name,t,o,e[r]);this.gl.disable(this.gl.STENCIL_TEST);}else n+=this.renderStyle(l.name,t,o);}else n+=this.renderStyle(l.name,t,o);i=l.blend;}return n}renderStyle(e,t,r,i=null){let n,s=this.styles[e],o=!0,a=0,l=this.tile_manager.getRenderableTiles().filter(e=>"number"!=typeof i||e.proxy_level===i).map(t=>{if(t.meshes[e])return [t,t.meshes[e].filter(e=>e.variant.blend_order===r)]}).filter(e=>e),u=Math.max(...l.map(([,e])=>Math.max(...e.map(e=>e.variant.mesh_order))));for(let r=0;r<u+1;r++)for(let[i,u]of l){let l=!0;if(!i.shouldProxyForStyle(e))continue;const h=u.filter(e=>e.variant.mesh_order===r);if(0!==h.length){if(!0===o&&(o=!1,!(n=this.setupStyle(s,t))))return 0;h.forEach(e=>{!0===l&&(l=!1,this.view.setupTile(i,n)),s.render(e)&&this.requestRedraw(),a+=e.geometry_count;});}}return a}setupStyle(e,t){let r;try{if(!(r=e.getProgram(t)))return}catch(t){return void this.trigger("warning",{type:"styles",message:`Error compiling style ${e.name}`,style:e,shader_errors:e.program&&e.program.shader_errors})}r.use(),e.setup(),r.uniform("1f","u_time",this.animated?(+new Date-this.start_time)/1e3:0),this.view.setupProgram(r);for(let e in this.lights)this.lights[e].setupProgram(r);return r}clearFrame(){this.initialized&&(this.render_states.depth_write.set({depth_write:!0}),this.gl.clear(this.gl.COLOR_BUFFER_BIT|this.gl.DEPTH_BUFFER_BIT|this.gl.STENCIL_BUFFER_BIT));}setRenderState({depth_test:e,depth_write:t,cull_face:r,blend:i}={}){if(!this.initialized)return;let n=this.render_states;e=!1!==e&&n.defaults.depth_test,t=!1!==t&&n.defaults.depth_write,r=!1!==r&&n.defaults.culling,i=null!=i?i:n.defaults.blending;let s=this.gl;n.depth_test.set({depth_test:e}),n.depth_write.set({depth_write:t}),n.culling.set({cull:r,face:n.defaults.culling_face}),i?"opaque"===i?n.blending.set({blend:!1}):"overlay"===i||"inlay"===i||"translucent"===i?n.blending.set({blend:!0,src:s.SRC_ALPHA,dst:s.ONE_MINUS_SRC_ALPHA,src_alpha:s.ONE,dst_alpha:s.ONE_MINUS_SRC_ALPHA}):"add"===i?n.blending.set({blend:!0,src:s.ONE,dst:s.ONE}):"multiply"===i&&n.blending.set({blend:!0,src:s.ZERO,dst:s.SRC_COLOR}):n.blending.set({blend:!1});}getFeatureAt(t,{radius:r}={}){if(!this.initialized)return e.log("debug","Scene.getFeatureAt() called before scene was initialized"),Promise.resolve();if(0===this.selection_feature_count)return Promise.resolve();this.selection||this.resetFeatureSelection();let i={x:t.x/this.view.size.css.width,y:t.y/this.view.size.css.height};return r=r>0?{x:r/this.view.size.css.width,y:r/this.view.size.css.height}:null,this.selection.getFeatureAt(i,{radius:r}).then(e=>Object.assign(e,{pixel:t})).catch(e=>Promise.resolve({error:e}))}async queryFeatures({filter:t,unique:r=!0,group_by:i=null,visible:n=null,geometry:s=!1}={}){if(!this.initialized)return [];t=e.Utils.serializeWithFunctions(t);const o=!0===(r="string"==typeof r?[r]:r)||Array.isArray(r)&&r.indexOf("$id")>-1,a=r&&(t=>{const i=Array.isArray(r)?e.sliceObject(t.properties,r):t.properties,n=o?t.id:null;return s?JSON.stringify({geometry:t.geometry,properties:i,id:n}):JSON.stringify({properties:i,id:n})}),l=(i=("string"==typeof i||Array.isArray(i))&&i)&&(t=>Array.isArray(i)?JSON.stringify(e.sliceObject(t,i)):t[i]),u=this.tile_manager.getRenderableTiles().map(e=>e.key),h=await e.WorkerBroker.postMessage(this.workers,"self.queryFeatures",{filter:t,visible:n,geometry:s,tile_keys:u}),c=[],f={},d={};return h.forEach(e=>e.forEach(e=>{if(a){const t=a(e);if(f[t])return;f[t]=!0;}if(l){const t=l(e.properties);d[t]=d[t]||[],d[t].push(e);}else c.push(e);})),l?d:c}rebuild({initial:t=!1,new_generation:r=!0,sources:i=null,serialize_funcs:n,profile:s=!1,fade_in:o=!1}={}){return new Promise((a,l)=>{if(this.building){this.building.queued&&this.building.queued.reject&&(e.log("debug","Scene.rebuild: request superceded by a newer call"),this.building.queued.resolve(!1));let u={initial:t,new_generation:r,sources:i,serialize_funcs:n,profile:s,fade_in:o};return this.building.queued={resolve:a,reject:l,options:u},void e.log("trace","Scene.rebuild(): queuing request")}if(this.building={resolve:a,reject:l,initial:t},s&&this.debug.profile("Scene.rebuild"),r){this.generation=++lh.generation;for(let e in this.styles)this.styles[e].setGeneration(this.generation);}this.syncConfigToWorker({serialize_funcs:n}),this.resetWorkerFeatureSelection(i),this.resetTime(),this.tile_manager.pruneToVisibleTiles(),this.tile_manager.forEachTile(e=>{(!i||i.indexOf(e.source.name)>-1)&&this.tile_manager.buildTile(e,{fade_in:o});}),this.tile_manager.updateTilesForView(),this.tile_manager.checkBuildQueue();}).then(()=>{s&&this.debug.profileEnd("Scene.rebuild");})}tileManagerBuildDone(){if(e.TextCanvas.pruneTextCache(),this.building){e.log("info","Scene: build geometry finished"),this.building.resolve&&(this.logFirstBuild(),this.building.resolve(!0));var t=this.building.queued;this.building=null,t?(e.log("debug","Scene: starting queued rebuild() request"),this.rebuild(t.options).then(t.resolve,t.reject)):this.tile_manager.updateLabels();}}async loadScene(t=null,{base_path:r,file_type:i}={}){this.config_source=t||this.config_source,"string"==typeof this.config_source?this.base_path=e.pathForURL(r||this.config_source):this.base_path=e.pathForURL(r),this.config_path=this.base_path;const{config:n,bundle:s,texture_nodes:o}=await Ku.loadScene(this.config_source,{path:this.base_path,type:i});return this.config=n,this.config_bundle=s,{texture_nodes:o}}setDataSource(t,r){if(!t||!r||!r.type||!r.url&&!r.data)return void e.log("error","No name provided or not a valid config:",t,r);let i=null==this.config.sources[t],n=this.config.sources[t]=Object.assign({},r);return n.data&&"object"==typeof n.data&&(n.url=e.createObjectURL(new Blob([JSON.stringify(n.data)])),delete n.data),i?this.updateConfig({rebuild:{sources:[t]}}):this.rebuild({sources:[t]})}createDataSources(t=!1){const r=[],i=Object.keys(this.sources);let n=0;for(var s in this.config.sources){const i=this.config.sources[s],o=this.sources[s];try{const t=e._extends({},i,{name:s,id:n++});if(this.sources[s]=e.DataSource.create(t,this.sources),!this.sources[s])throw {}}catch(t){delete this.sources[s];const r=`Could not create data source: ${t.message}`;e.log("warn",`Scene: ${r}`,i),this.trigger("warning",{type:"sources",source:i,message:r});}(t||e.DataSource.tileLayoutChanged(this.sources[s],o))&&r.push(s);}i.forEach(e=>{this.config.sources[e]||(delete this.sources[e],r.push(e));}),r.length>0&&this.tile_manager.removeTiles(e=>r.indexOf(e.source.name)>-1);for(let e in this.config.layers){let t=this.config.layers[e];!1!==t.enabled&&t.data&&this.sources[t.data.source]&&(this.sources[t.data.source].builds_geometry_tiles=!0);}}loadTextures(){return e.Texture.createFromObject(this.gl,this.config.textures).then(()=>e.Texture.createDefault(this.gl))}freePreviousTextures(){this.prev_textures&&(this.prev_textures.forEach(t=>{!this.config.textures[t]&&e.Texture.textures[t]&&e.Texture.textures[t].destroy();}),this.prev_textures=null);}updateStyles(){if(!this.initialized&&!this.initializing)throw new Error("Scene.updateStyles() called before scene was initialized");this.styles=this.style_manager.build(this.config.styles),this.style_manager.initStyles(this);for(let e in this.styles)this.styles[e].setGL(this.gl);this.dirty=!0;}get animated(){return !1!==this.config.scene.animated&&this.style_manager.getActiveStyles().some(e=>this.styles[e].animated)}getActiveCamera(){return this.view.getActiveCamera()}setActiveCamera(e){return this.view.setActiveCamera(e)}createLights(){this.lights={},e.debugSettings.wireframe&&(e.Light.enabled=!1);for(let t in this.config.lights){if(!this.config.lights[t]||"object"!=typeof this.config.lights[t])continue;let r=this.config.lights[t];r.name=t.replace("-","_"),r.visible=!1!==r.visible,r.visible&&(this.lights[r.name]=e.Light.create(this.view,r));}e.Light.inject(this.lights);}setBackground(){const t=this.config.scene.background;this.background={},t&&t.color&&(this.background.color=e.StyleParser.createColorPropertyCache(t.color)),this.background.color||(this.background.color=e.StyleParser.createColorPropertyCache([0,0,0,0]));}updateBackground(){const t=this.background.computed_color,r=this.background.computed_color=e.StyleParser.evalCachedColorProperty(this.background.color,{zoom:this.view.tile_zoom});t&&!r.some((e,r)=>t[r]!==e)||(1===r[3]?this.canvas.style.backgroundColor=`rgba(${r.map(e=>Math.floor(255*e)).join(", ")})`:this.canvas.style.backgroundColor="transparent",this.gl.clearColor(...r));}setIntrospection(e){return e!==this.introspection?(this.introspection=null!=e&&e,this.updating++,this.updateConfig({normalize:!1}).then(()=>this.updating--)):Promise.resolve()}updateConfig({loading:t=!1,rebuild:r=!0,serialize_funcs:i,texture_nodes:n={},normalize:s=!0,fade_in:o=!1}={}){this.generation=++lh.generation,this.updating++,this.config=Ku.applyGlobalProperties(this.config),s&&Ku.normalize(this.config,this.config_bundle,n),Ku.hoistTextureNodes(this.config,this.config_bundle,n),this.trigger(t?"load":"update",{config:this.config}),this.style_manager.init(),this.view.reset(),this.createLights(),this.createDataSources(t),this.loadTextures(),this.setBackground(),e.FontManager.loadFonts(this.config.fonts),this.updateStyles();let a=r?this.rebuild(Object.assign({initial:t,new_generation:!1,serialize_funcs:i,fade_in:o},"object"==typeof r&&r)):this.syncConfigToWorker({serialize_funcs:i});return this.updating--,this.view.updateBounds(),this.requestRedraw(),a.then(()=>{this.last_render_count=0,this.requestRedraw();})}syncConfigToWorker({serialize_funcs:t=!0}={}){let r=t?e.Utils.serializeWithFunctions(this.config):JSON.stringify(this.config);return e.WorkerBroker.postMessage(this.workers,"self.updateConfig",{config:r,generation:this.generation,introspection:this.introspection},e.debugSettings)}createListeners(){this.listeners={},this.listeners.view={move:()=>this.trigger("move")},this.view.subscribe(this.listeners.view),this.listeners.texture={update:()=>this.dirty=!0,warning:e=>this.trigger("warning",Object.assign({type:"textures"},e))},e.Texture.subscribe(this.listeners.texture),this.listeners.scene_loader={error:e=>this.trigger("error",Object.assign({type:"scene"},e))},Ku.subscribe(this.listeners.scene_loader);}destroyListeners(){this.unsubscribeAll(),this.view.unsubscribe(this.listeners.view),e.Texture.unsubscribe(this.listeners.texture),Ku.unsubscribe(this.listeners.scene_loader),this.listeners=null;}destroyFeatureSelection(){this.selection&&(this.selection.destroy(),this.selection=null);}resetFeatureSelection(){this.selection=new e.FeatureSelection(this.gl,this.workers,()=>this.building),this.last_render_count=0;}resetWorkerFeatureSelection(t=null){this.workers&&e.WorkerBroker.postMessage(this.workers,"self.resetFeatureSelection",t);}getFeatureSelectionMapSize(){return null==this.fetching_selection_map&&(this.fetching_selection_map=e.WorkerBroker.postMessage(this.workers,"self.getFeatureSelectionMapSize").then(e=>(this.fetching_selection_map=null,e.reduce((e,t)=>e+t)))),this.fetching_selection_map}resetTime(){this.start_time=+new Date;}updateViewComplete(){!this.render_count_changed&&this.generation===this.last_complete_generation||this.building||this.tile_manager.isLoadingVisibleTiles()||!this.tile_manager.allVisibleTilesLabeled()||(this.tile_manager.updateLabels(),this.last_complete_generation=this.generation,this.trigger("view_complete",{first:!0!==this.view_complete}),this.view_complete=!0);}resetViewComplete(){this.last_complete_generation=null;}screenshot({background:e="white"}={}){return this.requestRedraw(),this.media_capture.screenshot({background:e})}startVideoCapture(){return this.requestRedraw(),this.media_capture.startVideoCapture()}stopVideoCapture(){return this.media_capture.stopVideoCapture()}logFirstFrame(){0!==this.last_render_count||this.times.first_frame||(this.times.first_frame=+new Date-this.start_time,e.log("debug",`Scene: initial frame time: ${this.times.first_frame}`));}logFirstBuild(){null==this.times.first_build&&(this.times.first_build=+new Date-this.start_time,e.log("debug",`Scene: initial build time: ${this.times.first_build}`));}}var uh;lh.id=0,lh.generation=0;const hh={map:{},scrollWheelZoom:{},doubleClickZoom:{}};return {leafletLayer:function(t){return function(t){if(void 0!==uh)return new uh(t);if(e.Thread.is_main){let r,i=t.leaflet||window.L,n=i.GridLayer?i.GridLayer:i.TileLayer,s=n===i.GridLayer?"1.x":"0.7.x",o={};return n===i.TileLayer&&(o._addTile=function(){},o._removeTile=function(){},o._reset=function(){n.prototype._reset.apply(this,arguments),this.scene&&this.scene.container&&this.scene.canvas&&this.scene.container.appendChild(this.scene.canvas);}),Object.assign(o,{initialize(e){e.showDebug=!!e.showDebug,i.setOptions(this,e),this.updateTangramDebugSettings(),this.createScene(),this.hooks={},this._updating_tangram=!1;},createScene(){this.scene=lh.create(this.options.scene,{numWorkers:this.options.numWorkers,preUpdate:this.options.preUpdate,postUpdate:this.options.postUpdate,continuousZoom:"1.x"===uh.leafletVersion,wrapView:!0!==this.options.noWrap,highDensityDisplay:this.options.highDensityDisplay,logLevel:this.options.logLevel,introspection:this.options.introspection,webGLContextOptions:this.options.webGLContextOptions,disableRenderLoop:this.options.disableRenderLoop});},onAdd(t){this.scene||this.createScene(),n.prototype.onAdd.apply(this,arguments),this.hooks.resize=(()=>{this._updating_tangram=!0,this.updateSize(),this._updating_tangram=!1;}),t.on("resize",this.hooks.resize),this.hooks.move=(()=>{if(!this._updating_tangram){this._updating_tangram=!0,this.scene.view.setPanning(!0);var r=t.getCenter();r.zoom=Math.max(Math.min(t.getZoom(),t.getMaxZoom()||e.Geo.default_view_max_zoom),t.getMinZoom()),this.scene.view.setView(r),this._mapLayerCount>1&&this.scene.immediateRedraw(),this._updating_tangram=!1;}}),t.on("move",this.hooks.move),this.hooks.moveend=(()=>{this.scene.view.setPanning(!1),this.scene.requestRedraw();}),t.on("moveend",this.hooks.moveend),this.hooks.drag=(()=>{this.scene.view.markUserInput();}),t.on("drag",this.hooks.drag),this._map_pane_observer=new MutationObserver(e=>{e.forEach(()=>this.reverseTransform());}),this._map_pane_observer.observe(t.getPanes().mapPane,{attributes:!0}),this.modifyScrollWheelBehavior(t),this.modifyZoomBehavior(t),this.trackMapLayerCounts(t),this.setupSelectionEventHandlers(t),this.setSelectionEvents(this.options.events,{radius:this.options.selectionRadius}),this.scene.container=this.getContainer(),this.updateSize(),this.updateView(),this.resizeOnFirstVisible(),this.scene.subscribe({move:this.onTangramViewUpdate.bind(this)}),this.scene.load(this.options.scene,{base_path:this.options.sceneBasePath,file_type:this.options.sceneFileType,blocking:!1}).then(()=>{if(!this.options.attribution)for(const[,e]of Object.entries(this.scene.config.sources))e.attribution&&t.attributionControl.addAttribution(e.attribution);this._updating_tangram=!0,this.updateSize(),this.updateView(),this.reverseTransform(),this._updating_tangram=!1,this.fire("init");}).catch(e=>{this.fire("error",e);});},onRemove(e){n.prototype.onRemove.apply(this,arguments),e.off("layeradd layerremove overlayadd overlayremove",this._updateMapLayerCount),e.off("resize",this.hooks.resize),e.off("move",this.hooks.move),e.off("moveend",this.hooks.moveend),e.off("drag",this.hooks.drag),e.off("click",this.hooks.click),e.off("mousemove",this.hooks.mousemove),e.off("mouseout",this.hooks.mouseout),document.removeEventListener("visibilitychange",this.hooks.visibilitychange),this.hooks={},this._map_pane_observer.disconnect(),this.scene&&(this.scene.destroy(),this.scene=null);},createTile(e){var t=e.x+"/"+e.y+"/"+e.z,r=document.createElement("div");if(r.setAttribute("data-tile-key",t),r.style.width="256px",r.style.height="256px",this.options.showDebug){var i=document.createElement("div");i.textContent=t,i.style.position="absolute",i.style.left=0,i.style.top=0,i.style.color="white",i.style.fontSize="16px",i.style.textOutline="1px #000000",i.style.padding="8px",r.appendChild(i),r.style.borderStyle="solid",r.style.borderColor="white",r.style.borderWidth="1px";}return r},modifyScrollWheelBehavior(e){if(this.scene.view.continuous_zoom&&e.scrollWheelZoom&&!1!==this.options.modifyScrollWheel){e.options.zoomSnap=0;const a=e.scrollWheelZoom.enabled();e.scrollWheelZoom.disable(),i.Browser.chrome||i.Browser.safari?e.scrollWheelZoom._onWheelScroll=function(e){var t=i.DomEvent.getWheelDelta(e);this._delta+=t,this._lastMousePos=this._map.mouseEventToContainerPoint(e),this._performZoom(),i.DomEvent.stop(e);}:e.options.wheelDebounceTime=20;const l=(n=function(e){e._moveEnd(!0),e.fire("viewreset");},s=2*e.options.wheelDebounceTime,function(){var e=this,t=arguments;clearTimeout(o),o=setTimeout(function(){o=null,n.apply(e,t);},s);});hh.scrollWheelZoom._performZoom||(hh.scrollWheelZoom._performZoom=e.scrollWheelZoom._performZoom);var t=this;e.scrollWheelZoom._performZoom=function(){if(this._map===t._map){var e=this._map,i=e.getZoom();e._stop();var n=this._delta/(4*this._map.options.wheelPxPerZoomLevel);this._delta=0,i+n>=this._map.getMaxZoom()?n=this._map.getMaxZoom()-i:i+n<=this._map.getMinZoom()&&(n=this._map.getMinZoom()-i),n&&("center"===e.options.scrollWheelZoom?r(t,e.getCenter(),i+n):r(t,this._lastMousePos,i+n),l(e));}else hh.scrollWheelZoom._performZoom.call(this);},a&&e.scrollWheelZoom.enable();}var n,s,o;},modifyZoomBehavior(e){if(this.scene.view.continuous_zoom&&!1!==this.options.modifyZoomBehavior){var t=this;const n=function(t,n,s){e._stop();var o=e._zoom;n=i.latLng(n),s=void 0===s?o:s,s=Math.min(s,e.getMaxZoom());var a=Date.now(),l=75;return e._moveStart(!0),function u(){var h=(Date.now()-a)/l;h<=1?(e._flyToFrame=i.Util.requestAnimFrame(u,e),r(t,n,o+(s-o)*h)):r(t,n,s)._moveEnd(!0);}.call(e),e};if(e.doubleClickZoom){const r=e.doubleClickZoom.enabled();e.doubleClickZoom.disable(),hh.doubleClickZoom._onDoubleClick||(hh.doubleClickZoom._onDoubleClick=e.doubleClickZoom._onDoubleClick),e.doubleClickZoom._onDoubleClick=function(e){if(this._map===t._map){var r=this._map,i=r.getZoom(),s=r.options.zoomDelta,o=e.originalEvent.shiftKey?i-s:i+s;"center"===r.options.doubleClickZoom?n(t,r.getCenter(),o):n(t,r.containerPointToLatLng(e.containerPoint),o);}else hh.doubleClickZoom._onDoubleClick.call(this,e);},r&&e.doubleClickZoom.enable();}e._zoomAnimated&&(hh.map._animateZoom||(hh.map._animateZoom=e._animateZoom),e._animateZoom=function(e,r,s,o){this===t._map?(s&&(this._animatingZoom=!0,this._animateToCenter=e,this._animateToZoom=r,n(t,e,r)),setTimeout(i.Util.bind(this._onZoomTransitionEnd,this),250)):hh.map._animateZoom.call(this,e,r,s,o);});}},updateView(){var t=this._map.getCenter();t.zoom=Math.max(Math.min(this._map.getZoom(),this._map.getMaxZoom()||e.Geo.default_view_max_zoom),this._map.getMinZoom()),this.scene.view.setView(t);},updateSize(){var e=this._map.getSize();this.scene.resizeMap(e.x,e.y);},resizeOnFirstVisible(){let e=!0;this.hooks.visibilitychange=(()=>{e&&(e=!1,this.updateSize());}),document.addEventListener("visibilitychange",this.hooks.visibilitychange);},onTangramViewUpdate(){if(!this._map||this._updating_tangram)return;let e=this._map.getCenter(),t=this.scene.view.center;e.lng===t.lng&&e.lat===t.lat&&this._map.getZoom()===this.scene.view.zoom||(this._updating_tangram=!0,this._map.setView([this.scene.view.center.lat,this.scene.view.center.lng],this.scene.view.zoom,{animate:!1}),this._updating_tangram=!1);},render(){this.scene&&this.scene.update();},reverseTransform(){if(this._map&&this.scene&&this.scene.container){var e=this._map.containerPointToLayerPoint([0,0]);i.DomUtil.setPosition(this.scene.container,e);}},setupSelectionEventHandlers(e){this._selection_events={},this._selection_radius=null,this.hooks.click=(e=>{"function"==typeof this._selection_events.click&&this.scene.getFeatureAt(e.containerPoint,{radius:this._selection_radius}).then(t=>{let r=Object.assign({},t,{leaflet_event:e});this._selection_events.click(r);});}),e.on("click",this.hooks.click),this.hooks.mousemove=(e=>{"function"==typeof this._selection_events.hover&&this.scene.getFeatureAt(e.containerPoint,{radius:this._selection_radius}).then(t=>{let r=Object.assign({},t,{leaflet_event:e});this._selection_events.hover(r);});}),e.on("mousemove",this.hooks.mousemove),this.hooks.mouseout=(e=>{"function"==typeof this._selection_events.hover&&this._selection_events.hover({changed:!0,leaflet_event:e});}),e.on("mouseout",this.hooks.mouseout);},setSelectionEvents(e,{radius:t}={}){this._selection_events=Object.assign(this._selection_events,e),this._selection_radius=void 0!==t?t:this._selection_radius;},trackMapLayerCounts(e){this._updateMapLayerCount=(()=>{let t=e.getPanes().mapPane.childNodes;this._mapLayerCount=0;for(let e=0;e<t.length;e++)this._mapLayerCount+=t[e].childNodes.length;}),e.on("layeradd layerremove overlayadd overlayremove",this._updateMapLayerCount),this._updateMapLayerCount();},updateTangramDebugSettings(){e.mergeDebugSettings(this.options.debug||{});}}),r=function(e,t,r){var n=e._map,s=e.scene,o=n.getZoomScale(r),a=n.getSize().divideBy(2),l=t instanceof i.Point?t:n.latLngToContainerPoint(t),u=l.subtract(a).multiplyBy(1-1/o),h=n.containerPointToLatLng(a.add(u));return s&&s.view.markUserInput(),n._move(h,r,{flyTo:!0})},"function"!=typeof(uh=n.extend(o)).remove&&(uh.prototype.remove=function(){this._map&&this._map.removeLayer(this),this.fire("remove");}),uh.layerBaseClass=n,uh.leafletVersion=s,new uh(t)}}(t)},debug:{log:e.log,yaml:Vu,Utils:e.Utils,Geo:e.Geo,Vector:e.Vector,DataSource:e.DataSource,GLSL:e.GLSL,ShaderProgram:e.ShaderProgram,VertexData:e.VertexData,Texture:e.Texture,Material:e.Material,Light:e.Light,Scene:lh,WorkerBroker:e.WorkerBroker,Task:e.Task,StyleManager:e.StyleManager,StyleParser:e.StyleParser,TileID:e.TileID,Collision:e.Collision,FeatureSelection:e.FeatureSelection,TextCanvas:e.TextCanvas,debugSettings:e.debugSettings},version:e.version}});

// Loads each of the chunks produced by the first Rollup pass.

// This allows the rollup ESM build to work within a <script type="module"> tag
// Script modules can't expose exports
try {
	Tangram.debug.ESM = true; // mark build as ES module
	Tangram.debug.SHA = '81ee5a1ddf14547d5653c42972e0a66fa999d545';
	if (true === true && typeof window === 'object') {
	    window.Tangram = Tangram;
	}
} catch(e) {}

export default Tangram;
